(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    483427,      10639]
NotebookOptionsPosition[    475103,      10377]
NotebookOutlinePosition[    475556,      10395]
CellTagsIndexPosition[    475513,      10392]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Estimation of gBGC and SCU", "Title",
 CellChangeTimes->{{3.48255112685575*^9, 3.482551135465125*^9}, {
  3.4825514754495*^9, 3.482551496308875*^9}, {3.5613134824825583`*^9, 
  3.5613134945188*^9}, {3.7032209282215633`*^9, 3.703220933724842*^9}, {
  3.703220990201207*^9, 3.703220991786296*^9}, {3.703221092418655*^9, 
  3.703221093328718*^9}},
 FontWeight->"Plain"],

Cell["Sylvain Gl\[EAcute]min - sylvain.glemin@univ-montp2.fr", "Subtitle",
 CellChangeTimes->{{3.703221122140295*^9, 3.703221125436387*^9}, {
  3.7032356334917717`*^9, 3.703235641071836*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "\"\<`*\>\"", "]"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell["Likelihoods", "Chapter",
 CellChangeTimes->{{3.4955360340102997`*^9, 3.4955360370102997`*^9}, {
  3.564231080969344*^9, 3.564231084557279*^9}}],

Cell["\<\
Series of functions to compute likelihoods. To be evaluated initially.\
\>", "Text",
 CellChangeTimes->{{3.703221234900152*^9, 3.703221252561648*^9}, {
  3.703221349391302*^9, 3.703221355105317*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Expected values for the different count",
 FontWeight->"Plain"]], "Subsection",
 CellChangeTimes->{{3.564237392690611*^9, 3.5642374058879642`*^9}, {
  3.703221359976666*^9, 3.7032213643866997`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Expectations", " ", "without", " ", "polarization", " ", "error"}], 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Polymorphic", " ", "sites"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Approximate", " ", 
     RowBox[{"expression", ":", " ", 
      RowBox[{"very", " ", "accurate"}]}]}], ",", " ", 
    RowBox[{"especially", " ", "when", " ", "n", " ", "is", " ", "large"}]}], 
   "*)"}], " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Mu]B", "[", 
      RowBox[{"\[Theta]_", ",", "B_", ",", "n_", ",", "j_"}], "]"}], "=", 
     RowBox[{
      FractionBox[
       RowBox[{"n", " ", "\[Theta]"}], 
       RowBox[{"j", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "j"}], "+", "n"}], ")"}]}]], 
      FractionBox[
       RowBox[{"1", "-", 
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", "B"}], 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"j", "/", "n"}]}], ")"}]}], "]"}]}], 
       RowBox[{"1", "-", 
        RowBox[{"Exp", "[", 
         RowBox[{"-", "B"}], "]"}]}]]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"Exact", " ", 
      RowBox[{"expression", ":", " ", "sometime"}]}], ",", " ", 
     RowBox[{"possible", " ", "numerical", " ", "problems"}]}], "*)"}], " ", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Mu]B", "[", 
       RowBox[{"\[Theta]_", ",", "B_", ",", "n_", ",", "j_"}], "]"}], "=", 
      FractionBox[
       RowBox[{"n", " ", "\[Theta]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", "B"], "-", 
          RowBox[{"Hypergeometric1F1", "[", 
           RowBox[{"j", ",", "n", ",", 
            RowBox[{"B", "+", "0.0"}]}], "]"}]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["\[ExponentialE]", "B"]}], ")"}], " ", "j", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "j"}], "+", "n"}], ")"}]}]]}], ";"}], " ", "*)"}], 
   RowBox[{"(*", 
    RowBox[{
    "\"\<+0.0\>\"", " ", "is", " ", "used", " ", "to", " ", "avoid", " ", 
     "some", " ", "strange", " ", "behaviours", " ", "with", " ", "the", " ", 
     "Hypergeometric1F1", " ", "function"}], "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", "Divergence", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Mu]DB", "[", 
      RowBox[{
      "\[Tau]_", ",", "\[Theta]_", ",", "B0_", ",", "B1_", ",", "n_"}], "]"}],
      "=", 
     RowBox[{
      RowBox[{"\[Tau]", " ", 
       FractionBox["B0", 
        RowBox[{"1", "-", 
         RowBox[{"Exp", "[", 
          RowBox[{"-", "B0"}], "]"}]}]]}], "+", 
      FractionBox[
       RowBox[{"B1", " ", 
        SuperscriptBox["\[ExponentialE]", "B1"], " ", "\[Theta]"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["\[ExponentialE]", "B1"]}], ")"}], " ", "n"}]]}]}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Mu]DB", "[", 
      RowBox[{"\[Tau]_", ",", "B0_", ",", "n_"}], "]"}], "=", 
     RowBox[{"\[Tau]", " ", 
      FractionBox["B0", 
       RowBox[{"1", "-", 
        RowBox[{"Exp", "[", 
         RowBox[{"-", "B0"}], "]"}]}]]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Expectations", " ", "with", " ", "polarization", " ", "errors"}],
     "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Mu]e", "[", 
      RowBox[{
      "\[Theta]1_", ",", "\[Theta]2_", ",", "\[Epsilon]1_", ",", 
       "\[Epsilon]2_", ",", "n_", ",", "i_"}], "]"}], "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Epsilon]1"}], ")"}], 
        RowBox[{"\[Theta]1", "/", "i"}]}], "+", 
       RowBox[{"\[Epsilon]2", " ", 
        RowBox[{"\[Theta]2", "/", 
         RowBox[{"(", 
          RowBox[{"n", "-", "i"}], ")"}]}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Mu]Be", "[", 
      RowBox[{
      "\[Theta]1_", ",", "\[Theta]2_", ",", "B_", ",", "\[Epsilon]1_", ",", 
       "\[Epsilon]2_", ",", "n_", ",", "i_"}], "]"}], "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Epsilon]1"}], ")"}], 
        RowBox[{"\[Mu]B", "[", 
         RowBox[{"\[Theta]1", ",", "B", ",", "n", ",", "i"}], "]"}]}], "+", 
       RowBox[{"\[Epsilon]2", " ", 
        RowBox[{"\[Mu]B", "[", 
         RowBox[{"\[Theta]2", ",", 
          RowBox[{"-", "B"}], ",", "n", ",", 
          RowBox[{"n", "-", "i"}]}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Mu]fe", "[", 
      RowBox[{
      "\[Theta]1_", ",", "\[Theta]2_", ",", "B_", ",", "f_", ",", 
       "\[Epsilon]1_", ",", "\[Epsilon]2_", ",", "n_", ",", "i_"}], "]"}], 
     "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Epsilon]1"}], ")"}], 
        RowBox[{"\[Mu]fa", "[", 
         RowBox[{"\[Theta]1", ",", "B", ",", "f", ",", "n", ",", "i"}], 
         "]"}]}], "+", 
       RowBox[{"\[Epsilon]2", " ", 
        RowBox[{"\[Mu]fa", "[", 
         RowBox[{"\[Theta]2", ",", 
          RowBox[{"-", "B"}], ",", "f", ",", "n", ",", 
          RowBox[{"n", "-", "i"}]}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Mu]\[CapitalGamma]pluse", "[", 
      RowBox[{
      "\[Theta]1_", ",", "\[Theta]2_", ",", "Bmoy_", ",", "\[Beta]_", ",", 
       "\[Epsilon]1_", ",", "\[Epsilon]2_", ",", "n_", ",", "i_"}], "]"}], 
     "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Epsilon]1"}], ")"}], 
        RowBox[{"\[Mu]\[CapitalGamma]plus", "[", 
         RowBox[{
         "\[Theta]1", ",", "Bmoy", ",", "\[Beta]", ",", "n", ",", "i"}], 
         "]"}]}], "+", 
       RowBox[{"\[Epsilon]2", " ", 
        RowBox[{"\[Mu]\[CapitalGamma]moins", "[", 
         RowBox[{"\[Theta]2", ",", "Bmoy", ",", "\[Beta]", ",", "n", ",", 
          RowBox[{"n", "-", "i"}]}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Mu]\[CapitalGamma]moinse", "[", 
      RowBox[{
      "\[Theta]1_", ",", "\[Theta]2_", ",", "Bmoy_", ",", "\[Beta]_", ",", 
       "\[Epsilon]1_", ",", "\[Epsilon]2_", ",", "n_", ",", "i_"}], "]"}], 
     "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Epsilon]1"}], ")"}], 
        RowBox[{"\[Mu]\[CapitalGamma]moins", "[", 
         RowBox[{
         "\[Theta]1", ",", "Bmoy", ",", "\[Beta]", ",", "n", ",", "i"}], 
         "]"}]}], "+", 
       RowBox[{"\[Epsilon]2", " ", 
        RowBox[{"\[Mu]\[CapitalGamma]plus", "[", 
         RowBox[{"\[Theta]2", ",", "Bmoy", ",", "\[Beta]", ",", "n", ",", 
          RowBox[{"n", "-", "i"}]}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "If", " ", "the", " ", "orientation", " ", "is", " ", "wrong", " ", "we",
       " ", "observed", " ", "no", " ", "divergence"}], ",", " ", 
     RowBox[{
     "we", " ", "neglect", " ", "two", " ", "consecutive", " ", 
      "subsitutions"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Mu]De", "[", 
      RowBox[{"\[Tau]_", ",", "\[Theta]_", ",", "n_", ",", "\[Epsilon]_"}], 
      "]"}], "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "\[Epsilon]"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"\[Tau]", "+", 
         RowBox[{"\[Theta]", "/", "n"}]}], ")"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Mu]DBe", "[", 
      RowBox[{
      "\[Tau]_", ",", "\[Theta]_", ",", "B0_", ",", "B1_", ",", "n_", ",", 
       "\[Epsilon]_"}], "]"}], "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "\[Epsilon]"}], ")"}], 
       RowBox[{"\[Mu]DB", "[", 
        RowBox[{"\[Tau]", ",", "\[Theta]", ",", "B0", ",", "B1", ",", "n"}], 
        "]"}]}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.4940056658642187`*^9, 3.494005667105538*^9}, {
   3.494005987221553*^9, 3.494005989143428*^9}, {3.494006188721553*^9, 
   3.494006196346553*^9}, {3.561179779508519*^9, 3.561179795143834*^9}, {
   3.561179831034103*^9, 3.5611798678847857`*^9}, {3.564228969839754*^9, 
   3.5642289731461897`*^9}, {3.564232048673462*^9, 3.564232083574778*^9}, {
   3.5642376995569077`*^9, 3.564237745299337*^9}, {3.5642527128164663`*^9, 
   3.5642527483522367`*^9}, {3.564252868366748*^9, 3.564252918020035*^9}, {
   3.564253343221607*^9, 3.564253435142303*^9}, {3.564253591646447*^9, 
   3.564253714143167*^9}, {3.564255563836926*^9, 3.56425556645154*^9}, {
   3.564465024740593*^9, 3.564465037837082*^9}, {3.5644678123008537`*^9, 
   3.564467812953165*^9}, {3.564939305739423*^9, 3.5649393513473787`*^9}, {
   3.5650358498475103`*^9, 3.565035926672106*^9}, {3.565036029730361*^9, 
   3.565036247143754*^9}, {3.5650378462709627`*^9, 3.565037912733377*^9}, 
   3.565037967526767*^9, {3.5671640570585546`*^9, 3.5671640577462*^9}, {
   3.567164092899674*^9, 3.567164154600419*^9}, {3.5671857028773317`*^9, 
   3.567185756719508*^9}, {3.567186268570753*^9, 3.567186351487999*^9}, {
   3.5674041262860117`*^9, 3.567404316315624*^9}, {3.5674055421366777`*^9, 
   3.5674056230102882`*^9}, {3.567406224586637*^9, 3.567406233475617*^9}, {
   3.567407581569457*^9, 3.567407674613771*^9}, {3.567413065228266*^9, 
   3.567413075857526*^9}, 3.567413196592614*^9, {3.567417849809593*^9, 
   3.5674178573254538`*^9}, {3.56783275483885*^9, 3.5678328549940233`*^9}, {
   3.567832970231847*^9, 3.567833018982087*^9}, {3.567833286827713*^9, 
   3.567833420896872*^9}, {3.567834107471382*^9, 3.567834108404274*^9}, {
   3.56871914505504*^9, 3.568719158635133*^9}, {3.5687192487108927`*^9, 
   3.568719284683043*^9}, {3.568956754467782*^9, 3.568956758747321*^9}, {
   3.568957439396158*^9, 3.568957442186912*^9}, {3.593455188126164*^9, 
   3.5934552229128723`*^9}, {3.593456236872415*^9, 3.5934562542756844`*^9}, {
   3.5934565061108627`*^9, 3.593456517049469*^9}, {3.593456594457025*^9, 
   3.593456632793089*^9}, {3.593456698343396*^9, 3.593456722748036*^9}, {
   3.593456934917753*^9, 3.593456990983116*^9}, 3.5934571100162086`*^9, {
   3.593457160744796*^9, 3.5934571841430483`*^9}, {3.593457222946492*^9, 
   3.5934572559791393`*^9}, {3.593505771249268*^9, 3.5935057717108517`*^9}, {
   3.6485766897256107`*^9, 3.648576858147807*^9}, {3.64865939532264*^9, 
   3.648659416031402*^9}, {3.648659834512115*^9, 3.648659835195369*^9}, 
   3.6486599968283577`*^9, {3.6533768764457684`*^9, 3.653376917260068*^9}, {
   3.65337695428575*^9, 3.653376955728704*^9}, {3.653377276740389*^9, 
   3.6533772800122633`*^9}, {3.653377445088914*^9, 3.653377485761335*^9}, 
   3.653377912563716*^9, {3.653378906819571*^9, 3.653378955136805*^9}, {
   3.653378990067355*^9, 3.6533790108735*^9}, {3.6533790455868397`*^9, 
   3.6533790587343063`*^9}, {3.6533791781463137`*^9, 3.653379191517396*^9}, {
   3.653380411964177*^9, 3.653380439636907*^9}, 3.653380483694964*^9, 
   3.6557234456547318`*^9, 3.655723594264739*^9, 3.6557237090821943`*^9, 
   3.6557239833911448`*^9, {3.6557241192369537`*^9, 3.655724125315629*^9}, {
   3.673166638951404*^9, 3.673166648570634*^9}, {3.703221380633149*^9, 
   3.70322142024583*^9}, {3.703221457155507*^9, 3.703221459461581*^9}, {
   3.703221707912228*^9, 3.703221717548645*^9}, {3.703221759533758*^9, 
   3.703221795240889*^9}, {3.7032218611108313`*^9, 3.7032219870086308`*^9}, {
   3.703223398617702*^9, 3.703223425662375*^9}, {3.703223460188901*^9, 
   3.703223463248847*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Likelihood of the saturated model",
 FontWeight->"Plain"]], "Subsection",
 CellChangeTimes->{{3.564237302072982*^9, 3.56423730475856*^9}, {
  3.703221996390232*^9, 3.7032220032637777`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"lnLmax", "[", "k_", "]"}], "=", 
   RowBox[{
    RowBox[{"-", "k"}], "+", 
    RowBox[{"k", " ", 
     RowBox[{"Log", "[", 
      RowBox[{"k", "+", 
       SuperscriptBox["10", 
        RowBox[{"-", "100"}]]}], "]"}]}], "-", 
    RowBox[{"Log", "[", 
     RowBox[{"k", "!"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"logLikMax", "[", 
   RowBox[{"kn__", ",", "kWS__", ",", "kSW__"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLmax", "[", "kn", "]"}], "]"}]}], "]"}], "+", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLmax", "[", "kWS", "]"}], "]"}]}], "]"}], "+", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLmax", "[", "kSW", "]"}], "]"}]}], "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.564233524524336*^9, 3.564233543056694*^9}, {
   3.564233609983819*^9, 3.564233647176907*^9}, {3.564233716737445*^9, 
   3.5642337188516073`*^9}, 3.564233887736946*^9, {3.564238199777665*^9, 
   3.564238217907858*^9}, {3.5642382522012167`*^9, 3.5642382537128553`*^9}, {
   3.56447753557412*^9, 3.564477569569031*^9}, 3.5644776283164997`*^9, {
   3.56447770756248*^9, 3.5644777104187202`*^9}, {3.5644777703272333`*^9, 
   3.56447779560394*^9}, {3.57211327032513*^9, 3.572113300959813*^9}, {
   3.572113388015717*^9, 3.572113392003645*^9}, {3.6016579805890427`*^9, 
   3.601657991151349*^9}, {3.601658024499192*^9, 3.601658025026436*^9}, {
   3.601658110534783*^9, 3.6016581284282312`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Likelihoods for models without polarization errors", "Subsection",
 CellChangeTimes->{{3.482126208668176*^9, 3.482126209918176*^9}, {
  3.484974887227271*^9, 3.484974889805396*^9}, {3.484991746711978*^9, 
  3.4849917493589497`*^9}, {3.495471792211625*^9, 3.495471792742875*^9}, {
  3.49547188878975*^9, 3.495471898946*^9}, {3.56423327247073*^9, 
  3.564233291197975*^9}, {3.703222025257493*^9, 3.703222040152626*^9}},
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["gBGC or SCU", "Subsubsection",
 CellChangeTimes->{{3.703222088224196*^9, 3.703222090001573*^9}, {
  3.7032221737017527`*^9, 3.703222175647943*^9}}],

Cell["Likelihoods per categories", "Text",
 CellChangeTimes->{{3.703222124089013*^9, 3.7032221527202044`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"lnLnull", "[", 
    RowBox[{"\[Theta]_", ",", "n_", ",", "i_", ",", "k_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "\[Theta]"}], "/", "i"}], "+", 
    RowBox[{"k", " ", 
     RowBox[{"Log", "[", 
      RowBox[{"\[Theta]", "/", "i"}], "]"}]}], "-", 
    RowBox[{"Log", "[", 
     RowBox[{"k", "!"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"lnLB", "[", 
    RowBox[{"\[Theta]_", ",", "B_", ",", "n_", ",", "i_", ",", "k_"}], "]"}], 
   "=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"\[Mu]B", "[", 
      RowBox[{"\[Theta]", ",", "B", ",", "n", ",", "i"}], "]"}]}], "+", 
    RowBox[{"k", " ", 
     RowBox[{"Log", "[", 
      RowBox[{"\[Mu]B", "[", 
       RowBox[{"\[Theta]", ",", "B", ",", "n", ",", "i"}], "]"}], "]"}]}], 
    "-", 
    RowBox[{"Log", "[", 
     RowBox[{"k", "!"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"lnLDnull", "[", 
    RowBox[{"\[Tau]_", ",", "\[Theta]_", ",", "n_", ",", "k_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"-", "\[Tau]"}], "-", 
    RowBox[{"\[Theta]", "/", "n"}], "+", 
    RowBox[{"k", " ", 
     RowBox[{"Log", "[", 
      RowBox[{"\[Tau]", "+", 
       RowBox[{"\[Theta]", "/", "n"}]}], "]"}]}], "-", 
    RowBox[{"Log", "[", 
     RowBox[{"k", "!"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"lnLDB", "[", 
    RowBox[{
    "\[Tau]_", ",", "\[Theta]_", ",", "B0_", ",", "B1_", ",", "n_", ",", 
     "k_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"\[Mu]DB", "[", 
      RowBox[{"\[Tau]", ",", "\[Theta]", ",", "B0", ",", "B1", ",", "n"}], 
      "]"}]}], "+", 
    RowBox[{"k", " ", 
     RowBox[{"Log", "[", 
      RowBox[{"\[Mu]DB", "[", 
       RowBox[{"\[Tau]", ",", "\[Theta]", ",", "B0", ",", "B1", ",", "n"}], 
       "]"}], "]"}]}], "-", 
    RowBox[{"Log", "[", 
     RowBox[{"k", "!"}], "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5642380034577637`*^9, 3.5642380894493847`*^9}, {
  3.564253721353964*^9, 3.564253726200589*^9}, {3.567833464178841*^9, 
  3.567833549935272*^9}, {3.5678335814244423`*^9, 3.567833598853085*^9}, {
  3.567834948821879*^9, 3.5678349600146313`*^9}, {3.6485777650569153`*^9, 
  3.648577806587674*^9}, {3.648578182149837*^9, 3.6485782002570047`*^9}, {
  3.65337698709466*^9, 3.6533770599026613`*^9}, {3.653377248929275*^9, 
  3.653377273281416*^9}, {3.653380594167199*^9, 3.6533806075738907`*^9}, {
  3.6731666042220716`*^9, 3.673166630535969*^9}, {3.6731666672011623`*^9, 
  3.6731666780240917`*^9}, {3.67316704232139*^9, 3.673167044153282*^9}, {
  3.703222046657151*^9, 3.703222059492195*^9}}],

Cell["Sume over categories", "Text",
 CellChangeTimes->{{3.7032221547791977`*^9, 3.7032221585590553`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"logLik0", "[", 
   RowBox[{
   "n_", ",", "gc_", ",", "\[Theta]_", ",", "\[Theta]WS_", ",", "\[Lambda]_", 
    ",", "r__", ",", "kn__", ",", "kWS__", ",", "kSW__"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnull", "[", 
       RowBox[{
        RowBox[{"\[Theta]", " ", "r"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kn"}], "]"}], "]"}]}], "]"}], 
   "+", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnull", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "gc"}], ")"}], "\[Theta]WS", " ", "r"}], ",", "n",
         ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWS"}], "]"}], "]"}]}], "]"}], 
   "+", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnull", "[", 
       RowBox[{
        RowBox[{"\[Lambda]", " ", "gc", " ", "\[Theta]WS", " ", "r"}], ",", 
        "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSW"}], "]"}], "]"}]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"logLik1", "[", 
   RowBox[{
   "n_", ",", "gc_", ",", "\[Theta]_", ",", "\[Theta]WS_", ",", "\[Lambda]_", 
    ",", "B_", ",", "r__", ",", "kn__", ",", "kWS__", ",", "kSW__"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnull", "[", 
       RowBox[{
        RowBox[{"\[Theta]", " ", "r"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kn"}], "]"}], "]"}]}], "]"}], 
   "+", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLB", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "gc"}], ")"}], "\[Theta]WS", " ", "r"}], ",", "B",
         ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWS"}], "]"}], "]"}]}], "]"}], 
   "+", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLB", "[", 
       RowBox[{
        RowBox[{"\[Lambda]", " ", "gc", " ", "\[Theta]WS", " ", "r"}], ",", 
        RowBox[{"-", "B"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSW"}], "]"}], "]"}]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"logLikD0", "[", 
   RowBox[{
   "n_", ",", "gc_", ",", "\[Theta]_", ",", "\[Theta]WS_", ",", "\[Tau]_", 
    ",", "\[Tau]WS_", ",", "\[Lambda]_", ",", "r__", ",", "kn__", ",", 
    "kWS__", ",", "kSW__", ",", "kDn_", ",", "kDWS_", ",", "kDSW_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnull", "[", 
       RowBox[{
        RowBox[{"\[Theta]", " ", "r"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kn"}], "]"}], "]"}]}], "]"}], 
   "+", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnull", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "gc"}], ")"}], "\[Theta]WS", " ", "r"}], ",", "n",
         ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWS"}], "]"}], "]"}]}], "]"}], 
   "+", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnull", "[", 
       RowBox[{
        RowBox[{"\[Lambda]", " ", "gc", " ", "\[Theta]WS", " ", "r"}], ",", 
        "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSW"}], "]"}], "]"}]}], "]"}], 
   "+", 
   RowBox[{"lnLDnull", "[", 
    RowBox[{"\[Tau]", ",", "\[Theta]", ",", "n", ",", "kDn"}], "]"}], "+", 
   RowBox[{"lnLDnull", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "gc"}], ")"}], "\[Tau]WS"}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "gc"}], ")"}], "\[Theta]WS"}], ",", "n", ",", 
     "kDWS"}], "]"}], "+", 
   RowBox[{"lnLDnull", "[", 
    RowBox[{
     RowBox[{"\[Lambda]", " ", "gc", " ", "\[Tau]WS"}], ",", 
     RowBox[{"\[Lambda]", " ", "gc", " ", "\[Theta]WS"}], ",", "n", ",", 
     "kDSW"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"logLikD1", "[", 
   RowBox[{
   "n_", ",", "gc_", ",", "\[Theta]_", ",", "\[Theta]WS_", ",", "\[Tau]_", 
    ",", "\[Tau]WS_", ",", "\[Lambda]_", ",", "B0_", ",", "B1_", ",", "r__", 
    ",", "kn__", ",", "kWS__", ",", "kSW__", ",", "kDn_", ",", "kDWS_", ",", 
    "kDSW_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnull", "[", 
       RowBox[{
        RowBox[{"\[Theta]", " ", "r"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kn"}], "]"}], "]"}]}], "]"}], 
   "+", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLB", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "gc"}], ")"}], "\[Theta]WS", " ", "r"}], ",", 
        "B1", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWS"}], "]"}], "]"}]}], "]"}], 
   "+", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLB", "[", 
       RowBox[{
        RowBox[{"\[Lambda]", " ", "gc", " ", "\[Theta]WS", " ", "r"}], ",", 
        RowBox[{"-", "B1"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSW"}], "]"}], "]"}]}], "]"}], 
   "+", 
   RowBox[{"lnLDnull", "[", 
    RowBox[{"\[Tau]", ",", "\[Theta]", ",", "n", ",", "kDn"}], "]"}], "+", 
   RowBox[{"lnLDB", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "gc"}], ")"}], "\[Tau]WS"}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "gc"}], ")"}], "\[Theta]WS"}], ",", "B0", ",", "B1", 
     ",", "n", ",", "kDWS"}], "]"}], "+", 
   RowBox[{"lnLDB", "[", 
    RowBox[{
     RowBox[{"\[Lambda]", " ", "gc", " ", "\[Tau]WS"}], ",", 
     RowBox[{"\[Lambda]", " ", "gc", " ", "\[Theta]WS"}], ",", 
     RowBox[{"-", "B0"}], ",", 
     RowBox[{"-", "B1"}], ",", "n", ",", "kDSW"}], "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.5642312464387703`*^9, 3.564231467145146*^9}, {
   3.564231601664914*^9, 3.5642316197715073`*^9}, {3.564231663082399*^9, 
   3.564231677292872*^9}, {3.56423192808986*^9, 3.5642319283827353`*^9}, {
   3.5642320247561083`*^9, 3.564232027514914*^9}, {3.5642321160595512`*^9, 
   3.5642321600600853`*^9}, {3.564232854681942*^9, 3.56423287491221*^9}, {
   3.5678336048957253`*^9, 3.5678336871168003`*^9}, {3.567834898802054*^9, 
   3.567834916924305*^9}, {3.6485780651165752`*^9, 3.648578084225429*^9}, {
   3.648578218839635*^9, 3.648578405515031*^9}, {3.648578542543578*^9, 
   3.648578654171432*^9}, 3.648578945901758*^9, {3.648660783444654*^9, 
   3.6486608258657627`*^9}, 3.648661029105101*^9, {3.6533770894654713`*^9, 
   3.653377102561715*^9}, {3.653377145995977*^9, 3.653377155042582*^9}, {
   3.653377217496642*^9, 3.65337723571037*^9}, {3.653377296555509*^9, 
   3.653377363963601*^9}, {3.653380614273332*^9, 3.653380618401184*^9}, {
   3.6720467542138844`*^9, 3.6720467676272163`*^9}, {3.6731657301238213`*^9, 
   3.673165778081603*^9}, {3.673166691006024*^9, 3.673166811616459*^9}, 
   3.673167062381353*^9, {3.673167139802314*^9, 3.673167191460841*^9}, {
   3.673167468460102*^9, 3.673167492827712*^9}, {3.6731703823109837`*^9, 
   3.6731703838956013`*^9}, {3.703222112056233*^9, 3.703222119062392*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["gBGC and SCU", "Subsubsection",
 CellChangeTimes->{{3.601656168933371*^9, 3.601656174415443*^9}, {
  3.6533192215867147`*^9, 3.653319228535453*^9}, {3.703222177875505*^9, 
  3.703222184153123*^9}}],

Cell["9 spectra are used", "Text",
 CellChangeTimes->{{3.601656224461762*^9, 3.6016562290918427`*^9}, {
  3.601656367867547*^9, 3.601656388825644*^9}, {3.6533192324477377`*^9, 
  3.653319235959709*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"logLikBS0", "[", 
   RowBox[{
   "n_", ",", "\[Theta]NN_", ",", "\[Theta]WSN_", ",", "\[Theta]SWN_", ",", 
    "\[Theta]NUP_", ",", "\[Theta]WSUP_", ",", "\[Theta]SWUP_", ",", 
    "\[Theta]NPU_", ",", "\[Theta]WSPU_", ",", "\[Theta]SWPU_", ",", "r__", 
    ",", "kNN__", ",", "kWSN__", ",", "kSWN__", ",", "kNUP__", ",", "kWSUP__",
     ",", "kSWUP__", ",", "kNPU__", ",", "kWSPU__", ",", "kSWPU__"}], "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnull", "[", 
       RowBox[{
        RowBox[{"\[Theta]NN", " ", "r"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kNN"}], "]"}], "]"}]}], "]"}], 
   "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnull", "[", 
       RowBox[{
        RowBox[{"\[Theta]WSN", " ", "r"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWSN"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnull", "[", 
       RowBox[{
        RowBox[{"\[Theta]SWN", " ", "r"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSWN"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnull", "[", 
       RowBox[{
        RowBox[{"\[Theta]NUP", " ", "r"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kNUP"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnull", "[", 
       RowBox[{
        RowBox[{"\[Theta]WSUP", " ", "r"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWSUP"}], "]"}], "]"}]}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnull", "[", 
       RowBox[{
        RowBox[{"\[Theta]SWUP", " ", "r"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSWUP"}], "]"}], "]"}]}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnull", "[", 
       RowBox[{
        RowBox[{"\[Theta]NPU", " ", "r"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kNPU"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnull", "[", 
       RowBox[{
        RowBox[{"\[Theta]WSPU", " ", "r"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWSPU"}], "]"}], "]"}]}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnull", "[", 
       RowBox[{
        RowBox[{"\[Theta]SWPU", " ", "r"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSWPU"}], "]"}], "]"}]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"logLikBS1B", "[", 
   RowBox[{
   "n_", ",", "\[Theta]NN_", ",", "\[Theta]WSN_", ",", "\[Theta]SWN_", ",", 
    "\[Theta]NUP_", ",", "\[Theta]WSUP_", ",", "\[Theta]SWUP_", ",", 
    "\[Theta]NPU_", ",", "\[Theta]WSPU_", ",", "\[Theta]SWPU_", ",", "B_", 
    ",", "r__", ",", "kNN__", ",", "kWSN__", ",", "kSWN__", ",", "kNUP__", 
    ",", "kWSUP__", ",", "kSWUP__", ",", "kNPU__", ",", "kWSPU__", ",", 
    "kSWPU__"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnull", "[", 
       RowBox[{
        RowBox[{"\[Theta]NN", " ", "r"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kNN"}], "]"}], "]"}]}], "]"}], 
   "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLB", "[", 
       RowBox[{
        RowBox[{"\[Theta]WSN", " ", "r"}], ",", "B", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWSN"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLB", "[", 
       RowBox[{
        RowBox[{"\[Theta]SWN", " ", "r"}], ",", 
        RowBox[{"-", "B"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSWN"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnull", "[", 
       RowBox[{
        RowBox[{"\[Theta]NUP", " ", "r"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kNUP"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLB", "[", 
       RowBox[{
        RowBox[{"\[Theta]WSUP", " ", "r"}], ",", "B", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWSUP"}], "]"}], "]"}]}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLB", "[", 
       RowBox[{
        RowBox[{"\[Theta]SWUP", " ", "r"}], ",", 
        RowBox[{"-", "B"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSWUP"}], "]"}], "]"}]}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnull", "[", 
       RowBox[{
        RowBox[{"\[Theta]NPU", " ", "r"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kNPU"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLB", "[", 
       RowBox[{
        RowBox[{"\[Theta]WSPU", " ", "r"}], ",", "B", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWSPU"}], "]"}], "]"}]}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLB", "[", 
       RowBox[{
        RowBox[{"\[Theta]SWPU", " ", "r"}], ",", 
        RowBox[{"-", "B"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSWPU"}], "]"}], "]"}]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"logLikBS1S", "[", 
   RowBox[{
   "n_", ",", "\[Theta]NN_", ",", "\[Theta]WSN_", ",", "\[Theta]SWN_", ",", 
    "\[Theta]NUP_", ",", "\[Theta]WSUP_", ",", "\[Theta]SWUP_", ",", 
    "\[Theta]NPU_", ",", "\[Theta]WSPU_", ",", "\[Theta]SWPU_", ",", "S_", 
    ",", "r__", ",", "kNN__", ",", "kWSN__", ",", "kSWN__", ",", "kNUP__", 
    ",", "kWSUP__", ",", "kSWUP__", ",", "kNPU__", ",", "kWSPU__", ",", 
    "kSWPU__"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnull", "[", 
       RowBox[{
        RowBox[{"\[Theta]NN", " ", "r"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kNN"}], "]"}], "]"}]}], "]"}], 
   "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnull", "[", 
       RowBox[{
        RowBox[{"\[Theta]WSN", " ", "r"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWSN"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnull", "[", 
       RowBox[{
        RowBox[{"\[Theta]SWN", " ", "r"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSWN"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLB", "[", 
       RowBox[{
        RowBox[{"\[Theta]NUP", " ", "r"}], ",", "S", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kNUP"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLB", "[", 
       RowBox[{
        RowBox[{"\[Theta]WSUP", " ", "r"}], ",", "S", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWSUP"}], "]"}], "]"}]}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLB", "[", 
       RowBox[{
        RowBox[{"\[Theta]SWUP", " ", "r"}], ",", "S", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSWUP"}], "]"}], "]"}]}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLB", "[", 
       RowBox[{
        RowBox[{"\[Theta]NPU", " ", "r"}], ",", 
        RowBox[{"-", "S"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kNPU"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLB", "[", 
       RowBox[{
        RowBox[{"\[Theta]WSPU", " ", "r"}], ",", 
        RowBox[{"-", "S"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWSPU"}], "]"}], "]"}]}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLB", "[", 
       RowBox[{
        RowBox[{"\[Theta]SWPU", " ", "r"}], ",", 
        RowBox[{"-", "S"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSWPU"}], "]"}], "]"}]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"logLikBS2", "[", 
   RowBox[{
   "n_", ",", "\[Theta]NN_", ",", "\[Theta]WSN_", ",", "\[Theta]SWN_", ",", 
    "\[Theta]NUP_", ",", "\[Theta]WSUP_", ",", "\[Theta]SWUP_", ",", 
    "\[Theta]NPU_", ",", "\[Theta]WSPU_", ",", "\[Theta]SWPU_", ",", "B_", 
    ",", "S_", ",", "r__", ",", "kNN__", ",", "kWSN__", ",", "kSWN__", ",", 
    "kNUP__", ",", "kWSUP__", ",", "kSWUP__", ",", "kNPU__", ",", "kWSPU__", 
    ",", "kSWPU__"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnull", "[", 
       RowBox[{
        RowBox[{"\[Theta]NN", " ", "r"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kNN"}], "]"}], "]"}]}], "]"}], 
   "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLB", "[", 
       RowBox[{
        RowBox[{"\[Theta]WSN", " ", "r"}], ",", "B", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWSN"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLB", "[", 
       RowBox[{
        RowBox[{"\[Theta]SWN", " ", "r"}], ",", 
        RowBox[{"-", "B"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSWN"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLB", "[", 
       RowBox[{
        RowBox[{"\[Theta]NUP", " ", "r"}], ",", "S", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kNUP"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLB", "[", 
       RowBox[{
        RowBox[{"\[Theta]WSUP", " ", "r"}], ",", 
        RowBox[{"B", "+", "S"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWSUP"}], "]"}], "]"}]}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLB", "[", 
       RowBox[{
        RowBox[{"\[Theta]SWUP", " ", "r"}], ",", 
        RowBox[{
         RowBox[{"-", "B"}], "+", "S"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSWUP"}], "]"}], "]"}]}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLB", "[", 
       RowBox[{
        RowBox[{"\[Theta]NPU", " ", "r"}], ",", 
        RowBox[{"-", "S"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kNPU"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLB", "[", 
       RowBox[{
        RowBox[{"\[Theta]WSPU", " ", "r"}], ",", 
        RowBox[{"B", "-", "S"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWSPU"}], "]"}], "]"}]}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLB", "[", 
       RowBox[{
        RowBox[{"\[Theta]SWPU", " ", "r"}], ",", 
        RowBox[{
         RowBox[{"-", "B"}], "-", "S"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSWPU"}], "]"}], "]"}]}], 
    "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.6016562501979713`*^9, 3.601656365543172*^9}, {
  3.601656429762993*^9, 3.6016570955125523`*^9}}],

Cell["\<\
Similar models but including divergence. All combinations are not tested\
\>", "Text",
 CellChangeTimes->{{3.653319288234198*^9, 3.653319320369825*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"logLikDBS0", "[", 
    RowBox[{
    "n_", ",", "\[Theta]NN_", ",", "\[Theta]WSN_", ",", "\[Theta]SWN_", ",", 
     "\[Theta]NUP_", ",", "\[Theta]WSUP_", ",", "\[Theta]SWUP_", ",", 
     "\[Theta]NPU_", ",", "\[Theta]WSPU_", ",", "\[Theta]SWPU_", ",", 
     "\[Tau]NN_", ",", "\[Tau]WSN_", ",", "\[Tau]SWN_", ",", "\[Tau]NUP_", 
     ",", "\[Tau]WSUP_", ",", "\[Tau]SWUP_", ",", "\[Tau]NPU_", ",", 
     "\[Tau]WSPU_", ",", "\[Tau]SWPU_", ",", "r__", ",", "kNN__", ",", 
     "kWSN__", ",", "kSWN__", ",", "kNUP__", ",", "kWSUP__", ",", "kSWUP__", 
     ",", "kNPU__", ",", "kWSPU__", ",", "kSWPU__", ",", "kDNN_", ",", 
     "kDWSN_", ",", "kDSWN_", ",", "kDNUP_", ",", "kDWSUP_", ",", "kDSWUP_", 
     ",", "kDNPU_", ",", "kDWSPU_", ",", "kDSWPU_"}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnull", "[", 
        RowBox[{
         RowBox[{"\[Theta]NN", " ", "r"}], ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kNN"}], "]"}], "]"}]}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnull", "[", 
        RowBox[{
         RowBox[{"\[Theta]WSN", " ", "r"}], ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kWSN"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnull", "[", 
        RowBox[{
         RowBox[{"\[Theta]SWN", " ", "r"}], ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kSWN"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnull", "[", 
        RowBox[{
         RowBox[{"\[Theta]NUP", " ", "r"}], ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kNUP"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnull", "[", 
        RowBox[{
         RowBox[{"\[Theta]WSUP", " ", "r"}], ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kWSUP"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnull", "[", 
        RowBox[{
         RowBox[{"\[Theta]SWUP", " ", "r"}], ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kSWUP"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnull", "[", 
        RowBox[{
         RowBox[{"\[Theta]NPU", " ", "r"}], ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kNPU"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnull", "[", 
        RowBox[{
         RowBox[{"\[Theta]WSPU", " ", "r"}], ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kWSPU"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnull", "[", 
        RowBox[{
         RowBox[{"\[Theta]SWPU", " ", "r"}], ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kSWPU"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDnull", "[", 
     RowBox[{"\[Tau]NN", ",", "\[Theta]NN", ",", "n", ",", "kDNN"}], "]"}], 
    "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDnull", "[", 
     RowBox[{"\[Tau]WSN", ",", "\[Theta]WSN", ",", "n", ",", "kDWSN"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDnull", "[", 
     RowBox[{"\[Tau]SWN", ",", "\[Theta]SWN", ",", "n", ",", "kDSWN"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDnull", "[", 
     RowBox[{"\[Tau]NUP", ",", "\[Theta]NUP", ",", "n", ",", "kDNUP"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDnull", "[", 
     RowBox[{"\[Tau]WSUP", ",", "\[Theta]WSUP", ",", "n", ",", "kDWSUP"}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDnull", "[", 
     RowBox[{"\[Tau]SWUP", ",", "\[Theta]SWUP", ",", "n", ",", "kDSWUP"}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDnull", "[", 
     RowBox[{"\[Tau]NPU", ",", "\[Theta]NPU", ",", "n", ",", "kDNPU"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDnull", "[", 
     RowBox[{"\[Tau]WSPU", ",", "\[Theta]WSPU", ",", "n", ",", "kDWSPU"}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDnull", "[", 
     RowBox[{"\[Tau]SWPU", ",", "\[Theta]SWPU", ",", "n", ",", "kDSWPU"}], 
     "]"}]}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"logLikDBS1B", "[", 
    RowBox[{
    "n_", ",", "\[Theta]NN_", ",", "\[Theta]WSN_", ",", "\[Theta]SWN_", ",", 
     "\[Theta]NUP_", ",", "\[Theta]WSUP_", ",", "\[Theta]SWUP_", ",", 
     "\[Theta]NPU_", ",", "\[Theta]WSPU_", ",", "\[Theta]SWPU_", ",", 
     "\[Tau]NN_", ",", "\[Tau]WSN_", ",", "\[Tau]SWN_", ",", "\[Tau]NUP_", 
     ",", "\[Tau]WSUP_", ",", "\[Tau]SWUP_", ",", "\[Tau]NPU_", ",", 
     "\[Tau]WSPU_", ",", "\[Tau]SWPU_", ",", "B0_", ",", "B1_", ",", "r__", 
     ",", "kNN__", ",", "kWSN__", ",", "kSWN__", ",", "kNUP__", ",", 
     "kWSUP__", ",", "kSWUP__", ",", "kNPU__", ",", "kWSPU__", ",", "kSWPU__",
      ",", "kDNN_", ",", "kDWSN_", ",", "kDSWN_", ",", "kDNUP_", ",", 
     "kDWSUP_", ",", "kDSWUP_", ",", "kDNPU_", ",", "kDWSPU_", ",", 
     "kDSWPU_"}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnull", "[", 
        RowBox[{
         RowBox[{"\[Theta]NN", " ", "r"}], ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kNN"}], "]"}], "]"}]}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLB", "[", 
        RowBox[{
         RowBox[{"\[Theta]WSN", " ", "r"}], ",", "B1", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kWSN"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLB", "[", 
        RowBox[{
         RowBox[{"\[Theta]SWN", " ", "r"}], ",", 
         RowBox[{"-", "B1"}], ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kSWN"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnull", "[", 
        RowBox[{
         RowBox[{"\[Theta]NUP", " ", "r"}], ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kNUP"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLB", "[", 
        RowBox[{
         RowBox[{"\[Theta]WSUP", " ", "r"}], ",", "B1", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kWSUP"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLB", "[", 
        RowBox[{
         RowBox[{"\[Theta]SWUP", " ", "r"}], ",", 
         RowBox[{"-", "B1"}], ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kSWUP"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnull", "[", 
        RowBox[{
         RowBox[{"\[Theta]NPU", " ", "r"}], ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kNPU"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLB", "[", 
        RowBox[{
         RowBox[{"\[Theta]WSPU", " ", "r"}], ",", "B1", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kWSPU"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLB", "[", 
        RowBox[{
         RowBox[{"\[Theta]SWPU", " ", "r"}], ",", 
         RowBox[{"-", "B1"}], ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kSWPU"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDnull", "[", 
     RowBox[{"\[Tau]NN", ",", "\[Theta]NN", ",", "n", ",", "kDNN"}], "]"}], 
    "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDB", "[", 
     RowBox[{
     "\[Tau]WSN", ",", "\[Theta]WSN", ",", "B0", ",", "B1", ",", "n", ",", 
      "kDWSN"}], "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDB", "[", 
     RowBox[{"\[Tau]SWN", ",", "\[Theta]SWN", ",", 
      RowBox[{"-", "B0"}], ",", 
      RowBox[{"-", "B1"}], ",", "n", ",", "kDSWN"}], "]"}], "+", 
    "\[IndentingNewLine]", 
    RowBox[{"lnLDnull", "[", 
     RowBox[{"\[Tau]NUP", ",", "\[Theta]NUP", ",", "n", ",", "kDNUP"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDB", "[", 
     RowBox[{
     "\[Tau]WSUP", ",", "\[Theta]WSUP", ",", "B0", ",", "B1", ",", "n", ",", 
      "kDWSUP"}], "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDB", "[", 
     RowBox[{"\[Tau]SWUP", ",", "\[Theta]SWUP", ",", 
      RowBox[{"-", "B0"}], ",", 
      RowBox[{"-", "B1"}], ",", "n", ",", "kDSWUP"}], "]"}], "+", 
    "\[IndentingNewLine]", 
    RowBox[{"lnLDnull", "[", 
     RowBox[{"\[Tau]NPU", ",", "\[Theta]NPU", ",", "n", ",", "kDNPU"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDB", "[", 
     RowBox[{
     "\[Tau]WSPU", ",", "\[Theta]WSPU", ",", "B0", ",", "B1", ",", "n", ",", 
      "kDWSPU"}], "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDB", "[", 
     RowBox[{"\[Tau]SWPU", ",", "\[Theta]SWPU", ",", 
      RowBox[{"-", "B0"}], ",", 
      RowBox[{"-", "B1"}], ",", "n", ",", "kDSWPU"}], "]"}]}]}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"logLikDBS1S", "[", 
    RowBox[{
    "n_", ",", "\[Theta]NN_", ",", "\[Theta]WSN_", ",", "\[Theta]SWN_", ",", 
     "\[Theta]NUP_", ",", "\[Theta]WSUP_", ",", "\[Theta]SWUP_", ",", 
     "\[Theta]NPU_", ",", "\[Theta]WSPU_", ",", "\[Theta]SWPU_", ",", 
     "\[Tau]NN_", ",", "\[Tau]WSN_", ",", "\[Tau]SWN_", ",", "\[Tau]NUP_", 
     ",", "\[Tau]WSUP_", ",", "\[Tau]SWUP_", ",", "\[Tau]NPU_", ",", 
     "\[Tau]WSPU_", ",", "\[Tau]SWPU_", ",", "S0_", ",", "S1_", ",", "r__", 
     ",", "kNN__", ",", "kWSN__", ",", "kSWN__", ",", "kNUP__", ",", 
     "kWSUP__", ",", "kSWUP__", ",", "kNPU__", ",", "kWSPU__", ",", "kSWPU__",
      ",", "kDNN_", ",", "kDWSN_", ",", "kDSWN_", ",", "kDNUP_", ",", 
     "kDWSUP_", ",", "kDSWUP_", ",", "kDNPU_", ",", "kDWSPU_", ",", 
     "kDSWPU_"}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnull", "[", 
        RowBox[{
         RowBox[{"\[Theta]NN", " ", "r"}], ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kNN"}], "]"}], "]"}]}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnull", "[", 
        RowBox[{
         RowBox[{"\[Theta]WSN", " ", "r"}], ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kWSN"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnull", "[", 
        RowBox[{
         RowBox[{"\[Theta]SWN", " ", "r"}], ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kSWN"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLB", "[", 
        RowBox[{
         RowBox[{"\[Theta]NUP", " ", "r"}], ",", "S1", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kNUP"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLB", "[", 
        RowBox[{
         RowBox[{"\[Theta]WSUP", " ", "r"}], ",", "S1", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kWSUP"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLB", "[", 
        RowBox[{
         RowBox[{"\[Theta]SWUP", " ", "r"}], ",", "S1", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kSWUP"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLB", "[", 
        RowBox[{
         RowBox[{"\[Theta]NPU", " ", "r"}], ",", 
         RowBox[{"-", "S1"}], ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kNPU"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLB", "[", 
        RowBox[{
         RowBox[{"\[Theta]WSPU", " ", "r"}], ",", 
         RowBox[{"-", "S1"}], ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kWSPU"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLB", "[", 
        RowBox[{
         RowBox[{"\[Theta]SWPU", " ", "r"}], ",", 
         RowBox[{"-", "S1"}], ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kSWPU"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDnull", "[", 
     RowBox[{"\[Tau]NN", ",", "\[Theta]NN", ",", "n", ",", "kDNN"}], "]"}], 
    "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDnull", "[", 
     RowBox[{"\[Tau]WSN", ",", "\[Theta]WSN", ",", "n", ",", "kDWSN"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDnull", "[", 
     RowBox[{"\[Tau]SWN", ",", "\[Theta]SWN", ",", "n", ",", "kDSWN"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDB", "[", 
     RowBox[{
     "\[Tau]NUP", ",", "\[Theta]NUP", ",", "S0", ",", "S1", ",", "n", ",", 
      "kDNUP"}], "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDB", "[", 
     RowBox[{
     "\[Tau]WSUP", ",", "\[Theta]WSUP", ",", "S0", ",", "S1", ",", "n", ",", 
      "kDWSUP"}], "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDB", "[", 
     RowBox[{
     "\[Tau]SWUP", ",", "\[Theta]SWUP", ",", "S0", ",", "S1", ",", "n", ",", 
      "kDSWUP"}], "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDB", "[", 
     RowBox[{"\[Tau]NPU", ",", "\[Theta]NPU", ",", 
      RowBox[{"-", "S0"}], ",", 
      RowBox[{"-", "S1"}], ",", "n", ",", "kDNPU"}], "]"}], "+", 
    "\[IndentingNewLine]", 
    RowBox[{"lnLDB", "[", 
     RowBox[{"\[Tau]WSPU", ",", "\[Theta]WSPU", ",", 
      RowBox[{"-", "S0"}], ",", 
      RowBox[{"-", "S1"}], ",", "n", ",", "kDWSPU"}], "]"}], "+", 
    "\[IndentingNewLine]", 
    RowBox[{"lnLDB", "[", 
     RowBox[{"\[Tau]SWPU", ",", "\[Theta]SWPU", ",", 
      RowBox[{"-", "S0"}], ",", 
      RowBox[{"-", "S1"}], ",", "n", ",", "kDSWPU"}], "]"}]}]}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"logLikDBS2", "[", 
   RowBox[{
   "n_", ",", "\[Theta]NN_", ",", "\[Theta]WSN_", ",", "\[Theta]SWN_", ",", 
    "\[Theta]NUP_", ",", "\[Theta]WSUP_", ",", "\[Theta]SWUP_", ",", 
    "\[Theta]NPU_", ",", "\[Theta]WSPU_", ",", "\[Theta]SWPU_", ",", 
    "\[Tau]NN_", ",", "\[Tau]WSN_", ",", "\[Tau]SWN_", ",", "\[Tau]NUP_", ",",
     "\[Tau]WSUP_", ",", "\[Tau]SWUP_", ",", "\[Tau]NPU_", ",", "\[Tau]WSPU_",
     ",", "\[Tau]SWPU_", ",", "B0_", ",", "B1_", ",", "S0_", ",", "S1_", ",", 
    "r__", ",", "kNN__", ",", "kWSN__", ",", "kSWN__", ",", "kNUP__", ",", 
    "kWSUP__", ",", "kSWUP__", ",", "kNPU__", ",", "kWSPU__", ",", "kSWPU__", 
    ",", "kDNN_", ",", "kDWSN_", ",", "kDSWN_", ",", "kDNUP_", ",", "kDWSUP_",
     ",", "kDSWUP_", ",", "kDNPU_", ",", "kDWSPU_", ",", "kDSWPU_"}], "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnull", "[", 
       RowBox[{
        RowBox[{"\[Theta]NN", " ", "r"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kNN"}], "]"}], "]"}]}], "]"}], 
   "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLB", "[", 
       RowBox[{
        RowBox[{"\[Theta]WSN", " ", "r"}], ",", "B1", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWSN"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLB", "[", 
       RowBox[{
        RowBox[{"\[Theta]SWN", " ", "r"}], ",", 
        RowBox[{"-", "B1"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSWN"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLB", "[", 
       RowBox[{
        RowBox[{"\[Theta]NUP", " ", "r"}], ",", "S1", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kNUP"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLB", "[", 
       RowBox[{
        RowBox[{"\[Theta]WSUP", " ", "r"}], ",", 
        RowBox[{"B1", "+", "S1"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWSUP"}], "]"}], "]"}]}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLB", "[", 
       RowBox[{
        RowBox[{"\[Theta]SWUP", " ", "r"}], ",", 
        RowBox[{
         RowBox[{"-", "B1"}], "+", "S1"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSWUP"}], "]"}], "]"}]}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLB", "[", 
       RowBox[{
        RowBox[{"\[Theta]NPU", " ", "r"}], ",", 
        RowBox[{"-", "S1"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kNPU"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLB", "[", 
       RowBox[{
        RowBox[{"\[Theta]WSPU", " ", "r"}], ",", 
        RowBox[{"B1", "-", "S1"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWSPU"}], "]"}], "]"}]}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLB", "[", 
       RowBox[{
        RowBox[{"\[Theta]SWPU", " ", "r"}], ",", 
        RowBox[{
         RowBox[{"-", "B1"}], "-", "S1"}], ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSWPU"}], "]"}], "]"}]}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"lnLDnull", "[", 
    RowBox[{"\[Tau]NN", ",", "\[Theta]NN", ",", "n", ",", "kDNN"}], "]"}], 
   "+", "\[IndentingNewLine]", 
   RowBox[{"lnLDB", "[", 
    RowBox[{
    "\[Tau]WSN", ",", "\[Theta]WSN", ",", "B0", ",", "B1", ",", "n", ",", 
     "kDWSN"}], "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"lnLDB", "[", 
    RowBox[{"\[Tau]SWN", ",", "\[Theta]SWN", ",", 
     RowBox[{"-", "B0"}], ",", 
     RowBox[{"-", "B1"}], ",", "n", ",", "kDSWN"}], "]"}], "+", 
   "\[IndentingNewLine]", 
   RowBox[{"lnLDB", "[", 
    RowBox[{
    "\[Tau]NUP", ",", "\[Theta]NUP", ",", "S0", ",", "S1", ",", "n", ",", 
     "kDNUP"}], "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"lnLDB", "[", 
    RowBox[{"\[Tau]WSUP", ",", "\[Theta]WSUP", ",", 
     RowBox[{"B0", "+", "S0"}], ",", 
     RowBox[{"B1", "+", "S1"}], ",", "n", ",", "kDWSUP"}], "]"}], "+", 
   "\[IndentingNewLine]", 
   RowBox[{"lnLDB", "[", 
    RowBox[{"\[Tau]SWUP", ",", "\[Theta]SWUP", ",", 
     RowBox[{
      RowBox[{"-", "B0"}], "+", "S0"}], ",", 
     RowBox[{
      RowBox[{"-", "B1"}], "+", "S1"}], ",", "n", ",", "kDSWUP"}], "]"}], "+",
    "\[IndentingNewLine]", 
   RowBox[{"lnLDB", "[", 
    RowBox[{"\[Tau]NPU", ",", "\[Theta]NPU", ",", 
     RowBox[{"-", "S0"}], ",", 
     RowBox[{"-", "S1"}], ",", "n", ",", "kDNPU"}], "]"}], "+", 
   "\[IndentingNewLine]", 
   RowBox[{"lnLDB", "[", 
    RowBox[{"\[Tau]WSPU", ",", "\[Theta]WSPU", ",", 
     RowBox[{"B0", "-", "S0"}], ",", 
     RowBox[{"B1", "-", "S1"}], ",", "n", ",", "kDWSPU"}], "]"}], "+", 
   "\[IndentingNewLine]", 
   RowBox[{"lnLDB", "[", 
    RowBox[{"\[Tau]SWPU", ",", "\[Theta]SWPU", ",", 
     RowBox[{
      RowBox[{"-", "B0"}], "-", "S0"}], ",", 
     RowBox[{
      RowBox[{"-", "B1"}], "-", "S1"}], ",", "n", ",", "kDSWPU"}], 
    "]"}]}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.6533193668793488`*^9, 3.653319397698556*^9}, {
  3.653319432931397*^9, 3.6533194828313437`*^9}, {3.6533195271418037`*^9, 
  3.653319564198868*^9}, {3.6533196518697357`*^9, 3.653319773320496*^9}, {
  3.653319928129047*^9, 3.6533199283091297`*^9}, {3.6533199652068367`*^9, 
  3.653320376906125*^9}, {3.653320422952791*^9, 3.653320432753284*^9}, {
  3.6533811888468323`*^9, 3.6533812637556057`*^9}, {3.653381422214261*^9, 
  3.653381583007863*^9}, {3.653381652657619*^9, 3.653381704022805*^9}, {
  3.6533817495813*^9, 3.653381851759425*^9}, {3.6533826768494*^9, 
  3.653382696355101*^9}, {3.6534081825689583`*^9, 3.65340828777918*^9}, {
  3.653408505214748*^9, 3.65340850689892*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Same models with polarization errors",
 FontWeight->"Plain"]], "Subsection",
 CellChangeTimes->{{3.564237252556658*^9, 3.56423728032006*^9}, 
   3.5642544652240343`*^9, {3.565036255047193*^9, 3.565036258435347*^9}, {
   3.703222202694228*^9, 3.703222209195613*^9}}],

Cell[CellGroupData[{

Cell["gBGC or SCU", "Subsubsection",
 CellChangeTimes->{{3.70322224968414*^9, 3.703222253216639*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"lnLnullerr", "[", 
    RowBox[{
    "\[Theta]1_", ",", "\[Theta]2_", ",", "\[Epsilon]1_", ",", "\[Epsilon]2_",
      ",", "n_", ",", "i_", ",", "k_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"\[Mu]e", "[", 
      RowBox[{
      "\[Theta]1", ",", "\[Theta]2", ",", "\[Epsilon]1", ",", "\[Epsilon]2", 
       ",", "n", ",", "i"}], "]"}]}], "+", 
    RowBox[{"k", " ", 
     RowBox[{"Log", "[", 
      RowBox[{"\[Mu]e", "[", 
       RowBox[{
       "\[Theta]1", ",", "\[Theta]2", ",", "\[Epsilon]1", ",", "\[Epsilon]2", 
        ",", "n", ",", "i"}], "]"}], "]"}]}], "-", 
    RowBox[{"Log", "[", 
     RowBox[{"k", "!"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"lnLBerr", "[", 
     RowBox[{
     "\[Theta]1_", ",", "\[Theta]2_", ",", "B_", ",", "\[Epsilon]1_", ",", 
      "\[Epsilon]2_", ",", "n_", ",", "i_", ",", "k_"}], "]"}], "=", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"\[Mu]Be", "[", 
       RowBox[{
       "\[Theta]1", ",", "\[Theta]2", ",", "B", ",", "\[Epsilon]1", ",", 
        "\[Epsilon]2", ",", "n", ",", "i"}], "]"}]}], "+", 
     RowBox[{"k", " ", 
      RowBox[{"Log", "[", 
       RowBox[{"\[Mu]Be", "[", 
        RowBox[{
        "\[Theta]1", ",", "\[Theta]2", ",", "B", ",", "\[Epsilon]1", ",", 
         "\[Epsilon]2", ",", "n", ",", "i"}], "]"}], "]"}]}], "-", 
     RowBox[{"Log", "[", 
      RowBox[{"k", "!"}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"lnLDnullerr", "[", 
    RowBox[{
    "\[Tau]_", ",", "\[Theta]_", ",", "n_", ",", "\[Epsilon]_", ",", "k_"}], 
    "]"}], "=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"\[Mu]De", "[", 
      RowBox[{"\[Tau]", ",", "\[Theta]", ",", "n", ",", "\[Epsilon]"}], 
      "]"}]}], "+", 
    RowBox[{"k", " ", 
     RowBox[{"Log", "[", 
      RowBox[{"\[Mu]De", "[", 
       RowBox[{"\[Tau]", ",", "\[Theta]", ",", "n", ",", "\[Epsilon]"}], 
       "]"}], "]"}]}], "-", 
    RowBox[{"Log", "[", 
     RowBox[{"k", "!"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"lnLDBerr", "[", 
    RowBox[{
    "\[Tau]_", ",", "\[Theta]_", ",", "B0_", ",", "B1_", ",", "n_", ",", 
     "\[Epsilon]_", ",", "k_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"\[Mu]DBe", "[", 
      RowBox[{
      "\[Tau]", ",", "\[Theta]", ",", "B0", ",", "B1", ",", "n", ",", 
       "\[Epsilon]"}], "]"}]}], "+", 
    RowBox[{"k", " ", 
     RowBox[{"Log", "[", 
      RowBox[{"\[Mu]DBe", "[", 
       RowBox[{
       "\[Tau]", ",", "\[Theta]", ",", "B0", ",", "B1", ",", "n", ",", 
        "\[Epsilon]"}], "]"}], "]"}]}], "-", 
    RowBox[{"Log", "[", 
     RowBox[{"k", "!"}], "]"}]}]}], ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.564237314090456*^9, 3.564237336217445*^9}, 
   3.5642373667501307`*^9, {3.564237622250279*^9, 3.564237661396779*^9}, {
   3.56425268338205*^9, 3.564252701619594*^9}, {3.564252762842174*^9, 
   3.5642527660469007`*^9}, {3.5642528256028233`*^9, 3.564252828122671*^9}, {
   3.5642529971206217`*^9, 3.5642530710990753`*^9}, {3.564253130334136*^9, 
   3.5642531456277103`*^9}, {3.564253197856127*^9, 3.564253223345599*^9}, {
   3.564253771257348*^9, 3.564253844785268*^9}, {3.564255644524529*^9, 
   3.5642556457958193`*^9}, {3.5644650489034357`*^9, 3.564465075033431*^9}, {
   3.56446781887748*^9, 3.564467847430722*^9}, {3.564939365609761*^9, 
   3.564939391373795*^9}, {3.5678340414859533`*^9, 3.567834088768161*^9}, {
   3.567834133296948*^9, 3.567834169693039*^9}, {3.6485778389452047`*^9, 
   3.64857789791256*^9}, {3.648657171528411*^9, 3.648657232936873*^9}, {
   3.648659790842025*^9, 3.6486597934662724`*^9}, {3.653379203760766*^9, 
   3.653379274702354*^9}, {3.653380490500532*^9, 3.653380501467267*^9}, {
   3.703222212774641*^9, 3.703222214483807*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"logLik0err3", "[", 
    RowBox[{
    "n_", ",", "gc_", ",", "\[Theta]_", ",", "\[Theta]WS_", ",", "\[Lambda]_",
      ",", "r__", ",", "\[Epsilon]_", ",", "\[Epsilon]WS_", ",", 
     "\[Epsilon]SW_", ",", "kn__", ",", "kWS__", ",", "kSW__"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnullerr", "[", 
        RowBox[{
         RowBox[{"\[Theta]", " ", "r"}], ",", 
         RowBox[{"\[Theta]", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]", ",", 
         "\[Epsilon]", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kn"}], "]"}], "]"}]}], "]"}], 
    "+", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnullerr", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "gc"}], ")"}], "\[Theta]WS", " ", "r"}], ",", 
         RowBox[{"\[Lambda]", " ", "gc", " ", "\[Theta]WS", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]WS", ",", 
         "\[Epsilon]SW", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kWS"}], "]"}], "]"}]}], "]"}],
     "+", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnullerr", "[", 
        RowBox[{
         RowBox[{"\[Lambda]", " ", "gc", " ", "\[Theta]WS", " ", "r"}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "gc"}], ")"}], "\[Theta]WS", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]SW", ",", 
         "\[Epsilon]WS", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kSW"}], "]"}], "]"}]}], 
     "]"}]}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"logLik1err3", "[", 
    RowBox[{
    "n_", ",", "gc_", ",", "\[Theta]_", ",", "\[Theta]WS_", ",", "\[Lambda]_",
      ",", "B_", ",", "r__", ",", "\[Epsilon]_", ",", "\[Epsilon]WS_", ",", 
     "\[Epsilon]SW_", ",", "kn__", ",", "kWS__", ",", "kSW__"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnullerr", "[", 
        RowBox[{
         RowBox[{"\[Theta]", " ", "r"}], ",", 
         RowBox[{"\[Theta]", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]", ",", 
         "\[Epsilon]", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kn"}], "]"}], "]"}]}], "]"}], 
    "+", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLBerr", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "gc"}], ")"}], "\[Theta]WS", " ", "r"}], ",", 
         RowBox[{"\[Lambda]", " ", "gc", " ", "\[Theta]WS", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", "B", ",", "\[Epsilon]WS",
          ",", "\[Epsilon]SW", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kWS"}], "]"}], "]"}]}], "]"}],
     "+", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLBerr", "[", 
        RowBox[{
         RowBox[{"\[Lambda]", " ", "gc", " ", "\[Theta]WS", " ", "r"}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "gc"}], ")"}], " ", "\[Theta]WS", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", 
         RowBox[{"-", "B"}], ",", "\[Epsilon]SW", ",", "\[Epsilon]WS", ",", 
         "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kSW"}], "]"}], "]"}]}], 
     "]"}]}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"logLikD0err3", "[", 
    RowBox[{
    "n_", ",", "gc_", ",", "\[Theta]_", ",", "\[Theta]WS_", ",", "\[Tau]_", 
     ",", "\[Tau]WS_", ",", "\[Lambda]_", ",", "r__", ",", "\[Epsilon]_", ",",
      "\[Epsilon]WS_", ",", "\[Epsilon]SW_", ",", "kn__", ",", "kWS__", ",", 
     "kSW__", ",", "kDn_", ",", "kDWS_", ",", "kDSW_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnullerr", "[", 
        RowBox[{
         RowBox[{"\[Theta]", " ", "r"}], ",", 
         RowBox[{"\[Theta]", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]", ",", 
         "\[Epsilon]", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kn"}], "]"}], "]"}]}], "]"}], 
    "+", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnullerr", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "gc"}], ")"}], "\[Theta]WS", " ", "r"}], ",", 
         RowBox[{"\[Lambda]", " ", "gc", " ", "\[Theta]WS", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]WS", ",", 
         "\[Epsilon]SW", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kWS"}], "]"}], "]"}]}], "]"}],
     "+", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnullerr", "[", 
        RowBox[{
         RowBox[{"\[Lambda]", " ", "gc", " ", "\[Theta]WS", " ", "r"}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "gc"}], ")"}], "\[Theta]WS", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]SW", ",", 
         "\[Epsilon]WS", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kSW"}], "]"}], "]"}]}], "]"}],
     "+", 
    RowBox[{"lnLDnullerr", "[", 
     RowBox[{
     "\[Tau]", ",", "\[Theta]", ",", "n", ",", "\[Epsilon]", ",", "kDn"}], 
     "]"}], "+", 
    RowBox[{"lnLDnullerr", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "gc"}], ")"}], "\[Tau]WS"}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "gc"}], ")"}], "\[Theta]WS"}], ",", "n", ",", 
      "\[Epsilon]WS", ",", "kDWS"}], "]"}], "+", 
    RowBox[{"lnLDnullerr", "[", 
     RowBox[{
      RowBox[{"\[Lambda]", " ", "gc", " ", "\[Tau]WS"}], ",", 
      RowBox[{"\[Lambda]", " ", "gc", " ", "\[Theta]WS"}], ",", "n", ",", 
      "\[Epsilon]SW", ",", "kDSW"}], "]"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"logLikD1err3", "[", 
   RowBox[{
   "n_", ",", "gc_", ",", "\[Theta]_", ",", "\[Theta]WS_", ",", "\[Tau]_", 
    ",", "\[Tau]WS_", ",", "\[Lambda]_", ",", "B0_", ",", "B1_", ",", "r__", 
    ",", "\[Epsilon]_", ",", "\[Epsilon]WS_", ",", "\[Epsilon]SW_", ",", 
    "kn__", ",", "kWS__", ",", "kSW__", ",", "kDn_", ",", "kDWS_", ",", 
    "kDSW_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnullerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]", " ", "r"}], ",", 
        RowBox[{"\[Theta]", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]", ",", 
        "\[Epsilon]", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kn"}], "]"}], "]"}]}], "]"}], 
   "+", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLBerr", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "gc"}], ")"}], "\[Theta]WS", " ", "r"}], ",", 
        RowBox[{"\[Lambda]", " ", "gc", " ", "\[Theta]WS", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", "B1", ",", "\[Epsilon]WS",
         ",", "\[Epsilon]SW", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWS"}], "]"}], "]"}]}], "]"}], 
   "+", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLBerr", "[", 
       RowBox[{
        RowBox[{"\[Lambda]", " ", "gc", " ", "\[Theta]WS", " ", "r"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "gc"}], ")"}], " ", "\[Theta]WS", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", 
        RowBox[{"-", "B1"}], ",", "\[Epsilon]SW", ",", "\[Epsilon]WS", ",", 
        "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSW"}], "]"}], "]"}]}], "]"}], 
   "+", 
   RowBox[{"lnLDnullerr", "[", 
    RowBox[{
    "\[Tau]", ",", "\[Theta]", ",", "n", ",", "\[Epsilon]", ",", "kDn"}], 
    "]"}], "+", 
   RowBox[{"lnLDBerr", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "gc"}], ")"}], "\[Tau]WS"}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "gc"}], ")"}], "\[Theta]WS"}], ",", "B0", ",", "B1", 
     ",", "n", ",", "\[Epsilon]WS", ",", "kDWS"}], "]"}], "+", 
   RowBox[{"lnLDBerr", "[", 
    RowBox[{
     RowBox[{"\[Lambda]", " ", "gc", " ", "\[Tau]WS"}], ",", 
     RowBox[{"\[Lambda]", " ", "gc", " ", "\[Theta]WS"}], ",", 
     RowBox[{"-", "B0"}], ",", 
     RowBox[{"-", "B1"}], ",", "n", ",", "\[Epsilon]SW", ",", "kDSW"}], 
    "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.5642530972076693`*^9, 3.56425311052999*^9}, {
   3.564254457800436*^9, 3.5642545496593018`*^9}, {3.56425459156068*^9, 
   3.56425459399196*^9}, {3.564254634237797*^9, 3.5642546887869997`*^9}, {
   3.564257531081271*^9, 3.564257589115464*^9}, {3.564257943994001*^9, 
   3.564257944786811*^9}, {3.564465084548792*^9, 3.564465150196624*^9}, 
   3.5644678667669373`*^9, 3.564477811385539*^9, {3.564939407978381*^9, 
   3.564939495027536*^9}, {3.565004756753952*^9, 3.565004757549827*^9}, {
   3.567834181390832*^9, 3.567834367994503*^9}, {3.59350721307375*^9, 
   3.593507259568873*^9}, {3.593507354294498*^9, 3.5935073670388727`*^9}, {
   3.593507400023406*^9, 3.5935074474350157`*^9}, {3.593533112060301*^9, 
   3.5935331147870493`*^9}, {3.648657137489126*^9, 3.6486571382767467`*^9}, 
   3.6486572463290358`*^9, {3.648657286364149*^9, 3.648657363267305*^9}, {
   3.648657398238558*^9, 3.648657409100986*^9}, {3.648657464707488*^9, 
   3.64865751331285*^9}, {3.648659173447056*^9, 3.648659184732718*^9}, {
   3.648659435849464*^9, 3.648659525365068*^9}, {3.648660836217085*^9, 
   3.648660882478476*^9}, {3.653379292155739*^9, 3.653379409179509*^9}, {
   3.6533805297896147`*^9, 3.653380535121422*^9}, {3.672046306529652*^9, 
   3.67204630880895*^9}, {3.672046445131188*^9, 3.6720464560414953`*^9}, {
   3.7032222241863613`*^9, 3.703222235917091*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["gBGC and SCU", "Subsubsection",
 CellChangeTimes->{{3.703222264771784*^9, 3.703222268145718*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"logLikBS0err3", "[", 
   RowBox[{
   "n_", ",", "\[Theta]NN_", ",", "\[Theta]WSN_", ",", "\[Theta]SWN_", ",", 
    "\[Theta]NUP_", ",", "\[Theta]WSUP_", ",", "\[Theta]SWUP_", ",", 
    "\[Theta]NPU_", ",", "\[Theta]WSPU_", ",", "\[Theta]SWPU_", ",", "r__", 
    ",", "\[Epsilon]_", ",", "\[Epsilon]WS_", ",", "\[Epsilon]SW_", ",", 
    "kNN__", ",", "kWSN__", ",", "kSWN__", ",", "kNUP__", ",", "kWSUP__", ",",
     "kSWUP__", ",", "kNPU__", ",", "kWSPU__", ",", "kSWPU__"}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnullerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]NN", " ", "r"}], ",", 
        RowBox[{"\[Theta]NN", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]", ",", 
        "\[Epsilon]", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kNN"}], "]"}], "]"}]}], "]"}], 
   "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnullerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]WSN", " ", "r"}], ",", 
        RowBox[{"\[Theta]SWN", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]WS", ",", 
        "\[Epsilon]SW", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWSN"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnullerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]SWN", " ", "r"}], ",", 
        RowBox[{"\[Theta]WSN", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]SW", ",", 
        "\[Epsilon]WS", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSWN"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnullerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]NUP", " ", "r"}], ",", 
        RowBox[{"\[Theta]NPU", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]", ",", 
        "\[Epsilon]", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kNUP"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnullerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]WSUP", " ", "r"}], ",", 
        RowBox[{"\[Theta]SWPU", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]WS", ",", 
        "\[Epsilon]SW", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWSUP"}], "]"}], "]"}]}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnullerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]SWUP", " ", "r"}], ",", 
        RowBox[{"\[Theta]WSPU", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]SW", ",", 
        "\[Epsilon]WS", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSWUP"}], "]"}], "]"}]}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnullerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]NPU", " ", "r"}], ",", 
        RowBox[{"\[Theta]NUP", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]", ",", 
        "\[Epsilon]", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kNPU"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnullerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]WSPU", " ", "r"}], ",", 
        RowBox[{"\[Theta]SWUP", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]WS", ",", 
        "\[Epsilon]SW", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWSPU"}], "]"}], "]"}]}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnullerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]SWPU", " ", "r"}], ",", 
        RowBox[{"\[Theta]WSUP", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]SW", ",", 
        "\[Epsilon]WS", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSWPU"}], "]"}], "]"}]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"logLikBS1Berr3", "[", 
   RowBox[{
   "n_", ",", "\[Theta]NN_", ",", "\[Theta]WSN_", ",", "\[Theta]SWN_", ",", 
    "\[Theta]NUP_", ",", "\[Theta]WSUP_", ",", "\[Theta]SWUP_", ",", 
    "\[Theta]NPU_", ",", "\[Theta]WSPU_", ",", "\[Theta]SWPU_", ",", "B_", 
    ",", "r__", ",", "\[Epsilon]_", ",", "\[Epsilon]WS_", ",", 
    "\[Epsilon]SW_", ",", "kNN__", ",", "kWSN__", ",", "kSWN__", ",", 
    "kNUP__", ",", "kWSUP__", ",", "kSWUP__", ",", "kNPU__", ",", "kWSPU__", 
    ",", "kSWPU__"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnullerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]NN", " ", "r"}], ",", 
        RowBox[{"\[Theta]NN", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]", ",", 
        "\[Epsilon]", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kNN"}], "]"}], "]"}]}], "]"}], 
   "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLBerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]WSN", " ", "r"}], ",", 
        RowBox[{"\[Theta]SWN", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", "B", ",", "\[Epsilon]WS", 
        ",", "\[Epsilon]SW", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWSN"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLBerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]SWN", " ", "r"}], ",", 
        RowBox[{"\[Theta]WSN", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", 
        RowBox[{"-", "B"}], ",", "\[Epsilon]SW", ",", "\[Epsilon]WS", ",", 
        "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSWN"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnullerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]NUP", " ", "r"}], ",", 
        RowBox[{"\[Theta]NPU", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]", ",", 
        "\[Epsilon]", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kNUP"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLBerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]WSUP", " ", "r"}], ",", 
        RowBox[{"\[Theta]SWPU", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", "B", ",", "\[Epsilon]WS", 
        ",", "\[Epsilon]SW", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWSUP"}], "]"}], "]"}]}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLBerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]SWUP", " ", "r"}], ",", 
        RowBox[{"\[Theta]WSPU", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", 
        RowBox[{"-", "B"}], ",", "\[Epsilon]SW", ",", "\[Epsilon]WS", ",", 
        "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSWUP"}], "]"}], "]"}]}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnullerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]NPU", " ", "r"}], ",", 
        RowBox[{"\[Theta]NUP", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]", ",", 
        "\[Epsilon]", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kNPU"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLBerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]WSPU", " ", "r"}], ",", 
        RowBox[{"\[Theta]SWUP", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", "B", ",", "\[Epsilon]WS", 
        ",", "\[Epsilon]SW", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWSPU"}], "]"}], "]"}]}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLBerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]SWPU", " ", "r"}], ",", 
        RowBox[{"\[Theta]WSUP", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", 
        RowBox[{"-", "B"}], ",", "\[Epsilon]SW", ",", "\[Epsilon]WS", ",", 
        "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSWPU"}], "]"}], "]"}]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"logLikBS1Serr3", "[", 
   RowBox[{
   "n_", ",", "\[Theta]NN_", ",", "\[Theta]WSN_", ",", "\[Theta]SWN_", ",", 
    "\[Theta]NUP_", ",", "\[Theta]WSUP_", ",", "\[Theta]SWUP_", ",", 
    "\[Theta]NPU_", ",", "\[Theta]WSPU_", ",", "\[Theta]SWPU_", ",", "S_", 
    ",", "r__", ",", "\[Epsilon]_", ",", "\[Epsilon]WS_", ",", 
    "\[Epsilon]SW_", ",", "kNN__", ",", "kWSN__", ",", "kSWN__", ",", 
    "kNUP__", ",", "kWSUP__", ",", "kSWUP__", ",", "kNPU__", ",", "kWSPU__", 
    ",", "kSWPU__"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnullerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]NN", " ", "r"}], ",", 
        RowBox[{"\[Theta]NN", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]", ",", 
        "\[Epsilon]", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kNN"}], "]"}], "]"}]}], "]"}], 
   "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnullerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]WSN", " ", "r"}], ",", 
        RowBox[{"\[Theta]SWN", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]WS", ",", 
        "\[Epsilon]SW", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWSN"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnullerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]SWN", " ", "r"}], ",", 
        RowBox[{"\[Theta]WSN", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]SW", ",", 
        "\[Epsilon]WS", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSWN"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLBerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]NUP", " ", "r"}], ",", 
        RowBox[{"\[Theta]NPU", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", "S", ",", "\[Epsilon]", 
        ",", "\[Epsilon]", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kNUP"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLBerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]WSUP", " ", "r"}], ",", 
        RowBox[{"\[Theta]SWPU", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", "S", ",", "\[Epsilon]WS", 
        ",", "\[Epsilon]SW", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWSUP"}], "]"}], "]"}]}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLBerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]SWUP", " ", "r"}], ",", 
        RowBox[{"\[Theta]WSPU", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", "S", ",", "\[Epsilon]SW", 
        ",", "\[Epsilon]WS", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSWUP"}], "]"}], "]"}]}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLBerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]NPU", " ", "r"}], ",", 
        RowBox[{"\[Theta]NUP", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", 
        RowBox[{"-", "S"}], ",", "\[Epsilon]", ",", "\[Epsilon]", ",", "n", 
        ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kNPU"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLBerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]WSPU", " ", "r"}], ",", 
        RowBox[{"\[Theta]SWUP", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", 
        RowBox[{"-", "S"}], ",", "\[Epsilon]WS", ",", "\[Epsilon]SW", ",", 
        "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWSPU"}], "]"}], "]"}]}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLBerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]SWPU", " ", "r"}], ",", 
        RowBox[{"\[Theta]WSUP", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", 
        RowBox[{"-", "S"}], ",", "\[Epsilon]SW", ",", "\[Epsilon]WS", ",", 
        "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSWPU"}], "]"}], "]"}]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"logLikBS2err3", "[", 
   RowBox[{
   "n_", ",", "\[Theta]NN_", ",", "\[Theta]WSN_", ",", "\[Theta]SWN_", ",", 
    "\[Theta]NUP_", ",", "\[Theta]WSUP_", ",", "\[Theta]SWUP_", ",", 
    "\[Theta]NPU_", ",", "\[Theta]WSPU_", ",", "\[Theta]SWPU_", ",", "B_", 
    ",", "S_", ",", "r__", ",", "\[Epsilon]_", ",", "\[Epsilon]WS_", ",", 
    "\[Epsilon]SW_", ",", "kNN__", ",", "kWSN__", ",", "kSWN__", ",", 
    "kNUP__", ",", "kWSUP__", ",", "kSWUP__", ",", "kNPU__", ",", "kWSPU__", 
    ",", "kSWPU__"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnullerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]NN", " ", "r"}], ",", 
        RowBox[{"\[Theta]NN", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]", ",", 
        "\[Epsilon]", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kNN"}], "]"}], "]"}]}], "]"}], 
   "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLBerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]WSN", " ", "r"}], ",", 
        RowBox[{"\[Theta]SWN", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", "B", ",", "\[Epsilon]WS", 
        ",", "\[Epsilon]SW", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWSN"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLBerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]SWN", " ", "r"}], ",", 
        RowBox[{"\[Theta]WSN", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", 
        RowBox[{"-", "B"}], ",", "\[Epsilon]SW", ",", "\[Epsilon]WS", ",", 
        "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSWN"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLBerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]NUP", " ", "r"}], ",", 
        RowBox[{"\[Theta]NPU", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", "S", ",", "\[Epsilon]", 
        ",", "\[Epsilon]", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kNUP"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLBerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]WSUP", " ", "r"}], ",", 
        RowBox[{"\[Theta]SWPU", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", 
        RowBox[{"B", "+", "S"}], ",", "\[Epsilon]WS", ",", "\[Epsilon]SW", 
        ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWSUP"}], "]"}], "]"}]}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLBerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]SWUP", " ", "r"}], ",", 
        RowBox[{"\[Theta]WSPU", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", "B"}], "+", "S"}], ",", "\[Epsilon]SW", ",", 
        "\[Epsilon]WS", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSWUP"}], "]"}], "]"}]}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLBerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]NPU", " ", "r"}], ",", 
        RowBox[{"\[Theta]NUP", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", 
        RowBox[{"-", "S"}], ",", "\[Epsilon]", ",", "\[Epsilon]", ",", "n", 
        ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kNPU"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLBerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]WSPU", " ", "r"}], ",", 
        RowBox[{"\[Theta]SWUP", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", 
        RowBox[{"B", "-", "S"}], ",", "\[Epsilon]WS", ",", "\[Epsilon]SW", 
        ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWSPU"}], "]"}], "]"}]}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLBerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]SWPU", " ", "r"}], ",", 
        RowBox[{"\[Theta]WSUP", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", "B"}], "-", "S"}], ",", "\[Epsilon]SW", ",", 
        "\[Epsilon]WS", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSWPU"}], "]"}], "]"}]}], 
    "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.6016562501979713`*^9, 3.601656365543172*^9}, {
  3.601656429762993*^9, 3.6016570955125523`*^9}, {3.60241520128758*^9, 
  3.602415210860565*^9}, {3.6024153490792933`*^9, 3.6024153571412888`*^9}, {
  3.602415389576251*^9, 3.602415395830221*^9}, {3.6024154858389177`*^9, 
  3.602415491248251*^9}, {3.602415521849959*^9, 3.602415543696472*^9}, {
  3.602415744894446*^9, 3.6024157901213284`*^9}, {3.6024158642539797`*^9, 
  3.602415913355831*^9}, {3.602415944554319*^9, 3.602416028240237*^9}, {
  3.602416080406292*^9, 3.602416192515173*^9}, {3.6024169055515413`*^9, 
  3.6024169302327538`*^9}, {3.602417241897287*^9, 3.602417250956553*^9}}],

Cell["Similar models including divergence", "Text",
 CellChangeTimes->{{3.653320475723403*^9, 3.653320484602581*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"logLikDBS0err3", "[", 
    RowBox[{
    "n_", ",", "\[Theta]NN_", ",", "\[Theta]WSN_", ",", "\[Theta]SWN_", ",", 
     "\[Theta]NUP_", ",", "\[Theta]WSUP_", ",", "\[Theta]SWUP_", ",", 
     "\[Theta]NPU_", ",", "\[Theta]WSPU_", ",", "\[Theta]SWPU_", ",", 
     "\[Tau]NN_", ",", "\[Tau]WSN_", ",", "\[Tau]SWN_", ",", "\[Tau]NUP_", 
     ",", "\[Tau]WSUP_", ",", "\[Tau]SWUP_", ",", "\[Tau]NPU_", ",", 
     "\[Tau]WSPU_", ",", "\[Tau]SWPU_", ",", "r__", ",", "\[Epsilon]_", ",", 
     "\[Epsilon]WS_", ",", "\[Epsilon]SW_", ",", "kNN__", ",", "kWSN__", ",", 
     "kSWN__", ",", "kNUP__", ",", "kWSUP__", ",", "kSWUP__", ",", "kNPU__", 
     ",", "kWSPU__", ",", "kSWPU__", ",", "kDNN_", ",", "kDWSN_", ",", 
     "kDSWN_", ",", "kDNUP_", ",", "kDWSUP_", ",", "kDSWUP_", ",", "kDNPU_", 
     ",", "kDWSPU_", ",", "kDSWPU_"}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnullerr", "[", 
        RowBox[{
         RowBox[{"\[Theta]NN", " ", "r"}], ",", 
         RowBox[{"\[Theta]NN", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]", ",", 
         "\[Epsilon]", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kNN"}], "]"}], "]"}]}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnullerr", "[", 
        RowBox[{
         RowBox[{"\[Theta]WSN", " ", "r"}], ",", 
         RowBox[{"\[Theta]SWN", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]WS", ",", 
         "\[Epsilon]SW", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kWSN"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnullerr", "[", 
        RowBox[{
         RowBox[{"\[Theta]SWN", " ", "r"}], ",", 
         RowBox[{"\[Theta]WSN", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]SW", ",", 
         "\[Epsilon]WS", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kSWN"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnullerr", "[", 
        RowBox[{
         RowBox[{"\[Theta]NUP", " ", "r"}], ",", 
         RowBox[{"\[Theta]NPU", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]", ",", 
         "\[Epsilon]", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kNUP"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnullerr", "[", 
        RowBox[{
         RowBox[{"\[Theta]WSUP", " ", "r"}], ",", 
         RowBox[{"\[Theta]SWPU", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]WS", ",", 
         "\[Epsilon]SW", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kWSUP"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnullerr", "[", 
        RowBox[{
         RowBox[{"\[Theta]SWUP", " ", "r"}], ",", 
         RowBox[{"\[Theta]WSPU", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]SW", ",", 
         "\[Epsilon]WS", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kSWUP"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnullerr", "[", 
        RowBox[{
         RowBox[{"\[Theta]NPU", " ", "r"}], ",", 
         RowBox[{"\[Theta]NUP", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]", ",", 
         "\[Epsilon]", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kNPU"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnullerr", "[", 
        RowBox[{
         RowBox[{"\[Theta]WSPU", " ", "r"}], ",", 
         RowBox[{"\[Theta]SWUP", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]WS", ",", 
         "\[Epsilon]SW", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kWSPU"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnullerr", "[", 
        RowBox[{
         RowBox[{"\[Theta]SWPU", " ", "r"}], ",", 
         RowBox[{"\[Theta]WSUP", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]SW", ",", 
         "\[Epsilon]WS", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kSWPU"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDnullerr", "[", 
     RowBox[{
     "\[Tau]NN", ",", "\[Theta]NN", ",", "n", ",", "\[Epsilon]", ",", 
      "kDNN"}], "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDnullerr", "[", 
     RowBox[{
     "\[Tau]WSN", ",", "\[Theta]WSN", ",", "n", ",", "\[Epsilon]WS", ",", 
      "kDWSN"}], "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDnullerr", "[", 
     RowBox[{
     "\[Tau]SWN", ",", "\[Theta]SWN", ",", "n", ",", "\[Epsilon]SW", ",", 
      "kDSWN"}], "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDnullerr", "[", 
     RowBox[{
     "\[Tau]NUP", ",", "\[Theta]NUP", ",", "n", ",", "\[Epsilon]", ",", 
      "kDNUP"}], "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDnullerr", "[", 
     RowBox[{
     "\[Tau]WSUP", ",", "\[Theta]WSUP", ",", "n", ",", "\[Epsilon]WS", ",", 
      "kDWSUP"}], "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDnullerr", "[", 
     RowBox[{
     "\[Tau]SWUP", ",", "\[Theta]SWUP", ",", "n", ",", "\[Epsilon]SW", ",", 
      "kDSWUP"}], "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDnullerr", "[", 
     RowBox[{
     "\[Tau]NPU", ",", "\[Theta]NPU", ",", "n", ",", "\[Epsilon]", ",", 
      "kDNPU"}], "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDnullerr", "[", 
     RowBox[{
     "\[Tau]WSPU", ",", "\[Theta]WSPU", ",", "n", ",", "\[Epsilon]WS", ",", 
      "kDWSPU"}], "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDnullerr", "[", 
     RowBox[{
     "\[Tau]SWPU", ",", "\[Theta]SWPU", ",", "n", ",", "\[Epsilon]SW", ",", 
      "kDSWPU"}], "]"}]}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"logLikDBS1Berr3", "[", 
    RowBox[{
    "n_", ",", "\[Theta]NN_", ",", "\[Theta]WSN_", ",", "\[Theta]SWN_", ",", 
     "\[Theta]NUP_", ",", "\[Theta]WSUP_", ",", "\[Theta]SWUP_", ",", 
     "\[Theta]NPU_", ",", "\[Theta]WSPU_", ",", "\[Theta]SWPU_", ",", 
     "\[Tau]NN_", ",", "\[Tau]WSN_", ",", "\[Tau]SWN_", ",", "\[Tau]NUP_", 
     ",", "\[Tau]WSUP_", ",", "\[Tau]SWUP_", ",", "\[Tau]NPU_", ",", 
     "\[Tau]WSPU_", ",", "\[Tau]SWPU_", ",", "B0_", ",", "B1_", ",", "r__", 
     ",", "\[Epsilon]_", ",", "\[Epsilon]WS_", ",", "\[Epsilon]SW_", ",", 
     "kNN__", ",", "kWSN__", ",", "kSWN__", ",", "kNUP__", ",", "kWSUP__", 
     ",", "kSWUP__", ",", "kNPU__", ",", "kWSPU__", ",", "kSWPU__", ",", 
     "kDNN_", ",", "kDWSN_", ",", "kDSWN_", ",", "kDNUP_", ",", "kDWSUP_", 
     ",", "kDSWUP_", ",", "kDNPU_", ",", "kDWSPU_", ",", "kDSWPU_"}], "]"}], ":=",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnullerr", "[", 
        RowBox[{
         RowBox[{"\[Theta]NN", " ", "r"}], ",", 
         RowBox[{"\[Theta]NN", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]", ",", 
         "\[Epsilon]", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kNN"}], "]"}], "]"}]}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLBerr", "[", 
        RowBox[{
         RowBox[{"\[Theta]WSN", " ", "r"}], ",", 
         RowBox[{"\[Theta]SWN", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", "B1", ",", 
         "\[Epsilon]WS", ",", "\[Epsilon]SW", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kWSN"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLBerr", "[", 
        RowBox[{
         RowBox[{"\[Theta]SWN", " ", "r"}], ",", 
         RowBox[{"\[Theta]WSN", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", 
         RowBox[{"-", "B1"}], ",", "\[Epsilon]SW", ",", "\[Epsilon]WS", ",", 
         "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kSWN"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnullerr", "[", 
        RowBox[{
         RowBox[{"\[Theta]NUP", " ", "r"}], ",", 
         RowBox[{"\[Theta]NPU", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]", ",", 
         "\[Epsilon]", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kNUP"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLBerr", "[", 
        RowBox[{
         RowBox[{"\[Theta]WSUP", " ", "r"}], ",", 
         RowBox[{"\[Theta]SWPU", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", "B1", ",", 
         "\[Epsilon]WS", ",", "\[Epsilon]SW", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kWSUP"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLBerr", "[", 
        RowBox[{
         RowBox[{"\[Theta]SWUP", " ", "r"}], ",", 
         RowBox[{"\[Theta]WSPU", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", 
         RowBox[{"-", "B1"}], ",", "\[Epsilon]SW", ",", "\[Epsilon]WS", ",", 
         "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kSWUP"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnullerr", "[", 
        RowBox[{
         RowBox[{"\[Theta]NPU", " ", "r"}], ",", 
         RowBox[{"\[Theta]NUP", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]", ",", 
         "\[Epsilon]", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kNPU"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLBerr", "[", 
        RowBox[{
         RowBox[{"\[Theta]WSPU", " ", "r"}], ",", 
         RowBox[{"\[Theta]SWUP", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", "B1", ",", 
         "\[Epsilon]WS", ",", "\[Epsilon]SW", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kWSPU"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLBerr", "[", 
        RowBox[{
         RowBox[{"\[Theta]SWPU", " ", "r"}], ",", 
         RowBox[{"\[Theta]WSUP", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", 
         RowBox[{"-", "B1"}], ",", "\[Epsilon]SW", ",", "\[Epsilon]WS", ",", 
         "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kSWPU"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDnullerr", "[", 
     RowBox[{
     "\[Tau]NN", ",", "\[Theta]NN", ",", "n", ",", "\[Epsilon]", ",", 
      "kDNN"}], "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDBerr", "[", 
     RowBox[{
     "\[Tau]WSN", ",", "\[Theta]WSN", ",", "B0", ",", "B1", ",", "n", ",", 
      "\[Epsilon]WS", ",", "kDWSN"}], "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDBerr", "[", 
     RowBox[{"\[Tau]SWN", ",", "\[Theta]SWN", ",", 
      RowBox[{"-", "B0"}], ",", 
      RowBox[{"-", "B1"}], ",", "n", ",", "\[Epsilon]SW", ",", "kDSWN"}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDnullerr", "[", 
     RowBox[{
     "\[Tau]NUP", ",", "\[Theta]NUP", ",", "n", ",", "\[Epsilon]", ",", 
      "kDNUP"}], "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDBerr", "[", 
     RowBox[{
     "\[Tau]WSUP", ",", "\[Theta]WSUP", ",", "B0", ",", "B1", ",", "n", ",", 
      "\[Epsilon]WS", ",", "kDWSUP"}], "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDBerr", "[", 
     RowBox[{"\[Tau]SWUP", ",", "\[Theta]SWUP", ",", 
      RowBox[{"-", "B0"}], ",", 
      RowBox[{"-", "B1"}], ",", "n", ",", "\[Epsilon]SW", ",", "kDSWUP"}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDnullerr", "[", 
     RowBox[{
     "\[Tau]NPU", ",", "\[Theta]NPU", ",", "n", ",", "\[Epsilon]", ",", 
      "kDNPU"}], "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDBerr", "[", 
     RowBox[{
     "\[Tau]WSPU", ",", "\[Theta]WSPU", ",", "B0", ",", "B1", ",", "n", ",", 
      "\[Epsilon]WS", ",", "kDWSPU"}], "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDBerr", "[", 
     RowBox[{"\[Tau]SWPU", ",", "\[Theta]SWPU", ",", 
      RowBox[{"-", "B0"}], ",", 
      RowBox[{"-", "B1"}], ",", "n", ",", "\[Epsilon]SW", ",", "kDSWPU"}], 
     "]"}]}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"logLikDBS1Serr3", "[", 
    RowBox[{
    "n_", ",", "\[Theta]NN_", ",", "\[Theta]WSN_", ",", "\[Theta]SWN_", ",", 
     "\[Theta]NUP_", ",", "\[Theta]WSUP_", ",", "\[Theta]SWUP_", ",", 
     "\[Theta]NPU_", ",", "\[Theta]WSPU_", ",", "\[Theta]SWPU_", ",", 
     "\[Tau]NN_", ",", "\[Tau]WSN_", ",", "\[Tau]SWN_", ",", "\[Tau]NUP_", 
     ",", "\[Tau]WSUP_", ",", "\[Tau]SWUP_", ",", "\[Tau]NPU_", ",", 
     "\[Tau]WSPU_", ",", "\[Tau]SWPU_", ",", "S0_", ",", "S1_", ",", "r__", 
     ",", "\[Epsilon]_", ",", "\[Epsilon]WS_", ",", "\[Epsilon]SW_", ",", 
     "kNN__", ",", "kWSN__", ",", "kSWN__", ",", "kNUP__", ",", "kWSUP__", 
     ",", "kSWUP__", ",", "kNPU__", ",", "kWSPU__", ",", "kSWPU__", ",", 
     "kDNN_", ",", "kDWSN_", ",", "kDSWN_", ",", "kDNUP_", ",", "kDWSUP_", 
     ",", "kDSWUP_", ",", "kDNPU_", ",", "kDWSPU_", ",", "kDSWPU_"}], "]"}], ":=",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnullerr", "[", 
        RowBox[{
         RowBox[{"\[Theta]NN", " ", "r"}], ",", 
         RowBox[{"\[Theta]NN", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]", ",", 
         "\[Epsilon]", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kNN"}], "]"}], "]"}]}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnullerr", "[", 
        RowBox[{
         RowBox[{"\[Theta]WSN", " ", "r"}], ",", 
         RowBox[{"\[Theta]SWN", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]WS", ",", 
         "\[Epsilon]SW", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kWSN"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLnullerr", "[", 
        RowBox[{
         RowBox[{"\[Theta]SWN", " ", "r"}], ",", 
         RowBox[{"\[Theta]WSN", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]SW", ",", 
         "\[Epsilon]WS", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kSWN"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLBerr", "[", 
        RowBox[{
         RowBox[{"\[Theta]NUP", " ", "r"}], ",", 
         RowBox[{"\[Theta]NPU", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", "S1", ",", "\[Epsilon]", 
         ",", "\[Epsilon]", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kNUP"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLBerr", "[", 
        RowBox[{
         RowBox[{"\[Theta]WSUP", " ", "r"}], ",", 
         RowBox[{"\[Theta]SWPU", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", "S1", ",", 
         "\[Epsilon]WS", ",", "\[Epsilon]SW", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kWSUP"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLBerr", "[", 
        RowBox[{
         RowBox[{"\[Theta]SWUP", " ", "r"}], ",", 
         RowBox[{"\[Theta]WSPU", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", "S1", ",", 
         "\[Epsilon]SW", ",", "\[Epsilon]WS", ",", "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kSWUP"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLBerr", "[", 
        RowBox[{
         RowBox[{"\[Theta]NPU", " ", "r"}], ",", 
         RowBox[{"\[Theta]NUP", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", 
         RowBox[{"-", "S1"}], ",", "\[Epsilon]", ",", "\[Epsilon]", ",", "n", 
         ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kNPU"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLBerr", "[", 
        RowBox[{
         RowBox[{"\[Theta]WSPU", " ", "r"}], ",", 
         RowBox[{"\[Theta]SWUP", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", 
         RowBox[{"-", "S1"}], ",", "\[Epsilon]WS", ",", "\[Epsilon]SW", ",", 
         "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kWSPU"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLBerr", "[", 
        RowBox[{
         RowBox[{"\[Theta]SWPU", " ", "r"}], ",", 
         RowBox[{"\[Theta]WSUP", " ", 
          RowBox[{"Reverse", "[", "r", "]"}]}], ",", 
         RowBox[{"-", "S1"}], ",", "\[Epsilon]SW", ",", "\[Epsilon]WS", ",", 
         "n", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", "1"}], "]"}], ",", "kSWPU"}], "]"}], "]"}]}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDnullerr", "[", 
     RowBox[{
     "\[Tau]NN", ",", "\[Theta]NN", ",", "n", ",", "\[Epsilon]", ",", 
      "kDNN"}], "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDnullerr", "[", 
     RowBox[{
     "\[Tau]WSN", ",", "\[Theta]WSN", ",", "n", ",", "\[Epsilon]WS", ",", 
      "kDWSN"}], "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDnullerr", "[", 
     RowBox[{
     "\[Tau]SWN", ",", "\[Theta]SWN", ",", "n", ",", "\[Epsilon]SW", ",", 
      "kDSWN"}], "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDBerr", "[", 
     RowBox[{
     "\[Tau]NUP", ",", "\[Theta]NUP", ",", "S0", ",", "S1", ",", "n", ",", 
      "\[Epsilon]", ",", "kDNUP"}], "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDBerr", "[", 
     RowBox[{
     "\[Tau]WSUP", ",", "\[Theta]WSUP", ",", "S0", ",", "S1", ",", "n", ",", 
      "\[Epsilon]WS", ",", "kDWSUP"}], "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDBerr", "[", 
     RowBox[{
     "\[Tau]SWUP", ",", "\[Theta]SWUP", ",", "S0", ",", "S1", ",", "n", ",", 
      "\[Epsilon]SW", ",", "kDSWUP"}], "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDBerr", "[", 
     RowBox[{"\[Tau]NPU", ",", "\[Theta]NPU", ",", 
      RowBox[{"-", "S0"}], ",", 
      RowBox[{"-", "S1"}], ",", "n", ",", "\[Epsilon]", ",", "kDNPU"}], "]"}],
     "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDBerr", "[", 
     RowBox[{"\[Tau]WSPU", ",", "\[Theta]WSPU", ",", 
      RowBox[{"-", "S0"}], ",", 
      RowBox[{"-", "S1"}], ",", "n", ",", "\[Epsilon]WS", ",", "kDWSPU"}], 
     "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"lnLDBerr", "[", 
     RowBox[{"\[Tau]SWPU", ",", "\[Theta]SWPU", ",", 
      RowBox[{"-", "S0"}], ",", 
      RowBox[{"-", "S1"}], ",", "n", ",", "\[Epsilon]SW", ",", "kDSWPU"}], 
     "]"}]}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"logLikDBS2err3", "[", 
   RowBox[{
   "n_", ",", "\[Theta]NN_", ",", "\[Theta]WSN_", ",", "\[Theta]SWN_", ",", 
    "\[Theta]NUP_", ",", "\[Theta]WSUP_", ",", "\[Theta]SWUP_", ",", 
    "\[Theta]NPU_", ",", "\[Theta]WSPU_", ",", "\[Theta]SWPU_", ",", 
    "\[Tau]NN_", ",", "\[Tau]WSN_", ",", "\[Tau]SWN_", ",", "\[Tau]NUP_", ",",
     "\[Tau]WSUP_", ",", "\[Tau]SWUP_", ",", "\[Tau]NPU_", ",", "\[Tau]WSPU_",
     ",", "\[Tau]SWPU_", ",", "B0_", ",", "B1_", ",", "S0_", ",", "S1_", ",", 
    "r__", ",", "\[Epsilon]_", ",", "\[Epsilon]WS_", ",", "\[Epsilon]SW_", 
    ",", "kNN__", ",", "kWSN__", ",", "kSWN__", ",", "kNUP__", ",", "kWSUP__",
     ",", "kSWUP__", ",", "kNPU__", ",", "kWSPU__", ",", "kSWPU__", ",", 
    "kDNN_", ",", "kDWSN_", ",", "kDSWN_", ",", "kDNUP_", ",", "kDWSUP_", ",",
     "kDSWUP_", ",", "kDNPU_", ",", "kDWSPU_", ",", "kDSWPU_"}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLnullerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]NN", " ", "r"}], ",", 
        RowBox[{"\[Theta]NN", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", "\[Epsilon]", ",", 
        "\[Epsilon]", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kNN"}], "]"}], "]"}]}], "]"}], 
   "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLBerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]WSN", " ", "r"}], ",", 
        RowBox[{"\[Theta]SWN", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", "B1", ",", "\[Epsilon]WS",
         ",", "\[Epsilon]SW", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWSN"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLBerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]SWN", " ", "r"}], ",", 
        RowBox[{"\[Theta]WSN", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", 
        RowBox[{"-", "B1"}], ",", "\[Epsilon]SW", ",", "\[Epsilon]WS", ",", 
        "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSWN"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLBerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]NUP", " ", "r"}], ",", 
        RowBox[{"\[Theta]NPU", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", "S1", ",", "\[Epsilon]", 
        ",", "\[Epsilon]", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kNUP"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLBerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]WSUP", " ", "r"}], ",", 
        RowBox[{"\[Theta]SWPU", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", 
        RowBox[{"B1", "+", "S1"}], ",", "\[Epsilon]WS", ",", "\[Epsilon]SW", 
        ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWSUP"}], "]"}], "]"}]}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLBerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]SWUP", " ", "r"}], ",", 
        RowBox[{"\[Theta]WSPU", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", "B1"}], "+", "S1"}], ",", "\[Epsilon]SW", ",", 
        "\[Epsilon]WS", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSWUP"}], "]"}], "]"}]}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLBerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]NPU", " ", "r"}], ",", 
        RowBox[{"\[Theta]NUP", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", 
        RowBox[{"-", "S1"}], ",", "\[Epsilon]", ",", "\[Epsilon]", ",", "n", 
        ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kNPU"}], "]"}], "]"}]}], "]"}],
    "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLBerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]WSPU", " ", "r"}], ",", 
        RowBox[{"\[Theta]SWUP", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", 
        RowBox[{"B1", "-", "S1"}], ",", "\[Epsilon]WS", ",", "\[Epsilon]SW", 
        ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kWSPU"}], "]"}], "]"}]}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"lnLBerr", "[", 
       RowBox[{
        RowBox[{"\[Theta]SWPU", " ", "r"}], ",", 
        RowBox[{"\[Theta]WSUP", " ", 
         RowBox[{"Reverse", "[", "r", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", "B1"}], "-", "S1"}], ",", "\[Epsilon]SW", ",", 
        "\[Epsilon]WS", ",", "n", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"n", "-", "1"}], "]"}], ",", "kSWPU"}], "]"}], "]"}]}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"lnLDnullerr", "[", 
    RowBox[{
    "\[Tau]NN", ",", "\[Theta]NN", ",", "n", ",", "\[Epsilon]", ",", "kDNN"}],
     "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"lnLDBerr", "[", 
    RowBox[{
    "\[Tau]WSN", ",", "\[Theta]WSN", ",", "B0", ",", "B1", ",", "n", ",", 
     "\[Epsilon]WS", ",", "kDWSN"}], "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"lnLDBerr", "[", 
    RowBox[{"\[Tau]SWN", ",", "\[Theta]SWN", ",", 
     RowBox[{"-", "B0"}], ",", 
     RowBox[{"-", "B1"}], ",", "n", ",", "\[Epsilon]SW", ",", "kDSWN"}], 
    "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"lnLDBerr", "[", 
    RowBox[{
    "\[Tau]NUP", ",", "\[Theta]NUP", ",", "S0", ",", "S1", ",", "n", ",", 
     "\[Epsilon]", ",", "kDNUP"}], "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"lnLDBerr", "[", 
    RowBox[{"\[Tau]WSUP", ",", "\[Theta]WSUP", ",", 
     RowBox[{"B0", "+", "S0"}], ",", 
     RowBox[{"B1", "+", "S1"}], ",", "n", ",", "\[Epsilon]WS", ",", 
     "kDWSUP"}], "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"lnLDBerr", "[", 
    RowBox[{"\[Tau]SWUP", ",", "\[Theta]SWUP", ",", 
     RowBox[{
      RowBox[{"-", "B0"}], "+", "S0"}], ",", 
     RowBox[{
      RowBox[{"-", "B1"}], "+", "S1"}], ",", "n", ",", "\[Epsilon]SW", ",", 
     "kDSWUP"}], "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"lnLDBerr", "[", 
    RowBox[{"\[Tau]NPU", ",", "\[Theta]NPU", ",", 
     RowBox[{"-", "S0"}], ",", 
     RowBox[{"-", "S1"}], ",", "n", ",", "\[Epsilon]", ",", "kDNPU"}], "]"}], 
   "+", "\[IndentingNewLine]", 
   RowBox[{"lnLDBerr", "[", 
    RowBox[{"\[Tau]WSPU", ",", "\[Theta]WSPU", ",", 
     RowBox[{"B0", "-", "S0"}], ",", 
     RowBox[{"B1", "-", "S1"}], ",", "n", ",", "\[Epsilon]WS", ",", 
     "kDWSPU"}], "]"}], "+", "\[IndentingNewLine]", 
   RowBox[{"lnLDBerr", "[", 
    RowBox[{"\[Tau]SWPU", ",", "\[Theta]SWPU", ",", 
     RowBox[{
      RowBox[{"-", "B0"}], "-", "S0"}], ",", 
     RowBox[{
      RowBox[{"-", "B1"}], "-", "S1"}], ",", "n", ",", "\[Epsilon]SW", ",", 
     "kDSWPU"}], "]"}]}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.6533193668793488`*^9, 3.653319397698556*^9}, {
   3.653319432931397*^9, 3.6533194828313437`*^9}, {3.6533195271418037`*^9, 
   3.653319564198868*^9}, {3.6533196518697357`*^9, 3.653319773320496*^9}, {
   3.653319928129047*^9, 3.6533199283091297`*^9}, {3.6533199652068367`*^9, 
   3.653320376906125*^9}, {3.653320422952791*^9, 3.653320432753284*^9}, {
   3.653320532083252*^9, 3.65332057577247*^9}, 3.653320618688018*^9, {
   3.653320661193234*^9, 3.653320820459939*^9}, {3.653320866667741*^9, 
   3.653320930669516*^9}, {3.6533209652803307`*^9, 3.653321224684012*^9}, {
   3.653408856994383*^9, 3.653409300398582*^9}, {3.6534093848326387`*^9, 
   3.653409440821931*^9}, {3.653409896578412*^9, 3.65340991291201*^9}, {
   3.653412665291288*^9, 3.6534127434313917`*^9}, {3.653413259156955*^9, 
   3.653413290565131*^9}, {3.653413386278944*^9, 3.653413387286594*^9}}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Models fitting", "Chapter",
 CellChangeTimes->{{3.683560118038097*^9, 3.683560123243195*^9}, {
  3.70322266210157*^9, 3.703222668252635*^9}}],

Cell[CellGroupData[{

Cell["Recent and past gBGC or SCU", "Section",
 CellChangeTimes->{{3.683560225916225*^9, 3.68356023939541*^9}, {
  3.703222672179199*^9, 3.703222676386546*^9}, {3.703223662349576*^9, 
  3.7032236630126257`*^9}}],

Cell["Polymorphism and divergence are used here", "Text",
 CellChangeTimes->{{3.648576934985671*^9, 3.648576943096407*^9}}],

Cell[CellGroupData[{

Cell["Dataset", "Subsection",
 CellChangeTimes->{{3.5642568869165573`*^9, 3.564256894138021*^9}, {
   3.648576919576269*^9, 3.6485769207679996`*^9}, 3.7032237419438457`*^9}],

Cell["Example:", "Text",
 CellChangeTimes->{{3.703222902951685*^9, 3.703222915190465*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"tabneutral", "=", 
   RowBox[{"{", 
    RowBox[{
    "3252", ",", "1672", ",", "1022", ",", "722", ",", "578", ",", "465", ",",
      "370", ",", "325", ",", "303", ",", "271", ",", "240", ",", "251", ",", 
     "222", ",", "222", ",", "219", ",", "240", ",", "201", ",", "212", ",", 
     "239", ",", "223", ",", "238", ",", "293", ",", "310"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tabWS", "=", 
   RowBox[{"{", 
    RowBox[{
    "3206", ",", "1660", ",", "998", ",", "690", ",", "516", ",", "442", ",", 
     "341", ",", "360", ",", "301", ",", "263", ",", "272", ",", "255", ",", 
     "240", ",", "204", ",", "216", ",", "203", ",", "185", ",", "227", ",", 
     "260", ",", "214", ",", "271", ",", "281", ",", "382"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tabSW", "=", 
   RowBox[{"{", 
    RowBox[{
    "5809", ",", "2958", ",", "1799", ",", "1238", ",", "971", ",", "768", 
     ",", "650", ",", "584", ",", "528", ",", "443", ",", "422", ",", "467", 
     ",", "370", ",", "361", ",", "384", ",", "391", ",", "330", ",", "363", 
     ",", "434", ",", "357", ",", "398", ",", "446", ",", "490"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dneutral", "=", "3826"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DWS", "=", "7342"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DSW", "=", "6422"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pGC", "=", "0.51"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Nchrom", "=", 
   RowBox[{
    RowBox[{"Length", "[", "tabneutral", "]"}], "+", "1"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tabcoef", "=", 
   RowBox[{"Union", "[", 
    RowBox[{
     RowBox[{"{", "1", "}"}], ",", 
     RowBox[{"Array", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Subscript", "[", 
         RowBox[{"r", ",", "#1"}], "]"}], "&"}], ",", 
       RowBox[{"Nchrom", "-", "2"}], ",", "2"}], "]"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7032227256961403`*^9, 3.7032228143346643`*^9}, {
   3.703222861576066*^9, 3.7032228770551233`*^9}, 3.703223089996999*^9, {
   3.703223250241126*^9, 3.703223250745459*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Skewness, NI and DoS", "Subsection",
 CellChangeTimes->{{3.653125578102325*^9, 3.65312558627919*^9}, {
  3.653408084657879*^9, 3.6534080901615267`*^9}, {3.703222918047982*^9, 
  3.703222921873023*^9}}],

Cell[CellGroupData[{

Cell["Skewness", "Subsubsection",
 CellChangeTimes->{{3.653128159813798*^9, 3.653128162905513*^9}}],

Cell["Spectrum of GC alleles", "Text",
 CellChangeTimes->{{3.7032229459041147`*^9, 3.7032229547232037`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"GCspectrum", "=", 
   RowBox[{"tabWS", "+", 
    RowBox[{"Reverse", "[", "tabSW", "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.653126312574781*^9, 3.653126326610383*^9}, {
  3.653126423881024*^9, 3.653126435614498*^9}, {3.653126557170084*^9, 
  3.653126568396399*^9}, {3.653126797447194*^9, 3.6531267993365927`*^9}, {
  3.653127065356073*^9, 3.653127068628669*^9}, {3.703222935442335*^9, 
  3.7032229391454773`*^9}, {3.703223001186323*^9, 3.703223003953549*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BarChart", "[", "GCspectrum", "]"}]], "Input",
 CellChangeTimes->{{3.703222956647092*^9, 3.703222967255781*^9}, {
  3.703223138842712*^9, 3.7032231663615294`*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {Opacity[0], PointBox[{0.07717734447539448, 0.}]}, {{}, 
    {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
     0.5389999999999999], Thickness[Small]}], 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
      0.5389999999999999], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0.5357474466109563, 0.}, {1.4642525533890436`, 
            3696.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{31.039574653390773`, 
           44.274600678722365`}, {-19.27304792960514, 98.17335224246489}}],
         StatusArea[#, 3696]& ,
         TagBoxNote->"3696"],
        StyleBox["3696", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[3696, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
      0.5389999999999999], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{1.5357474466109564`, 0.}, {2.4642525533890436`, 
            2106.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{44.7551976826729, 57.99022370800449}, {
           31.036685910652253`, 98.17335224246489}}],
         StatusArea[#, 2106]& ,
         TagBoxNote->"2106"],
        StyleBox["2106", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[2106, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
      0.5389999999999999], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{2.5357474466109564`, 0.}, {3.4642525533890436`, 
            1396.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{58.47082071195503, 71.70584673728662}, {
           53.502038757559646`, 98.17335224246489}}],
         StatusArea[#, 1396]& ,
         TagBoxNote->"1396"],
        StyleBox["1396", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[1396, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
      0.5389999999999999], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{3.5357474466109564`, 0.}, {4.464252553389044, 1047.},
             "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{72.18644374123716, 85.42146976656876}, {
           64.54486712878597, 98.17335224246489}}],
         StatusArea[#, 1047]& ,
         TagBoxNote->"1047"],
        StyleBox["1047", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[1047, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
      0.5389999999999999], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{4.535747446610957, 0.}, {5.464252553389044, 950.}, 
            "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{85.9020667705193, 99.13709279585088}, {
           67.61407730646204, 98.17335224246489}}],
         StatusArea[#, 950]& ,
         TagBoxNote->"950"],
        StyleBox["950", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[950, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
      0.5389999999999999], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{5.535747446610957, 0.}, {6.464252553389044, 805.}, 
            "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{99.61768979980141, 112.852715825133}, {
           72.20207190195721, 98.17335224246489}}],
         StatusArea[#, 805]& ,
         TagBoxNote->"805"],
        StyleBox["805", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[805, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
      0.5389999999999999], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{6.535747446610957, 0.}, {7.464252553389044, 671.}, 
            "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{113.33331282908354`, 126.56833885441513`}, {
           76.4420117350355, 98.17335224246489}}],
         StatusArea[#, 671]& ,
         TagBoxNote->"671"],
        StyleBox["671", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[671, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
      0.5389999999999999], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{7.535747446610957, 0.}, {8.464252553389045, 751.}, 
            "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{127.04893585836567`, 140.2839618836973}, {
           73.91070437200369, 98.17335224246489}}],
         StatusArea[#, 751]& ,
         TagBoxNote->"751"],
        StyleBox["751", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[751, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
      0.5389999999999999], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{8.535747446610957, 0.}, {9.464252553389045, 685.}, 
            "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{140.7645588876478, 153.9995849129794}, {
           75.99903294650494, 98.17335224246489}}],
         StatusArea[#, 685]& ,
         TagBoxNote->"685"],
        StyleBox["685", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[685, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
      0.5389999999999999], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{9.535747446610957, 0.}, {10.464252553389045`, 624.}, 
            "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{154.48018191692992`, 167.71520794226154`}, {
           77.9291548108167, 98.17335224246489}}],
         StatusArea[#, 624]& ,
         TagBoxNote->"624"],
        StyleBox["624", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[624, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
      0.5389999999999999], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{10.535747446610957`, 0.}, {11.464252553389045`, 
            642.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{168.19580494621206`, 181.43083097154366`}, {
           77.35961065413454, 98.17335224246489}}],
         StatusArea[#, 642]& ,
         TagBoxNote->"642"],
        StyleBox["642", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[642, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
      0.5389999999999999], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{11.535747446610957`, 0.}, {12.464252553389045`, 
            722.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{181.91142797549418`, 195.1464540008258}, {
           74.82830329110271, 98.17335224246489}}],
         StatusArea[#, 722]& ,
         TagBoxNote->"722"],
        StyleBox["722", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[722, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
      0.5389999999999999], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{12.535747446610957`, 0.}, {13.464252553389045`, 
            662.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{195.62705100477632`, 208.8620770301079}, {
           76.72678381337658, 98.17335224246489}}],
         StatusArea[#, 662]& ,
         TagBoxNote->"662"],
        StyleBox["662", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[662, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
      0.5389999999999999], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{13.535747446610957`, 0.}, {14.464252553389045`, 
            647.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{209.34267403405843`, 222.57770005939005`}, {
           77.20140394394505, 98.17335224246489}}],
         StatusArea[#, 647]& ,
         TagBoxNote->"647"],
        StyleBox["647", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[647, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
      0.5389999999999999], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{14.535747446610957`, 0.}, {15.464252553389045`, 
            744.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{223.05829706334058`, 236.29332308867217`}, {
           74.13219376626897, 98.17335224246489}}],
         StatusArea[#, 744]& ,
         TagBoxNote->"744"],
        StyleBox["744", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[744, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
      0.5389999999999999], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{15.535747446610957`, 0.}, {16.464252553389045`, 
            787.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{236.7739200926227, 250.0089461179543}, {
           72.77161605863937, 98.17335224246489}}],
         StatusArea[#, 787]& ,
         TagBoxNote->"787"],
        StyleBox["787", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[787, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
      0.5389999999999999], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{16.53574744661096, 0.}, {17.464252553389045`, 835.}, 
            "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{250.48954312190486`, 263.7245691472364}, {
           71.25283164082028, 98.17335224246489}}],
         StatusArea[#, 835]& ,
         TagBoxNote->"835"],
        StyleBox["835", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[835, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
      0.5389999999999999], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{17.53574744661096, 0.}, {18.464252553389045`, 995.}, 
            "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{264.205166151187, 277.44019217651856`}, {
           66.19021691475663, 98.17335224246489}}],
         StatusArea[#, 995]& ,
         TagBoxNote->"995"],
        StyleBox["995", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[995, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
      0.5389999999999999], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{18.53574744661096, 0.}, {19.464252553389045`, 1231.},
             "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{277.9207891804691, 291.1558152058007}, {
           58.72286019381277, 98.17335224246489}}],
         StatusArea[#, 1231]& ,
         TagBoxNote->"1231"],
        StyleBox["1231", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[1231, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
      0.5389999999999999], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{19.53574744661096, 0.}, {20.464252553389045`, 1452.},
             "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{291.63641220975126`, 304.87143823508285`}, {
           51.73012360343737, 98.17335224246489}}],
         StatusArea[#, 1452]& ,
         TagBoxNote->"1452"],
        StyleBox["1452", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[1452, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
      0.5389999999999999], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{20.53574744661096, 0.}, {21.464252553389045`, 2070.},
             "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{305.3520352390334, 318.587061264365}, {
           32.17577422401658, 98.17335224246489}}],
         StatusArea[#, 2070]& ,
         TagBoxNote->"2070"],
        StyleBox["2070", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[2070, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
      0.5389999999999999], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{21.53574744661096, 0.}, {22.464252553389045`, 3239.},
             "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{319.06765826831554`, 
           332.3026842936471}, {-4.812954618285886, 98.17335224246489}}],
         StatusArea[#, 3239]& ,
         TagBoxNote->"3239"],
        StyleBox["3239", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[3239, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
      0.5389999999999999], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{22.53574744661096, 0.}, {23.464252553389045`, 6191.},
             "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{332.7832812975976, 
           346.0183073229292}, {-98.21819631416, 98.17335224246489}}],
         StatusArea[#, 6191]& ,
         TagBoxNote->"6191"],
        StyleBox["6191", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[6191, {}], "Tooltip"]& ]}}, {}, {}}, {}, {}, 
   StyleBox[
    StyleBox[{
      {Thickness[Tiny], 
       LineBox[{{0.07717734447539448, 0.}, {23.931994057567316`, 0.}}], 
       StyleBox[{}, "GraphicsLabel",
        StripOnInput->False]}, 
      StyleBox[{
        {Thickness[Tiny], 
         LineBox[{{0.5357474466109563, 0.}, 
           Offset[{-1.102182119232618*^-15, -6.}, {0.5357474466109563, 0.}]}],
          LineBox[{{23.46425255338904, 0.}, 
           Offset[{-1.102182119232618*^-15, -6.}, {23.46425255338904, 
            
            0.}]}], {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}}, 
        StyleBox[{}, "GraphicsLabel",
         StripOnInput->False]}, "GraphicsTicks",
       StripOnInput->False]},
     Antialiasing->False], "GraphicsAxes",
    StripOnInput->False]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.07717734447539448, 0.},
  BaseStyle->{FontFamily -> "Arial"},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Identity[
       Part[#, 1]], 
      Identity[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Identity[
       Part[#, 1]], 
      Identity[
       Part[#, 2]]}& )},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {{{1., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {2., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {7., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {8., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {9., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {10., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {11., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {12., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {13., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {14., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {15., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {16., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {17., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {18., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {19., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {20., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {21., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {22., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {23., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}}, {{1., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {2., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {7., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {8., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {9., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {10., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {11., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {12., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {13., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {14., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {15., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {16., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {17., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {18., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {19., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {20., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {21., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {22., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {23., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}}}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotRange->{{All, All}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{None, Automatic}]], "Output",
 CellChangeTimes->{
  3.703222967971087*^9, 3.703223005673883*^9, 3.70322309486502*^9, {
   3.703223147963504*^9, 3.703223166694353*^9}, 3.703223260394925*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"freq", "=", 
   RowBox[{
    RowBox[{"Range", "[", 
     RowBox[{"Nchrom", "-", "1"}], "]"}], "/", "Nchrom"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mean", "=", 
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{"Tr", "[", 
      RowBox[{"freq", "*", "GCspectrum"}], "]"}], "/", 
     RowBox[{"Tr", "[", "GCspectrum", "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Nsample", "=", 
    RowBox[{"Tr", "[", "GCspectrum", "]"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Unbiased", " ", "estimates"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"var", "=", 
   RowBox[{
    FractionBox["Nsample", 
     RowBox[{"Nsample", "-", "1"}]], " ", 
    RowBox[{
     RowBox[{"Tr", "[", 
      RowBox[{"GCspectrum", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"freq", "-", "mean"}], ")"}], "^", "2"}]}], "]"}], "/", 
     "Nsample"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"skew", "=", 
    RowBox[{
     FractionBox[
      SuperscriptBox["Nsample", "2"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Nsample", "-", "1"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"Nsample", "-", "2"}], ")"}]}]], 
     RowBox[{
      RowBox[{"Tr", "[", 
       RowBox[{"GCspectrum", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"freq", "-", "mean"}], ")"}], "^", "3"}]}], "]"}], "/", 
      "Nsample"}]}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"se", "=", 
   RowBox[{"N", "[", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"6", "*", "Nsample", "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Nsample", "-", "1"}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Nsample", "-", "2"}], ")"}], "*", 
         RowBox[{"(", 
          RowBox[{"Nsample", "+", "1"}], ")"}], "*", 
         RowBox[{"(", 
          RowBox[{"Nsample", "+", "3"}], ")"}]}], ")"}]}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"skewNorm", "=", 
   FractionBox["skew", 
    SuperscriptBox["var", 
     RowBox[{"3", "/", "2"}]]]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"PvalueSkew", " ", "=", " ", 
  RowBox[{"2", 
   RowBox[{"Probability", "[", 
    RowBox[{
     RowBox[{"x", "\[GreaterEqual]", 
      RowBox[{"Abs", "[", 
       FractionBox["skewNorm", "se"], "]"}]}], ",", 
     RowBox[{"x", "\[Distributed]", " ", 
      RowBox[{"NormalDistribution", "[", 
       RowBox[{"0", ",", "1"}], "]"}]}]}], "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.653126579972197*^9, 3.653126582582242*^9}, {
   3.653126621687224*^9, 3.653126747655044*^9}, {3.6531268039048843`*^9, 
   3.6531269058649473`*^9}, {3.653126988261079*^9, 3.653126989418442*^9}, {
   3.653127608183633*^9, 3.6531276311321383`*^9}, 3.653127665204067*^9, {
   3.653127718949409*^9, 3.653127765975671*^9}, {3.65312787490821*^9, 
   3.653127882703494*^9}, {3.653127913077795*^9, 3.6531280429826107`*^9}, {
   3.6531280741367292`*^9, 3.653128138349524*^9}, {3.653128178829419*^9, 
   3.6531282778764267`*^9}, {3.6531285087811937`*^9, 3.653128567091679*^9}, 
   3.653128964420768*^9, {3.6531315670985737`*^9, 3.653131625954216*^9}, {
   3.703222929028953*^9, 3.7032229307386293`*^9}, {3.703222987316258*^9, 
   3.7032230197381163`*^9}, {3.703223102211978*^9, 3.703223104349105*^9}}],

Cell[BoxData[
 RowBox[{"-", "0.30339128827732376`"}]], "Output",
 CellChangeTimes->{{3.70322297512536*^9, 3.703223020149213*^9}, {
   3.703223098719489*^9, 3.703223105344679*^9}, 3.703223260426817*^9}],

Cell[BoxData["6.035126815199986`*^-112"], "Output",
 CellChangeTimes->{{3.70322297512536*^9, 3.703223020149213*^9}, {
   3.703223098719489*^9, 3.703223105344679*^9}, 3.7032232604348707`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["NI and DoS", "Subsubsection",
 CellChangeTimes->{{3.653128977892264*^9, 3.6531289809284353`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"NI", "=", 
  RowBox[{"N", "[", 
   FractionBox[
    RowBox[{"PWS", "/", "PSW"}], 
    RowBox[{"DWS", "/", "DSW"}]], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"DoS", "=", 
  RowBox[{"N", "[", 
   RowBox[{
    FractionBox["DWS", 
     RowBox[{"DWS", "+", "DSW"}]], "-", 
    FractionBox["PWS", 
     RowBox[{"PWS", "+", "PSW"}]]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"chi2", "[", 
    RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "]"}], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "b"}], ")"}], 
           RowBox[{"(", 
            RowBox[{"a", "+", "c"}], ")"}]}], 
          RowBox[{"a", "+", "b", "+", "c", "+", "d"}]], "-", "a"}], ")"}], 
       "2"], 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", "+", "b"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"a", "+", "c"}], ")"}]}], 
       RowBox[{"a", "+", "b", "+", "c", "+", "d"}]]], "+", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"b", "+", "a"}], ")"}], 
           RowBox[{"(", 
            RowBox[{"b", "+", "d"}], ")"}]}], 
          RowBox[{"a", "+", "b", "+", "c", "+", "d"}]], "-", "b"}], ")"}], 
       "2"], 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"b", "+", "a"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"b", "+", "d"}], ")"}]}], 
       RowBox[{"a", "+", "b", "+", "c", "+", "d"}]]], "+", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"c", "+", "a"}], ")"}], 
           RowBox[{"(", 
            RowBox[{"c", "+", "d"}], ")"}]}], 
          RowBox[{"a", "+", "b", "+", "c", "+", "d"}]], "-", "c"}], ")"}], 
       "2"], 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"c", "+", "a"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"c", "+", "d"}], ")"}]}], 
       RowBox[{"a", "+", "b", "+", "c", "+", "d"}]]], "+", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"d", "+", "b"}], ")"}], 
           RowBox[{"(", 
            RowBox[{"d", "+", "c"}], ")"}]}], 
          RowBox[{"a", "+", "b", "+", "c", "+", "d"}]], "-", "d"}], ")"}], 
       "2"], 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"d", "+", "b"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"d", "+", "c"}], ")"}]}], 
       RowBox[{"a", "+", "b", "+", "c", "+", "d"}]]]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Needs", "[", "\"\<HypothesisTesting`\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"PvalueNI", "=", 
  RowBox[{"TwoSidedPValue", "/.", 
   RowBox[{"ChiSquarePValue", "[", 
    RowBox[{
     RowBox[{"chi2", "[", 
      RowBox[{"PWS", ",", "PSW", ",", "DWS", ",", "DSW"}], "]"}], ",", "1", 
     ",", 
     RowBox[{"TwoSided", "\[Rule]", "True"}]}], "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.6531289921923943`*^9, 3.653129022634039*^9}, {
  3.653129053110586*^9, 3.653129072561994*^9}, {3.653129135452239*^9, 
  3.653129141446598*^9}, {3.653129753279562*^9, 3.6531297573283567`*^9}, {
  3.6531301032560596`*^9, 3.65313016852122*^9}, {3.6531303117755136`*^9, 
  3.65313037630378*^9}, {3.6531304823196383`*^9, 3.653130495798997*^9}, {
  3.6531306598022623`*^9, 3.65313067743078*^9}, {3.653132256819915*^9, 
  3.653132258713592*^9}, {3.703223122091639*^9, 3.7032231258603697`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"0.8746935439934622`", " ", "PWS"}], "PSW"]], "Output",
 CellChangeTimes->{3.703223126711424*^9, 3.703223260479887*^9}],

Cell[BoxData[
 RowBox[{"0.533420517291485`", "\[VeryThinSpace]", "-", 
  FractionBox[
   RowBox[{"1.`", " ", "PWS"}], 
   RowBox[{"PSW", "+", "PWS"}]]}]], "Output",
 CellChangeTimes->{3.703223126711424*^9, 3.703223260488166*^9}],

Cell[BoxData[
 RowBox[{"2", " ", 
  RowBox[{"Min", "[", 
   RowBox[{
    RowBox[{"GammaRegularized", "[", 
     RowBox[{
      FractionBox["1", "2"], ",", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"7342", " ", "PSW"}], "-", 
           RowBox[{"6422", " ", "PWS"}]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"13764", "+", "PSW", "+", "PWS"}], ")"}]}], 
       RowBox[{"27528", " ", 
        RowBox[{"(", 
         RowBox[{"6422", "+", "PSW"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"7342", "+", "PWS"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"PSW", "+", "PWS"}], ")"}]}]]}], "]"}], ",", 
    RowBox[{"GammaRegularized", "[", 
     RowBox[{
      FractionBox["1", "2"], ",", "0", ",", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"7342", " ", "PSW"}], "-", 
           RowBox[{"6422", " ", "PWS"}]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"13764", "+", "PSW", "+", "PWS"}], ")"}]}], 
       RowBox[{"27528", " ", 
        RowBox[{"(", 
         RowBox[{"6422", "+", "PSW"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"7342", "+", "PWS"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"PSW", "+", "PWS"}], ")"}]}]]}], "]"}]}], "]"}]}]], "Output",
 CellChangeTimes->{3.703223126711424*^9, 3.703223260492874*^9}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["ML Estimates", "Subsection",
 CellChangeTimes->{{3.564231579156546*^9, 3.56423159473543*^9}, 
   3.593837615921116*^9}],

Cell[TextData[{
 "In models with two ",
 StyleBox["B",
  FontSlant->"Italic"],
 ", ",
 StyleBox["B",
  FontSlant->"Italic"],
 "0 is the ancestral and ",
 StyleBox["B",
  FontSlant->"Italic"],
 "1 the recent values."
}], "Text",
 CellChangeTimes->{{3.6531969987417707`*^9, 3.6531970295206957`*^9}, 
   3.703223206994974*^9}],

Cell[CellGroupData[{

Cell["Initial conditions", "Subsubsection",
 CellChangeTimes->{{3.564231560467885*^9, 3.56423156404556*^9}, {
  3.5642317951558437`*^9, 3.564231797427649*^9}, {3.648659199192721*^9, 
  3.648659200646469*^9}, {3.703224553982258*^9, 3.703224556344049*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Theta]init", "=", 
   RowBox[{
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", "tabneutral"}], "]"}], "/", 
    RowBox[{"HarmonicNumber", "[", "Nchrom", "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Theta]WSinit", "=", 
   RowBox[{
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", "tabWS"}], "]"}], "/", 
    RowBox[{"HarmonicNumber", "[", "Nchrom", "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]init", "=", 
   FractionBox[
    RowBox[{"pGC", " ", 
     RowBox[{"tabSW", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "pGC"}], ")"}], 
     RowBox[{"tabWS", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Tau]init", "=", "Dneutral"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Tau]WSinit", "=", 
   RowBox[{"DWS", "/", 
    RowBox[{"(", 
     RowBox[{"1", "-", "pGC"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rinit", "=", 
   RowBox[{
    RowBox[{"tabneutral", " ", 
     RowBox[{
      RowBox[{"Range", "[", 
       RowBox[{"Nchrom", "-", "1"}], "]"}], "/", 
      RowBox[{"tabneutral", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}]}], "+", "0.1"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rninit", "=", "1.1"}], ";"}]}], "Input",
 CellChangeTimes->{{3.5642304395653563`*^9, 3.564230566937914*^9}, {
   3.5642306210531816`*^9, 3.5642306690535393`*^9}, {3.5642307186900797`*^9, 
   3.564230719723556*^9}, {3.5642307500347*^9, 3.564230867472843*^9}, {
   3.564231715207657*^9, 3.564231793202677*^9}, {3.5650053897748823`*^9, 
   3.5650054291564083`*^9}, {3.5650055915180693`*^9, 3.56500561007064*^9}, {
   3.5650183843275127`*^9, 3.5650183881924334`*^9}, {3.567165882458559*^9, 
   3.567165896911628*^9}, {3.56716603263902*^9, 3.567166035409156*^9}, {
   3.567166164573626*^9, 3.567166171513049*^9}, 3.5671662461627207`*^9, {
   3.567166292152424*^9, 3.567166309926059*^9}, 3.567166475680993*^9, {
   3.5671665897150593`*^9, 3.567166596239398*^9}, {3.5671853148370647`*^9, 
   3.567185319857675*^9}, {3.593627022179501*^9, 3.593627035993046*^9}, {
   3.6485775519581537`*^9, 3.648577607915954*^9}, {3.648660903219761*^9, 
   3.648660946200028*^9}, {3.653410683319467*^9, 3.6534106893597803`*^9}, {
   3.67316628826692*^9, 3.673166313600519*^9}, {3.6731663609407177`*^9, 
   3.673166420588265*^9}, {3.673167216548057*^9, 3.673167226897375*^9}, {
   3.6731696196153917`*^9, 3.673169635151804*^9}, {3.703223268959565*^9, 
   3.7032232770368032`*^9}, {3.7032245491670237`*^9, 3.703224549594442*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Basic models", "Subsubsection",
 CellChangeTimes->{{3.5678344796549597`*^9, 3.5678344939425573`*^9}, 
   3.593837615922243*^9, 3.6531322830247107`*^9}],

Cell["Saturated model:", "Text",
 CellChangeTimes->{{3.564233658109749*^9, 3.5642336674106503`*^9}, 
   3.59383761592309*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lnLsat", "=", 
  RowBox[{"N", "[", 
   RowBox[{"logLikMax", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"{", 
       RowBox[{"tabneutral", ",", "Dneutral"}], "}"}], "]"}], ",", 
     RowBox[{"Flatten", "[", 
      RowBox[{"{", 
       RowBox[{"tabWS", ",", "DWS"}], "}"}], "]"}], ",", 
     RowBox[{"Flatten", "[", 
      RowBox[{"{", 
       RowBox[{"tabSW", ",", "DSW"}], "}"}], "]"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.564477890113482*^9, 3.564477909283383*^9}, {
   3.565040344130828*^9, 3.56504035492936*^9}, {3.5650816915513763`*^9, 
   3.565081694856119*^9}, {3.565081878898121*^9, 3.565081882023203*^9}, {
   3.565086032317608*^9, 3.565086039112772*^9}, 3.593837615923627*^9, {
   3.648577623524515*^9, 3.648577685605568*^9}, {3.653195844578567*^9, 
   3.6531958557614517`*^9}, {3.653195995014976*^9, 3.653196009481579*^9}, {
   3.6531960503653927`*^9, 3.653196083258874*^9}, {3.6531961145691547`*^9, 
   3.653196119338957*^9}, {3.703223280468069*^9, 3.703223300587998*^9}}],

Cell[BoxData[
 RowBox[{"-", "288.71467769605806`"}]], "Output",
 CellChangeTimes->{
  3.653669362169216*^9, {3.653669458537662*^9, 3.653669497898128*^9}, {
   3.653669536926803*^9, 3.6536695551360903`*^9}, {3.653669591159294*^9, 
   3.653669661643053*^9}, 3.653669706111768*^9, 3.6536697442086287`*^9, 
   3.653669797691663*^9, 3.653669876918126*^9, 3.6536699274209223`*^9, 
   3.653670641436521*^9, 3.655625607655389*^9, 3.655723484051343*^9, 
   3.6557235146587048`*^9, 3.6557236835002003`*^9, 3.665164213945236*^9, 
   3.665164508382511*^9, 3.66516518527844*^9, 3.665165277579571*^9, 
   3.671264100432035*^9, 3.671265853813369*^9, 3.672044992653281*^9, 
   3.6720450542904778`*^9, 3.672045382921616*^9, 3.6720455017435093`*^9, 
   3.672046847286306*^9, 3.6720478853666162`*^9, 3.672048347169395*^9, 
   3.6720483819376383`*^9, 3.672048610692827*^9, 3.672048711580352*^9, {
   3.672048750899271*^9, 3.672048765867421*^9}, {3.672048835158204*^9, 
   3.6720489046342*^9}, {3.672048960205638*^9, 3.672048982495647*^9}, {
   3.672049024384129*^9, 3.672049091816869*^9}, {3.672049123408896*^9, 
   3.672049133179948*^9}, {3.672049199503183*^9, 3.672049219417131*^9}, {
   3.672049276871711*^9, 3.6720492953668747`*^9}, 3.673166270446282*^9, 
   3.673166423203568*^9, 3.673166847099703*^9, 3.673166898260849*^9, 
   3.673167231596642*^9, 3.673168118739285*^9, 3.673169677459343*^9, {
   3.683528421008973*^9, 3.6835284303717327`*^9}, 3.683528576749854*^9, 
   3.6835289708908033`*^9, {3.683529168658771*^9, 3.683529187985194*^9}, 
   3.6835292968870277`*^9, 3.68352936153091*^9, {3.683529392862409*^9, 
   3.683529693989362*^9}, 3.6835399851126623`*^9, 3.6835407499869328`*^9, 
   3.683541182272662*^9, 3.683541276062232*^9, 3.6835415643048573`*^9, 
   3.683542663239252*^9, 3.6835429651420517`*^9, 3.6835437913734217`*^9, 
   3.6835603978463917`*^9, 3.683560716018262*^9, 3.683561152765314*^9, 
   3.683563434936268*^9, 3.683564365050215*^9, 3.683565262381406*^9, 
   3.68356549610643*^9, 3.6835658241821833`*^9, 3.683565931451778*^9, 
   3.683566129773254*^9, 3.683566556205481*^9, 3.6835667544872417`*^9, 
   3.6835669531478777`*^9, 3.683567180436994*^9, 3.6835676237349243`*^9, 
   3.683567852312785*^9, {3.683568068197612*^9, 3.683568095887631*^9}, 
   3.6835682843305807`*^9, 3.6835684765718184`*^9, 3.683568700231934*^9, 
   3.68356887768364*^9, 3.6835690672309933`*^9, 3.6835692577731953`*^9, 
   3.683569366507391*^9, 3.6835694716200647`*^9, 3.6835697423495293`*^9, 
   3.683570369094734*^9, 3.683570516569715*^9, 3.683570760737108*^9, 
   3.683571007634059*^9, 3.683571102816697*^9, 3.6835712224526176`*^9, 
   3.683571414589107*^9, 3.683571606282834*^9, 3.68357182649713*^9, 
   3.683572033055415*^9, 3.683572237996896*^9, 3.683572497667697*^9, 
   3.683572708000491*^9, 3.6835729234906063`*^9, 3.683573115560054*^9, 
   3.6835733182095337`*^9, 3.683573556909545*^9, 3.683573739659258*^9, 
   3.6835739320311337`*^9, 3.683574126828219*^9, 3.6835742310832653`*^9, 
   3.683574331947817*^9, 3.683574616334983*^9, 3.703221619185296*^9, 
   3.7032217369804077`*^9, 3.7032232193134193`*^9, 3.703223306287199*^9}]
}, Open  ]],

Cell["M0", "Text",
 CellChangeTimes->{{3.564231998899579*^9, 3.5642319991987886`*^9}, 
   3.593837615927609*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"init0", "=", 
   RowBox[{"Union", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[Theta]", ",", "\[Theta]init"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Theta]WS", ",", "\[Theta]WSinit"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Lambda]", ",", "\[Lambda]init"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Tau]", ",", "\[Tau]init"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Tau]WS", ",", "\[Tau]WSinit"}], "}"}]}], "}"}], ",", 
     RowBox[{"Take", "[", 
      RowBox[{
       RowBox[{"Thread", "[", 
        RowBox[{"{", 
         RowBox[{"tabcoef", ",", "rinit"}], "}"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         RowBox[{"Nchrom", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cons0", "=", 
   RowBox[{"Union", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Theta]", ">", "0"}], ",", 
       RowBox[{"\[Theta]WS", ">", "0"}], ",", 
       RowBox[{"\[Lambda]", ">", "0"}], ",", 
       RowBox[{"\[Tau]", ">", "0"}], ",", 
       RowBox[{"\[Tau]WS", ">", "0"}]}], "}"}], ",", 
     RowBox[{"Take", "[", 
      RowBox[{
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"#", ">", "0"}], "&"}], ",", "tabcoef"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         RowBox[{"Nchrom", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"M0", "=", 
  RowBox[{"FindMaximum", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"logLikD0", "[", 
       RowBox[{
       "Nchrom", ",", "pGC", ",", "\[Theta]", ",", "\[Theta]WS", ",", 
        "\[Tau]", ",", "\[Tau]WS", ",", "\[Lambda]", ",", "tabcoef", ",", 
        "tabneutral", ",", "tabWS", ",", "tabSW", ",", "Dneutral", ",", "DWS",
         ",", "DSW"}], "]"}], ",", "cons0"}], "}"}], ",", "init0", ",", 
    RowBox[{"AccuracyGoal", "\[Rule]", "6"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.564232469186648*^9, 3.564232504601274*^9}, {
   3.564232651890757*^9, 3.564232705919312*^9}, {3.5642383301577883`*^9, 
   3.564238330725251*^9}, {3.564601538913146*^9, 3.56460156019914*^9}, {
   3.56460258758848*^9, 3.5646025878041487`*^9}, {3.56460320179915*^9, 
   3.564603227939867*^9}, {3.565040333313615*^9, 3.5650403418806477`*^9}, {
   3.565041050379075*^9, 3.565041055786252*^9}, {3.565081699666359*^9, 
   3.565081703907675*^9}, {3.565081896013822*^9, 3.565081899117942*^9}, 
   3.56716590787289*^9, 3.567165989906786*^9, 3.567166061569615*^9, 
   3.5671661042287703`*^9, {3.567166386117901*^9, 3.5671664049880466`*^9}, {
   3.567166539306595*^9, 3.567166565481502*^9}, {3.567166681910309*^9, 
   3.5671667040045433`*^9}, {3.567166751637766*^9, 3.56716681464578*^9}, {
   3.567166847242338*^9, 3.567166857410989*^9}, {3.567167391103218*^9, 
   3.567167413873209*^9}, {3.5671674492241917`*^9, 3.567167454744521*^9}, {
   3.5671675092285852`*^9, 3.5671675159537373`*^9}, {3.567167677967989*^9, 
   3.567167690903077*^9}, {3.567185327213584*^9, 3.56718533284521*^9}, {
   3.5672763374559927`*^9, 3.56727634106347*^9}, {3.5674025989937067`*^9, 
   3.567402607913027*^9}, {3.5674047715664387`*^9, 3.5674047741741056`*^9}, {
   3.56871704131802*^9, 3.5687170571901093`*^9}, {3.568718054777659*^9, 
   3.568718058059078*^9}, {3.568719197547818*^9, 3.568719201530346*^9}, {
   3.568720244638262*^9, 3.5687202990643263`*^9}, 3.5938376159287157`*^9, {
   3.648577693773278*^9, 3.648577729514756*^9}, 3.648577929975047*^9, 
   3.6485780371703987`*^9, {3.648578463482917*^9, 3.6485784806021013`*^9}, {
   3.648660964749044*^9, 3.648660986550733*^9}, {3.648661071810432*^9, 
   3.6486610784263277`*^9}, {3.653376325213256*^9, 3.653376349077314*^9}, {
   3.65337959811946*^9, 3.653379630768881*^9}, {3.653379722949993*^9, 
   3.653379739004698*^9}, {3.672045071767982*^9, 3.672045129716762*^9}, {
   3.6720452600105*^9, 3.672045267929317*^9}, {3.6720453881725483`*^9, 
   3.6720454185001497`*^9}, {3.6720455134066563`*^9, 
   3.6720455195343847`*^9}, {3.683560370425002*^9, 3.6835603933267107`*^9}, {
   3.7032232905547037`*^9, 3.70322330059186*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "887.4101623011375`"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Theta]", "\[Rule]", "3292.9532758582295`"}], ",", 
     RowBox[{"\[Theta]WS", "\[Rule]", "7578.323995761238`"}], ",", 
     RowBox[{"\[Lambda]", "\[Rule]", "1.3611235378202484`"}], ",", 
     RowBox[{"\[Tau]", "\[Rule]", "3688.7936150220053`"}], ",", 
     RowBox[{"\[Tau]WS", "\[Rule]", "11307.538122101092`"}], ",", 
     RowBox[{
      SubscriptBox["r", "2"], "\[Rule]", "1.025515613795328`"}], ",", 
     RowBox[{
      SubscriptBox["r", "3"], "\[Rule]", "0.9339691883217315`"}], ",", 
     RowBox[{
      SubscriptBox["r", "4"], "\[Rule]", "0.8641069562665558`"}], ",", 
     RowBox[{
      SubscriptBox["r", "5"], "\[Rule]", "0.8416890872546924`"}], ",", 
     RowBox[{
      SubscriptBox["r", "6"], "\[Rule]", "0.8192712182428289`"}], ",", 
     RowBox[{
      SubscriptBox["r", "7"], "\[Rule]", "0.776636507246874`"}], ",", 
     RowBox[{
      SubscriptBox["r", "8"], "\[Rule]", "0.8275862099514725`"}], ",", 
     RowBox[{
      SubscriptBox["r", "9"], "\[Rule]", "0.8305209129438531`"}], ",", 
     RowBox[{
      SubscriptBox["r", "10"], "\[Rule]", "0.7964457519814855`"}], ",", 
     RowBox[{
      SubscriptBox["r", "11"], "\[Rule]", "0.8375315922664259`"}], ",", 
     RowBox[{
      SubscriptBox["r", "12"], "\[Rule]", "0.9518219652195689`"}], ",", 
     RowBox[{
      SubscriptBox["r", "13"], "\[Rule]", "0.8817151745920059`"}], ",", 
     RowBox[{
      SubscriptBox["r", "14"], "\[Rule]", "0.898182118589867`"}], ",", 
     RowBox[{
      SubscriptBox["r", "15"], "\[Rule]", "1.0014673557855402`"}], ",", 
     RowBox[{
      SubscriptBox["r", "16"], "\[Rule]", "1.0877965319622978`"}], ",", 
     RowBox[{
      SubscriptBox["r", "17"], "\[Rule]", "0.9922556498063618`"}], ",", 
     RowBox[{
      SubscriptBox["r", "18"], "\[Rule]", "1.1768158525590473`"}], ",", 
     RowBox[{
      SubscriptBox["r", "19"], "\[Rule]", "1.4450966065926265`"}], ",", 
     RowBox[{
      SubscriptBox["r", "20"], "\[Rule]", "1.2945300456493452`"}], ",", 
     RowBox[{
      SubscriptBox["r", "21"], "\[Rule]", "1.5527023786908778`"}], ",", 
     RowBox[{
      SubscriptBox["r", "22"], "\[Rule]", "1.8292981241856545`"}], ",", 
     RowBox[{
      SubscriptBox["r", "23"], "\[Rule]", "2.216189785827509`"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.655723514781382*^9, 3.655723683645936*^9, 3.665164215715189*^9, 
   3.6651645087725554`*^9, 3.6651651854197702`*^9, 3.665165277740223*^9, 
   3.671264100570671*^9, 3.671265853886837*^9, 3.672044994414008*^9, {
   3.672045060200122*^9, 3.672045130207306*^9}, {3.672045390863741*^9, 
   3.672045419055106*^9}, {3.672045504783239*^9, 3.672045522525687*^9}, 
   3.672046849121662*^9, 3.6720478854515953`*^9, 3.6720483472529287`*^9, 
   3.672048382021308*^9, 3.6720486107622643`*^9, 3.672048711656188*^9, {
   3.672048750982347*^9, 3.672048766294344*^9}, {3.67204883523742*^9, 
   3.672048904734808*^9}, {3.6720489602848673`*^9, 3.672048982585191*^9}, {
   3.672049024462132*^9, 3.6720490918840523`*^9}, {3.672049123470971*^9, 
   3.672049133242116*^9}, {3.6720491995691137`*^9, 3.672049219492628*^9}, {
   3.672049276962047*^9, 3.672049295439816*^9}, 3.6835284335135107`*^9, 
   3.683528597176756*^9, 3.6835286960418863`*^9, 3.683528970968244*^9, {
   3.683529168750659*^9, 3.6835291888016233`*^9}, 3.683529296965322*^9, 
   3.683529361582871*^9, {3.683529392913143*^9, 3.683529694068468*^9}, 
   3.683539986008821*^9, 3.683541182347801*^9, 3.683541276139773*^9, 
   3.683541565827874*^9, 3.6835426640080137`*^9, 3.6835429666889353`*^9, 
   3.68354379273558*^9, 3.6835604001887503`*^9, 3.68356071866794*^9, 
   3.683561152845252*^9, 3.683563436104514*^9, 3.683564365137356*^9, 
   3.683565262478598*^9, 3.683565496170875*^9, 3.683565824235845*^9, 
   3.683565931530827*^9, 3.683566129845087*^9, 3.683566556279764*^9, 
   3.6835667545700502`*^9, 3.6835669532207212`*^9, 3.683567180514246*^9, 
   3.683567623808984*^9, 3.683567852385736*^9, {3.683568068453348*^9, 
   3.68356809595185*^9}, 3.68356828439878*^9, 3.6835684766336727`*^9, 
   3.683568700297742*^9, 3.683568877771468*^9, 3.683569067300858*^9, 
   3.683569257823409*^9, 3.683569366558456*^9, 3.683569471704369*^9, 
   3.6835697424293013`*^9, 3.68357037054786*^9, 3.683570516652239*^9, 
   3.683570760816324*^9, 3.683571007685513*^9, 3.683571102868445*^9, 
   3.683571222526359*^9, 3.683571414663117*^9, 3.683571606391383*^9, 
   3.683571826575727*^9, 3.6835720331280518`*^9, 3.683572238080722*^9, 
   3.683572497742231*^9, 3.683572708074213*^9, 3.683572923560916*^9, 
   3.683573115629745*^9, 3.6835733182708063`*^9, 3.6835735569700727`*^9, 
   3.683573739734816*^9, 3.683573932118971*^9, 3.683574126878133*^9, 
   3.683574231141055*^9, 3.683574332020603*^9, 3.6835746164172773`*^9, 
   3.703221622744252*^9, 3.7032217386760473`*^9, 3.703223221085363*^9, 
   3.703223308236763*^9, 3.703223411320051*^9}]
}, Open  ]],

Cell["M1 B0 = B1", "Text",
 CellChangeTimes->{{3.564232003416295*^9, 3.564232003664201*^9}, 
   3.5938376159349413`*^9, {3.64857874431444*^9, 3.648578752850864*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"init1", "=", 
   RowBox[{"Union", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[Theta]", ",", 
         RowBox[{"\[Theta]", "/.", 
          RowBox[{"M0", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Theta]WS", ",", 
         RowBox[{"\[Theta]WS", "/.", 
          RowBox[{"M0", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Tau]", ",", "\[Tau]init"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Tau]WS", ",", "\[Tau]WSinit"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Lambda]", ",", 
         RowBox[{"\[Lambda]", "/.", 
          RowBox[{"M0", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"B", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"Take", "[", 
      RowBox[{
       RowBox[{"Thread", "[", 
        RowBox[{"{", 
         RowBox[{"tabcoef", ",", "rinit"}], "}"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         RowBox[{"Nchrom", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cons1", "=", 
   RowBox[{"Union", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Theta]", ">", "0"}], ",", 
       RowBox[{"\[Theta]WS", ">", "0"}], ",", 
       RowBox[{"\[Lambda]", ">", "0"}], ",", 
       RowBox[{"\[Tau]", ">", "0"}], ",", 
       RowBox[{"\[Tau]WS", ">", "0"}]}], "}"}], ",", 
     RowBox[{"Take", "[", 
      RowBox[{
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"#", ">", "0"}], "&"}], ",", "tabcoef"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         RowBox[{"Nchrom", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"M1", "=", 
  RowBox[{"FindMaximum", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"logLikD1", "[", 
       RowBox[{
       "Nchrom", ",", "pGC", ",", "\[Theta]", ",", "\[Theta]WS", ",", 
        "\[Tau]", ",", "\[Tau]WS", ",", "\[Lambda]", ",", "B", ",", "B", ",", 
        "tabcoef", ",", "tabneutral", ",", "tabWS", ",", "tabSW", ",", 
        "Dneutral", ",", "DWS", ",", "DSW"}], "]"}], ",", "cons1"}], "}"}], 
    ",", "init1", ",", 
    RowBox[{"AccuracyGoal", "\[Rule]", "6"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.4849918812651997`*^9, 3.4849919131714497`*^9}, {
   3.4849919690620747`*^9, 3.484992003148012*^9}, 3.484992082688813*^9, {
   3.484992141204438*^9, 3.484992231870532*^9}, {3.484992265909301*^9, 
   3.484992343315551*^9}, {3.4849924113150015`*^9, 3.4849924815047894`*^9}, {
   3.489138966926263*^9, 3.489138969941888*^9}, {3.4954718462585*^9, 
   3.4954718693835*^9}, {3.495471912680375*^9, 3.495471913196*^9}, {
   3.495471979196*^9, 3.49547200297725*^9}, {3.495472044617875*^9, 
   3.49547208235225*^9}, {3.496504439538522*^9, 3.496504440085397*^9}, {
   3.49926354336675*^9, 3.4992635633355*^9}, {3.499338237553625*^9, 
   3.499338263178625*^9}, {3.564226049081957*^9, 3.564226105960425*^9}, {
   3.564229115421522*^9, 3.564229190300817*^9}, {3.5642303854180613`*^9, 
   3.564230396396782*^9}, {3.564230879500187*^9, 3.5642309560727453`*^9}, {
   3.5642315198642282`*^9, 3.564231528465914*^9}, {3.564231629325408*^9, 
   3.5642316480873003`*^9}, {3.564231686212853*^9, 3.564231695069336*^9}, {
   3.5642318008190317`*^9, 3.564231879410396*^9}, {3.5642319719944572`*^9, 
   3.5642319918483057`*^9}, {3.564232710118916*^9, 3.564232724696784*^9}, {
   3.564238326760501*^9, 3.564238327311071*^9}, {3.564601563856604*^9, 
   3.564601571055615*^9}, {3.5650404516759357`*^9, 3.5650404566815557`*^9}, {
   3.56504106147506*^9, 3.565041066370307*^9}, {3.5671673292190523`*^9, 
   3.567167356285079*^9}, {3.567167388106946*^9, 3.567167402624468*^9}, {
   3.567167888232828*^9, 3.567167911779674*^9}, {3.5671853673896503`*^9, 
   3.56718537269184*^9}, {3.567276358695696*^9, 3.5672763624599257`*^9}, {
   3.567402613448998*^9, 3.567402637153288*^9}, {3.567404779903269*^9, 
   3.567404782612885*^9}, 3.567839227821903*^9, {3.568717062028139*^9, 
   3.56871706412099*^9}, {3.568718067254978*^9, 3.568718070798678*^9}, {
   3.56871920581846*^9, 3.568719208259226*^9}, {3.568720280637864*^9, 
   3.56872030546612*^9}, 3.593837615935915*^9, {3.6485787078064003`*^9, 
   3.64857876401831*^9}, {3.64857881553244*^9, 3.648578821907339*^9}, {
   3.648579056653618*^9, 3.648579094840046*^9}, {3.648661126090811*^9, 
   3.6486611387539587`*^9}, {3.6533763659954147`*^9, 3.653376375890634*^9}, {
   3.6533797539558363`*^9, 3.65337978703719*^9}, {3.6720451093257837`*^9, 
   3.6720451328130207`*^9}, {3.6720454234044323`*^9, 3.672045425115884*^9}, {
   3.683560412778221*^9, 3.683560425007546*^9}, {3.7032232905616207`*^9, 
   3.7032233005958347`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "435.8392395328119`"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"B", "\[Rule]", "0.6967346821390822`"}], ",", 
     RowBox[{"\[Theta]", "\[Rule]", "3231.010329080596`"}], ",", 
     RowBox[{"\[Theta]WS", "\[Rule]", "6166.679356785065`"}], ",", 
     RowBox[{"\[Lambda]", "\[Rule]", "1.9308240820517155`"}], ",", 
     RowBox[{"\[Tau]", "\[Rule]", "3691.374572908126`"}], ",", 
     RowBox[{"\[Tau]WS", "\[Rule]", "9852.07740356653`"}], ",", 
     RowBox[{
      SubscriptBox["r", "2"], "\[Rule]", "1.0301725958964674`"}], ",", 
     RowBox[{
      SubscriptBox["r", "3"], "\[Rule]", "0.942284574588092`"}], ",", 
     RowBox[{
      SubscriptBox["r", "4"], "\[Rule]", "0.8754125292442438`"}], ",", 
     RowBox[{
      SubscriptBox["r", "5"], "\[Rule]", "0.8560643247896604`"}], ",", 
     RowBox[{
      SubscriptBox["r", "6"], "\[Rule]", "0.8363833725970078`"}], ",", 
     RowBox[{
      SubscriptBox["r", "7"], "\[Rule]", "0.7956679421804871`"}], ",", 
     RowBox[{
      SubscriptBox["r", "8"], "\[Rule]", "0.8507008923528943`"}], ",", 
     RowBox[{
      SubscriptBox["r", "9"], "\[Rule]", "0.8564004112445726`"}], ",", 
     RowBox[{
      SubscriptBox["r", "10"], "\[Rule]", "0.8236791503153741`"}], ",", 
     RowBox[{
      SubscriptBox["r", "11"], "\[Rule]", "0.8685432379438274`"}], ",", 
     RowBox[{
      SubscriptBox["r", "12"], "\[Rule]", "0.9895711218058854`"}], ",", 
     RowBox[{
      SubscriptBox["r", "13"], "\[Rule]", "0.9188258569413786`"}], ",", 
     RowBox[{
      SubscriptBox["r", "14"], "\[Rule]", "0.9379838350884944`"}], ",", 
     RowBox[{
      SubscriptBox["r", "15"], "\[Rule]", "1.0478669924844195`"}], ",", 
     RowBox[{
      SubscriptBox["r", "16"], "\[Rule]", "1.1401650326458899`"}], ",", 
     RowBox[{
      SubscriptBox["r", "17"], "\[Rule]", "1.0416132757816434`"}], ",", 
     RowBox[{
      SubscriptBox["r", "18"], "\[Rule]", "1.2369907131919373`"}], ",", 
     RowBox[{
      SubscriptBox["r", "19"], "\[Rule]", "1.5206941624999233`"}], ",", 
     RowBox[{
      SubscriptBox["r", "20"], "\[Rule]", "1.3635033716268727`"}], ",", 
     RowBox[{
      SubscriptBox["r", "21"], "\[Rule]", "1.6366030536094571`"}], ",", 
     RowBox[{
      SubscriptBox["r", "22"], "\[Rule]", "1.9291350282017903`"}], ",", 
     RowBox[{
      SubscriptBox["r", "23"], "\[Rule]", "2.3378680937677334`"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7032233133697433`*^9, 3.70322341291046*^9, 
  3.703223445544717*^9, 3.703223487911394*^9}]
}, Open  ]],

Cell["M2a B0 = 0 et B1 \[NotEqual] 0", "Text",
 CellChangeTimes->{{3.648656708520397*^9, 3.648656792652615*^9}, 
   3.648656869946093*^9, {3.653130753202903*^9, 3.65313075381927*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"init2a", "=", 
   RowBox[{"Union", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[Theta]", ",", 
         RowBox[{"\[Theta]", "/.", 
          RowBox[{"M0", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Theta]WS", ",", 
         RowBox[{"\[Theta]WS", "/.", 
          RowBox[{"M0", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Tau]", ",", "\[Tau]init"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Tau]WS", ",", "\[Tau]WSinit"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Lambda]", ",", 
         RowBox[{"\[Lambda]", "/.", 
          RowBox[{"M0", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"B1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"Take", "[", 
      RowBox[{
       RowBox[{"Thread", "[", 
        RowBox[{"{", 
         RowBox[{"tabcoef", ",", "rinit"}], "}"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         RowBox[{"Nchrom", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cons2a", "=", 
   RowBox[{"Union", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Theta]", ">", "0"}], ",", 
       RowBox[{"\[Theta]WS", ">", "0"}], ",", 
       RowBox[{"\[Lambda]", ">", "0"}], ",", 
       RowBox[{"\[Tau]", ">", "0"}], ",", 
       RowBox[{"\[Tau]WS", ">", "0"}]}], "}"}], ",", 
     RowBox[{"Take", "[", 
      RowBox[{
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"#", ">", "0"}], "&"}], ",", "tabcoef"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         RowBox[{"Nchrom", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"M2a", "=", 
  RowBox[{"FindMaximum", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"logLikD1", "[", 
       RowBox[{
       "Nchrom", ",", "pGC", ",", "\[Theta]", ",", "\[Theta]WS", ",", 
        "\[Tau]", ",", "\[Tau]WS", ",", "\[Lambda]", ",", 
        SuperscriptBox["10", 
         RowBox[{"-", "8"}]], ",", "B1", ",", "tabcoef", ",", "tabneutral", 
        ",", "tabWS", ",", "tabSW", ",", "Dneutral", ",", "DWS", ",", "DSW"}],
        "]"}], ",", "cons2a"}], "}"}], ",", "init2a", ",", 
    RowBox[{"AccuracyGoal", "\[Rule]", "6"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.4849918812651997`*^9, 3.4849919131714497`*^9}, {
   3.4849919690620747`*^9, 3.484992003148012*^9}, 3.484992082688813*^9, {
   3.484992141204438*^9, 3.484992231870532*^9}, {3.484992265909301*^9, 
   3.484992343315551*^9}, {3.4849924113150015`*^9, 3.4849924815047894`*^9}, {
   3.489138966926263*^9, 3.489138969941888*^9}, {3.4954718462585*^9, 
   3.4954718693835*^9}, {3.495471912680375*^9, 3.495471913196*^9}, {
   3.495471979196*^9, 3.49547200297725*^9}, {3.495472044617875*^9, 
   3.49547208235225*^9}, {3.496504439538522*^9, 3.496504440085397*^9}, {
   3.49926354336675*^9, 3.4992635633355*^9}, {3.499338237553625*^9, 
   3.499338263178625*^9}, {3.564226049081957*^9, 3.564226105960425*^9}, {
   3.564229115421522*^9, 3.564229190300817*^9}, {3.5642303854180613`*^9, 
   3.564230396396782*^9}, {3.564230879500187*^9, 3.5642309560727453`*^9}, {
   3.5642315198642282`*^9, 3.564231528465914*^9}, {3.564231629325408*^9, 
   3.5642316480873003`*^9}, {3.564231686212853*^9, 3.564231695069336*^9}, {
   3.5642318008190317`*^9, 3.564231879410396*^9}, {3.5642319719944572`*^9, 
   3.5642319918483057`*^9}, {3.564232710118916*^9, 3.564232724696784*^9}, {
   3.564238326760501*^9, 3.564238327311071*^9}, {3.564601563856604*^9, 
   3.564601571055615*^9}, {3.5650404516759357`*^9, 3.5650404566815557`*^9}, {
   3.56504106147506*^9, 3.565041066370307*^9}, {3.5671673292190523`*^9, 
   3.567167356285079*^9}, {3.567167388106946*^9, 3.567167402624468*^9}, {
   3.567167888232828*^9, 3.567167911779674*^9}, {3.5671853673896503`*^9, 
   3.56718537269184*^9}, {3.567276358695696*^9, 3.5672763624599257`*^9}, {
   3.567402613448998*^9, 3.567402637153288*^9}, {3.567404779903269*^9, 
   3.567404782612885*^9}, 3.567839227821903*^9, {3.568717062028139*^9, 
   3.56871706412099*^9}, {3.568718067254978*^9, 3.568718070798678*^9}, {
   3.56871920581846*^9, 3.568719208259226*^9}, {3.568720280637864*^9, 
   3.56872030546612*^9}, 3.593837615935915*^9, {3.6485787078064003`*^9, 
   3.64857876401831*^9}, {3.64857881553244*^9, 3.648578821907339*^9}, {
   3.648579056653618*^9, 3.6485790663089123`*^9}, {3.648579097682631*^9, 
   3.648579101712769*^9}, {3.6485791676861353`*^9, 3.6485791927824717`*^9}, {
   3.648656798138771*^9, 3.648656802131193*^9}, {3.648656844414584*^9, 
   3.648656847512055*^9}, {3.6486612466520443`*^9, 3.648661263723988*^9}, {
   3.6531308097392817`*^9, 3.653130836344945*^9}, {3.653376386280767*^9, 
   3.653376401783183*^9}, {3.6720451563101883`*^9, 3.672045158717688*^9}, {
   3.672045538865007*^9, 3.672045539648788*^9}, {3.683560433984023*^9, 
   3.6835604428722153`*^9}, {3.70322329058349*^9, 3.703223300606185*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "828.3846523148095`"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"B1", "\[Rule]", 
      RowBox[{"-", "0.38907443433981515`"}]}], ",", 
     RowBox[{"\[Theta]", "\[Rule]", "3307.128883570215`"}], ",", 
     RowBox[{"\[Theta]WS", "\[Rule]", "7904.39680736196`"}], ",", 
     RowBox[{"\[Lambda]", "\[Rule]", "1.2567958590232036`"}], ",", 
     RowBox[{"\[Tau]", "\[Rule]", "3688.202964607966`"}], ",", 
     RowBox[{"\[Tau]WS", "\[Rule]", "11841.252235910608`"}], ",", 
     RowBox[{
      SubscriptBox["r", "2"], "\[Rule]", "1.0262475244905753`"}], ",", 
     RowBox[{
      SubscriptBox["r", "3"], "\[Rule]", "0.9341083437527545`"}], ",", 
     RowBox[{
      SubscriptBox["r", "4"], "\[Rule]", "0.8636937400808428`"}], ",", 
     RowBox[{
      SubscriptBox["r", "5"], "\[Rule]", "0.840706252504208`"}], ",", 
     RowBox[{
      SubscriptBox["r", "6"], "\[Rule]", "0.8176988039163291`"}], ",", 
     RowBox[{
      SubscriptBox["r", "7"], "\[Rule]", "0.7745141473834953`"}], ",", 
     RowBox[{
      SubscriptBox["r", "8"], "\[Rule]", "0.8246003717007252`"}], ",", 
     RowBox[{
      SubscriptBox["r", "9"], "\[Rule]", "0.8267466668965968`"}], ",", 
     RowBox[{
      SubscriptBox["r", "10"], "\[Rule]", "0.7920317397036507`"}], ",", 
     RowBox[{
      SubscriptBox["r", "11"], "\[Rule]", "0.8320032649692969`"}], ",", 
     RowBox[{
      SubscriptBox["r", "12"], "\[Rule]", "0.9444739416282302`"}], ",", 
     RowBox[{
      SubscriptBox["r", "13"], "\[Rule]", "0.8738683521656768`"}], ",", 
     RowBox[{
      SubscriptBox["r", "14"], "\[Rule]", "0.8890753948333341`"}], ",", 
     RowBox[{
      SubscriptBox["r", "15"], "\[Rule]", "0.9900122409327978`"}], ",", 
     RowBox[{
      SubscriptBox["r", "16"], "\[Rule]", "1.0738760237053855`"}], ",", 
     RowBox[{
      SubscriptBox["r", "17"], "\[Rule]", "0.9781510695256148`"}], ",", 
     RowBox[{
      SubscriptBox["r", "18"], "\[Rule]", "1.1583503922383187`"}], ",", 
     RowBox[{
      SubscriptBox["r", "19"], "\[Rule]", "1.4202037577022628`"}], ",", 
     RowBox[{
      SubscriptBox["r", "20"], "\[Rule]", "1.270169086499416`"}], ",", 
     RowBox[{
      SubscriptBox["r", "21"], "\[Rule]", "1.520920746235757`"}], ",", 
     RowBox[{
      SubscriptBox["r", "22"], "\[Rule]", "1.7887316583799917`"}], ",", 
     RowBox[{
      SubscriptBox["r", "23"], "\[Rule]", "2.1631339485601995`"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.655723515224598*^9, 3.655723683982789*^9, 3.665164219809038*^9, 
   3.665164509044293*^9, 3.665165185859571*^9, 3.6651652781717167`*^9, 
   3.671264101128531*^9, 3.6712658544260607`*^9, 3.672045541088449*^9, 
   3.6720468552964373`*^9, 3.672047886054268*^9, 3.67204834779563*^9, 
   3.672048382654563*^9, 3.672048611257934*^9, 3.672048712159747*^9, {
   3.6720487516715918`*^9, 3.672048767584058*^9}, {3.672048835722328*^9, 
   3.672048905286871*^9}, {3.6720489607915688`*^9, 3.672048983093568*^9}, {
   3.672049024956008*^9, 3.672049092302302*^9}, {3.672049123753973*^9, 
   3.672049133523752*^9}, {3.672049199997188*^9, 3.672049220001107*^9}, {
   3.672049277440193*^9, 3.672049295911283*^9}, 3.6835287031062403`*^9, 
   3.683528971678769*^9, {3.6835291694758587`*^9, 3.683529193203306*^9}, 
   3.6835292976849613`*^9, 3.683529361946809*^9, {3.683529393282484*^9, 
   3.683529694733405*^9}, 3.683539988711975*^9, 3.6835407529770184`*^9, 
   3.683541182903041*^9, 3.683541276694541*^9, 3.683541569900022*^9, 
   3.6835426664344*^9, 3.6835429683758793`*^9, 3.683543797562982*^9, 
   3.68356044379464*^9, 3.683560723523041*^9, 3.683561153549687*^9, 
   3.68356343983746*^9, 3.683564365853434*^9, 3.683565263183311*^9, 
   3.683565496504326*^9, 3.683565824580748*^9, 3.683565932183187*^9, 
   3.683566130453537*^9, 3.683566556922467*^9, 3.683566755353915*^9, 
   3.683566953821447*^9, 3.6835671811117773`*^9, 3.683567624447714*^9, 
   3.683567852999707*^9, {3.683568071235001*^9, 3.683568096587556*^9}, 
   3.6835682850093317`*^9, 3.683568477032071*^9, 3.683568700692284*^9, 
   3.6835688783706512`*^9, 3.683569067922269*^9, 3.683569258170224*^9, 
   3.68356936689439*^9, 3.6835694722522707`*^9, 3.68356974294345*^9, 
   3.683570373788971*^9, 3.683570517384529*^9, 3.683570761525785*^9, 
   3.6835710080200233`*^9, 3.683571103237288*^9, 3.6835712231430492`*^9, 
   3.683571415280251*^9, 3.6835716073138742`*^9, 3.683571827296815*^9, 
   3.6835720337593193`*^9, 3.6835722389306297`*^9, 3.683572498342197*^9, 
   3.6835727086887693`*^9, 3.683572924180325*^9, 3.683573116285205*^9, 
   3.683573318665441*^9, 3.683573557369875*^9, 3.68357374038972*^9, 
   3.683573932795394*^9, 3.683574127260614*^9, 3.6835742315061607`*^9, 
   3.683574332554584*^9, 3.6835746169440536`*^9, 3.703221631656246*^9, 
   3.7032233346663313`*^9, 3.70322345387953*^9, 3.7032234929802437`*^9}]
}, Open  ]],

Cell["M2b B0 \[NotEqual] 0 et B1= 0", "Text",
 CellChangeTimes->{{3.648656708520397*^9, 3.648656792652615*^9}, {
  3.6486568734333887`*^9, 3.648656882490163*^9}, {3.653130756605493*^9, 
  3.653130757105775*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"init2b", "=", 
   RowBox[{"Union", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[Theta]", ",", 
         RowBox[{"\[Theta]", "/.", 
          RowBox[{"M0", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Theta]WS", ",", 
         RowBox[{"\[Theta]WS", "/.", 
          RowBox[{"M0", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Tau]", ",", "\[Tau]init"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Tau]WS", ",", "\[Tau]WSinit"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Lambda]", ",", 
         RowBox[{"\[Lambda]", "/.", 
          RowBox[{"M0", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"B0", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"Take", "[", 
      RowBox[{
       RowBox[{"Thread", "[", 
        RowBox[{"{", 
         RowBox[{"tabcoef", ",", "rinit"}], "}"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         RowBox[{"Nchrom", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cons2b", "=", 
   RowBox[{"Union", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Theta]", ">", "0"}], ",", 
       RowBox[{"\[Theta]WS", ">", "0"}], ",", 
       RowBox[{"\[Lambda]", ">", "0"}], ",", 
       RowBox[{"\[Tau]", ">", "0"}], ",", 
       RowBox[{"\[Tau]WS", ">", "0"}]}], "}"}], ",", 
     RowBox[{"Take", "[", 
      RowBox[{
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"#", ">", "0"}], "&"}], ",", "tabcoef"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         RowBox[{"Nchrom", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"M2b", "=", 
  RowBox[{"FindMaximum", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"logLikD1", "[", 
       RowBox[{
       "Nchrom", ",", "pGC", ",", "\[Theta]", ",", "\[Theta]WS", ",", 
        "\[Tau]", ",", "\[Tau]WS", ",", "\[Lambda]", ",", "B0", ",", 
        SuperscriptBox["10", 
         RowBox[{"-", "8"}]], ",", "tabcoef", ",", "tabneutral", ",", "tabWS",
         ",", "tabSW", ",", "Dneutral", ",", "DWS", ",", "DSW"}], "]"}], ",", 
      "cons2b"}], "}"}], ",", "init2b", ",", 
    RowBox[{"AccuracyGoal", "\[Rule]", "6"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.4849918812651997`*^9, 3.4849919131714497`*^9}, {
   3.4849919690620747`*^9, 3.484992003148012*^9}, 3.484992082688813*^9, {
   3.484992141204438*^9, 3.484992231870532*^9}, {3.484992265909301*^9, 
   3.484992343315551*^9}, {3.4849924113150015`*^9, 3.4849924815047894`*^9}, {
   3.489138966926263*^9, 3.489138969941888*^9}, {3.4954718462585*^9, 
   3.4954718693835*^9}, {3.495471912680375*^9, 3.495471913196*^9}, {
   3.495471979196*^9, 3.49547200297725*^9}, {3.495472044617875*^9, 
   3.49547208235225*^9}, {3.496504439538522*^9, 3.496504440085397*^9}, {
   3.49926354336675*^9, 3.4992635633355*^9}, {3.499338237553625*^9, 
   3.499338263178625*^9}, {3.564226049081957*^9, 3.564226105960425*^9}, {
   3.564229115421522*^9, 3.564229190300817*^9}, {3.5642303854180613`*^9, 
   3.564230396396782*^9}, {3.564230879500187*^9, 3.5642309560727453`*^9}, {
   3.5642315198642282`*^9, 3.564231528465914*^9}, {3.564231629325408*^9, 
   3.5642316480873003`*^9}, {3.564231686212853*^9, 3.564231695069336*^9}, {
   3.5642318008190317`*^9, 3.564231879410396*^9}, {3.5642319719944572`*^9, 
   3.5642319918483057`*^9}, {3.564232710118916*^9, 3.564232724696784*^9}, {
   3.564238326760501*^9, 3.564238327311071*^9}, {3.564601563856604*^9, 
   3.564601571055615*^9}, {3.5650404516759357`*^9, 3.5650404566815557`*^9}, {
   3.56504106147506*^9, 3.565041066370307*^9}, {3.5671673292190523`*^9, 
   3.567167356285079*^9}, {3.567167388106946*^9, 3.567167402624468*^9}, {
   3.567167888232828*^9, 3.567167911779674*^9}, {3.5671853673896503`*^9, 
   3.56718537269184*^9}, {3.567276358695696*^9, 3.5672763624599257`*^9}, {
   3.567402613448998*^9, 3.567402637153288*^9}, {3.567404779903269*^9, 
   3.567404782612885*^9}, 3.567839227821903*^9, {3.568717062028139*^9, 
   3.56871706412099*^9}, {3.568718067254978*^9, 3.568718070798678*^9}, {
   3.56871920581846*^9, 3.568719208259226*^9}, {3.568720280637864*^9, 
   3.56872030546612*^9}, 3.593837615935915*^9, {3.6485787078064003`*^9, 
   3.64857876401831*^9}, {3.64857881553244*^9, 3.648578821907339*^9}, {
   3.648579056653618*^9, 3.6485790663089123`*^9}, {3.648579097682631*^9, 
   3.648579101712769*^9}, {3.6485791676861353`*^9, 3.6485791927824717`*^9}, {
   3.648656798138771*^9, 3.648656802131193*^9}, {3.648656844414584*^9, 
   3.648656847512055*^9}, {3.64865688660071*^9, 3.648656897801052*^9}, {
   3.648661271173156*^9, 3.64866128182089*^9}, {3.653130815578032*^9, 
   3.653130825498733*^9}, {3.6533764193808527`*^9, 3.6533764280182858`*^9}, {
   3.672045169678241*^9, 3.6720451721900053`*^9}, {3.673168199753435*^9, 
   3.673168201452075*^9}, {3.6835604484180393`*^9, 3.683560460288101*^9}, {
   3.703223290593528*^9, 3.703223300611805*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "316.75498638329736`"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"B0", "\[Rule]", "0.7117651050347463`"}], ",", 
     RowBox[{"\[Theta]", "\[Rule]", "3292.953274239355`"}], ",", 
     RowBox[{"\[Theta]WS", "\[Rule]", "6663.059513266157`"}], ",", 
     RowBox[{"\[Lambda]", "\[Rule]", "1.6800700498593422`"}], ",", 
     RowBox[{"\[Tau]", "\[Rule]", "3688.7936153083115`"}], ",", 
     RowBox[{"\[Tau]WS", "\[Rule]", "10521.24424309839`"}], ",", 
     RowBox[{
      SubscriptBox["r", "2"], "\[Rule]", "1.0255156135511536`"}], ",", 
     RowBox[{
      SubscriptBox["r", "3"], "\[Rule]", "0.9339691906281254`"}], ",", 
     RowBox[{
      SubscriptBox["r", "4"], "\[Rule]", "0.8641069609744518`"}], ",", 
     RowBox[{
      SubscriptBox["r", "5"], "\[Rule]", "0.8416890914661848`"}], ",", 
     RowBox[{
      SubscriptBox["r", "6"], "\[Rule]", "0.819271225164106`"}], ",", 
     RowBox[{
      SubscriptBox["r", "7"], "\[Rule]", "0.7766365167997823`"}], ",", 
     RowBox[{
      SubscriptBox["r", "8"], "\[Rule]", "0.827586207202545`"}], ",", 
     RowBox[{
      SubscriptBox["r", "9"], "\[Rule]", "0.8305209131461195`"}], ",", 
     RowBox[{
      SubscriptBox["r", "10"], "\[Rule]", "0.7964457554259848`"}], ",", 
     RowBox[{
      SubscriptBox["r", "11"], "\[Rule]", "0.8375315952427931`"}], ",", 
     RowBox[{
      SubscriptBox["r", "12"], "\[Rule]", "0.9518219733504668`"}], ",", 
     RowBox[{
      SubscriptBox["r", "13"], "\[Rule]", "0.8817151873658426`"}], ",", 
     RowBox[{
      SubscriptBox["r", "14"], "\[Rule]", "0.8981821316126516`"}], ",", 
     RowBox[{
      SubscriptBox["r", "15"], "\[Rule]", "1.0014673505838987`"}], ",", 
     RowBox[{
      SubscriptBox["r", "16"], "\[Rule]", "1.0877965332684854`"}], ",", 
     RowBox[{
      SubscriptBox["r", "17"], "\[Rule]", "0.9922556491525151`"}], ",", 
     RowBox[{
      SubscriptBox["r", "18"], "\[Rule]", "1.176815862668442`"}], ",", 
     RowBox[{
      SubscriptBox["r", "19"], "\[Rule]", "1.4450966377304488`"}], ",", 
     RowBox[{
      SubscriptBox["r", "20"], "\[Rule]", "1.2945300758787637`"}], ",", 
     RowBox[{
      SubscriptBox["r", "21"], "\[Rule]", "1.5527023277970151`"}], ",", 
     RowBox[{
      SubscriptBox["r", "22"], "\[Rule]", "1.8292980857982082`"}], ",", 
     RowBox[{
      SubscriptBox["r", "23"], "\[Rule]", "2.2161896606727627`"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.6557235153273573`*^9, 3.6557236840717487`*^9, 3.66516423057953*^9, 
   3.665164509127503*^9, 3.665165185976286*^9, 3.6651652782757177`*^9, 
   3.671264101210328*^9, 3.6712658545094843`*^9, 3.6720455478938513`*^9, 
   3.672046858333191*^9, 3.672047886250587*^9, 3.6720483479160347`*^9, 
   3.6720483828717823`*^9, 3.672048611361772*^9, 3.672048712260195*^9, {
   3.6720487517819366`*^9, 3.6720487682250853`*^9}, {3.672048835822441*^9, 
   3.672048905381732*^9}, {3.6720489608888597`*^9, 3.672048983187784*^9}, {
   3.6720490250532618`*^9, 3.672049092387299*^9}, {3.672049123851028*^9, 
   3.6720491335920887`*^9}, {3.672049200090097*^9, 3.672049220085268*^9}, {
   3.672049277536831*^9, 3.6720492960116997`*^9}, 3.6835287044151993`*^9, 
   3.68352897177258*^9, {3.6835291695717907`*^9, 3.683529195249897*^9}, 
   3.683529297778614*^9, 3.683529362014081*^9, {3.683529393360755*^9, 
   3.6835296948423147`*^9}, 3.683539990959375*^9, {3.683540754472063*^9, 
   3.683540756372615*^9}, 3.683541182999063*^9, 3.683541276784153*^9, 
   3.683541571025956*^9, 3.683542667508408*^9, 3.683542969704924*^9, 
   3.6835437992317467`*^9, 3.683560460563602*^9, 3.683560726807864*^9, 
   3.6835611536370697`*^9, 3.683563441468297*^9, 3.683564365942966*^9, 
   3.683565263277245*^9, 3.68356549657016*^9, 3.6835658246472683`*^9, 
   3.6835659322661953`*^9, 3.683566130538788*^9, 3.6835665570296307`*^9, 
   3.68356675549925*^9, 3.6835669539224997`*^9, 3.683567181212222*^9, 
   3.683567624548128*^9, 3.683567853142989*^9, {3.68356807264086*^9, 
   3.683568096668058*^9}, 3.6835682850929937`*^9, 3.6835684771046133`*^9, 
   3.6835687007658253`*^9, 3.683568878459519*^9, 3.683569068009778*^9, 
   3.683569258232922*^9, 3.683569366959467*^9, 3.683569472332761*^9, 
   3.683569743025321*^9, 3.68357037481102*^9, 3.683570517576284*^9, 
   3.68357076173186*^9, 3.683571008084086*^9, 3.683571103297765*^9, 
   3.683571223227565*^9, 3.6835714153634043`*^9, 3.6835716076236362`*^9, 
   3.6835718275131617`*^9, 3.6835720338588743`*^9, 3.683572239216177*^9, 
   3.683572498432434*^9, 3.683572708773822*^9, 3.6835729242628603`*^9, 
   3.68357311651861*^9, 3.683573318737564*^9, 3.683573557439335*^9, 
   3.68357374064653*^9, 3.68357393304362*^9, 3.683574127325306*^9, 
   3.683574231569852*^9, 3.683574332638693*^9, 3.683574617027419*^9, 
   3.7032216358100767`*^9, 3.703223337023933*^9, 3.703223499931746*^9}]
}, Open  ]],

Cell["M3 B0 \[NotEqual] B1", "Text",
 CellChangeTimes->{{3.648656708520397*^9, 3.648656722573554*^9}, {
  3.6486567636164837`*^9, 3.648656776227512*^9}, {3.6531307616727457`*^9, 
  3.653130761941749*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"init3", "=", 
   RowBox[{"Union", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[Theta]", ",", 
         RowBox[{"\[Theta]", "/.", 
          RowBox[{"M0", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Theta]WS", ",", 
         RowBox[{"\[Theta]WS", "/.", 
          RowBox[{"M0", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Tau]", ",", "\[Tau]init"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Tau]WS", ",", "\[Tau]WSinit"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Lambda]", ",", 
         RowBox[{"\[Lambda]", "/.", 
          RowBox[{"M0", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"B0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"B1", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"Take", "[", 
      RowBox[{
       RowBox[{"Thread", "[", 
        RowBox[{"{", 
         RowBox[{"tabcoef", ",", "rinit"}], "}"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         RowBox[{"Nchrom", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cons3", "=", 
   RowBox[{"Union", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Theta]", ">", "0"}], ",", 
       RowBox[{"\[Theta]WS", ">", "0"}], ",", 
       RowBox[{"\[Lambda]", ">", "0"}], ",", 
       RowBox[{"\[Tau]", ">", "0"}], ",", 
       RowBox[{"\[Tau]WS", ">", "0"}]}], "}"}], ",", 
     RowBox[{"Take", "[", 
      RowBox[{
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"#", ">", "0"}], "&"}], ",", "tabcoef"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         RowBox[{"Nchrom", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"M3", "=", 
  RowBox[{"FindMaximum", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"logLikD1", "[", 
       RowBox[{
       "Nchrom", ",", "pGC", ",", "\[Theta]", ",", "\[Theta]WS", ",", 
        "\[Tau]", ",", "\[Tau]WS", ",", "\[Lambda]", ",", "B0", ",", "B1", 
        ",", "tabcoef", ",", "tabneutral", ",", "tabWS", ",", "tabSW", ",", 
        "Dneutral", ",", "DWS", ",", "DSW"}], "]"}], ",", "cons3"}], "}"}], 
    ",", "init3", ",", 
    RowBox[{"AccuracyGoal", "\[Rule]", "6"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.4849918812651997`*^9, 3.4849919131714497`*^9}, {
   3.4849919690620747`*^9, 3.484992003148012*^9}, 3.484992082688813*^9, {
   3.484992141204438*^9, 3.484992231870532*^9}, {3.484992265909301*^9, 
   3.484992343315551*^9}, {3.4849924113150015`*^9, 3.4849924815047894`*^9}, {
   3.489138966926263*^9, 3.489138969941888*^9}, {3.4954718462585*^9, 
   3.4954718693835*^9}, {3.495471912680375*^9, 3.495471913196*^9}, {
   3.495471979196*^9, 3.49547200297725*^9}, {3.495472044617875*^9, 
   3.49547208235225*^9}, {3.496504439538522*^9, 3.496504440085397*^9}, {
   3.49926354336675*^9, 3.4992635633355*^9}, {3.499338237553625*^9, 
   3.499338263178625*^9}, {3.564226049081957*^9, 3.564226105960425*^9}, {
   3.564229115421522*^9, 3.564229190300817*^9}, {3.5642303854180613`*^9, 
   3.564230396396782*^9}, {3.564230879500187*^9, 3.5642309560727453`*^9}, {
   3.5642315198642282`*^9, 3.564231528465914*^9}, {3.564231629325408*^9, 
   3.5642316480873003`*^9}, {3.564231686212853*^9, 3.564231695069336*^9}, {
   3.5642318008190317`*^9, 3.564231879410396*^9}, {3.5642319719944572`*^9, 
   3.5642319918483057`*^9}, {3.564232710118916*^9, 3.564232724696784*^9}, {
   3.564238326760501*^9, 3.564238327311071*^9}, {3.564601563856604*^9, 
   3.564601571055615*^9}, {3.5650404516759357`*^9, 3.5650404566815557`*^9}, {
   3.56504106147506*^9, 3.565041066370307*^9}, {3.5671673292190523`*^9, 
   3.567167356285079*^9}, {3.567167388106946*^9, 3.567167402624468*^9}, {
   3.567167888232828*^9, 3.567167911779674*^9}, {3.5671853673896503`*^9, 
   3.56718537269184*^9}, {3.567276358695696*^9, 3.5672763624599257`*^9}, {
   3.567402613448998*^9, 3.567402637153288*^9}, {3.567404779903269*^9, 
   3.567404782612885*^9}, 3.567839227821903*^9, {3.568717062028139*^9, 
   3.56871706412099*^9}, {3.568718067254978*^9, 3.568718070798678*^9}, {
   3.56871920581846*^9, 3.568719208259226*^9}, {3.568720280637864*^9, 
   3.56872030546612*^9}, 3.593837615935915*^9, {3.6485787078064003`*^9, 
   3.64857876401831*^9}, {3.64857881553244*^9, 3.648578821907339*^9}, {
   3.648579056653618*^9, 3.6485790663089123`*^9}, {3.648579097682631*^9, 
   3.648579101712769*^9}, {3.6485791676861353`*^9, 3.6485791927824717`*^9}, {
   3.648661171364004*^9, 3.6486611815309896`*^9}, {3.653130840495838*^9, 
   3.653130846626216*^9}, {3.6532008974669733`*^9, 3.653200897746039*^9}, {
   3.653376455901746*^9, 3.653376463494617*^9}, {3.6533798223235693`*^9, 
   3.653379857728095*^9}, {3.672045187110854*^9, 3.672045189262622*^9}, {
   3.6835604670583973`*^9, 3.683560478265409*^9}, {3.703223290601882*^9, 
   3.7032233006170187`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "306.18150777374103`"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"B0", "\[Rule]", "0.7599715962576792`"}], ",", 
     RowBox[{"B1", "\[Rule]", "0.1833240795375282`"}], ",", 
     RowBox[{"\[Theta]", "\[Rule]", "3277.589051603177`"}], ",", 
     RowBox[{"\[Theta]WS", "\[Rule]", "6463.181065668543`"}], ",", 
     RowBox[{"\[Lambda]", "\[Rule]", "1.7697828547055134`"}], ",", 
     RowBox[{"\[Tau]", "\[Rule]", "3689.433791599862`"}], ",", 
     RowBox[{"\[Tau]WS", "\[Rule]", "10288.830104720584`"}], ",", 
     RowBox[{
      SubscriptBox["r", "2"], "\[Rule]", "1.0264333952244677`"}], ",", 
     RowBox[{
      SubscriptBox["r", "3"], "\[Rule]", "0.9356288816152164`"}], ",", 
     RowBox[{
      SubscriptBox["r", "4"], "\[Rule]", "0.8663935680599888`"}], ",", 
     RowBox[{
      SubscriptBox["r", "5"], "\[Rule]", "0.8446370588688992`"}], ",", 
     RowBox[{
      SubscriptBox["r", "6"], "\[Rule]", "0.8228315159781171`"}], ",", 
     RowBox[{
      SubscriptBox["r", "7"], "\[Rule]", "0.7806562966325222`"}], ",", 
     RowBox[{
      SubscriptBox["r", "8"], "\[Rule]", "0.832545954665859`"}], ",", 
     RowBox[{
      SubscriptBox["r", "9"], "\[Rule]", "0.8361659927056813`"}], ",", 
     RowBox[{
      SubscriptBox["r", "10"], "\[Rule]", "0.8024890906142225`"}], ",", 
     RowBox[{
      SubscriptBox["r", "11"], "\[Rule]", "0.8445379907051189`"}], ",", 
     RowBox[{
      SubscriptBox["r", "12"], "\[Rule]", "0.9605120430186981`"}], ",", 
     RowBox[{
      SubscriptBox["r", "13"], "\[Rule]", "0.8904274609743859`"}], ",", 
     RowBox[{
      SubscriptBox["r", "14"], "\[Rule]", "0.907719800304181`"}], ",", 
     RowBox[{
      SubscriptBox["r", "15"], "\[Rule]", "1.012827321127384`"}], ",", 
     RowBox[{
      SubscriptBox["r", "16"], "\[Rule]", "1.1009092363475623`"}], ",", 
     RowBox[{
      SubscriptBox["r", "17"], "\[Rule]", "1.00490888460863`"}], ",", 
     RowBox[{
      SubscriptBox["r", "18"], "\[Rule]", "1.1926277137574999`"}], ",", 
     RowBox[{
      SubscriptBox["r", "19"], "\[Rule]", "1.4654822679080326`"}], ",", 
     RowBox[{
      SubscriptBox["r", "20"], "\[Rule]", "1.3136423343078245`"}], ",", 
     RowBox[{
      SubscriptBox["r", "21"], "\[Rule]", "1.5766254951029766`"}], ",", 
     RowBox[{
      SubscriptBox["r", "22"], "\[Rule]", "1.8586351641697894`"}], ",", 
     RowBox[{
      SubscriptBox["r", "23"], "\[Rule]", "2.253097302609498`"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.6557235155393353`*^9, 3.655723684304555*^9, 3.665164237482161*^9, 
   3.665164509271639*^9, 3.665165186202157*^9, 3.66516527846981*^9, 
   3.671264101497685*^9, 3.671265854792363*^9, 3.672045551381535*^9, 
   3.6720468604141493`*^9, 3.6720478865228558`*^9, 3.672048348222225*^9, 
   3.672048383194289*^9, 3.672048611622284*^9, 3.672048712516078*^9, {
   3.672048752117283*^9, 3.672048768834484*^9}, {3.672048836090185*^9, 
   3.67204890565438*^9}, {3.6720489611455793`*^9, 3.672048983446897*^9}, {
   3.6720490253233*^9, 3.672049092624878*^9}, {3.6720491240119057`*^9, 
   3.672049133743392*^9}, {3.672049200311322*^9, 3.672049220371828*^9}, {
   3.672049277805542*^9, 3.672049296245489*^9}, 3.6835287067099037`*^9, 
   3.6835289721350317`*^9, {3.68352916998287*^9, 3.683529197297242*^9}, 
   3.6835292981719637`*^9, 3.683529362191378*^9, {3.6835293935502357`*^9, 
   3.683529695165653*^9}, 3.683539992506982*^9, 3.6835407577851267`*^9, 
   3.683541183311842*^9, 3.683541277061845*^9, 3.6835415725929403`*^9, 
   3.68354266905394*^9, 3.68354297116436*^9, 3.683543801189036*^9, 
   3.683560479057785*^9, 3.68356072885454*^9, 3.683561153988381*^9, 
   3.6835634434163933`*^9, 3.683564366339937*^9, 3.6835652637072077`*^9, 
   3.6835654967431717`*^9, 3.6835658248203382`*^9, 3.683565932634227*^9, 
   3.683566130848196*^9, 3.683566557349041*^9, 3.683566755851461*^9, 
   3.68356695424506*^9, 3.683567181593128*^9, 3.683567624934196*^9, 
   3.683567853445937*^9, {3.6835680739998217`*^9, 3.683568097036232*^9}, 
   3.683568285436121*^9, 3.683568477313936*^9, 3.683568700970389*^9, 
   3.683568878768058*^9, 3.683569068363557*^9, 3.6835692584049892`*^9, 
   3.683569367130316*^9, 3.683569472599505*^9, 3.6835697433324413`*^9, 
   3.683570376269835*^9, 3.683570517951384*^9, 3.683570762104047*^9, 
   3.683571008258292*^9, 3.683571103471079*^9, 3.683571223664834*^9, 
   3.683571415800171*^9, 3.683571608086981*^9, 3.683571827858419*^9, 
   3.683572034303912*^9, 3.683572239561718*^9, 3.683572498885026*^9, 
   3.683572709224843*^9, 3.683572924737225*^9, 3.683573116824346*^9, 
   3.683573318940032*^9, 3.683573557644038*^9, 3.6835737409614058`*^9, 
   3.683573933358724*^9, 3.683574127499907*^9, 3.683574231753706*^9, 
   3.683574332911257*^9, 3.683574617527326*^9, 3.703223339620172*^9, 
   3.7032235088357153`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Models with errors", "Subsubsection",
 CellChangeTimes->{{3.653132290921894*^9, 3.653132296827187*^9}}],

Cell["M0e", "Text",
 CellChangeTimes->{{3.564254696525721*^9, 3.564254711296219*^9}, 
   3.593837615945965*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"init0e3", "=", 
   RowBox[{"Union", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[Theta]", ",", 
         RowBox[{"\[Theta]", "/.", 
          RowBox[{"M0", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Theta]WS", ",", 
         RowBox[{"\[Theta]WS", "/.", 
          RowBox[{"M0", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Tau]", ",", "\[Tau]init"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Tau]WS", ",", "\[Tau]WSinit"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Lambda]", ",", 
         RowBox[{"\[Lambda]", "/.", 
          RowBox[{"M0", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Epsilon]", ",", "0.01"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Epsilon]WS", ",", "0.01"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Epsilon]SW", ",", "0.005"}], "}"}]}], "}"}], ",", 
     RowBox[{"Take", "[", 
      RowBox[{
       RowBox[{"Thread", "[", 
        RowBox[{"{", 
         RowBox[{"tabcoef", ",", "rinit"}], "}"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         RowBox[{"Nchrom", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cons0e3", "=", 
   RowBox[{"Union", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Theta]", ">", "0"}], ",", 
       RowBox[{"\[Theta]WS", ">", "0"}], ",", 
       RowBox[{"\[Tau]", ">", "0"}], ",", 
       RowBox[{"\[Tau]WS", ">", "0"}], ",", 
       RowBox[{"\[Lambda]", ">", "0"}], ",", 
       RowBox[{"0", "\[LessEqual]", "\[Epsilon]", "\[LessEqual]", 
        RowBox[{"1", "/", "2"}]}], ",", 
       RowBox[{"0", "\[LessEqual]", "\[Epsilon]WS", "\[LessEqual]", 
        RowBox[{"1", "/", "2"}]}], ",", 
       RowBox[{"0", "\[LessEqual]", "\[Epsilon]SW", "\[LessEqual]", 
        RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
     RowBox[{"Take", "[", 
      RowBox[{
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"10", ">", "#", ">", "0"}], "&"}], ",", "tabcoef"}], "]"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         RowBox[{"Nchrom", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"M0e3", "=", 
  RowBox[{"FindMaximum", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"logLikD0err3", "[", 
       RowBox[{
       "Nchrom", ",", "pGC", ",", "\[Theta]", ",", "\[Theta]WS", ",", 
        "\[Tau]", ",", "\[Tau]WS", ",", "\[Lambda]", ",", "tabcoef", ",", 
        "\[Epsilon]", ",", "\[Epsilon]WS", ",", "\[Epsilon]SW", ",", 
        "tabneutral", ",", "tabWS", ",", "tabSW", ",", "Dneutral", ",", "DWS",
         ",", "DSW"}], "]"}], ",", "cons0e3"}], "}"}], ",", "init0e3", ",", 
    RowBox[{"AccuracyGoal", "\[Rule]", "6"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.564257616458166*^9, 3.564257730881503*^9}, {
   3.564258344046747*^9, 3.564258377812049*^9}, {3.564258655633152*^9, 
   3.564258678670308*^9}, {3.564259163230528*^9, 3.564259213154874*^9}, {
   3.5642594916648207`*^9, 3.564259582458425*^9}, {3.564259633488701*^9, 
   3.564259666964861*^9}, {3.564260818745007*^9, 3.564260864821734*^9}, {
   3.5643902471642323`*^9, 3.564390250674714*^9}, {3.56439057196614*^9, 
   3.564390579291585*^9}, {3.564420895627928*^9, 3.564420906750004*^9}, {
   3.564420965661008*^9, 3.564420995681019*^9}, {3.5644218547441053`*^9, 
   3.564421860825508*^9}, {3.564467251194352*^9, 3.564467257536964*^9}, {
   3.5646499378970222`*^9, 3.5646499618894176`*^9}, {3.567168268755954*^9, 
   3.567168296712059*^9}, {3.567185407011644*^9, 3.5671854128426657`*^9}, {
   3.5672764008949413`*^9, 3.567276404918326*^9}, {3.567402919914804*^9, 
   3.567402924165704*^9}, {3.567403185575417*^9, 3.5674032020422983`*^9}, {
   3.567404806027811*^9, 3.56740480860177*^9}, {3.567406538464699*^9, 
   3.567406546001855*^9}, {3.567406580326034*^9, 3.567406609193047*^9}, 
   3.5674070424790087`*^9, {3.567415551539797*^9, 3.567415586527021*^9}, {
   3.56741561812897*^9, 3.567415636781228*^9}, 3.567417199358523*^9, 
   3.5674173052788773`*^9, {3.568717223200315*^9, 3.5687172254265614`*^9}, {
   3.568718164547765*^9, 3.568718167146441*^9}, {3.5687192211762*^9, 
   3.5687192238870792`*^9}, {3.568720345751384*^9, 3.568720357668529*^9}, {
   3.593348004464582*^9, 3.593348027357484*^9}, {3.593348755289654*^9, 
   3.593348784756736*^9}, {3.593349265416524*^9, 3.593349282437333*^9}, {
   3.593349592331809*^9, 3.593349613617342*^9}, {3.5933496669214897`*^9, 
   3.593349668888267*^9}, {3.5933498521197233`*^9, 3.59334986339218*^9}, {
   3.593349919100996*^9, 3.593349935656147*^9}, {3.593506168473413*^9, 
   3.593506207339313*^9}, {3.5935066291522083`*^9, 3.5935066351229353`*^9}, {
   3.59350674608365*^9, 3.593506752461071*^9}, 3.593837615947096*^9, {
   3.648659701231577*^9, 3.6486597397664957`*^9}, {3.648661292615144*^9, 
   3.648661304840163*^9}, {3.653125302110778*^9, 3.653125302898697*^9}, {
   3.653376487620139*^9, 3.6533765066443872`*^9}, 3.653410855964436*^9, 
   3.6536685235857983`*^9, {3.671264126434413*^9, 3.6712641318174458`*^9}, {
   3.671264194841735*^9, 3.6712642139197407`*^9}, {3.671264249211735*^9, 
   3.671264268033442*^9}, {3.672045280866219*^9, 3.672045283697871*^9}, {
   3.683560489230153*^9, 3.683560505510454*^9}, {3.7032232906091137`*^9, 
   3.703223300622629*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "880.0253503482775`"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Epsilon]", "\[Rule]", "0.01251412626162494`"}], ",", 
     RowBox[{"\[Epsilon]SW", "\[Rule]", "5.1475264909669876`*^-8"}], ",", 
     RowBox[{"\[Epsilon]WS", "\[Rule]", "0.027861088040604276`"}], ",", 
     RowBox[{"\[Theta]", "\[Rule]", "3325.420031942634`"}], ",", 
     RowBox[{"\[Theta]WS", "\[Rule]", "7844.732002622396`"}], ",", 
     RowBox[{"\[Lambda]", "\[Rule]", "1.3043866053549562`"}], ",", 
     RowBox[{"\[Tau]", "\[Rule]", "3735.926639402741`"}], ",", 
     RowBox[{"\[Tau]WS", "\[Rule]", "11730.054902232525`"}], ",", 
     RowBox[{
      SubscriptBox["r", "2"], "\[Rule]", "1.025837090689176`"}], ",", 
     RowBox[{
      SubscriptBox["r", "3"], "\[Rule]", "0.9331914915129679`"}], ",", 
     RowBox[{
      SubscriptBox["r", "4"], "\[Rule]", "0.8631606650346716`"}], ",", 
     RowBox[{
      SubscriptBox["r", "5"], "\[Rule]", "0.8391078525177985`"}], ",", 
     RowBox[{
      SubscriptBox["r", "6"], "\[Rule]", "0.8164549397342644`"}], ",", 
     RowBox[{
      SubscriptBox["r", "7"], "\[Rule]", "0.7736746971342641`"}], ",", 
     RowBox[{
      SubscriptBox["r", "8"], "\[Rule]", "0.8235429844275488`"}], ",", 
     RowBox[{
      SubscriptBox["r", "9"], "\[Rule]", "0.8253866576973976`"}], ",", 
     RowBox[{
      SubscriptBox["r", "10"], "\[Rule]", "0.7907646512774252`"}], ",", 
     RowBox[{
      SubscriptBox["r", "11"], "\[Rule]", "0.8304659257772122`"}], ",", 
     RowBox[{
      SubscriptBox["r", "12"], "\[Rule]", "0.9425291336739231`"}], ",", 
     RowBox[{
      SubscriptBox["r", "13"], "\[Rule]", "0.8717934262151122`"}], ",", 
     RowBox[{
      SubscriptBox["r", "14"], "\[Rule]", "0.8864803183236583`"}], ",", 
     RowBox[{
      SubscriptBox["r", "15"], "\[Rule]", "0.9867326771444705`"}], ",", 
     RowBox[{
      SubscriptBox["r", "16"], "\[Rule]", "1.0691028187130516`"}], ",", 
     RowBox[{
      SubscriptBox["r", "17"], "\[Rule]", "0.9713464768969846`"}], ",", 
     RowBox[{
      SubscriptBox["r", "18"], "\[Rule]", "1.1497790596977842`"}], ",", 
     RowBox[{
      SubscriptBox["r", "19"], "\[Rule]", "1.4095697134412069`"}], ",", 
     RowBox[{
      SubscriptBox["r", "20"], "\[Rule]", "1.2444404785695073`"}], ",", 
     RowBox[{
      SubscriptBox["r", "21"], "\[Rule]", "1.4791571830534536`"}], ",", 
     RowBox[{
      SubscriptBox["r", "22"], "\[Rule]", "1.6977665640567319`"}], ",", 
     RowBox[{
      SubscriptBox["r", "23"], "\[Rule]", "1.9699989333284496`"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.5995007940776167`*^9, 3.602421916837772*^9, 3.648659260693906*^9, 
   3.648659680612892*^9, 3.648659740553383*^9, 3.648659802724764*^9, 
   3.648659848912581*^9, 3.6486600848596697`*^9, 3.648661305391821*^9, 
   3.6531252734153347`*^9, 3.65312530349654*^9, 3.6531292172746*^9, 
   3.653130699725827*^9, 3.653130869352708*^9, 3.65313180606428*^9, 
   3.653132303804392*^9, 3.653132708323833*^9, 3.653132863265252*^9, 
   3.653132986305839*^9, 3.653190722459667*^9, 3.653195396990244*^9, 
   3.653195531961707*^9, 3.653195614672546*^9, 3.6531956941218843`*^9, 
   3.653195823590609*^9, 3.653195929407233*^9, 3.653196133016914*^9, 
   3.653196184741982*^9, 3.653196319884708*^9, {3.653196356175405*^9, 
   3.6531963773738613`*^9}, {3.653196485581181*^9, 3.653196515186325*^9}, {
   3.653196547148143*^9, 3.653196593888598*^9}, 3.653196658277032*^9, 
   3.6531970468249807`*^9, 3.653197265453133*^9, 3.653197335815269*^9, 
   3.653197387374618*^9, 3.653197442644989*^9, 3.653197543450449*^9, 
   3.653197573721922*^9, 3.6531981355684032`*^9, 3.653200902213203*^9, 
   3.653201012776745*^9, 3.653211649993434*^9, 3.6533765086734*^9, 
   3.6533794992011547`*^9, 3.653379882777533*^9, 3.653379929432064*^9, 
   3.6533806527253923`*^9, 3.6534081068229322`*^9, 3.6534108595419903`*^9, 
   3.653666551499406*^9, 3.653668123064827*^9, 3.6536682633417377`*^9, 
   3.653668356913517*^9, {3.6536683898920403`*^9, 3.653668408082324*^9}, 
   3.653668476055203*^9, {3.653668519924258*^9, 3.65366852437462*^9}, {
   3.653668595178966*^9, 3.6536686146447163`*^9}, {3.6536686471807632`*^9, 
   3.6536686896512403`*^9}, 3.6536688069370613`*^9, 3.6536688575929203`*^9, 
   3.653668946861158*^9, 3.6536689826004763`*^9, 3.653669184798428*^9, 
   3.653669253240733*^9, 3.6536693659645*^9, {3.6536694587787237`*^9, 
   3.65366949839683*^9}, {3.6536695373388157`*^9, 3.653669555608197*^9}, {
   3.653669591628388*^9, 3.653669662133872*^9}, 3.653669706496007*^9, 
   3.653669747252042*^9, 3.653669798107226*^9, 3.653669877403408*^9, 
   3.653669927890679*^9, 3.65367064446001*^9, 3.655625610609723*^9, 
   3.655723478380067*^9, 3.655723515894157*^9, 3.6557236045115013`*^9, 
   3.65572368649631*^9, 3.655723717489428*^9, 3.66516424364857*^9, 
   3.665164512473871*^9, {3.6651651900380573`*^9, 3.665165214758657*^9}, 
   3.665165280509602*^9, {3.67126409825031*^9, 3.671264134241914*^9}, 
   3.6712642703319674`*^9, 3.671264351634*^9, 3.671265855284031*^9, 
   3.672045643643283*^9, 3.672045872349209*^9, 3.6720468636497297`*^9, 
   3.6720478869895144`*^9, 3.672048348717883*^9, 3.672048383696312*^9, 
   3.672048612069536*^9, 3.6720487129320307`*^9, {3.672048753808763*^9, 
   3.672048769674459*^9}, {3.672048836478615*^9, 3.672048906115055*^9}, {
   3.672048961536978*^9, 3.672048983827627*^9}, {3.6720490257169437`*^9, 
   3.6720490929864073`*^9}, {3.67204912422573*^9, 3.672049133929121*^9}, {
   3.6720492006379747`*^9, 3.672049220742285*^9}, {3.6720492782363997`*^9, 
   3.672049296600704*^9}, 3.6835287118795233`*^9, 3.683528972579439*^9, {
   3.683529170402012*^9, 3.683529199371142*^9}, 3.683529298611476*^9, 
   3.683529362366969*^9, {3.6835293937302313`*^9, 3.6835296443658457`*^9}, {
   3.683529674560522*^9, 3.683529695631879*^9}, 3.683539994248774*^9, 
   3.683540762788239*^9, 3.68354118375056*^9, 3.683541277538715*^9, 
   3.683541577504375*^9, 3.6835426708777657`*^9, 3.683542972428297*^9, 
   3.6835438031723213`*^9, 3.683560506059218*^9, 3.68356073622329*^9, 
   3.683561154451941*^9, 3.683563445533689*^9, 3.683564366763568*^9, 
   3.683565264197227*^9, 3.683565825002241*^9, 3.683565932985886*^9, 
   3.683566131244143*^9, 3.683566557804101*^9, 3.683566756211638*^9, 
   3.683566954700204*^9, 3.6835671819481688`*^9, 3.683567625292913*^9, 
   3.6835678537966223`*^9, {3.683568075387454*^9, 3.683568097476763*^9}, 
   3.683568285874424*^9, 3.683568477665387*^9, 3.683568701292591*^9, 
   3.68356887919414*^9, 3.683569068803385*^9, 3.6835692585775433`*^9, 
   3.683569367306684*^9, 3.683569473114667*^9, 3.683569743858179*^9, 
   3.683570378307778*^9, 3.683570518409398*^9, 3.6835707625238953`*^9, 
   3.683571008438157*^9, 3.683571103652213*^9, 3.683571224018777*^9, 
   3.6835714161501093`*^9, 3.6835716085832357`*^9, 3.683571828247821*^9, 
   3.683572034680439*^9, 3.6835722399327717`*^9, 3.683572499236829*^9, 
   3.6835727095803337`*^9, 3.683572925094657*^9, 3.683573117172696*^9, 
   3.683573319420945*^9, 3.6835735581529837`*^9, 3.683573741315983*^9, 
   3.683573933717662*^9, 3.683574127677679*^9, 3.683574232109741*^9, 
   3.683574333534875*^9, 3.6835746179556103`*^9, 3.7032216437048388`*^9, 
   3.703223343897129*^9, 3.703223519312275*^9}]
}, Open  ]],

Cell["M1e", "Text",
 CellChangeTimes->{{3.564254696525721*^9, 3.564254711296219*^9}, {
   3.5642548723629217`*^9, 3.564254872553527*^9}, 3.593837615952228*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"init1e3", "=", 
   RowBox[{"Union", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[Theta]", ",", 
         RowBox[{"\[Theta]", "/.", 
          RowBox[{"M1", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Theta]WS", ",", 
         RowBox[{"\[Theta]WS", "/.", 
          RowBox[{"M1", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Tau]", ",", "\[Tau]init"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Tau]WS", ",", "\[Tau]WSinit"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Lambda]", ",", 
         RowBox[{"\[Lambda]", "/.", 
          RowBox[{"M1", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"B", ",", 
         RowBox[{"B", "/.", 
          RowBox[{"M1", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Epsilon]", ",", 
         RowBox[{"\[Epsilon]", "/.", 
          RowBox[{"M0e3", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Epsilon]WS", ",", 
         RowBox[{"\[Epsilon]WS", "/.", 
          RowBox[{"M0e3", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Epsilon]SW", ",", 
         RowBox[{"\[Epsilon]SW", "/.", 
          RowBox[{"M0e3", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"Take", "[", 
      RowBox[{
       RowBox[{"Thread", "[", 
        RowBox[{"{", 
         RowBox[{"tabcoef", ",", "rinit"}], "}"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         RowBox[{"Nchrom", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cons1e3", "=", 
   RowBox[{"Union", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Theta]", ">", "0"}], ",", 
       RowBox[{"\[Theta]WS", ">", "0"}], ",", 
       RowBox[{"\[Tau]", ">", "0"}], ",", 
       RowBox[{"\[Tau]WS", ">", "0"}], ",", 
       RowBox[{
        RowBox[{"-", "1"}], "<", "B", "<", "10"}], ",", 
       RowBox[{"\[Lambda]", ">", "0"}], ",", 
       RowBox[{"0", "\[LessEqual]", "\[Epsilon]", "\[LessEqual]", 
        RowBox[{"1", "/", "2"}]}], ",", 
       RowBox[{"0", "\[LessEqual]", "\[Epsilon]WS", "\[LessEqual]", 
        RowBox[{"1", "/", "2"}]}], ",", 
       RowBox[{"0", "\[LessEqual]", "\[Epsilon]SW", "\[LessEqual]", 
        RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
     RowBox[{"Take", "[", 
      RowBox[{
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"10", ">", "#", ">", "0"}], "&"}], ",", "tabcoef"}], "]"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         RowBox[{"Nchrom", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"M1e3", "=", 
  RowBox[{"FindMaximum", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"logLikD1err3", "[", 
       RowBox[{
       "Nchrom", ",", "pGC", ",", "\[Theta]", ",", "\[Theta]WS", ",", 
        "\[Tau]", ",", "\[Tau]WS", ",", "\[Lambda]", ",", "B", ",", "B", ",", 
        "tabcoef", ",", "\[Epsilon]", ",", "\[Epsilon]WS", ",", 
        "\[Epsilon]SW", ",", "tabneutral", ",", "tabWS", ",", "tabSW", ",", 
        "Dneutral", ",", "DWS", ",", "DSW"}], "]"}], ",", "cons1e3"}], "}"}], 
    ",", "init1e3", ",", 
    RowBox[{"AccuracyGoal", "\[Rule]", "6"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.5642577241235847`*^9, 3.564257749704468*^9}, {
   3.5642578206053534`*^9, 3.564257824227219*^9}, {3.564257894510888*^9, 
   3.564257920556471*^9}, {3.564258085258842*^9, 3.5642581876178913`*^9}, {
   3.564258437640936*^9, 3.564258451734435*^9}, {3.5642584918053417`*^9, 
   3.564258562844203*^9}, {3.564258714773546*^9, 3.56425884308426*^9}, {
   3.564258913465157*^9, 3.564258919025383*^9}, {3.5642595973546877`*^9, 
   3.564259597738083*^9}, {3.564259769334746*^9, 3.564259839905995*^9}, {
   3.564260349531742*^9, 3.5642603571948977`*^9}, {3.56426040695984*^9, 
   3.5642606000949306`*^9}, {3.564390716440209*^9, 3.564390721051715*^9}, {
   3.564390868789227*^9, 3.5643908814673634`*^9}, {3.5643909181864567`*^9, 
   3.564390947606907*^9}, {3.564390989749899*^9, 3.564390991974864*^9}, {
   3.56439129718023*^9, 3.564391297415978*^9}, {3.564418884264182*^9, 
   3.564418896958001*^9}, {3.5644190406825743`*^9, 3.564419044996611*^9}, {
   3.564419102123251*^9, 3.564419105456602*^9}, {3.5644191647086782`*^9, 
   3.564419172099958*^9}, {3.5644193422987967`*^9, 3.5644193452088842`*^9}, {
   3.564420558146777*^9, 3.564420562328792*^9}, {3.564420598667795*^9, 
   3.564420599625935*^9}, {3.564420749874487*^9, 3.564420760079729*^9}, {
   3.5644214018364162`*^9, 3.5644214155825233`*^9}, {3.564421493825964*^9, 
   3.56442149872165*^9}, {3.56442158005374*^9, 3.5644216371845703`*^9}, {
   3.564466455261829*^9, 3.5644664633714523`*^9}, {3.564466581973983*^9, 
   3.5644665866190357`*^9}, {3.5644666588121023`*^9, 3.564466660689242*^9}, {
   3.564642471434883*^9, 3.5646426547488203`*^9}, {3.564938675319601*^9, 
   3.5649388420628653`*^9}, {3.565005979756937*^9, 3.56500599040947*^9}, {
   3.565041114867258*^9, 3.565041210507667*^9}, {3.565082155936466*^9, 
   3.565082177899263*^9}, {3.567168311113689*^9, 3.5671683659283743`*^9}, {
   3.567185422796089*^9, 3.567185433579032*^9}, {3.567276442405864*^9, 
   3.567276445661359*^9}, {3.567402930340309*^9, 3.5674029347387657`*^9}, {
   3.5674032056564093`*^9, 3.567403237571084*^9}, {3.567403306467596*^9, 
   3.567403309876526*^9}, {3.567404790109828*^9, 3.567404799243469*^9}, {
   3.567404863571045*^9, 3.567404863706314*^9}, 3.567786264887442*^9, {
   3.5687172398281403`*^9, 3.568717242708214*^9}, {3.56871817832001*^9, 
   3.568718180524124*^9}, {3.568719229896356*^9, 3.568719232191062*^9}, {
   3.5687203719014273`*^9, 3.568720377819476*^9}, {3.59334744200837*^9, 
   3.5933474780586576`*^9}, {3.5933480859640007`*^9, 3.593348107245837*^9}, {
   3.5933481492533216`*^9, 3.593348149422243*^9}, {3.593348774048688*^9, 
   3.593348797437286*^9}, {3.593349298503961*^9, 3.5933493159196653`*^9}, {
   3.593349408554369*^9, 3.5933494229177094`*^9}, {3.593349498487121*^9, 
   3.593349499417815*^9}, {3.593453567605763*^9, 3.59345363251348*^9}, {
   3.5935058580845737`*^9, 3.593505909575251*^9}, {3.593506003008971*^9, 
   3.593506004345495*^9}, {3.593506064692576*^9, 3.5935060659646177`*^9}, {
   3.5935060998487597`*^9, 3.5935061528346987`*^9}, 3.593506284370851*^9, {
   3.5935063165190687`*^9, 3.593506329152761*^9}, {3.593506769797804*^9, 
   3.593506824166952*^9}, {3.5935075767439737`*^9, 3.5935075769105377`*^9}, {
   3.593507734165144*^9, 3.59350775346859*^9}, {3.593507905312686*^9, 
   3.5935079399262943`*^9}, {3.593759692017202*^9, 3.5937597140436287`*^9}, {
   3.593767245913066*^9, 3.593767247336506*^9}, 3.593837615953558*^9, {
   3.648659358499181*^9, 3.648659365858315*^9}, {3.6486598659101152`*^9, 
   3.648659875432884*^9}, {3.648660098336587*^9, 3.6486600999600554`*^9}, {
   3.648660165350772*^9, 3.6486601659886627`*^9}, {3.648661318947104*^9, 
   3.648661329650587*^9}, {3.653125308568232*^9, 3.653125309406513*^9}, {
   3.653196716577393*^9, 3.653196719736198*^9}, {3.653376517205673*^9, 
   3.653376529495905*^9}, {3.6712866165845013`*^9, 3.671286633424461*^9}, {
   3.672045291106077*^9, 3.6720453153055677`*^9}, {3.6835605306968937`*^9, 
   3.683560561018238*^9}, {3.703223290617618*^9, 3.7032233006280212`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "372.2880296184303`"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"B", "\[Rule]", "0.7626690452511011`"}], ",", 
     RowBox[{"\[Epsilon]", "\[Rule]", "0.022098528165022755`"}], ",", 
     RowBox[{"\[Epsilon]SW", "\[Rule]", "1.657177015131856`*^-7"}], ",", 
     RowBox[{"\[Epsilon]WS", "\[Rule]", "0.08410458481838715`"}], ",", 
     RowBox[{"\[Theta]", "\[Rule]", "3309.541466644673`"}], ",", 
     RowBox[{"\[Theta]WS", "\[Rule]", "6723.562220317866`"}], ",", 
     RowBox[{"\[Lambda]", "\[Rule]", "1.7476510061569792`"}], ",", 
     RowBox[{"\[Tau]", "\[Rule]", "3774.5620407462243`"}], ",", 
     RowBox[{"\[Tau]WS", "\[Rule]", "10858.650067102302`"}], ",", 
     RowBox[{
      SubscriptBox["r", "2"], "\[Rule]", "1.0330225113504652`"}], ",", 
     RowBox[{
      SubscriptBox["r", "3"], "\[Rule]", "0.9430868054750499`"}], ",", 
     RowBox[{
      SubscriptBox["r", "4"], "\[Rule]", "0.875816978193801`"}], ",", 
     RowBox[{
      SubscriptBox["r", "5"], "\[Rule]", "0.8524938870795914`"}], ",", 
     RowBox[{
      SubscriptBox["r", "6"], "\[Rule]", "0.8318635716712383`"}], ",", 
     RowBox[{
      SubscriptBox["r", "7"], "\[Rule]", "0.7902916280435167`"}], ",", 
     RowBox[{
      SubscriptBox["r", "8"], "\[Rule]", "0.8423845120084696`"}], ",", 
     RowBox[{
      SubscriptBox["r", "9"], "\[Rule]", "0.8450304098961914`"}], ",", 
     RowBox[{
      SubscriptBox["r", "10"], "\[Rule]", "0.8103483637605007`"}], ",", 
     RowBox[{
      SubscriptBox["r", "11"], "\[Rule]", "0.8509919860649948`"}], ",", 
     RowBox[{
      SubscriptBox["r", "12"], "\[Rule]", "0.9658765102426621`"}], ",", 
     RowBox[{
      SubscriptBox["r", "13"], "\[Rule]", "0.8929844626214665`"}], ",", 
     RowBox[{
      SubscriptBox["r", "14"], "\[Rule]", "0.9065334588220008`"}], ",", 
     RowBox[{
      SubscriptBox["r", "15"], "\[Rule]", "1.0074402665596491`"}], ",", 
     RowBox[{
      SubscriptBox["r", "16"], "\[Rule]", "1.088485319613628`"}], ",", 
     RowBox[{
      SubscriptBox["r", "17"], "\[Rule]", "0.9833288662101706`"}], ",", 
     RowBox[{
      SubscriptBox["r", "18"], "\[Rule]", "1.1604953878523152`"}], ",", 
     RowBox[{
      SubscriptBox["r", "19"], "\[Rule]", "1.418966993472293`"}], ",", 
     RowBox[{
      SubscriptBox["r", "20"], "\[Rule]", "1.224129785961538`"}], ",", 
     RowBox[{
      SubscriptBox["r", "21"], "\[Rule]", "1.4347207857751618`"}], ",", 
     RowBox[{
      SubscriptBox["r", "22"], "\[Rule]", "1.5838305241533368`"}], ",", 
     RowBox[{
      SubscriptBox["r", "23"], "\[Rule]", "1.7474092600744255`"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.599500803995963*^9, 3.6024219225521708`*^9, 3.648659264615419*^9, 
   3.6486593668914967`*^9, 3.648659537247431*^9, 3.64865987741969*^9, 
   3.648660009068657*^9, {3.6486600867115717`*^9, 3.64866010056397*^9}, 
   3.648660166850325*^9, 3.648660294199308*^9, 3.6486612212269087`*^9, 
   3.648661330641534*^9, 3.6531253111379004`*^9, 3.653130702972917*^9, 
   3.653130871372448*^9, 3.653131808231662*^9, 3.6531323066124363`*^9, 
   3.653132709204468*^9, 3.653132864193219*^9, 3.6531329880584373`*^9, 
   3.6531907242646933`*^9, 3.653195397755371*^9, 3.653195532779398*^9, 
   3.653195615269182*^9, 3.6531956947171707`*^9, 3.653195824264473*^9, 
   3.6531959302248583`*^9, 3.653196133860128*^9, 3.653196185370811*^9, 
   3.65319632066702*^9, {3.6531963569397163`*^9, 3.653196378206353*^9}, {
   3.653196486146728*^9, 3.653196515874874*^9}, {3.6531965478692617`*^9, 
   3.653196594338542*^9}, 3.653196666734537*^9, 3.6531967212156563`*^9, 
   3.6531970474128847`*^9, 3.6531972657686167`*^9, 3.653197336060123*^9, 
   3.6531973880084467`*^9, 3.65319744319646*^9, 3.653197543883486*^9, 
   3.653197574163287*^9, 3.653198137514286*^9, 3.653200906034515*^9, 
   3.653201013381082*^9, 3.6532116515381737`*^9, 3.653376531029168*^9, 
   3.653379937910523*^9, 3.6533806568284283`*^9, 3.6536665531008577`*^9, 
   3.6536681248489656`*^9, 3.653668263697904*^9, 3.653668357912464*^9, {
   3.653668390965234*^9, 3.653668408869916*^9}, 3.65366847697526*^9, 
   3.653668526281382*^9, {3.6536685958273373`*^9, 3.653668615213118*^9}, {
   3.6536686478281813`*^9, 3.6536686902376423`*^9}, 3.653668807631391*^9, 
   3.6536688594937353`*^9, 3.6536689474865932`*^9, 3.653668983333927*^9, 
   3.653669185370502*^9, 3.653669253832367*^9, 3.653669367698649*^9, {
   3.6536694588117237`*^9, 3.653669499114163*^9}, {3.6536695378664303`*^9, 
   3.653669556194105*^9}, {3.65366959227419*^9, 3.6536696628360853`*^9}, 
   3.6536697068634*^9, 3.653669749374065*^9, 3.653669798495797*^9, 
   3.653669878143621*^9, 3.653669928524699*^9, 3.653670646539217*^9, 
   3.6556256107910967`*^9, 3.655723516760633*^9, 3.6557236084819937`*^9, 
   3.655723688975319*^9, 3.655723721299821*^9, 3.665164256576199*^9, 
   3.665164523855748*^9, {3.665165192075356*^9, 3.665165216342782*^9}, 
   3.665165282293638*^9, 3.671264338711153*^9, 3.671265856402609*^9, 
   3.67204564877514*^9, 3.672045875641304*^9, 3.672046867174794*^9, 
   3.6720478881025248`*^9, 3.6720483498461533`*^9, 3.672048384836919*^9, 
   3.672048613101573*^9, 3.672048713828554*^9, {3.672048755088066*^9, 
   3.672048770362294*^9}, {3.672048837443441*^9, 3.672048907246187*^9}, {
   3.672048963592452*^9, 3.672048984736895*^9}, {3.672049026664275*^9, 
   3.6720490938636093`*^9}, {3.672049124676524*^9, 3.6720491343818083`*^9}, {
   3.6720492014708557`*^9, 3.672049221683584*^9}, {3.672049279426157*^9, 
   3.672049297545207*^9}, 3.6835287144924192`*^9, 3.683528974138938*^9, {
   3.6835291719084253`*^9, 3.683529200900136*^9}, 3.683529300128289*^9, 
   3.683529362955244*^9, {3.6835293943376637`*^9, 3.683529644991246*^9}, {
   3.6835296757213182`*^9, 3.6835296969022617`*^9}, 3.683539997170865*^9, 
   3.6835407739074373`*^9, 3.683541184866542*^9, 3.683541278667253*^9, 
   3.683541580337593*^9, 3.6835426733542347`*^9, 3.683542973863886*^9, 
   3.683543805465554*^9, 3.683560564182987*^9, 3.683560739242301*^9, 
   3.683561156206861*^9, 3.6835634478368063`*^9, 3.6835643683948593`*^9, 
   3.6835652657149963`*^9, 3.6835658256598673`*^9, 3.683565934182087*^9, 
   3.683566132528893*^9, 3.683566559102751*^9, 3.6835667574964952`*^9, 
   3.683566955951796*^9, 3.683567183284952*^9, 3.6835676266118193`*^9, 
   3.683567855092758*^9, {3.683568077250691*^9, 3.683568098706582*^9}, 
   3.6835682870769367`*^9, 3.683568478557192*^9, 3.6835687021658373`*^9, 
   3.6835688803802977`*^9, 3.683569070057733*^9, 3.683569259281756*^9, 
   3.683569367985112*^9, 3.683569474243462*^9, 3.683569744939864*^9, 
   3.68357038101782*^9, 3.6835705200992403`*^9, 3.6835707640279627`*^9, 
   3.683571009254191*^9, 3.683571104363488*^9, 3.683571225356258*^9, 
   3.683571417357995*^9, 3.6835716100578327`*^9, 3.6835718297459173`*^9, 
   3.683572035928893*^9, 3.683572241228512*^9, 3.6835725004650517`*^9, 
   3.683572710836268*^9, 3.683572926324465*^9, 3.683573118529685*^9, 
   3.6835733202681828`*^9, 3.6835735590274363`*^9, 3.6835737425322943`*^9, 
   3.683573934932382*^9, 3.683574128441957*^9, 3.683574232713573*^9, 
   3.683574334640616*^9, 3.683574619078047*^9, 3.703221650333659*^9, 
   3.703223348490259*^9, 3.7032235227045794`*^9}]
}, Open  ]],

Cell["M2ae B0 = 0 et B1 \[NotEqual] 0", "Text",
 CellChangeTimes->{{3.65313090074037*^9, 3.653130900741921*^9}, {
   3.6531309566707067`*^9, 3.6531309837022743`*^9}, {3.6531310581468554`*^9, 
   3.653131092557337*^9}, 3.653195630275135*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"init2ae3", "=", 
   RowBox[{"Union", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[Theta]", ",", 
         RowBox[{"\[Theta]", "/.", 
          RowBox[{"M1", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Theta]WS", ",", 
         RowBox[{"\[Theta]WS", "/.", 
          RowBox[{"M1", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Tau]", ",", "\[Tau]init"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Tau]WS", ",", "\[Tau]WSinit"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Lambda]", ",", 
         RowBox[{"\[Lambda]", "/.", 
          RowBox[{"M1", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"B1", ",", 
         RowBox[{"B", "/.", 
          RowBox[{"M1", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Epsilon]", ",", 
         RowBox[{"\[Epsilon]", "/.", 
          RowBox[{"M0e3", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Epsilon]WS", ",", 
         RowBox[{"\[Epsilon]WS", "/.", 
          RowBox[{"M0e3", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Epsilon]SW", ",", 
         RowBox[{"\[Epsilon]SW", "/.", 
          RowBox[{"M0e3", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"Take", "[", 
      RowBox[{
       RowBox[{"Thread", "[", 
        RowBox[{"{", 
         RowBox[{"tabcoef", ",", "rinit"}], "}"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         RowBox[{"Nchrom", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cons2ae3", "=", 
   RowBox[{"Union", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Theta]", ">", "0"}], ",", 
       RowBox[{"\[Theta]WS", ">", "0"}], ",", 
       RowBox[{"\[Tau]", ">", "0"}], ",", 
       RowBox[{"\[Tau]WS", ">", "0"}], ",", 
       RowBox[{
        RowBox[{"-", "2"}], "<", "B1", "<", "1"}], ",", 
       RowBox[{"\[Lambda]", ">", "0"}], ",", 
       RowBox[{"0", "\[LessEqual]", "\[Epsilon]", "\[LessEqual]", 
        RowBox[{"1", "/", "2"}]}], ",", 
       RowBox[{"0", "\[LessEqual]", "\[Epsilon]WS", "\[LessEqual]", 
        RowBox[{"1", "/", "2"}]}], ",", 
       RowBox[{"0", "\[LessEqual]", "\[Epsilon]SW", "\[LessEqual]", 
        RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
     RowBox[{"Take", "[", 
      RowBox[{
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"10", ">", "#", ">", "0"}], "&"}], ",", "tabcoef"}], "]"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         RowBox[{"Nchrom", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"M2ae3", "=", 
  RowBox[{"FindMaximum", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"logLikD1err3", "[", 
       RowBox[{
       "Nchrom", ",", "pGC", ",", "\[Theta]", ",", "\[Theta]WS", ",", 
        "\[Tau]", ",", "\[Tau]WS", ",", "\[Lambda]", ",", 
        SuperscriptBox["10", 
         RowBox[{"-", "8"}]], ",", "B1", ",", "tabcoef", ",", "\[Epsilon]", 
        ",", "\[Epsilon]WS", ",", "\[Epsilon]SW", ",", "tabneutral", ",", 
        "tabWS", ",", "tabSW", ",", "Dneutral", ",", "DWS", ",", "DSW"}], 
       "]"}], ",", "cons2ae3"}], "}"}], ",", "init2ae3", ",", 
    RowBox[{"AccuracyGoal", "\[Rule]", "6"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.653130886791933*^9, 3.65313095043122*^9}, {
   3.653132418043232*^9, 3.6531324617937937`*^9}, {3.65337656201611*^9, 
   3.653376569196958*^9}, {3.653668905552739*^9, 3.653668906288521*^9}, {
   3.653669211678705*^9, 3.6536692187740383`*^9}, 3.653669376378745*^9, {
   3.6536697677254333`*^9, 3.653669767932453*^9}, {3.653669813598194*^9, 
   3.653669829895072*^9}, {3.671286644253131*^9, 3.671286645047052*^9}, {
   3.6712867903851233`*^9, 3.671286790395784*^9}, {3.683560574556304*^9, 
   3.683560589411034*^9}, {3.70322329062562*^9, 3.703223300634358*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "780.926999059724`"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"B1", "\[Rule]", 
      RowBox[{"-", "0.9077601060527893`"}]}], ",", 
     RowBox[{"\[Epsilon]", "\[Rule]", "0.093039260427736`"}], ",", 
     RowBox[{"\[Epsilon]SW", "\[Rule]", "0.0758941820362263`"}], ",", 
     RowBox[{"\[Epsilon]WS", "\[Rule]", "0.10731562788632659`"}], ",", 
     RowBox[{"\[Theta]", "\[Rule]", "3629.91091388225`"}], ",", 
     RowBox[{"\[Theta]WS", "\[Rule]", "9040.628182625496`"}], ",", 
     RowBox[{"\[Lambda]", "\[Rule]", "1.1634993886039444`"}], ",", 
     RowBox[{"\[Tau]", "\[Rule]", "4067.2384150054218`"}], ",", 
     RowBox[{"\[Tau]WS", "\[Rule]", "13574.048518975134`"}], ",", 
     RowBox[{
      SubscriptBox["r", "2"], "\[Rule]", "1.0256809478594704`"}], ",", 
     RowBox[{
      SubscriptBox["r", "3"], "\[Rule]", "0.9309386585828561`"}], ",", 
     RowBox[{
      SubscriptBox["r", "4"], "\[Rule]", "0.8545385210267097`"}], ",", 
     RowBox[{
      SubscriptBox["r", "5"], "\[Rule]", "0.8208251255818793`"}], ",", 
     RowBox[{
      SubscriptBox["r", "6"], "\[Rule]", "0.7953663710408657`"}], ",", 
     RowBox[{
      SubscriptBox["r", "7"], "\[Rule]", "0.7478183529674899`"}], ",", 
     RowBox[{
      SubscriptBox["r", "8"], "\[Rule]", "0.782222299827023`"}], ",", 
     RowBox[{
      SubscriptBox["r", "9"], "\[Rule]", "0.7788874190837977`"}], ",", 
     RowBox[{
      SubscriptBox["r", "10"], "\[Rule]", "0.7375037045817741`"}], ",", 
     RowBox[{
      SubscriptBox["r", "11"], "\[Rule]", "0.7663550208464653`"}], ",", 
     RowBox[{
      SubscriptBox["r", "12"], "\[Rule]", "0.8564554410575491`"}], ",", 
     RowBox[{
      SubscriptBox["r", "13"], "\[Rule]", "0.7784508591262311`"}], ",", 
     RowBox[{
      SubscriptBox["r", "14"], "\[Rule]", "0.779426538049189`"}], ",", 
     RowBox[{
      SubscriptBox["r", "15"], "\[Rule]", "0.8496434624302533`"}], ",", 
     RowBox[{
      SubscriptBox["r", "16"], "\[Rule]", "0.9056673098746568`"}], ",", 
     RowBox[{
      SubscriptBox["r", "17"], "\[Rule]", "0.7798979169655204`"}], ",", 
     RowBox[{
      SubscriptBox["r", "18"], "\[Rule]", "0.8938290187121763`"}], ",", 
     RowBox[{
      SubscriptBox["r", "19"], "\[Rule]", "1.0715375072336597`"}], ",", 
     RowBox[{
      SubscriptBox["r", "20"], "\[Rule]", "0.8157526550881586`"}], ",", 
     RowBox[{
      SubscriptBox["r", "21"], "\[Rule]", "0.8312447412730829`"}], ",", 
     RowBox[{
      SubscriptBox["r", "22"], "\[Rule]", "0.6622351912806711`"}], ",", 
     RowBox[{
      SubscriptBox["r", "23"], "\[Rule]", "1.1019223385320052`*^-6"}]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.6531309270700293`*^9, 3.653130951605609*^9}, 
   3.653132319676004*^9, {3.653132424805969*^9, 3.653132462972418*^9}, 
   3.653132709743845*^9, 3.653132864759473*^9, 3.653132989329714*^9, 
   3.653190726503799*^9, 3.6531953986805058`*^9, 3.6531955336683693`*^9, 
   3.653195615939806*^9, 3.65319569561197*^9, 3.6531958248844213`*^9, 
   3.65319593080409*^9, 3.6531961344794407`*^9, 3.653196186052116*^9, 
   3.6531963215224*^9, {3.653196357697673*^9, 3.6531963790102587`*^9}, {
   3.653196486787346*^9, 3.65319651647056*^9}, {3.6531965483870373`*^9, 
   3.6531965946907*^9}, 3.653196667305949*^9, {3.653196725046342*^9, 
   3.653196731344728*^9}, 3.653197048330825*^9, 3.653197266048665*^9, 
   3.653197336372916*^9, 3.6531973889565363`*^9, 3.6531974439352407`*^9, 
   3.6531975443694353`*^9, 3.653197574873674*^9, 3.653198139971973*^9, 
   3.653200908595026*^9, 3.653201013960978*^9, 3.653211656534634*^9, 
   3.653376570151483*^9, 3.653379964118753*^9, 3.6533806616750727`*^9, 
   3.653666553635515*^9, 3.653668125310473*^9, 3.653668263928048*^9, 
   3.6536683586952257`*^9, {3.653668391663615*^9, 3.65366840953393*^9}, 
   3.653668477802978*^9, 3.653668529099391*^9, {3.6536685964613533`*^9, 
   3.653668615978106*^9}, {3.653668648435336*^9, 3.653668690856708*^9}, 
   3.653668808562161*^9, 3.653668863273356*^9, 3.653668907508568*^9, 
   3.653668948140798*^9, 3.653668984022182*^9, {3.6536691933054*^9, 
   3.653669219596286*^9}, 3.653669262178502*^9, {3.653669376639076*^9, 
   3.6536693830258207`*^9}, {3.653669458842342*^9, 3.653669499788308*^9}, {
   3.653669538461523*^9, 3.65366955682054*^9}, {3.653669592918091*^9, 
   3.6536696635667458`*^9}, 3.6536697079862967`*^9, {3.653669754027677*^9, 
   3.653669768533658*^9}, {3.653669800938699*^9, 3.653669831611412*^9}, 
   3.653669878882469*^9, 3.6536699292543697`*^9, 3.6536706492450027`*^9, 
   3.655625610871661*^9, 3.655723517671338*^9, 3.655723616847713*^9, 
   3.6557236917408667`*^9, 3.655723728000813*^9, 3.665164259938121*^9, 
   3.6651645307402697`*^9, {3.665165196349671*^9, 3.665165218867372*^9}, 
   3.665165284405442*^9, 3.671264347135995*^9, 3.671265857512994*^9, 
   3.6720458793408012`*^9, 3.672046876959105*^9, 3.672047889246956*^9, 
   3.672048350963945*^9, 3.672048386255342*^9, 3.6720486141000566`*^9, 
   3.672048714747466*^9, {3.672048756426146*^9, 3.6720487710562153`*^9}, {
   3.67204883855282*^9, 3.672048908411771*^9}, {3.672048964543229*^9, 
   3.672048985680461*^9}, {3.672049028271031*^9, 3.672049048069503*^9}, 
   3.672049094727824*^9, {3.672049125813308*^9, 3.672049134842535*^9}, {
   3.672049202305779*^9, 3.672049222482277*^9}, {3.672049280364312*^9, 
   3.672049298491934*^9}, 3.683528717520381*^9, 3.683528975639669*^9, {
   3.68352917342666*^9, 3.6835292023864527`*^9}, 3.683529301538444*^9, 
   3.683529363528117*^9, {3.6835293950153418`*^9, 3.6835296455871572`*^9}, {
   3.683529676904224*^9, 3.68352969812607*^9}, 3.6835399993070908`*^9, 
   3.683540776517153*^9, 3.683541186148012*^9, 3.6835412799387503`*^9, 
   3.683541587035987*^9, 3.683542674632983*^9, 3.683542975516242*^9, 
   3.683543807073834*^9, 3.683560591155312*^9, 3.6835607440873413`*^9, 
   3.683561157696216*^9, 3.683563449368548*^9, 3.683564369926139*^9, 
   3.6835652672368727`*^9, 3.683565826407477*^9, 3.683565935399329*^9, 
   3.683566133825685*^9, 3.6835665603597383`*^9, 3.68356675896706*^9, 
   3.6835669572521267`*^9, 3.6835671847754793`*^9, 3.6835676280031147`*^9, 
   3.683567856328841*^9, {3.683568079041883*^9, 3.683568100039719*^9}, 
   3.6835682883512497`*^9, 3.683568479347423*^9, 3.683568702951977*^9, 
   3.683568881620098*^9, 3.683569071397882*^9, 3.6835692598497963`*^9, 
   3.683569368623191*^9, 3.68356947541857*^9, 3.683569746115761*^9, 
   3.683570385965641*^9, 3.683570521775552*^9, 3.683570765605268*^9, 
   3.6835710098564587`*^9, 3.683571104943862*^9, 3.683571226679034*^9, 
   3.683571418689411*^9, 3.683571611831543*^9, 3.683571831212328*^9, 
   3.6835720374151983`*^9, 3.683572242568564*^9, 3.683572501901518*^9, 
   3.683572712193245*^9, 3.683572927704336*^9, 3.6835731199752903`*^9, 
   3.6835733214017982`*^9, 3.683573560038664*^9, 3.683573743911414*^9, 
   3.6835739362801857`*^9, 3.683574129011531*^9, 3.6835742332955027`*^9, 
   3.683574335897077*^9, 3.683574620348434*^9, 3.703221657777664*^9, 
   3.7032233702837276`*^9, 3.703223526551448*^9}]
}, Open  ]],

Cell["M2be B0 \[NotEqual] 0 et B1 = 0", "Text",
 CellChangeTimes->{{3.65313090074037*^9, 3.653130900741921*^9}, {
   3.6531309566707067`*^9, 3.6531309837022743`*^9}, {3.6531310581468554`*^9, 
   3.6531311294012957`*^9}, 3.6531956316923656`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"init2be3", "=", 
   RowBox[{"Union", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[Theta]", ",", 
         RowBox[{"\[Theta]", "/.", 
          RowBox[{"M1", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Theta]WS", ",", 
         RowBox[{"\[Theta]WS", "/.", 
          RowBox[{"M1", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Tau]", ",", "\[Tau]init"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Tau]WS", ",", "\[Tau]WSinit"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Lambda]", ",", 
         RowBox[{"\[Lambda]", "/.", 
          RowBox[{"M1", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"B0", ",", 
         RowBox[{"B", "/.", 
          RowBox[{"M1", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Epsilon]", ",", 
         RowBox[{"\[Epsilon]", "/.", 
          RowBox[{"M0e3", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Epsilon]WS", ",", 
         RowBox[{"\[Epsilon]WS", "/.", 
          RowBox[{"M0e3", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Epsilon]SW", ",", 
         RowBox[{"\[Epsilon]SW", "/.", 
          RowBox[{"M0e3", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"Take", "[", 
      RowBox[{
       RowBox[{"Thread", "[", 
        RowBox[{"{", 
         RowBox[{"tabcoef", ",", "rinit"}], "}"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         RowBox[{"Nchrom", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cons2be3", "=", 
   RowBox[{"Union", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Theta]", ">", "0"}], ",", 
       RowBox[{"\[Theta]WS", ">", "0"}], ",", 
       RowBox[{"\[Tau]", ">", "0"}], ",", 
       RowBox[{"\[Tau]WS", ">", "0"}], ",", 
       RowBox[{
        RowBox[{"-", "2"}], "<", "B0", "<", "10"}], ",", 
       RowBox[{"\[Lambda]", ">", "0"}], ",", 
       RowBox[{"0", "\[LessEqual]", "\[Epsilon]", "\[LessEqual]", 
        RowBox[{"1", "/", "2"}]}], ",", 
       RowBox[{"0", "\[LessEqual]", "\[Epsilon]WS", "\[LessEqual]", 
        RowBox[{"1", "/", "2"}]}], ",", 
       RowBox[{"0", "\[LessEqual]", "\[Epsilon]SW", "\[LessEqual]", 
        RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
     RowBox[{"Take", "[", 
      RowBox[{
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"10", ">", "#", ">", "0"}], "&"}], ",", "tabcoef"}], "]"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         RowBox[{"Nchrom", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"M2be3", "=", 
  RowBox[{"FindMaximum", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"logLikD1err3", "[", 
       RowBox[{
       "Nchrom", ",", "pGC", ",", "\[Theta]", ",", "\[Theta]WS", ",", 
        "\[Tau]", ",", "\[Tau]WS", ",", "\[Lambda]", ",", "B0", ",", 
        SuperscriptBox["10", 
         RowBox[{"-", "8"}]], ",", "tabcoef", ",", "\[Epsilon]", ",", 
        "\[Epsilon]WS", ",", "\[Epsilon]SW", ",", "tabneutral", ",", "tabWS", 
        ",", "tabSW", ",", "Dneutral", ",", "DWS", ",", "DSW"}], "]"}], ",", 
      "cons2be3"}], "}"}], ",", "init2be3", ",", 
    RowBox[{"AccuracyGoal", "\[Rule]", "6"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.653130886791933*^9, 3.65313095043122*^9}, {
   3.653131118867268*^9, 3.6531311452042933`*^9}, {3.65313171748112*^9, 
   3.653131717886333*^9}, {3.653132472392177*^9, 3.6531324768912077`*^9}, {
   3.653376583144022*^9, 3.653376590552519*^9}, {3.6533799863512793`*^9, 
   3.6533799873753033`*^9}, {3.65366972764398*^9, 3.653669728491282*^9}, 
   3.671286648320256*^9, 3.6712866788250637`*^9, {3.671286790407669*^9, 
   3.6712867904149942`*^9}, {3.683543156281604*^9, 3.683543169296174*^9}, {
   3.683560605978319*^9, 3.683560621313056*^9}, {3.703223290633761*^9, 
   3.703223300639977*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindMaximum", "::", "cvmit"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Failed to converge to the requested accuracy or precision \
within \[NoBreak]\\!\\(\\*RowBox[{\\\"500\\\"}]\\)\[NoBreak] iterations. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/FindMaximum/cvmit\\\", \
ButtonNote -> \\\"FindMaximum::cvmit\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.683573745951269*^9, 3.683573938322695*^9, 
  3.683574130529203*^9, 3.683574234844507*^9, 3.683574355651314*^9, 
  3.683574642935512*^9, 3.7032216789196997`*^9, 3.7032233901794147`*^9, 
  3.7032235526644583`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "301.7458785256458`"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"B0", "\[Rule]", "0.7434856724483407`"}], ",", 
     RowBox[{"\[Epsilon]", "\[Rule]", "0.05220985313239683`"}], ",", 
     RowBox[{"\[Epsilon]SW", "\[Rule]", "0.039504487727130035`"}], ",", 
     RowBox[{"\[Epsilon]WS", "\[Rule]", "0.06954602768144563`"}], ",", 
     RowBox[{"\[Theta]", "\[Rule]", "3461.834181898679`"}], ",", 
     RowBox[{"\[Theta]WS", "\[Rule]", "7008.431984427326`"}], ",", 
     RowBox[{"\[Lambda]", "\[Rule]", "1.6786902040023237`"}], ",", 
     RowBox[{"\[Tau]", "\[Rule]", "3892.512144921483`"}], ",", 
     RowBox[{"\[Tau]WS", "\[Rule]", "11155.416454924343`"}], ",", 
     RowBox[{
      SubscriptBox["r", "2"], "\[Rule]", "1.021448357252749`"}], ",", 
     RowBox[{
      SubscriptBox["r", "3"], "\[Rule]", "0.9271937624825128`"}], ",", 
     RowBox[{
      SubscriptBox["r", "4"], "\[Rule]", "0.854466851882376`"}], ",", 
     RowBox[{
      SubscriptBox["r", "5"], "\[Rule]", "0.8256309121879256`"}], ",", 
     RowBox[{
      SubscriptBox["r", "6"], "\[Rule]", "0.8025214274910816`"}], ",", 
     RowBox[{
      SubscriptBox["r", "7"], "\[Rule]", "0.7585594648300075`"}], ",", 
     RowBox[{
      SubscriptBox["r", "8"], "\[Rule]", "0.8017490226586301`"}], ",", 
     RowBox[{
      SubscriptBox["r", "9"], "\[Rule]", "0.8022248417868905`"}], ",", 
     RowBox[{
      SubscriptBox["r", "10"], "\[Rule]", "0.7657006748312427`"}], ",", 
     RowBox[{
      SubscriptBox["r", "11"], "\[Rule]", "0.8016735158319709`"}], ",", 
     RowBox[{
      SubscriptBox["r", "12"], "\[Rule]", "0.9053878552900185`"}], ",", 
     RowBox[{
      SubscriptBox["r", "13"], "\[Rule]", "0.8327915478824709`"}], ",", 
     RowBox[{
      SubscriptBox["r", "14"], "\[Rule]", "0.8430120678441324`"}], ",", 
     RowBox[{
      SubscriptBox["r", "15"], "\[Rule]", "0.9322439405085868`"}], ",", 
     RowBox[{
      SubscriptBox["r", "16"], "\[Rule]", "1.005656691894063`"}], ",", 
     RowBox[{
      SubscriptBox["r", "17"], "\[Rule]", "0.895737205993727`"}], ",", 
     RowBox[{
      SubscriptBox["r", "18"], "\[Rule]", "1.049751808776519`"}], ",", 
     RowBox[{
      SubscriptBox["r", "19"], "\[Rule]", "1.2795862600529182`"}], ",", 
     RowBox[{
      SubscriptBox["r", "20"], "\[Rule]", "1.0688027221429033`"}], ",", 
     RowBox[{
      SubscriptBox["r", "21"], "\[Rule]", "1.2054403837390255`"}], ",", 
     RowBox[{
      SubscriptBox["r", "22"], "\[Rule]", "1.2344753027443873`"}], ",", 
     RowBox[{
      SubscriptBox["r", "23"], "\[Rule]", "0.9860315460802921`"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.6531309270700293`*^9, 3.653130951605609*^9}, 
   3.6531311566374598`*^9, 3.6531317306416197`*^9, 3.6531323852175913`*^9, 
   3.653132488651168*^9, 3.6531327154538603`*^9, 3.653132870514339*^9, 
   3.653133001915649*^9, 3.653190742024404*^9, 3.653195411402945*^9, 
   3.653195546567004*^9, 3.653195627561584*^9, 3.6531957068221807`*^9, 
   3.653195835584149*^9, 3.653195941708193*^9, 3.6531961454297047`*^9, 
   3.6531961972440577`*^9, 3.653196334848956*^9, {3.653196366079075*^9, 
   3.6531963921027193`*^9}, {3.653196498255355*^9, 3.6531965281129093`*^9}, {
   3.653196560104303*^9, 3.65319659504257*^9}, 3.653196678262179*^9, 
   3.653196743475956*^9, 3.653197059226672*^9, 3.653197267350418*^9, 
   3.653197338190559*^9, 3.6531974031018476`*^9, 3.653197457945606*^9, 
   3.653197554087295*^9, 3.6531975845352783`*^9, 3.65319815088315*^9, 
   3.653200922699197*^9, 3.653201025776094*^9, 3.6532116659806128`*^9, 
   3.653376592350559*^9, {3.653379971717093*^9, 3.653379987954918*^9}, 
   3.653380666884111*^9, 3.653666554118931*^9, 3.653668125853586*^9, 
   3.6536682642247467`*^9, 3.653668372460573*^9, {3.653668405963428*^9, 
   3.653668420248828*^9}, 3.6536684840223513`*^9, 3.653668548071162*^9, {
   3.653668607850029*^9, 3.6536686920728083`*^9}, 3.653668809103793*^9, 
   3.653668914660523*^9, 3.653668962005685*^9, 3.65366899408436*^9, 
   3.653669194188673*^9, 3.653669225449545*^9, 3.653669262990018*^9, 
   3.6536693869266157`*^9, {3.653669458886298*^9, 3.653669503594203*^9}, {
   3.653669549625677*^9, 3.6536695680691023`*^9}, {3.653669604592984*^9, 
   3.653669664195561*^9}, {3.6536697123482018`*^9, 3.6536697718283787`*^9}, 
   3.653669802139475*^9, 3.6536698358980103`*^9, 3.653669889532234*^9, 
   3.653669944643828*^9, 3.653670652110223*^9, 3.6556256109581633`*^9, 
   3.655723529739664*^9, 3.6557236331039133`*^9, 3.6557237070300417`*^9, 
   3.655723745239415*^9, 3.665164274428423*^9, 3.6651645436555862`*^9, {
   3.665165198714903*^9, 3.6651652211407013`*^9}, 3.665165286497643*^9, 
   3.6712658608563538`*^9, 3.672045900097101*^9, 3.672046904464843*^9, 
   3.672047905038158*^9, 3.672048368449277*^9, 3.67204840255023*^9, 
   3.67204863146483*^9, {3.6720487299294033`*^9, 3.672048771699544*^9}, {
   3.6720488533581057`*^9, 3.672048872866454*^9}, {3.6720489031972113`*^9, 
   3.672048933139801*^9}, {3.672048981164461*^9, 3.672049000935794*^9}, {
   3.672049043666719*^9, 3.6720490951754208`*^9}, {3.672049132474362*^9, 
   3.6720491409569397`*^9}, {3.6720492182158613`*^9, 3.672049233470047*^9}, {
   3.672049294005533*^9, 3.6720493156613894`*^9}, 3.683528721671077*^9, 
   3.6835289777381144`*^9, {3.683529175625437*^9, 3.6835292038723288`*^9}, 
   3.683529303616919*^9, 3.683529364627486*^9, {3.683529396183536*^9, 
   3.6835295517984867`*^9}, {3.683529583507063*^9, 3.683529646794653*^9}, {
   3.683529692531974*^9, 3.6835297164209833`*^9}, 3.683540003697701*^9, 
   3.6835407951301537`*^9, 3.68354120539541*^9, 3.683541300423934*^9, 
   3.683541593081875*^9, 3.683542695342705*^9, 3.68354297799797*^9, {
   3.683543158653798*^9, 3.6835431710092783`*^9}, 3.683543814711187*^9, 
   3.683560623904792*^9, 3.6835607539901457`*^9, 3.683561160002692*^9, 
   3.683563451631198*^9, 3.683564372217132*^9, 3.6835652695750647`*^9, 
   3.683565827691245*^9, 3.683565937435924*^9, 3.6835661358115587`*^9, 
   3.683566562233062*^9, 3.68356676085903*^9, 3.683566959152179*^9, 
   3.683567186814883*^9, 3.683567630135565*^9, 3.683567858327231*^9, {
   3.683568080773407*^9, 3.6835681010801277`*^9}, 3.683568289244596*^9, 
   3.683568494293742*^9, 3.683568704054853*^9, 3.683568883536426*^9, 
   3.683569073559719*^9, 3.6835692613293047`*^9, 3.683569370060418*^9, 
   3.6835694952815332`*^9, 3.683569768839028*^9, 3.6835703906213827`*^9, 
   3.683570524144478*^9, 3.68357076792082*^9, 3.6835710113663588`*^9, 
   3.683571106282572*^9, 3.683571228756592*^9, 3.68357142065184*^9, 
   3.6835716141923027`*^9, 3.683571833123201*^9, 3.683572039556142*^9, 
   3.6835722447969847`*^9, 3.6835725042022963`*^9, 3.683572714372912*^9, 
   3.683572928768395*^9, 3.683573121015121*^9, 3.683573337089967*^9, 
   3.683573561289483*^9, 3.6835737459786654`*^9, 3.683573938348548*^9, 
   3.683574130542199*^9, 3.68357423487678*^9, 3.6835743556779337`*^9, 
   3.683574642954672*^9, 3.703221678940323*^9, 3.7032233902198963`*^9, 
   3.703223552686516*^9}]
}, Open  ]],

Cell["M3e B0 \[NotEqual] B1", "Text",
 CellChangeTimes->{{3.564254696525721*^9, 3.564254711296219*^9}, {
   3.5642548723629217`*^9, 3.564254872553527*^9}, {3.564466261321538*^9, 
   3.564466262346858*^9}, 3.593837615958664*^9, 3.648659316569202*^9, {
   3.653130782746182*^9, 3.65313078302421*^9}, {3.703223604109182*^9, 
   3.703223604311902*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"init3e3", "=", 
   RowBox[{"Union", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[Theta]", ",", 
         RowBox[{"\[Theta]", "/.", 
          RowBox[{"M1", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Theta]WS", ",", 
         RowBox[{"\[Theta]WS", "/.", 
          RowBox[{"M1", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Tau]", ",", "\[Tau]init"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Tau]WS", ",", "\[Tau]WSinit"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Lambda]", ",", 
         RowBox[{"\[Lambda]", "/.", 
          RowBox[{"M1", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"B0", ",", 
         RowBox[{"B", "/.", 
          RowBox[{"M1", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"B1", ",", 
         RowBox[{"B", "/.", 
          RowBox[{"M1", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Epsilon]", ",", 
         RowBox[{"\[Epsilon]", "/.", 
          RowBox[{"M0e3", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Epsilon]WS", ",", 
         RowBox[{"\[Epsilon]WS", "/.", 
          RowBox[{"M0e3", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Epsilon]SW", ",", 
         RowBox[{"\[Epsilon]SW", "/.", 
          RowBox[{"M0e3", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"Take", "[", 
      RowBox[{
       RowBox[{"Thread", "[", 
        RowBox[{"{", 
         RowBox[{"tabcoef", ",", "rinit"}], "}"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         RowBox[{"Nchrom", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cons3e3", "=", 
   RowBox[{"Union", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Theta]", ">", "0"}], ",", 
       RowBox[{"\[Theta]WS", ">", "0"}], ",", 
       RowBox[{"\[Tau]", ">", "0"}], ",", 
       RowBox[{"\[Tau]WS", ">", "0"}], ",", 
       RowBox[{
        RowBox[{"-", "1"}], "<", "B0", "<", "10"}], ",", 
       RowBox[{
        RowBox[{"-", "1"}], "<", "B1", "<", "10"}], ",", 
       RowBox[{"\[Lambda]", ">", "0"}], ",", 
       RowBox[{"0", "\[LessEqual]", "\[Epsilon]", "\[LessEqual]", 
        RowBox[{"1", "/", "2"}]}], ",", 
       RowBox[{"0", "\[LessEqual]", "\[Epsilon]WS", "\[LessEqual]", 
        RowBox[{"1", "/", "2"}]}], ",", 
       RowBox[{"0", "\[LessEqual]", "\[Epsilon]SW", "\[LessEqual]", 
        RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
     RowBox[{"Take", "[", 
      RowBox[{
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"10", ">", "#", ">", "0"}], "&"}], ",", "tabcoef"}], "]"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         RowBox[{"Nchrom", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"M3e3", "=", 
  RowBox[{"FindMaximum", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"logLikD1err3", "[", 
       RowBox[{
       "Nchrom", ",", "pGC", ",", "\[Theta]", ",", "\[Theta]WS", ",", 
        "\[Tau]", ",", "\[Tau]WS", ",", "\[Lambda]", ",", "B0", ",", "B1", 
        ",", "tabcoef", ",", "\[Epsilon]", ",", "\[Epsilon]WS", ",", 
        "\[Epsilon]SW", ",", "tabneutral", ",", "tabWS", ",", "tabSW", ",", 
        "Dneutral", ",", "DWS", ",", "DSW"}], "]"}], ",", "cons3e3"}], "}"}], 
    ",", "init3e3", ",", 
    RowBox[{"AccuracyGoal", "\[Rule]", "6"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.5642577241235847`*^9, 3.564257749704468*^9}, {
   3.5642578206053534`*^9, 3.564257824227219*^9}, {3.564257894510888*^9, 
   3.564257920556471*^9}, {3.564258085258842*^9, 3.5642581876178913`*^9}, {
   3.564258437640936*^9, 3.564258451734435*^9}, {3.5642584918053417`*^9, 
   3.564258562844203*^9}, {3.564258714773546*^9, 3.56425884308426*^9}, {
   3.564258913465157*^9, 3.564258919025383*^9}, {3.5642595973546877`*^9, 
   3.564259597738083*^9}, {3.564259769334746*^9, 3.564259839905995*^9}, {
   3.564260349531742*^9, 3.5642603571948977`*^9}, {3.56426040695984*^9, 
   3.5642606000949306`*^9}, {3.564390716440209*^9, 3.564390721051715*^9}, {
   3.564390868789227*^9, 3.5643908814673634`*^9}, {3.5643909181864567`*^9, 
   3.564390947606907*^9}, {3.564390989749899*^9, 3.564390991974864*^9}, {
   3.56439129718023*^9, 3.564391297415978*^9}, {3.564418884264182*^9, 
   3.564418896958001*^9}, {3.5644190406825743`*^9, 3.564419044996611*^9}, {
   3.564419102123251*^9, 3.564419105456602*^9}, {3.5644191647086782`*^9, 
   3.564419172099958*^9}, {3.5644193422987967`*^9, 3.5644193452088842`*^9}, {
   3.564420558146777*^9, 3.564420562328792*^9}, {3.564420598667795*^9, 
   3.564420599625935*^9}, {3.564420749874487*^9, 3.564420760079729*^9}, {
   3.5644214018364162`*^9, 3.5644214155825233`*^9}, {3.564421493825964*^9, 
   3.56442149872165*^9}, {3.56442158005374*^9, 3.5644216371845703`*^9}, {
   3.564466455261829*^9, 3.5644664633714523`*^9}, {3.564466581973983*^9, 
   3.5644665866190357`*^9}, {3.5644666588121023`*^9, 3.564466660689242*^9}, {
   3.564642471434883*^9, 3.5646426547488203`*^9}, {3.564938675319601*^9, 
   3.5649388420628653`*^9}, {3.565005979756937*^9, 3.56500599040947*^9}, {
   3.565041114867258*^9, 3.565041210507667*^9}, {3.565082155936466*^9, 
   3.565082177899263*^9}, {3.567168311113689*^9, 3.5671683659283743`*^9}, {
   3.567185422796089*^9, 3.567185433579032*^9}, {3.567276442405864*^9, 
   3.567276445661359*^9}, {3.567402930340309*^9, 3.5674029347387657`*^9}, {
   3.5674032056564093`*^9, 3.567403237571084*^9}, {3.567403306467596*^9, 
   3.567403309876526*^9}, {3.567404790109828*^9, 3.567404799243469*^9}, {
   3.567404863571045*^9, 3.567404863706314*^9}, 3.567786264887442*^9, {
   3.5687172398281403`*^9, 3.568717242708214*^9}, {3.56871817832001*^9, 
   3.568718180524124*^9}, {3.568719229896356*^9, 3.568719232191062*^9}, {
   3.5687203719014273`*^9, 3.568720377819476*^9}, {3.59334744200837*^9, 
   3.5933474780586576`*^9}, {3.5933480859640007`*^9, 3.593348107245837*^9}, {
   3.5933481492533216`*^9, 3.593348149422243*^9}, {3.593348774048688*^9, 
   3.593348797437286*^9}, {3.593349298503961*^9, 3.5933493159196653`*^9}, {
   3.593349408554369*^9, 3.5933494229177094`*^9}, {3.593349498487121*^9, 
   3.593349499417815*^9}, {3.593453567605763*^9, 3.59345363251348*^9}, {
   3.5935058580845737`*^9, 3.593505909575251*^9}, {3.593506003008971*^9, 
   3.593506004345495*^9}, {3.593506064692576*^9, 3.5935060659646177`*^9}, {
   3.5935060998487597`*^9, 3.5935061528346987`*^9}, 3.593506284370851*^9, {
   3.5935063165190687`*^9, 3.593506329152761*^9}, {3.593506769797804*^9, 
   3.593506824166952*^9}, {3.5935075767439737`*^9, 3.5935075769105377`*^9}, {
   3.593507734165144*^9, 3.59350775346859*^9}, {3.593507905312686*^9, 
   3.5935079399262943`*^9}, {3.593759692017202*^9, 3.5937597140436287`*^9}, {
   3.593767245913066*^9, 3.593767247336506*^9}, 3.593837615953558*^9, {
   3.648659358499181*^9, 3.648659365858315*^9}, {3.6486598659101152`*^9, 
   3.648659875432884*^9}, {3.648660098336587*^9, 3.6486600999600554`*^9}, {
   3.648660165350772*^9, 3.64866020524876*^9}, {3.648661349499161*^9, 
   3.648661362550561*^9}, {3.6486613978752823`*^9, 3.648661448792385*^9}, {
   3.653125320584207*^9, 3.653125321145679*^9}, {3.653125468272292*^9, 
   3.653125477514353*^9}, {3.6531255143885307`*^9, 3.6531255158844223`*^9}, {
   3.6531317872777863`*^9, 3.653131800337674*^9}, {3.6531324875771*^9, 
   3.653132494520544*^9}, 3.6531957337726107`*^9, 3.653195959030672*^9, {
   3.653196701444766*^9, 3.653196704245072*^9}, {3.653376610865052*^9, 
   3.653376618793379*^9}, {3.671264288350212*^9, 3.671264304291524*^9}, {
   3.671264375650474*^9, 3.6712643876772223`*^9}, {3.671286681393361*^9, 
   3.6712866888354597`*^9}, {3.6712867904303093`*^9, 
   3.6712867904412003`*^9}, {3.683540017632539*^9, 3.683540026508779*^9}, {
   3.683540094426264*^9, 3.683540108668243*^9}, 3.6835402140911713`*^9, {
   3.683540328999618*^9, 3.683540396903534*^9}, {3.6835404646971693`*^9, 
   3.683540471378161*^9}, {3.6835416114417257`*^9, 3.683541692171767*^9}, {
   3.683541749344367*^9, 3.683541803310122*^9}, {3.6835419658409233`*^9, 
   3.6835419684147167`*^9}, {3.6835420213581343`*^9, 3.683542022370263*^9}, 
   3.683542057729335*^9, {3.683542137593008*^9, 3.683542158405836*^9}, {
   3.683542520307918*^9, 3.683542520497858*^9}, 3.683543065831275*^9, {
   3.6835430980949917`*^9, 3.683543129144981*^9}, {3.683543180130362*^9, 
   3.683543261917131*^9}, {3.6835438312690773`*^9, 3.683543831414569*^9}, {
   3.683560634065249*^9, 3.683560649120112*^9}, {3.683570417721881*^9, 
   3.6835704179536467`*^9}, {3.703223290642145*^9, 3.703223300645699*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "301.6683379510505`"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"B0", "\[Rule]", "0.7461867275248337`"}], ",", 
     RowBox[{"B1", "\[Rule]", "0.026240671078686856`"}], ",", 
     RowBox[{"\[Epsilon]", "\[Rule]", "0.08598124919490173`"}], ",", 
     RowBox[{"\[Epsilon]SW", "\[Rule]", "0.05864978759716102`"}], ",", 
     RowBox[{"\[Epsilon]WS", "\[Rule]", "0.1275668697408558`"}], ",", 
     RowBox[{"\[Theta]", "\[Rule]", "3595.6647324972264`"}], ",", 
     RowBox[{"\[Theta]WS", "\[Rule]", "7475.822296197393`"}], ",", 
     RowBox[{"\[Lambda]", "\[Rule]", "1.6113650870358218`"}], ",", 
     RowBox[{"\[Tau]", "\[Rule]", "4036.0903880144847`"}], ",", 
     RowBox[{"\[Tau]WS", "\[Rule]", "11880.321514568126`"}], ",", 
     RowBox[{
      SubscriptBox["r", "2"], "\[Rule]", "1.0188263920406389`"}], ",", 
     RowBox[{
      SubscriptBox["r", "3"], "\[Rule]", "0.9220450007239278`"}], ",", 
     RowBox[{
      SubscriptBox["r", "4"], "\[Rule]", "0.8476798031667906`"}], ",", 
     RowBox[{
      SubscriptBox["r", "5"], "\[Rule]", "0.8139838283946598`"}], ",", 
     RowBox[{
      SubscriptBox["r", "6"], "\[Rule]", "0.7903989789089141`"}], ",", 
     RowBox[{
      SubscriptBox["r", "7"], "\[Rule]", "0.7457101716462886`"}], ",", 
     RowBox[{
      SubscriptBox["r", "8"], "\[Rule]", "0.7838665588413242`"}], ",", 
     RowBox[{
      SubscriptBox["r", "9"], "\[Rule]", "0.7821551621784064`"}], ",", 
     RowBox[{
      SubscriptBox["r", "10"], "\[Rule]", "0.7439536898080338`"}], ",", 
     RowBox[{
      SubscriptBox["r", "11"], "\[Rule]", "0.776045005375016`"}], ",", 
     RowBox[{
      SubscriptBox["r", "12"], "\[Rule]", "0.8722449501418464`"}], ",", 
     RowBox[{
      SubscriptBox["r", "13"], "\[Rule]", "0.7979002718492864`"}], ",", 
     RowBox[{
      SubscriptBox["r", "14"], "\[Rule]", "0.8033085260069496`"}], ",", 
     RowBox[{
      SubscriptBox["r", "15"], "\[Rule]", "0.8824946189950719`"}], ",", 
     RowBox[{
      SubscriptBox["r", "16"], "\[Rule]", "0.945656520399402`"}], ",", 
     RowBox[{
      SubscriptBox["r", "17"], "\[Rule]", "0.8262165004325477`"}], ",", 
     RowBox[{
      SubscriptBox["r", "18"], "\[Rule]", "0.9586984560167381`"}], ",", 
     RowBox[{
      SubscriptBox["r", "19"], "\[Rule]", "1.16077887193873`"}], ",", 
     RowBox[{
      SubscriptBox["r", "20"], "\[Rule]", "0.9045156300409755`"}], ",", 
     RowBox[{
      SubscriptBox["r", "21"], "\[Rule]", "0.9547523199299217`"}], ",", 
     RowBox[{
      SubscriptBox["r", "22"], "\[Rule]", "0.7962825636713253`"}], ",", 
     RowBox[{
      SubscriptBox["r", "23"], "\[Rule]", "0.08248911225800984`"}]}], "}"}]}],
   "}"}]], "Output",
 CellChangeTimes->{
  3.599500803995963*^9, 3.6024219225521708`*^9, 3.648659264615419*^9, 
   3.6486593668914967`*^9, 3.648659537247431*^9, 3.64865987741969*^9, 
   3.648660009068657*^9, {3.6486600867115717`*^9, 3.64866010056397*^9}, 
   3.648660166850325*^9, 3.64866020583442*^9, 3.64866024324935*^9, 
   3.648660288717639*^9, 3.648660406250906*^9, {3.64866045115001*^9, 
   3.648660466258012*^9}, 3.64866136328226*^9, {3.648661404864069*^9, 
   3.648661449955669*^9}, 3.648661483295039*^9, 3.653125322430231*^9, 
   3.653125479475292*^9, 3.653125517179862*^9, 3.6531307080131073`*^9, 
   3.653131177852376*^9, 3.6531317760904093`*^9, 3.6531318196318197`*^9, 
   3.653132398112214*^9, 3.653132528910739*^9, 3.6531327161190968`*^9, 
   3.6531328712349443`*^9, 3.653132944217884*^9, 3.6531330025450993`*^9, 
   3.653190745289977*^9, 3.653195412173695*^9, 3.653195547418221*^9, 
   3.653195628298213*^9, {3.653195715718543*^9, 3.653195734821233*^9}, 
   3.653195836219989*^9, {3.653195942393991*^9, 3.653195960364273*^9}, 
   3.6531961461435337`*^9, 3.653196197875393*^9, 3.653196335663733*^9, 
   3.6531963930399103`*^9, {3.653196507574033*^9, 3.653196528816289*^9}, {
   3.6531965609685383`*^9, 3.653196595570862*^9}, 3.653196687086915*^9, 
   3.6531967497236147`*^9, 3.653197059788527*^9, 3.6531972677045193`*^9, 
   3.653197338556766*^9, 3.6531974038903027`*^9, 3.6531974586232357`*^9, 
   3.653197554616522*^9, 3.6531975851061153`*^9, 3.6531981514268713`*^9, 
   3.6532009711558933`*^9, 3.6532010265663023`*^9, 3.65321167095121*^9, 
   3.653376619622661*^9, 3.653379996289275*^9, 3.653380674384981*^9, 
   3.653666554452518*^9, 3.65366812612706*^9, 3.6536682644728003`*^9, 
   3.6536683731743507`*^9, {3.653668406765176*^9, 3.653668420875242*^9}, 
   3.6536685538945827`*^9, {3.6536686085025377`*^9, 3.65366869284853*^9}, 
   3.6536688097760553`*^9, 3.65366891959522*^9, 3.653668962707552*^9, 
   3.653668995035775*^9, 3.653669194962551*^9, 3.6536692279128513`*^9, 
   3.653669263636552*^9, 3.6536693899454603`*^9, {3.6536694589391127`*^9, 
   3.653669504238986*^9}, {3.653669550248025*^9, 3.653669568782332*^9}, {
   3.653669605219427*^9, 3.653669664938554*^9}, {3.653669712819232*^9, 
   3.653669802591835*^9}, {3.6536698374066687`*^9, 3.653669839260552*^9}, 
   3.653669890437076*^9, 3.653669945421403*^9, 3.6536706547845373`*^9, 
   3.655625611056781*^9, 3.6557235305629787`*^9, 3.6557236402670383`*^9, 
   3.6557237080700407`*^9, 3.655723751775576*^9, 3.665164338073131*^9, 
   3.6651645494844093`*^9, 3.665165223599463*^9, 3.665165288658352*^9, 
   3.67126430575209*^9, 3.671264389276071*^9, 3.672045905933982*^9, 
   3.672046905647566*^9, 3.672047286756949*^9, 3.6720479061602716`*^9, 
   3.672048369605103*^9, 3.672048403705455*^9, 3.6720486324417057`*^9, {
   3.6720487309365997`*^9, 3.672048772382368*^9}, {3.672048854337645*^9, 
   3.672048873938839*^9}, 3.6720489044167423`*^9, 3.672048934432111*^9, {
   3.672048982230918*^9, 3.672049002053858*^9}, {3.672049044623844*^9, 
   3.672049096059623*^9}, {3.67204913296513*^9, 3.672049141457015*^9}, {
   3.672049219177742*^9, 3.672049234354151*^9}, {3.672049295109517*^9, 
   3.672049316713974*^9}, 3.683528725063753*^9, 3.683528979312339*^9, {
   3.683529177238058*^9, 3.6835292053957443`*^9}, 3.683529305190854*^9, 
   3.683529365285656*^9, {3.683529396825801*^9, 3.683529553074312*^9}, {
   3.683529584376247*^9, 3.6835296474314547`*^9}, {3.683529693725267*^9, 
   3.683529717687746*^9}, {3.683540008912429*^9, 3.6835400273954573`*^9}, {
   3.6835400956594257`*^9, 3.68354010991571*^9}, 3.6835402163297358`*^9, {
   3.683540330846838*^9, 3.683540397897667*^9}, 3.6835404731012506`*^9, 
   3.6835412065786343`*^9, 3.683541301576892*^9, {3.683541597611754*^9, 
   3.683541693516074*^9}, {3.683541750286537*^9, 3.683541767355357*^9}, 
   3.683541805100309*^9, 3.683541969872464*^9, 3.683542023763481*^9, 
   3.683542058682207*^9, {3.683542140411776*^9, 3.683542159359024*^9}, 
   3.683542521652274*^9, 3.683542698284864*^9, {3.6835429801578903`*^9, 
   3.683542999797723*^9}, 3.6835430669960537`*^9, {3.683543100978147*^9, 
   3.683543130603568*^9}, {3.6835431811148233`*^9, 3.683543250396235*^9}, 
   3.683543344839225*^9, {3.683543819139165*^9, 3.6835438330784817`*^9}, 
   3.683560650935091*^9, 3.683560768475399*^9, 3.683561161558943*^9, {
   3.683563453101837*^9, 3.683563460492552*^9}, 3.6835643739892178`*^9, 
   3.683565271084629*^9, 3.6835658283715878`*^9, 3.683565938696898*^9, 
   3.683566137157268*^9, 3.683566563532786*^9, 3.683566762129076*^9, 
   3.683566960481098*^9, 3.6835671886362543`*^9, 3.683567631552024*^9, 
   3.68356785962248*^9, {3.683568082552884*^9, 3.683568102468067*^9}, 
   3.683568290471196*^9, 3.683568495808641*^9, 3.68356870492724*^9, 
   3.683568884852902*^9, 3.683569074891614*^9, 3.6835692621717587`*^9, 
   3.683569370782745*^9, 3.683569496572603*^9, 3.6835697702805777`*^9, {
   3.6835703969063063`*^9, 3.683570422522876*^9}, 3.68357052580711*^9, 
   3.683570769522482*^9, 3.683571012105022*^9, 3.683571107032202*^9, 
   3.683571230177837*^9, 3.683571422002508*^9, 3.683571615781045*^9, 
   3.683571834702971*^9, 3.683572040970867*^9, 3.683572246316601*^9, 
   3.683572505635845*^9, 3.6835727159713507`*^9, 3.6835729301812487`*^9, 
   3.6835731225224953`*^9, 3.683573338523295*^9, 3.683573562329441*^9, 
   3.6835737473929243`*^9, 3.6835739399624243`*^9, 3.683574131534809*^9, 
   3.683574235758782*^9, 3.683574357390341*^9, 3.683574644443531*^9, 
   3.703221690446*^9, 3.703223555848464*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Bootstrap on the full model M3e", "Subsection",
 CellChangeTimes->{{3.683561230541175*^9, 3.683561264341255*^9}, {
  3.703223572182098*^9, 3.703223610565283*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"X", "=", 
   RowBox[{"Round", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{"tabneutral", ",", "tabWS", ",", "tabSW"}], "}"}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LX", "=", 
   RowBox[{"Length", "[", "X", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SX", "=", 
   RowBox[{"Round", "[", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{"X", "[", 
       RowBox[{"[", "i", "]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "LX"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pX", "=", 
   RowBox[{"X", "/", "SX"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Y", "=", 
   RowBox[{"Round", "[", 
    RowBox[{"{", 
     RowBox[{"Dneutral", ",", "DWS", ",", "DSW"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SY", "=", 
   RowBox[{"Round", "[", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{"Y", "[", 
       RowBox[{"[", "i", "]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "Y", "]"}]}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pY", "=", 
   RowBox[{"Y", "/", "SY"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Nboot", "=", "200"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Number", " ", "of", " ", "bootstraps"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Alpha]", "=", "0.05"}], ";", 
  RowBox[{"(*", "Threshold", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"boot\[Lambda]", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"\"\<lambda\>\"", ",", "Nboot"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bootB0", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"\"\<B0\>\"", ",", "Nboot"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bootB1", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"\"\<B1\>\"", ",", "Nboot"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.683561329776108*^9, 3.6835614110934563`*^9}, {
   3.683561629231946*^9, 3.6835618086898947`*^9}, 3.683561965850258*^9, {
   3.683561996740901*^9, 3.6835620755202*^9}, {3.683562211801325*^9, 
   3.683562225744276*^9}, {3.683562389916044*^9, 3.683562420034657*^9}, {
   3.6835627506579437`*^9, 3.683562784850803*^9}, {3.683562819911375*^9, 
   3.683562859509226*^9}, 3.683562913695405*^9, 3.6835630155334682`*^9, {
   3.6835630988524237`*^9, 3.6835631073487186`*^9}, {3.683563190797596*^9, 
   3.6835631914374228`*^9}, {3.683563866373053*^9, 3.68356386646736*^9}, {
   3.703223290650247*^9, 3.703223300651064*^9}, {3.703224846956394*^9, 
   3.7032248686115303`*^9}}],

Cell[BoxData[
 RowBox[{"For", "[", 
  RowBox[{
   RowBox[{"rep", "=", "1"}], ",", 
   RowBox[{"rep", "\[LessEqual]", "Nboot"}], ",", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"bootX", "=", 
       RowBox[{"RandomVariate", "[", 
        RowBox[{"MultinomialDistribution", "[", 
         RowBox[{"SX", ",", "pX"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"bootY", "=", 
       RowBox[{"RandomVariate", "[", 
        RowBox[{"MultinomialDistribution", "[", 
         RowBox[{"SY", ",", "pY"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"bootSFS", "=", 
       RowBox[{"Partition", "[", 
        RowBox[{"bootX", ",", 
         RowBox[{"LX", "/", "3"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"tabneutralb", "=", 
       RowBox[{"bootSFS", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"tabWSb", "=", 
       RowBox[{"bootSFS", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"tabSWb", "=", 
       RowBox[{"bootSFS", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Dneutralb", "=", 
       RowBox[{"bootY", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"DWSb", "=", 
       RowBox[{"bootY", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"DSWb", "=", 
       RowBox[{"bootY", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"init3e3b", "=", 
       RowBox[{"Union", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\[Theta]", ",", 
             RowBox[{"\[Theta]", "/.", 
              RowBox[{"M1", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Theta]WS", ",", 
             RowBox[{"\[Theta]WS", "/.", 
              RowBox[{"M1", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Tau]", ",", "\[Tau]init"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Tau]WS", ",", "\[Tau]WSinit"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Lambda]", ",", 
             RowBox[{"\[Lambda]", "/.", 
              RowBox[{"M1", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"B0", ",", 
             RowBox[{"B", "/.", 
              RowBox[{"M1", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"B1", ",", 
             RowBox[{"B", "/.", 
              RowBox[{"M1", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Epsilon]", ",", 
             RowBox[{"\[Epsilon]", "/.", 
              RowBox[{"M0e3", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Epsilon]WS", ",", 
             RowBox[{"\[Epsilon]WS", "/.", 
              RowBox[{"M0e3", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Epsilon]SW", ",", 
             RowBox[{"\[Epsilon]SW", "/.", 
              RowBox[{"M0e3", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}]}], "}"}], ",", 
         RowBox[{"Take", "[", 
          RowBox[{
           RowBox[{"Thread", "[", 
            RowBox[{"{", 
             RowBox[{"tabcoef", ",", "rinit"}], "}"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", 
             RowBox[{"Nchrom", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], ";", 
      "\n", 
      RowBox[{"cons3e3b", "=", 
       RowBox[{"Union", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Theta]", ">", "0"}], ",", 
           RowBox[{"\[Theta]WS", ">", "0"}], ",", 
           RowBox[{"\[Tau]", ">", "0"}], ",", 
           RowBox[{"\[Tau]WS", ">", "0"}], ",", 
           RowBox[{
            RowBox[{"-", "1"}], "<", "B0", "<", "10"}], ",", 
           RowBox[{
            RowBox[{"-", "1"}], "<", "B1", "<", "10"}], ",", 
           RowBox[{"\[Lambda]", ">", "0"}], ",", 
           RowBox[{"0", "\[LessEqual]", "\[Epsilon]", "\[LessEqual]", 
            RowBox[{"1", "/", "2"}]}], ",", 
           RowBox[{"0", "\[LessEqual]", "\[Epsilon]WS", "\[LessEqual]", 
            RowBox[{"1", "/", "2"}]}], ",", 
           RowBox[{"0", "\[LessEqual]", "\[Epsilon]SW", "\[LessEqual]", 
            RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
         RowBox[{"Take", "[", 
          RowBox[{
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"10", ">", "#", ">", "0"}], "&"}], ",", "tabcoef"}], 
            "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", 
             RowBox[{"Nchrom", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], ";", 
      "\n", 
      RowBox[{"M3e3b", "=", 
       RowBox[{"FindMaximum", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"logLikD1err3", "[", 
            RowBox[{
            "Nchrom", ",", "pGC", ",", "\[Theta]", ",", "\[Theta]WS", ",", 
             "\[Tau]", ",", "\[Tau]WS", ",", "\[Lambda]", ",", "B0", ",", 
             "B1", ",", "tabcoef", ",", "\[Epsilon]", ",", "\[Epsilon]WS", 
             ",", "\[Epsilon]SW", ",", "tabneutralb", ",", "tabWSb", ",", 
             "tabSWb", ",", "Dneutralb", ",", "DWSb", ",", "DSWb"}], "]"}], 
           ",", "cons3e3b"}], "}"}], ",", "init3e3b", ",", 
         RowBox[{"AccuracyGoal", "\[Rule]", "6"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"boot\[Lambda]", "[", 
        RowBox[{"[", "rep", "]"}], "]"}], "=", 
       RowBox[{"\[Lambda]", "/.", 
        RowBox[{"M3e3b", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"bootB0", "[", 
        RowBox[{"[", "rep", "]"}], "]"}], "=", 
       RowBox[{"B0", "/.", 
        RowBox[{"M3e3b", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"bootB1", "[", 
        RowBox[{"[", "rep", "]"}], "]"}], "=", 
       RowBox[{"B1", "/.", 
        RowBox[{"M3e3b", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"Element", "[", 
         RowBox[{
          RowBox[{"rep", "/", "10"}], ",", "Integers"}], "]"}], ",", 
        RowBox[{"Print", "[", "rep", "]"}]}], "]"}], ";"}], 
     "\[IndentingNewLine]", "}"}], ";", 
    RowBox[{"rep", "++"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.68356181035355*^9, 3.683561818545994*^9}, {
   3.6835618740843687`*^9, 3.683561876843871*^9}, {3.6835619247522497`*^9, 
   3.683561950375908*^9}, 3.683562023618206*^9, {3.683562245115274*^9, 
   3.6835622629716597`*^9}, {3.683562308329623*^9, 3.6835623094414167`*^9}, {
   3.6835626174163837`*^9, 3.683562629929874*^9}, {3.683562660826641*^9, 
   3.6835626933153353`*^9}, 3.6835627335788727`*^9, {3.683562869525917*^9, 
   3.683562963873783*^9}, {3.683563011375608*^9, 3.683563042279622*^9}, {
   3.683563650943725*^9, 3.683563686295414*^9}, {3.683564196020643*^9, 
   3.683564214043721*^9}, {3.68357044150222*^9, 3.683570441742361*^9}, {
   3.703223290657864*^9, 3.703223300659582*^9}, {3.703223960005814*^9, 
   3.703224011552226*^9}}],

Cell["Bootstrap CI", "Text",
 CellChangeTimes->{{3.703223638116452*^9, 3.7032236419413157`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"boot\[Lambda]s", "=", 
   RowBox[{"Sort", "[", "boot\[Lambda]", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bootB0s", "=", 
   RowBox[{"Sort", "[", "bootB0", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bootB1s", "=", 
   RowBox[{"Sort", "[", "bootB1", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"\[Lambda]min", "=", 
  RowBox[{"boot\[Lambda]s", "[", 
   RowBox[{"[", 
    RowBox[{"Floor", "[", 
     RowBox[{"Nboot", " ", 
      RowBox[{"\[Alpha]", "/", "2"}]}], "]"}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"\[Lambda]max", "=", 
  RowBox[{"boot\[Lambda]s", "[", 
   RowBox[{"[", 
    RowBox[{"Ceiling", "[", 
     RowBox[{"Nboot", 
      RowBox[{"(", 
       RowBox[{"1", "-", " ", 
        RowBox[{"\[Alpha]", "/", "2"}]}], ")"}]}], "]"}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"B0min", "=", 
  RowBox[{"bootB0s", "[", 
   RowBox[{"[", 
    RowBox[{"Floor", "[", 
     RowBox[{"Nboot", " ", 
      RowBox[{"\[Alpha]", "/", "2"}]}], "]"}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"B0max", "=", 
  RowBox[{"bootB0s", "[", 
   RowBox[{"[", 
    RowBox[{"Ceiling", "[", 
     RowBox[{"Nboot", 
      RowBox[{"(", 
       RowBox[{"1", "-", " ", 
        RowBox[{"\[Alpha]", "/", "2"}]}], ")"}]}], "]"}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"B1min", "=", 
  RowBox[{"bootB1s", "[", 
   RowBox[{"[", 
    RowBox[{"Floor", "[", 
     RowBox[{"Nboot", " ", 
      RowBox[{"\[Alpha]", "/", "2"}]}], "]"}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"B1max", "=", 
  RowBox[{"bootB1s", "[", 
   RowBox[{"[", 
    RowBox[{"Ceiling", "[", 
     RowBox[{"Nboot", 
      RowBox[{"(", 
       RowBox[{"1", "-", " ", 
        RowBox[{"\[Alpha]", "/", "2"}]}], ")"}]}], "]"}], "]"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.6835630683456287`*^9, 3.683563080245479*^9}, {
  3.683563112412595*^9, 3.683563155653837*^9}, {3.683563214237645*^9, 
  3.683563382267342*^9}, {3.683563875684319*^9, 3.6835638858039217`*^9}, {
  3.703223631546554*^9, 3.7032236353939867`*^9}}],

Cell[BoxData["1.563957373672906`"], "Output",
 CellChangeTimes->{3.7032239472694063`*^9}],

Cell[BoxData["1.7772213140359499`"], "Output",
 CellChangeTimes->{3.703223947274398*^9}],

Cell[BoxData["0.6907743210545338`"], "Output",
 CellChangeTimes->{3.7032239472798853`*^9}],

Cell[BoxData["0.7913991596363056`"], "Output",
 CellChangeTimes->{3.7032239472841454`*^9}],

Cell[BoxData[
 RowBox[{"-", "0.12203808871062642`"}]], "Output",
 CellChangeTimes->{3.703223947288044*^9}],

Cell[BoxData["0.16431642870491386`"], "Output",
 CellChangeTimes->{3.703223947291601*^9}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["gBGC+SCU", "Section",
 CellChangeTimes->{{3.683560281592166*^9, 3.683560284768293*^9}}],

Cell[CellGroupData[{

Cell["Dataset", "Subsection",
 CellChangeTimes->{{3.65340956898013*^9, 3.653409569378682*^9}, {
  3.703223756322111*^9, 3.703223756657996*^9}}],

Cell["Example", "Text",
 CellChangeTimes->{{3.703224492973535*^9, 3.703224493782505*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"tabNN", "=", 
   RowBox[{"{", 
    RowBox[{
    "1232", ",", "526", ",", "255", ",", "163", ",", "135", ",", "108", ",", 
     "100", ",", "38", ",", "37", ",", "71", ",", "63", ",", "106", ",", "26",
      ",", "35", ",", "14", ",", "26", ",", "40", ",", "34", ",", "39", ",", 
     "29", ",", "37", ",", "41", ",", "70"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tabNUP", "=", 
   RowBox[{"{", 
    RowBox[{
    "467", ",", "213", ",", "112", ",", "71", ",", "58", ",", "40", ",", "37",
      ",", "13", ",", "14", ",", "30", ",", "20", ",", "26", ",", "14", ",", 
     "15", ",", "12", ",", "12", ",", "13", ",", "12", ",", "12", ",", "17", 
     ",", "14", ",", "9", ",", "14"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tabNPU", "=", 
   RowBox[{"{", 
    RowBox[{
    "495", ",", "199", ",", "85", ",", "67", ",", "59", ",", "36", ",", "32", 
     ",", "19", ",", "19", ",", "29", ",", "21", ",", "23", ",", "16", ",", 
     "20", ",", "12", ",", "11", ",", "9", ",", "13", ",", "12", ",", "14", 
     ",", "11", ",", "11", ",", "19"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tabWSN", "=", 
   RowBox[{"{", 
    RowBox[{
    "2475", ",", "1150", ",", "505", ",", "384", ",", "299", ",", "220", ",", 
     "188", ",", "98", ",", "106", ",", "136", ",", "132", ",", "171", ",", 
     "99", ",", "104", ",", "55", ",", "73", ",", "84", ",", "75", ",", "66", 
     ",", "78", ",", "79", ",", "113", ",", "157"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tabWSUP", "=", 
   RowBox[{"{", 
    RowBox[{
    "5073", ",", "2356", ",", "1125", ",", "769", ",", "597", ",", "480", ",",
      "416", ",", "217", ",", "187", ",", "315", ",", "300", ",", "408", ",", 
     "200", ",", "227", ",", "109", ",", "120", ",", "169", ",", "171", ",", 
     "170", ",", "201", ",", "213", ",", "249", ",", "461"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tabWSPU", "=", 
   RowBox[{"{", 
    RowBox[{
    "118", ",", "28", ",", "14", ",", "16", ",", "10", ",", "10", ",", "8", 
     ",", "6", ",", "1", ",", "6", ",", "8", ",", "12", ",", "6", ",", "6", 
     ",", "1", ",", "2", ",", "1", ",", "4", ",", "1", ",", "4", ",", "2", 
     ",", "2", ",", "4"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tabSWN", "=", 
   RowBox[{"{", 
    RowBox[{
    "1682", ",", "666", ",", "331", ",", "222", ",", "174", ",", "137", ",", 
     "107", ",", "64", ",", "48", ",", "96", ",", "75", ",", "116", ",", "50",
      ",", "45", ",", "35", ",", "32", ",", "50", ",", "48", ",", "48", ",", 
     "43", ",", "31", ",", "52", ",", "82"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tabSWUP", "=", 
   RowBox[{"{", 
    RowBox[{
    "142", ",", "42", ",", "14", ",", "20", ",", "6", ",", "4", ",", "14", 
     ",", "2", ",", "2", ",", "10", ",", "2", ",", "2", ",", "2", ",", "2", 
     ",", "2", ",", "4", ",", "1", ",", "2", ",", "1", ",", "1", ",", "2", 
     ",", "1", ",", "4"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tabSWPU", "=", 
   RowBox[{"{", 
    RowBox[{
    "3606", ",", "1515", ",", "725", ",", "509", ",", "390", ",", "290", ",", 
     "289", ",", "124", ",", "106", ",", "207", ",", "153", ",", "254", ",", 
     "135", ",", "125", ",", "68", ",", "84", ",", "111", ",", "93", ",", 
     "93", ",", "105", ",", "109", ",", "122", ",", "185"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DNN", "=", "1086"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DNUP", "=", "438"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DNPU", "=", "423"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DWSN", "=", "2517"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DWSUP", "=", "5672"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DWSPU", "=", "58"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DSWN", "=", "1443"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DSWUP", "=", "44"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DSWPU", "=", "3331"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Nchrom", "=", 
   RowBox[{
    RowBox[{"Length", "[", "tabNN", "]"}], "+", "1"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tabcoef", "=", 
   RowBox[{"Union", "[", 
    RowBox[{
     RowBox[{"{", "1", "}"}], ",", 
     RowBox[{"Array", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Subscript", "[", 
         RowBox[{"r", ",", "#1"}], "]"}], "&"}], ",", 
       RowBox[{"Nchrom", "-", "2"}], ",", "2"}], "]"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7032241747476397`*^9, 3.703224362990837*^9}, {
  3.703224480543746*^9, 3.7032244810148277`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["ML estimates", "Subsection",
 CellChangeTimes->{{3.6533217440278788`*^9, 3.653321752602378*^9}, {
   3.653374423896041*^9, 3.653374425670393*^9}, {3.6537595830496197`*^9, 
   3.653759584119748*^9}, 3.665173981184309*^9, 3.66517449343513*^9, {
   3.703224563760468*^9, 3.7032245657715178`*^9}}],

Cell[CellGroupData[{

Cell["Initial conditions", "Subsubsection",
 CellChangeTimes->{{3.703224572431466*^9, 3.703224575941537*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Theta]NNi", "=", 
   RowBox[{
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", "tabNN"}], "]"}], "/", 
    RowBox[{"HarmonicNumber", "[", "Nchrom", "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Theta]NUPi", "=", 
   RowBox[{
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", "tabNUP"}], "]"}], "/", 
    RowBox[{"HarmonicNumber", "[", "Nchrom", "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Theta]NPUi", "=", 
   RowBox[{
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", "tabNPU"}], "]"}], "/", 
    RowBox[{"HarmonicNumber", "[", "Nchrom", "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Theta]WSNi", "=", 
   RowBox[{
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", "tabWSN"}], "]"}], "/", 
    RowBox[{"HarmonicNumber", "[", "Nchrom", "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Theta]WSUPi", "=", 
   RowBox[{
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", "tabWSUP"}], "]"}], "/", 
    RowBox[{"HarmonicNumber", "[", "Nchrom", "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Theta]WSPUi", "=", 
   RowBox[{
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", "tabWSPU"}], "]"}], "/", 
    RowBox[{"HarmonicNumber", "[", "Nchrom", "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Theta]SWNi", "=", 
   RowBox[{
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", "tabSWN"}], "]"}], "/", 
    RowBox[{"HarmonicNumber", "[", "Nchrom", "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Theta]SWUPi", "=", 
   RowBox[{
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", "tabSWUP"}], "]"}], "/", 
    RowBox[{"HarmonicNumber", "[", "Nchrom", "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Theta]SWPUi", "=", 
   RowBox[{
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", "tabSWPU"}], "]"}], "/", 
    RowBox[{"HarmonicNumber", "[", "Nchrom", "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Tau]NNi", "=", 
   RowBox[{"Max", "[", 
    RowBox[{"1", ",", "DNN"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Tau]NUPi", "=", 
   RowBox[{"Max", "[", 
    RowBox[{"1", ",", "DNUP"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Tau]NPUi", "=", 
   RowBox[{"Max", "[", 
    RowBox[{"1", ",", "DNPU"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Tau]WSNi", "=", 
   RowBox[{"Max", "[", 
    RowBox[{"1", ",", "DWSN"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Tau]WSUPi", "=", 
   RowBox[{"Max", "[", 
    RowBox[{"1", ",", "DWSUP"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Tau]WSPUi", "=", 
   RowBox[{"Max", "[", 
    RowBox[{"1", ",", "DWSPU"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Tau]SWNi", "=", 
   RowBox[{"Max", "[", 
    RowBox[{"1", ",", "DSWN"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Tau]SWUPi", "=", 
   RowBox[{"Max", "[", 
    RowBox[{"1", ",", "DSWUP"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Tau]SWPUi", "=", 
   RowBox[{"Max", "[", 
    RowBox[{"1", ",", "DSWPU"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rinit", "=", 
   RowBox[{
    RowBox[{"tabNN", " ", 
     RowBox[{
      RowBox[{"Range", "[", 
       RowBox[{"Nchrom", "-", "1"}], "]"}], "/", 
      RowBox[{"tabNN", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}]}], "+", "0.1"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.601658276915842*^9, 3.6016584080235977`*^9}, {
   3.601658954709395*^9, 3.601658957676182*^9}, {3.612600447995092*^9, 
   3.61260045170721*^9}, {3.6126006394817657`*^9, 3.612600643750126*^9}, {
   3.6126027235400467`*^9, 3.612602731028554*^9}, {3.6533743243337383`*^9, 
   3.653374393483604*^9}, {3.653376080063841*^9, 3.653376136126587*^9}, {
   3.653646911687496*^9, 3.6536469151864223`*^9}, {3.653647190845583*^9, 
   3.6536471942107983`*^9}, 3.6536473786199827`*^9, {3.653647447526918*^9, 
   3.6536474611953297`*^9}, 3.653659840641971*^9, 3.6536599061169558`*^9, {
   3.68360216142098*^9, 3.68360221319204*^9}, {3.683606937863598*^9, 
   3.683606944679737*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Likelihood of the saturated model", "Subsubsection",
 CellChangeTimes->{{3.703224584154274*^9, 3.7032245913092537`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lnLsat", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"lnLmax", "[", "DNN", "]"}], "+", 
    RowBox[{"lnLmax", "[", "DNUP", "]"}], "+", 
    RowBox[{"lnLmax", "[", "DNPU", "]"}], "+", 
    RowBox[{"lnLmax", "[", "DWSN", "]"}], "+", 
    RowBox[{"lnLmax", "[", "DWSUP", "]"}], "+", 
    RowBox[{"lnLmax", "[", "DWSPU", "]"}], "+", 
    RowBox[{"lnLmax", "[", "DSWN", "]"}], "+", 
    RowBox[{"lnLmax", "[", "DSWUP", "]"}], "+", 
    RowBox[{"lnLmax", "[", "DSWPU", "]"}], "+", "\[IndentingNewLine]", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Thread", "[", 
       RowBox[{"lnLmax", "[", 
        RowBox[{"Flatten", "[", 
         RowBox[{"{", 
          RowBox[{
          "tabNN", ",", "tabNUP", ",", " ", "tabNPU", ",", "tabWSN", ",", 
           "tabWSUP", ",", "tabWSPU", ",", "tabSWN", ",", "tabSWUP", ",", 
           "tabSWPU"}], "}"}], "]"}], "]"}], "]"}]}], "]"}]}], "//", 
   "N"}]}]], "Input",
 CellChangeTimes->{{3.564477890113482*^9, 3.564477909283383*^9}, {
   3.565040344130828*^9, 3.56504035492936*^9}, {3.5650816915513763`*^9, 
   3.565081694856119*^9}, {3.565081878898121*^9, 3.565081882023203*^9}, {
   3.565086032317608*^9, 3.565086039112772*^9}, 3.593837615923627*^9, {
   3.601657862900764*^9, 3.601657896800817*^9}, {3.601658034232298*^9, 
   3.601658094079516*^9}, {3.6016581549046803`*^9, 3.601658155352097*^9}, {
   3.602435021205246*^9, 3.602435023393598*^9}, {3.6024359715342073`*^9, 
   3.6024359728520937`*^9}, {3.653375284074914*^9, 3.653375301799155*^9}, {
   3.653375341428482*^9, 3.65337540428822*^9}, {3.6836913130600853`*^9, 
   3.6836913130778913`*^9}, {3.70322446140662*^9, 3.7032244623730164`*^9}}],

Cell[BoxData[
 RowBox[{"-", "626.4850383197772`"}]], "Output",
 CellChangeTimes->{{3.593837632572783*^9, 3.593837634444993*^9}, 
   3.5938408651920958`*^9, 3.5994994000706987`*^9, 3.599499658997755*^9, 
   3.5994999547328873`*^9, 3.599500657744315*^9, 3.599500754146975*^9, {
   3.601657898023616*^9, 3.6016579185249853`*^9}, {3.6016580496467743`*^9, 
   3.601658095851795*^9}, {3.601658151594717*^9, 3.601658156063533*^9}, 
   3.602416211696719*^9, 3.6024173063268147`*^9, 3.602435024135607*^9, {
   3.602435343543728*^9, 3.6024353725721684`*^9}, 3.602435943096239*^9, 
   3.602435998882745*^9, 3.6024987603397923`*^9, 3.6024990266908092`*^9, 
   3.602499221880158*^9, 3.602499528532219*^9, {3.602502581173635*^9, 
   3.6025025920672092`*^9}, 3.602502805433449*^9, 3.602503183663487*^9, 
   3.602503387408904*^9, 3.602503418135117*^9, 3.602503513597148*^9, {
   3.602503677657166*^9, 3.602503686857328*^9}, 3.602504589925508*^9, 
   3.6025047128382587`*^9, 3.6025061478784237`*^9, {3.602506329627033*^9, 
   3.602506353121091*^9}, 3.6025064554804163`*^9, 3.604904779567935*^9, 
   3.612600403933002*^9, 3.61260059353461*^9, 3.612600725166616*^9, 
   3.6126008454756737`*^9, 3.6126009475345163`*^9, 3.612601004326339*^9, 
   3.6126012014869967`*^9, 3.6126013558533*^9, 3.6126014394765043`*^9, 
   3.612601502929554*^9, 3.612601721390573*^9, 3.61260186143742*^9, 
   3.612602736684545*^9, 3.612603030302084*^9, {3.6126031469888287`*^9, 
   3.612603235789019*^9}, 3.6126038186199903`*^9, 3.612603916620428*^9, 
   3.612604204360435*^9, 3.612604253287445*^9, {3.612604341836648*^9, 
   3.612604370140224*^9}, 3.6126047578852997`*^9, 3.6126051800143414`*^9, 
   3.612605252783449*^9, 3.612605414570859*^9, 3.612605483283874*^9, 
   3.612605881332328*^9, 3.612605966658701*^9, 3.612607202016675*^9, 
   3.612607327235509*^9, 3.653321344379794*^9, 3.65332137810539*^9, 
   3.6533214779820633`*^9, 3.6533216530352583`*^9, 3.6533218895916653`*^9, 
   3.65337440965975*^9, 3.653375404882844*^9, 3.6533818915605927`*^9, 
   3.6533827156163273`*^9, {3.6534080177525187`*^9, 3.65340804038326*^9}, 
   3.653408118765987*^9, 3.653408322908345*^9, 3.653409944154551*^9, 
   3.653410647721545*^9, 3.653410890762759*^9, 3.6534117001204967`*^9, 
   3.6534119141754436`*^9, 3.653412013050579*^9, 3.653412187121663*^9, 
   3.653412229775794*^9, 3.653412314004374*^9, 3.653412520239257*^9, 
   3.6534131159081306`*^9, 3.653413319445812*^9, 3.653413426674758*^9, 
   3.6534134773221903`*^9, 3.653413715506774*^9, 3.653413880656721*^9, 
   3.653413916676388*^9, 3.653645702071637*^9, 3.653646690169835*^9, 
   3.653646767392457*^9, 3.6536469056887293`*^9, 3.653646950461705*^9, 
   3.653647040304319*^9, {3.653656537334106*^9, 3.6536565655398397`*^9}, 
   3.653657016143711*^9, {3.653657063554434*^9, 3.653657097580985*^9}, 
   3.653657336843502*^9, 3.6536599075515337`*^9, 3.653660310524313*^9, 
   3.653660358538639*^9, 3.653662749654818*^9, 3.653663214714136*^9, 
   3.653663573580038*^9, 3.653663780517992*^9, 3.653664469900916*^9, 
   3.653665459960413*^9, 3.653665500882922*^9, 3.653665980406776*^9, 
   3.6537337427271633`*^9, 3.653735181970634*^9, 3.653752948893368*^9, 
   3.653756467090251*^9, 3.653756769669106*^9, 3.6537574759567204`*^9, 
   3.6537577928938017`*^9, 3.653758256254116*^9, 3.653758647004532*^9, 
   3.653758730369018*^9, 3.653758945380015*^9, 3.653759058702935*^9, 
   3.653759220188477*^9, 3.653759586685438*^9, 3.653760805904995*^9, 
   3.653761233402199*^9, 3.653761331127865*^9, 3.653761486231675*^9, {
   3.6538157251102743`*^9, 3.653815735877239*^9}, 3.653816010797317*^9, 
   3.6538169109878883`*^9, 3.653817884012972*^9, 3.655723790711713*^9, 
   3.665172606871173*^9, 3.6651728363975286`*^9, 3.665172890561811*^9, 
   3.665172947437582*^9, 3.6651732106296053`*^9, 3.665174000024447*^9, 
   3.665174497898404*^9, {3.672051099912487*^9, 3.67205111963249*^9}, 
   3.672051169472267*^9, 3.672051300744492*^9, 3.672051420515697*^9, 
   3.672051498173805*^9, 3.672051565473384*^9, 3.672051679385674*^9, 
   3.67205177717702*^9, 3.672051930339727*^9, 3.672051995508461*^9, 
   3.672052068482172*^9, 3.672052593249021*^9, 3.672052666259359*^9, 
   3.672052727318927*^9, 3.672052788052656*^9, 3.672052848970716*^9, 
   3.672052942448059*^9, 3.6720531053253307`*^9, 3.672053176086652*^9, 
   3.672053290129068*^9, 3.683531885803349*^9, 3.683532015920637*^9, 
   3.683532139062808*^9, 3.683532187161278*^9, 3.6835324509854307`*^9, 
   3.683532849272902*^9, 3.6835329108712683`*^9, 3.683532976110804*^9, 
   3.683533043820198*^9, 3.683533210703368*^9, 3.683533384648645*^9, 
   3.683533634949296*^9, 3.683533906759801*^9, 3.6835339700192947`*^9, 
   3.6835340233109827`*^9, 3.683534396612122*^9, 3.683575490524531*^9, 
   3.683575776469018*^9, 3.683575842377623*^9, 3.683575905771893*^9, 
   3.683575996636073*^9, 3.683576059533255*^9, 3.683576145329221*^9, 
   3.683576251842588*^9, 3.6835764436597013`*^9, 3.6835766335971317`*^9, 
   3.683576665416893*^9, 3.68357691968226*^9, 3.683604672251075*^9, 
   3.683605954459613*^9, 3.683606041515267*^9, 3.683606112313546*^9, 
   3.683606406114662*^9, 3.68360695807789*^9, 3.6836071340448217`*^9, 
   3.6836072254620943`*^9, 3.683607274141675*^9, 3.6836073570023317`*^9, 
   3.683607423817624*^9, 3.683607491674889*^9, 3.683607557785431*^9, 
   3.683607709104308*^9, 3.683607776876823*^9, 3.683607947853051*^9, 
   3.683608043321165*^9, 3.683608077645537*^9, 3.683652705057701*^9, 
   3.683653531182329*^9, 3.6836892602740088`*^9, 3.683690072228163*^9, 
   3.6836913161370373`*^9, 3.683691734850021*^9, 3.683692018210009*^9, 
   3.6836922695457163`*^9, 3.683692327446657*^9, 3.683693164441486*^9, 
   3.68371833041051*^9, 3.6837193689865026`*^9, 3.683725985000098*^9, 
   3.683745041780611*^9, 3.6837758841872587`*^9, 3.7032244630212727`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Series of models with errors", "Subsubsection",
 CellChangeTimes->{{3.6024162589069138`*^9, 3.602416274172925*^9}, {
  3.653409602124381*^9, 3.653409602763777*^9}, {3.703224595651531*^9, 
  3.7032246010628*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tB0", "=", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox["10", 
      RowBox[{"-", "8"}]], ",", "B0"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tB1", "=", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox["10", 
      RowBox[{"-", "8"}]], ",", "B1"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tS0", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1.1", " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "8"}]]}], ",", "S0"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tS1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1.1", " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "8"}]]}], ",", "S1"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tabParam", "=", 
   RowBox[{"N", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"tB0", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"tB1", "[", 
           RowBox[{"[", "j", "]"}], "]"}], ",", 
          RowBox[{"tS0", "[", 
           RowBox[{"[", "k", "]"}], "]"}], ",", 
          RowBox[{"tS1", "[", 
           RowBox[{"[", "l", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "1", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"l", ",", "1", ",", "2"}], "}"}]}], "]"}], ",", "3"}], "]"}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tB0", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "B0"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tB1", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "B1"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tS0", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "S0"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"tS1", "=", 
    RowBox[{"{", 
     RowBox[{"0", ",", "S1"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "NUll", " ", "and", " ", "free", " ", "parameters", " ", "for", " ", "the",
     " ", "different", " ", "models"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"tabParamExp", "=", 
  RowBox[{
   RowBox[{"N", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"tB0", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"tB1", "[", 
           RowBox[{"[", "j", "]"}], "]"}], ",", 
          RowBox[{"tS0", "[", 
           RowBox[{"[", "k", "]"}], "]"}], ",", 
          RowBox[{"tS1", "[", 
           RowBox[{"[", "l", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "1", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"l", ",", "1", ",", "2"}], "}"}]}], "]"}], ",", "3"}], "]"}],
     "]"}], "//", "MatrixForm"}]}]}], "Input",
 CellChangeTimes->{{3.653734145612835*^9, 3.653734253182621*^9}, {
  3.653734442139843*^9, 3.653734820590086*^9}, {3.653734859268697*^9, 
  3.653734873588962*^9}, {3.653734920479395*^9, 3.6537350197723293`*^9}, {
  3.653735221948201*^9, 3.653735226458962*^9}, {3.6537512398136*^9, 
  3.653751245084709*^9}, {3.653753736984013*^9, 3.653753742838664*^9}, {
  3.6537564389724617`*^9, 3.653756453319364*^9}, {3.703224692505432*^9, 
  3.703224742937682*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0.`", "0.`", "0.`", "0.`"},
     {"0.`", "0.`", "0.`", "S1"},
     {"0.`", "0.`", "S0", "0.`"},
     {"0.`", "0.`", "S0", "S1"},
     {"0.`", "B1", "0.`", "0.`"},
     {"0.`", "B1", "0.`", "S1"},
     {"0.`", "B1", "S0", "0.`"},
     {"0.`", "B1", "S0", "S1"},
     {"B0", "0.`", "0.`", "0.`"},
     {"B0", "0.`", "0.`", "S1"},
     {"B0", "0.`", "S0", "0.`"},
     {"B0", "0.`", "S0", "S1"},
     {"B0", "B1", "0.`", "0.`"},
     {"B0", "B1", "0.`", "S1"},
     {"B0", "B1", "S0", "0.`"},
     {"B0", "B1", "S0", "S1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.7032246929068213`*^9, 3.70322469961266*^9}, 
   3.703224743822983*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"tabres", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "B0", ",", "B1", ",", "S0", ",", "S1", ",", "eN", ",", "eWS", ",", 
       "eSW", ",", "lnL", ",", "aic"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{
        RowBox[{"Length", "[", "tabParam", "]"}], "+", "1"}]}], "}"}]}], 
    "]"}]}], ";", 
  RowBox[{"(*", 
   RowBox[{
   "To", " ", "store", " ", "the", " ", "results", " ", "of", " ", "the", " ",
     "16", " ", "models"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.653753163489019*^9, 3.6537531892507668`*^9}, {
  3.653753746149275*^9, 3.653753769637641*^9}, {3.653756476092101*^9, 
  3.653756497491843*^9}, {3.653756573800542*^9, 3.6537565760006313`*^9}, {
  3.653756748744635*^9, 3.653756777980206*^9}, {3.6651727352460327`*^9, 
  3.66517275018434*^9}, {3.703224751982421*^9, 3.703224759283635*^9}}],

Cell["\<\
Here we impose the constraint that the total WS/SW and the total UP/PU bias \
is contant in polymorphism and divergence.
There is 9 \[Tau] to estimate this constraint reduces it to 7. We impose the \
constraint on \[Tau]SWN and \[Tau]NPU. The constraint is obtained as follow\
\>", "Text",
 CellChangeTimes->{{3.683604289269004*^9, 3.683604385670639*^9}, {
  3.683604482534129*^9, 3.683604490745893*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"k1", "=", 
   FractionBox[
    RowBox[{"\[Theta]WSN", "+", "\[Theta]WSUP", "+", "\[Theta]WSPU"}], 
    RowBox[{"\[Theta]SWN", "+", "\[Theta]SWUP", "+", "\[Theta]SWPU"}]]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"k2", "=", 
   FractionBox[
    RowBox[{"\[Theta]NUP", "+", "\[Theta]WSUP", "+", "\[Theta]SWUP"}], 
    RowBox[{"\[Theta]NPU", "+", "\[Theta]WSPU", "+", "\[Theta]SWPU"}]]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.683603987741543*^9, 3.683604097110304*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]WSN", "+", "\[Tau]WSUP", "+", "\[Tau]WSPU"}], ")"}], 
       "\[Equal]", 
       RowBox[{"k1", 
        RowBox[{"(", 
         RowBox[{"\[Tau]SWN", "+", "\[Tau]SWUP", "+", "\[Tau]SWPU"}], 
         ")"}]}]}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Tau]NUP", "+", "\[Tau]WSUP", "+", "\[Tau]SWUP"}], ")"}], 
       "\[Equal]", 
       RowBox[{"k2", 
        RowBox[{"(", 
         RowBox[{"\[Tau]NPU", "+", "\[Tau]WSPU", "+", "\[Tau]SWPU"}], 
         ")"}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Tau]SWN", ",", "\[Tau]NPU"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.683603544183054*^9, 3.683603663227866*^9}, {
  3.6836041540785437`*^9, 3.683604251907958*^9}, {3.68360439097055*^9, 
  3.6836044531259127`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[Tau]SWN", "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"\[Theta]WSN", "+", "\[Theta]WSPU", "+", "\[Theta]WSUP"}], 
          ")"}]}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Tau]SWPU", "+", "\[Tau]SWUP"}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Theta]SWN", "+", "\[Theta]SWPU", "+", "\[Theta]SWUP"}], 
         ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Tau]WSN", "+", "\[Tau]WSPU", "+", "\[Tau]WSUP"}], 
         ")"}]}]}], 
      RowBox[{"\[Theta]WSN", "+", "\[Theta]WSPU", "+", "\[Theta]WSUP"}]]}], 
    ",", 
    RowBox[{"\[Tau]NPU", "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"\[Theta]NUP", "+", "\[Theta]SWUP", "+", "\[Theta]WSUP"}], 
          ")"}]}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Tau]SWPU", "+", "\[Tau]WSPU"}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Theta]NPU", "+", "\[Theta]SWPU", "+", "\[Theta]WSPU"}], 
         ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Tau]NUP", "+", "\[Tau]SWUP", "+", "\[Tau]WSUP"}], 
         ")"}]}]}], 
      RowBox[{"\[Theta]NUP", "+", "\[Theta]SWUP", "+", "\[Theta]WSUP"}]]}]}], 
   "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.683603620772778*^9, 3.68360366379599*^9}, 
   3.683604253235026*^9, {3.6836044492711277`*^9, 3.683604454120096*^9}, 
   3.68360467793893*^9, 3.683605954758753*^9, 3.6836060419565277`*^9, 
   3.68360611261919*^9, 3.683606406379877*^9, 3.683607139433901*^9, 
   3.683607225747404*^9, 3.683607274421073*^9, 3.683607357323143*^9, 
   3.68360742415135*^9, 3.683607491979295*^9, 3.683607558092862*^9, 
   3.68360770945096*^9, 3.683607777186401*^9, 3.683607948167338*^9, 
   3.683608043617741*^9, 3.683608077960759*^9, 3.703224613148597*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Do", " ", "not", " ", "use", " ", "the", " ", "same", " ", "value", " ", 
    "for", " ", "B0", " ", "and", " ", "S0", " ", "or", " ", "S0", " ", "and",
     " ", "S1", " ", "for", " ", "initial", " ", "values"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"L", "=", 
     RowBox[{"Length", "[", "tabParam", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ",", 
     RowBox[{"i", "\[LessEqual]", "L"}], ",", 
     RowBox[{
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"B0num", "=", 
         RowBox[{
          RowBox[{"tabParam", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"B1num", "=", 
         RowBox[{
          RowBox[{"tabParam", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"S0num", "=", 
         RowBox[{
          RowBox[{"tabParam", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "[", 
          RowBox[{"[", "3", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"S1num", "=", 
         RowBox[{
          RowBox[{"tabParam", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "[", 
          RowBox[{"[", "4", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"initDBe", "=", 
         RowBox[{"Union", "[", 
          RowBox[{
           RowBox[{"Delete", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"B0", ",", "0.4"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"B1", ",", "0.3"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"S0", ",", "0.2"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"S1", ",", "0.1"}], "}"}]}], "}"}], ",", 
             RowBox[{"Position", "[", 
              RowBox[{
               RowBox[{"tabParam", "[", 
                RowBox[{"[", "i", "]"}], "]"}], ",", "_Real"}], "]"}]}], 
            "]"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"\[Theta]NN", ",", "\[Theta]NNi"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"\[Theta]NUP", ",", "\[Theta]NUPi"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"\[Theta]NPU", ",", "\[Theta]NPUi"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"\[Theta]WSN", ",", "\[Theta]WSNi"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"\[Theta]WSUP", ",", "\[Theta]WSPUi"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"\[Theta]WSPU", ",", "\[Theta]WSPUi"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"\[Theta]SWN", ",", "\[Theta]SWNi"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"\[Theta]SWUP", ",", "\[Theta]SWUPi"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"\[Theta]SWPU", ",", "\[Theta]SWPUi"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"\[Tau]NN", ",", "\[Tau]NNi"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"\[Tau]WSN", ",", "\[Tau]WSNi"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"\[Tau]NUP", ",", "\[Tau]NUPi"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"\[Tau]WSUP", ",", "\[Tau]WSUPi"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"\[Tau]SWUP", ",", "\[Tau]SWUPi"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"\[Tau]WSPU", ",", "\[Tau]WSPUi"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"\[Tau]SWPU", ",", "\[Tau]SWPUi"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"\[Epsilon]", ",", "0.01"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"\[Epsilon]WS", ",", "0.03"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"\[Epsilon]SW", ",", "0.05"}], "}"}]}], "}"}], ",", 
           RowBox[{"Take", "[", 
            RowBox[{
             RowBox[{"Thread", "[", 
              RowBox[{"{", 
               RowBox[{"tabcoef", ",", "rinit"}], "}"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2", ",", 
               RowBox[{"Nchrom", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], ";",
         "\[IndentingNewLine]", 
        RowBox[{"consDBe", "=", 
         RowBox[{"Union", "[", 
          RowBox[{
           RowBox[{"Delete", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "3"}], "<", "B0", "<", "3"}], ",", 
               RowBox[{
                RowBox[{"-", "3"}], "<", "B1", "<", "3"}], ",", 
               RowBox[{
                RowBox[{"-", "3"}], "<", "S0", "<", "3"}], ",", 
               RowBox[{
                RowBox[{"-", "3"}], "<", "S1", "<", "3"}]}], "}"}], ",", 
             RowBox[{"Position", "[", 
              RowBox[{
               RowBox[{"tabParam", "[", 
                RowBox[{"[", "i", "]"}], "]"}], ",", "_Real"}], "]"}]}], 
            "]"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"\[Theta]NN", ">", "0"}], ",", 
             RowBox[{"\[Theta]NUP", ">", "0"}], ",", 
             RowBox[{"\[Theta]NPU", ">", "0"}], ",", 
             RowBox[{"\[Theta]WSN", ">", "0"}], ",", 
             RowBox[{"\[Theta]WSUP", ">", "0"}], ",", 
             RowBox[{"\[Theta]WSPU", ">", "0"}], ",", 
             RowBox[{"\[Theta]SWN", ">", "0"}], ",", 
             RowBox[{"\[Theta]SWUP", ">", "0"}], ",", 
             RowBox[{"\[Theta]SWPU", ">", "0"}], ",", "\[IndentingNewLine]", 
             RowBox[{"\[Tau]NN", ">", "0"}], ",", 
             RowBox[{"\[Tau]WSN", ">", "0"}], ",", 
             RowBox[{"\[Tau]NUP", ">", "0"}], ",", 
             RowBox[{"\[Tau]WSUP", ">", "0"}], ",", 
             RowBox[{"\[Tau]SWUP", ">", "0"}], ",", 
             RowBox[{"\[Tau]WSPU", ">", "0"}], ",", 
             RowBox[{"\[Tau]SWPU", ">", "0"}], ",", 
             RowBox[{
              FractionBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{"(", 
                   RowBox[{
                   "\[Theta]WSN", "+", "\[Theta]WSPU", "+", "\[Theta]WSUP"}], 
                   ")"}]}], " ", 
                 RowBox[{"(", 
                  RowBox[{"\[Tau]SWPU", "+", "\[Tau]SWUP"}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                  "\[Theta]SWN", "+", "\[Theta]SWPU", "+", "\[Theta]SWUP"}], 
                  ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"\[Tau]WSN", "+", "\[Tau]WSPU", "+", "\[Tau]WSUP"}],
                   ")"}]}]}], 
               RowBox[{
               "\[Theta]WSN", "+", "\[Theta]WSPU", "+", "\[Theta]WSUP"}]], 
              ">", "0"}], ",", 
             RowBox[{
              FractionBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{"(", 
                   RowBox[{
                   "\[Theta]NUP", "+", "\[Theta]SWUP", "+", "\[Theta]WSUP"}], 
                   ")"}]}], " ", 
                 RowBox[{"(", 
                  RowBox[{"\[Tau]SWPU", "+", "\[Tau]WSPU"}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                  "\[Theta]NPU", "+", "\[Theta]SWPU", "+", "\[Theta]WSPU"}], 
                  ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"\[Tau]NUP", "+", "\[Tau]SWUP", "+", "\[Tau]WSUP"}],
                   ")"}]}]}], 
               RowBox[{
               "\[Theta]NUP", "+", "\[Theta]SWUP", "+", "\[Theta]WSUP"}]], 
              ">", "0"}], ",", 
             RowBox[{"0", "\[LessEqual]", "\[Epsilon]", "\[LessEqual]", 
              RowBox[{"1", "/", "2"}]}], ",", 
             RowBox[{"0", "\[LessEqual]", "\[Epsilon]WS", "\[LessEqual]", 
              RowBox[{"1", "/", "2"}]}], ",", 
             RowBox[{"0", "\[LessEqual]", "\[Epsilon]SW", "\[LessEqual]", 
              RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
           RowBox[{"Take", "[", 
            RowBox[{
             RowBox[{"Map", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"10", ">", "#", ">", "0"}], "&"}], ",", "tabcoef"}], 
              "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2", ",", 
               RowBox[{"Nchrom", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], ";",
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"MDBe", "=", 
         RowBox[{"FindMaximum", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"logLikDBS2err3", "[", 
              RowBox[{
              "Nchrom", ",", "\[Theta]NN", ",", "\[Theta]WSN", ",", 
               "\[Theta]SWN", ",", "\[Theta]NUP", ",", "\[Theta]WSUP", ",", 
               "\[Theta]SWUP", ",", "\[Theta]NPU", ",", "\[Theta]WSPU", ",", 
               "\[Theta]SWPU", ",", "\[Tau]NN", ",", "\[Tau]WSN", ",", 
               FractionBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"(", 
                    RowBox[{
                    "\[Theta]WSN", "+", "\[Theta]WSPU", "+", "\[Theta]WSUP"}],
                     ")"}]}], " ", 
                  RowBox[{"(", 
                   RowBox[{"\[Tau]SWPU", "+", "\[Tau]SWUP"}], ")"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                   "\[Theta]SWN", "+", "\[Theta]SWPU", "+", "\[Theta]SWUP"}], 
                   ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                   "\[Tau]WSN", "+", "\[Tau]WSPU", "+", "\[Tau]WSUP"}], 
                   ")"}]}]}], 
                RowBox[{
                "\[Theta]WSN", "+", "\[Theta]WSPU", "+", "\[Theta]WSUP"}]], 
               ",", "\[Tau]NUP", ",", "\[Tau]WSUP", ",", "\[Tau]SWUP", ",", 
               FractionBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"(", 
                    RowBox[{
                    "\[Theta]NUP", "+", "\[Theta]SWUP", "+", "\[Theta]WSUP"}],
                     ")"}]}], " ", 
                  RowBox[{"(", 
                   RowBox[{"\[Tau]SWPU", "+", "\[Tau]WSPU"}], ")"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                   "\[Theta]NPU", "+", "\[Theta]SWPU", "+", "\[Theta]WSPU"}], 
                   ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                   "\[Tau]NUP", "+", "\[Tau]SWUP", "+", "\[Tau]WSUP"}], 
                   ")"}]}]}], 
                RowBox[{
                "\[Theta]NUP", "+", "\[Theta]SWUP", "+", "\[Theta]WSUP"}]], 
               ",", "\[Tau]WSPU", ",", "\[Tau]SWPU", ",", "B0num", ",", 
               "B1num", ",", "S0num", ",", "S1num", ",", "tabcoef", ",", 
               "\[Epsilon]", ",", "\[Epsilon]WS", ",", "\[Epsilon]SW", ",", 
               "tabNN", ",", "tabWSN", ",", "tabSWN", ",", "tabNUP", ",", 
               "tabWSUP", ",", "tabSWUP", ",", "tabNPU", ",", "tabWSPU", ",", 
               "tabSWPU", ",", "DNN", ",", "DWSN", ",", "DSWN", ",", "DNUP", 
               ",", "DWSUP", ",", "DSWUP", ",", "DNPU", ",", "DWSPU", ",", 
               "DSWPU"}], "]"}], ",", "consDBe"}], "}"}], ",", "initDBe", ",", 
           RowBox[{"AccuracyGoal", "\[Rule]", "6"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{"i", ",", "\"\<  \>\"", ",", 
          RowBox[{"MDBe", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"B0num", "=", 
         RowBox[{
          RowBox[{"tabParamExp", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"B1num", "=", 
         RowBox[{
          RowBox[{"tabParamExp", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"S0num", "=", 
         RowBox[{
          RowBox[{"tabParamExp", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "[", 
          RowBox[{"[", "3", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"S1num", "=", 
         RowBox[{
          RowBox[{"tabParamExp", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "[", 
          RowBox[{"[", "4", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"dof", "=", 
         RowBox[{"4", "-", 
          RowBox[{"Count", "[", 
           RowBox[{
            RowBox[{"tabParamExp", "[", 
             RowBox[{"[", "i", "]"}], "]"}], ",", "_Real"}], "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"AIC", "=", 
         RowBox[{
          RowBox[{"2", "dof"}], "-", 
          RowBox[{"2", 
           RowBox[{"MDBe", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}]}]}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"tabres", "[", 
          RowBox[{"[", 
           RowBox[{"i", "+", "1"}], "]"}], "]"}], "=", 
         RowBox[{"Flatten", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"{", 
              RowBox[{
              "B0num", ",", "B1num", ",", "S0num", ",", "S1num", ",", 
               "\[Epsilon]", ",", "\[Epsilon]WS", ",", "\[Epsilon]SW"}], 
              "}"}], "/.", 
             RowBox[{"MDBe", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], ",", 
            RowBox[{"MDBe", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", "AIC"}], "}"}], "]"}]}]}], 
       "\[IndentingNewLine]", "}"}], ";", 
      RowBox[{"i", "++"}]}]}], "\[IndentingNewLine]", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.65373400303469*^9, 3.653734143074047*^9}, {
   3.653734694612143*^9, 3.653734701019662*^9}, {3.653735030592297*^9, 
   3.653735116081588*^9}, {3.653735156370069*^9, 3.653735199164605*^9}, {
   3.653735249958486*^9, 3.653735363606181*^9}, {3.653753195039281*^9, 
   3.653753208511236*^9}, {3.653753252510456*^9, 3.653753329826664*^9}, {
   3.6537534606188793`*^9, 3.653753478993801*^9}, {3.653753569891334*^9, 
   3.6537535716503963`*^9}, 3.6537536450939713`*^9, {3.653753781380617*^9, 
   3.653753815820415*^9}, {3.653753944151794*^9, 3.653753944414426*^9}, {
   3.653754040667725*^9, 3.653754181697949*^9}, {3.653756519533805*^9, 
   3.653756584838965*^9}, {3.6537566297072144`*^9, 3.653756646052767*^9}, {
   3.6537568051990223`*^9, 3.653756902128758*^9}, 3.653756948271596*^9, {
   3.653757011952985*^9, 3.653757104828805*^9}, {3.65375713824631*^9, 
   3.653757139238858*^9}, {3.653757172410963*^9, 3.653757212051075*^9}, {
   3.653757249741775*^9, 3.653757345907467*^9}, {3.653757489404386*^9, 
   3.653757501482259*^9}, {3.653757781548493*^9, 3.6537577824202547`*^9}, {
   3.653757915911271*^9, 3.653757916780591*^9}, {3.653758147078246*^9, 
   3.653758152227619*^9}, {3.653758194076358*^9, 3.6537582289816923`*^9}, {
   3.6537582673336763`*^9, 3.653758269510188*^9}, {3.653758300022583*^9, 
   3.653758374070094*^9}, {3.653758456460436*^9, 3.653758467640526*^9}, {
   3.6537585033402557`*^9, 3.653758522928685*^9}, {3.653758578155723*^9, 
   3.6537585854824057`*^9}, {3.653758745912722*^9, 3.6537588470331306`*^9}, {
   3.65375959442426*^9, 3.653759603762061*^9}, {3.653759639104941*^9, 
   3.653759652211752*^9}, {3.653759988673428*^9, 3.6537600246403112`*^9}, {
   3.653760081267394*^9, 3.6537600817538347`*^9}, {3.653760138716716*^9, 
   3.653760162303059*^9}, 3.6537602007858753`*^9, {3.6537602388345547`*^9, 
   3.653760239268302*^9}, {3.6537602830647383`*^9, 3.6537603162449627`*^9}, {
   3.653760525387795*^9, 3.653760548070983*^9}, {3.6537609484711103`*^9, 
   3.653760952081965*^9}, 3.653761054153509*^9, {3.6537610879809313`*^9, 
   3.653761141710444*^9}, {3.653761240270129*^9, 3.653761257905654*^9}, {
   3.6537613632164783`*^9, 3.6537614059039707`*^9}, {3.65376150406452*^9, 
   3.6537615566910257`*^9}, {3.6538157960344954`*^9, 3.653815882194355*^9}, 
   3.653815927128415*^9, {3.653816017583181*^9, 3.6538160562309732`*^9}, {
   3.6538161035763073`*^9, 3.653816142633319*^9}, {3.653816188050271*^9, 
   3.6538161884535217`*^9}, {3.653816326672975*^9, 3.653816405673089*^9}, {
   3.6538164431420803`*^9, 3.653816494028804*^9}, {3.6538165349394827`*^9, 
   3.653816679035315*^9}, {3.6538167147189703`*^9, 3.653816878520878*^9}, {
   3.653816924149486*^9, 3.65381704009095*^9}, {3.653817070412017*^9, 
   3.6538171201145363`*^9}, {3.6538171616163683`*^9, 
   3.6538173213668737`*^9}, {3.6538173549587927`*^9, 3.653817437984357*^9}, {
   3.653817469653769*^9, 3.653817528704439*^9}, {3.653817559092558*^9, 
   3.653817758530411*^9}, {3.65381789197294*^9, 3.653817893897275*^9}, {
   3.665172997778788*^9, 3.6651730078902903`*^9}, {3.665173236123234*^9, 
   3.665173241457993*^9}, {3.665173332244475*^9, 3.665173337901325*^9}, {
   3.665173389923169*^9, 3.6651733999583273`*^9}, {3.665173537286694*^9, 
   3.6651735378991213`*^9}, {3.665173755981818*^9, 3.665173771929631*^9}, {
   3.665174068233397*^9, 3.6651740831930723`*^9}, 3.6651741372342052`*^9, {
   3.665174208609591*^9, 3.665174248948092*^9}, {3.665174279418909*^9, 
   3.665174279737776*^9}, {3.6651743103483953`*^9, 3.66517431225229*^9}, {
   3.665174350513488*^9, 3.665174353145072*^9}, {3.665174577211898*^9, 
   3.6651745808182287`*^9}, {3.66517463078938*^9, 3.665174707019011*^9}, {
   3.66517478811371*^9, 3.66517479886495*^9}, {3.665174875756072*^9, 
   3.6651748775808268`*^9}, {3.665174928077318*^9, 3.665174934226946*^9}, {
   3.6651749947263727`*^9, 3.665174994922432*^9}, {3.6651750898840637`*^9, 
   3.665175102131407*^9}, {3.665175318893133*^9, 3.6651753233637743`*^9}, {
   3.665175378620631*^9, 3.665175391253058*^9}, {3.665175491352499*^9, 
   3.6651754950381308`*^9}, {3.6651755527442083`*^9, 3.66517556235184*^9}, {
   3.665175809741971*^9, 3.6651758172987547`*^9}, {3.665175878828525*^9, 
   3.665175925932416*^9}, {3.665176047224408*^9, 3.665176073091461*^9}, {
   3.6651761156031427`*^9, 3.665176117532517*^9}, {3.665176161803426*^9, 
   3.6651761725156603`*^9}, {3.6651762836306067`*^9, 3.665176283900303*^9}, {
   3.6651764158589582`*^9, 3.665176430112966*^9}, {3.665176472061318*^9, 
   3.665176472725068*^9}, {3.67128672002663*^9, 3.671286721109541*^9}, {
   3.671286790622157*^9, 3.6712867906317663`*^9}, {3.672052376674868*^9, 
   3.6720523920578413`*^9}, {3.683532406134097*^9, 3.6835324448437643`*^9}, {
   3.68353263142712*^9, 3.683532634688272*^9}, {3.683533165824669*^9, 
   3.683533171178111*^9}, {3.683533474333075*^9, 3.683533481914432*^9}, {
   3.6835645439989967`*^9, 3.683564544860018*^9}, 3.683565306837372*^9, {
   3.683565346599454*^9, 3.683565383561305*^9}, {3.683565486211465*^9, 
   3.683565496031448*^9}, {3.6835655414991827`*^9, 3.68356560854585*^9}, {
   3.683565878934311*^9, 3.683565972105735*^9}, 3.6835755790128403`*^9, {
   3.683575741663672*^9, 3.6835757485188513`*^9}, {3.683576856574459*^9, 
   3.683576867612526*^9}, 3.683604506363295*^9, {3.68360454697686*^9, 
   3.683604636102418*^9}, {3.683604686253399*^9, 3.683604688997473*^9}, 
   3.683604790868842*^9, {3.683604822963141*^9, 3.683604921928893*^9}, {
   3.683604972948777*^9, 3.683604974061336*^9}, {3.683605273853491*^9, 
   3.68360527969075*^9}, {3.683605386105011*^9, 3.683605432645679*^9}, {
   3.683605526472719*^9, 3.683605534695648*^9}, {3.683605756072296*^9, 
   3.68360575715301*^9}, {3.683606291372716*^9, 3.683606301271789*^9}, 
   3.6836063649303093`*^9, {3.683606427270225*^9, 3.683606436282712*^9}, {
   3.6836065894894114`*^9, 3.683606665872684*^9}, 3.683606968520975*^9, {
   3.683607041173671*^9, 3.683607082618623*^9}, 3.6836071423336077`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "762.4345282841969`"}]}],
  SequenceForm[1, "  ", -762.4345282841969],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6537353507019987`*^9, 3.6537353678746367`*^9}, 
   3.653753595157206*^9, {3.653753791095648*^9, 3.653753816956078*^9}, 
   3.6537568255504*^9, 3.653756871362311*^9, {3.6537570356298923`*^9, 
   3.653757109646379*^9}, 3.6537571440080547`*^9, {3.653757177349011*^9, 
   3.653757217215476*^9}, {3.653757264785472*^9, 3.653757279922448*^9}, {
   3.653757314622417*^9, 3.6537573478860693`*^9}, {3.653757481663856*^9, 
   3.6537575042344112`*^9}, 3.6537577979631987`*^9, 3.653757920730242*^9, {
   3.6537582003161373`*^9, 3.653758224470086*^9}, 3.6537582768437347`*^9, 
   3.65375830823526*^9, 3.653758338985917*^9, 3.653758375170657*^9, 
   3.653758473629262*^9, 3.653758512160017*^9, 3.653758586390959*^9, 
   3.653758650608068*^9, {3.653758737233205*^9, 3.653758840941415*^9}, 
   3.653758952416843*^9, 3.653759063182476*^9, 3.6537592306191473`*^9, 
   3.653759609564907*^9, {3.653759642274246*^9, 3.6537596532806*^9}, 
   3.6537602033606052`*^9, 3.653760250624804*^9, 3.653760549965597*^9, 
   3.653760810934359*^9, 3.6537609530399027`*^9, 3.653761061405295*^9, {
   3.653761092400545*^9, 3.65376114263573*^9}, 3.653761261074397*^9, {
   3.653761339912877*^9, 3.653761409007627*^9}, {3.653761493375175*^9, 
   3.653761557983556*^9}, 3.65381574257742*^9, {3.653815813191924*^9, 
   3.65381588562243*^9}, 3.653815928052978*^9, {3.653816048245337*^9, 
   3.653816059809569*^9}, {3.653816107049507*^9, 3.653816146620564*^9}, {
   3.653816333990164*^9, 3.653816371023144*^9}, 3.653816409277748*^9, {
   3.653816447033968*^9, 3.653816498076222*^9}, {3.653816552227981*^9, 
   3.653816684425982*^9}, {3.653816720927617*^9, 3.653816883686573*^9}, {
   3.653816920814067*^9, 3.6538169506342278`*^9}, {3.653817018854169*^9, 
   3.653817032642501*^9}, {3.6538170756965933`*^9, 3.65381712463675*^9}, {
   3.653817166671172*^9, 3.653817329755625*^9}, {3.6538173634722643`*^9, 
   3.653817442961931*^9}, {3.653817481002366*^9, 3.6538175355604267`*^9}, {
   3.653817568974964*^9, 3.653817762323675*^9}, 3.653817895498541*^9, 
   3.655723803807336*^9, 3.665172627838635*^9, 3.665172845378978*^9, 
   3.66517289533454*^9, 3.6651730088765182`*^9, {3.665173219467082*^9, 
   3.66517324247403*^9}, 3.6651733392907877`*^9, 3.665173539882122*^9, {
   3.665173756912462*^9, 3.665173773916938*^9}, 3.665174008992251*^9, 
   3.6651740840885067`*^9, 3.6651741379215117`*^9, 3.6651742497068033`*^9, 
   3.665174280964031*^9, 3.665174313074729*^9, 3.665174353905439*^9, 
   3.665174503097184*^9, 3.665174581825877*^9, {3.665174640057911*^9, 
   3.6651747101209717`*^9}, {3.665174790308454*^9, 3.6651748000077887`*^9}, 
   3.665174878505142*^9, 3.665174935335528*^9, 3.6651749990407963`*^9, 
   3.6651751034461937`*^9, 3.665175325194867*^9, 3.665175394593892*^9, 
   3.665175496425726*^9, 3.665175563329906*^9, 3.6651758182549143`*^9, {
   3.665175901844242*^9, 3.665175927252474*^9}, {3.665176051019786*^9, 
   3.665176073972555*^9}, 3.6651761186391087`*^9, 3.665176173424182*^9, 
   3.6651762849402*^9, 3.6651764322700377`*^9, 3.665176473718185*^9, 
   3.6720511337900953`*^9, 3.672051175260414*^9, 3.672051308335801*^9, 
   3.672051426341082*^9, 3.672051502592539*^9, 3.672051571873619*^9, 
   3.6720516858708487`*^9, 3.672051786171648*^9, 3.67205193644697*^9, 
   3.672052004934044*^9, 3.672052072189774*^9, 3.672052594998761*^9, 
   3.6720526677129927`*^9, 3.672052728704809*^9, 3.672052790577158*^9, 
   3.6720528504410353`*^9, 3.672052943916559*^9, 3.6720531060196733`*^9, 
   3.672053177434525*^9, 3.6720532916258698`*^9, 3.6835320213830013`*^9, 
   3.683532139717029*^9, 3.683532188606955*^9, 3.683532451652563*^9, 
   3.683532636173314*^9, 3.683532850676217*^9, 3.683532912277225*^9, 
   3.6835329777321463`*^9, 3.6835330452968493`*^9, 3.683533228396986*^9, 
   3.6835333862198153`*^9, 3.68353365530201*^9, 3.683533908162311*^9, 
   3.683533970721621*^9, 3.683534024697435*^9, 3.683534398244235*^9, 
   3.683575500466292*^9, 3.6835755882991962`*^9, 3.683575778018519*^9, 
   3.6835758431034307`*^9, 3.683575907295032*^9, 3.683575998052547*^9, 
   3.683576063732778*^9, 3.6835761469513693`*^9, 3.683576273191695*^9, 
   3.683576445068966*^9, 3.683576634310623*^9, 3.683576666756711*^9, 
   3.6835769209471207`*^9, 3.683604713307065*^9, 3.683604925483173*^9, 
   3.6836049807157707`*^9, 3.683605281905941*^9, 3.683605434390905*^9, 
   3.68360552876963*^9, 3.683605760850281*^9, 3.683605956729253*^9, 
   3.68360604274993*^9, 3.683606114166766*^9, 3.683606440310569*^9, 
   3.6836066767305517`*^9, 3.6836069757285213`*^9, 3.6836070494982967`*^9, 
   3.683607091367445*^9, 3.683607145477809*^9, 3.6836072264712133`*^9, 
   3.683607276338035*^9, 3.683607358864353*^9, 3.6836074256762533`*^9, 
   3.6836074934323397`*^9, 3.683607561348053*^9, 3.683607710951056*^9, 
   3.683607778281397*^9, 3.683607949815056*^9, 3.683608044391985*^9, 
   3.683608079311475*^9, 3.703224620902823*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"2", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "761.5158157584519`"}]}],
  SequenceForm[2, "  ", -761.5158157584519],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6537353507019987`*^9, 3.6537353678746367`*^9}, 
   3.653753595157206*^9, {3.653753791095648*^9, 3.653753816956078*^9}, 
   3.6537568255504*^9, 3.653756871362311*^9, {3.6537570356298923`*^9, 
   3.653757109646379*^9}, 3.6537571440080547`*^9, {3.653757177349011*^9, 
   3.653757217215476*^9}, {3.653757264785472*^9, 3.653757279922448*^9}, {
   3.653757314622417*^9, 3.6537573478860693`*^9}, {3.653757481663856*^9, 
   3.6537575042344112`*^9}, 3.6537577979631987`*^9, 3.653757920730242*^9, {
   3.6537582003161373`*^9, 3.653758224470086*^9}, 3.6537582768437347`*^9, 
   3.65375830823526*^9, 3.653758338985917*^9, 3.653758375170657*^9, 
   3.653758473629262*^9, 3.653758512160017*^9, 3.653758586390959*^9, 
   3.653758650608068*^9, {3.653758737233205*^9, 3.653758840941415*^9}, 
   3.653758952416843*^9, 3.653759063182476*^9, 3.6537592306191473`*^9, 
   3.653759609564907*^9, {3.653759642274246*^9, 3.6537596532806*^9}, 
   3.6537602033606052`*^9, 3.653760250624804*^9, 3.653760549965597*^9, 
   3.653760810934359*^9, 3.6537609530399027`*^9, 3.653761061405295*^9, {
   3.653761092400545*^9, 3.65376114263573*^9}, 3.653761261074397*^9, {
   3.653761339912877*^9, 3.653761409007627*^9}, {3.653761493375175*^9, 
   3.653761557983556*^9}, 3.65381574257742*^9, {3.653815813191924*^9, 
   3.65381588562243*^9}, 3.653815928052978*^9, {3.653816048245337*^9, 
   3.653816059809569*^9}, {3.653816107049507*^9, 3.653816146620564*^9}, {
   3.653816333990164*^9, 3.653816371023144*^9}, 3.653816409277748*^9, {
   3.653816447033968*^9, 3.653816498076222*^9}, {3.653816552227981*^9, 
   3.653816684425982*^9}, {3.653816720927617*^9, 3.653816883686573*^9}, {
   3.653816920814067*^9, 3.6538169506342278`*^9}, {3.653817018854169*^9, 
   3.653817032642501*^9}, {3.6538170756965933`*^9, 3.65381712463675*^9}, {
   3.653817166671172*^9, 3.653817329755625*^9}, {3.6538173634722643`*^9, 
   3.653817442961931*^9}, {3.653817481002366*^9, 3.6538175355604267`*^9}, {
   3.653817568974964*^9, 3.653817762323675*^9}, 3.653817895498541*^9, 
   3.655723803807336*^9, 3.665172627838635*^9, 3.665172845378978*^9, 
   3.66517289533454*^9, 3.6651730088765182`*^9, {3.665173219467082*^9, 
   3.66517324247403*^9}, 3.6651733392907877`*^9, 3.665173539882122*^9, {
   3.665173756912462*^9, 3.665173773916938*^9}, 3.665174008992251*^9, 
   3.6651740840885067`*^9, 3.6651741379215117`*^9, 3.6651742497068033`*^9, 
   3.665174280964031*^9, 3.665174313074729*^9, 3.665174353905439*^9, 
   3.665174503097184*^9, 3.665174581825877*^9, {3.665174640057911*^9, 
   3.6651747101209717`*^9}, {3.665174790308454*^9, 3.6651748000077887`*^9}, 
   3.665174878505142*^9, 3.665174935335528*^9, 3.6651749990407963`*^9, 
   3.6651751034461937`*^9, 3.665175325194867*^9, 3.665175394593892*^9, 
   3.665175496425726*^9, 3.665175563329906*^9, 3.6651758182549143`*^9, {
   3.665175901844242*^9, 3.665175927252474*^9}, {3.665176051019786*^9, 
   3.665176073972555*^9}, 3.6651761186391087`*^9, 3.665176173424182*^9, 
   3.6651762849402*^9, 3.6651764322700377`*^9, 3.665176473718185*^9, 
   3.6720511337900953`*^9, 3.672051175260414*^9, 3.672051308335801*^9, 
   3.672051426341082*^9, 3.672051502592539*^9, 3.672051571873619*^9, 
   3.6720516858708487`*^9, 3.672051786171648*^9, 3.67205193644697*^9, 
   3.672052004934044*^9, 3.672052072189774*^9, 3.672052594998761*^9, 
   3.6720526677129927`*^9, 3.672052728704809*^9, 3.672052790577158*^9, 
   3.6720528504410353`*^9, 3.672052943916559*^9, 3.6720531060196733`*^9, 
   3.672053177434525*^9, 3.6720532916258698`*^9, 3.6835320213830013`*^9, 
   3.683532139717029*^9, 3.683532188606955*^9, 3.683532451652563*^9, 
   3.683532636173314*^9, 3.683532850676217*^9, 3.683532912277225*^9, 
   3.6835329777321463`*^9, 3.6835330452968493`*^9, 3.683533228396986*^9, 
   3.6835333862198153`*^9, 3.68353365530201*^9, 3.683533908162311*^9, 
   3.683533970721621*^9, 3.683534024697435*^9, 3.683534398244235*^9, 
   3.683575500466292*^9, 3.6835755882991962`*^9, 3.683575778018519*^9, 
   3.6835758431034307`*^9, 3.683575907295032*^9, 3.683575998052547*^9, 
   3.683576063732778*^9, 3.6835761469513693`*^9, 3.683576273191695*^9, 
   3.683576445068966*^9, 3.683576634310623*^9, 3.683576666756711*^9, 
   3.6835769209471207`*^9, 3.683604713307065*^9, 3.683604925483173*^9, 
   3.6836049807157707`*^9, 3.683605281905941*^9, 3.683605434390905*^9, 
   3.68360552876963*^9, 3.683605760850281*^9, 3.683605956729253*^9, 
   3.68360604274993*^9, 3.683606114166766*^9, 3.683606440310569*^9, 
   3.6836066767305517`*^9, 3.6836069757285213`*^9, 3.6836070494982967`*^9, 
   3.683607091367445*^9, 3.683607145477809*^9, 3.6836072264712133`*^9, 
   3.683607276338035*^9, 3.683607358864353*^9, 3.6836074256762533`*^9, 
   3.6836074934323397`*^9, 3.683607561348053*^9, 3.683607710951056*^9, 
   3.683607778281397*^9, 3.683607949815056*^9, 3.683608044391985*^9, 
   3.683608079311475*^9, 3.703224623991431*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"3", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "749.7293169205805`"}]}],
  SequenceForm[3, "  ", -749.7293169205805],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6537353507019987`*^9, 3.6537353678746367`*^9}, 
   3.653753595157206*^9, {3.653753791095648*^9, 3.653753816956078*^9}, 
   3.6537568255504*^9, 3.653756871362311*^9, {3.6537570356298923`*^9, 
   3.653757109646379*^9}, 3.6537571440080547`*^9, {3.653757177349011*^9, 
   3.653757217215476*^9}, {3.653757264785472*^9, 3.653757279922448*^9}, {
   3.653757314622417*^9, 3.6537573478860693`*^9}, {3.653757481663856*^9, 
   3.6537575042344112`*^9}, 3.6537577979631987`*^9, 3.653757920730242*^9, {
   3.6537582003161373`*^9, 3.653758224470086*^9}, 3.6537582768437347`*^9, 
   3.65375830823526*^9, 3.653758338985917*^9, 3.653758375170657*^9, 
   3.653758473629262*^9, 3.653758512160017*^9, 3.653758586390959*^9, 
   3.653758650608068*^9, {3.653758737233205*^9, 3.653758840941415*^9}, 
   3.653758952416843*^9, 3.653759063182476*^9, 3.6537592306191473`*^9, 
   3.653759609564907*^9, {3.653759642274246*^9, 3.6537596532806*^9}, 
   3.6537602033606052`*^9, 3.653760250624804*^9, 3.653760549965597*^9, 
   3.653760810934359*^9, 3.6537609530399027`*^9, 3.653761061405295*^9, {
   3.653761092400545*^9, 3.65376114263573*^9}, 3.653761261074397*^9, {
   3.653761339912877*^9, 3.653761409007627*^9}, {3.653761493375175*^9, 
   3.653761557983556*^9}, 3.65381574257742*^9, {3.653815813191924*^9, 
   3.65381588562243*^9}, 3.653815928052978*^9, {3.653816048245337*^9, 
   3.653816059809569*^9}, {3.653816107049507*^9, 3.653816146620564*^9}, {
   3.653816333990164*^9, 3.653816371023144*^9}, 3.653816409277748*^9, {
   3.653816447033968*^9, 3.653816498076222*^9}, {3.653816552227981*^9, 
   3.653816684425982*^9}, {3.653816720927617*^9, 3.653816883686573*^9}, {
   3.653816920814067*^9, 3.6538169506342278`*^9}, {3.653817018854169*^9, 
   3.653817032642501*^9}, {3.6538170756965933`*^9, 3.65381712463675*^9}, {
   3.653817166671172*^9, 3.653817329755625*^9}, {3.6538173634722643`*^9, 
   3.653817442961931*^9}, {3.653817481002366*^9, 3.6538175355604267`*^9}, {
   3.653817568974964*^9, 3.653817762323675*^9}, 3.653817895498541*^9, 
   3.655723803807336*^9, 3.665172627838635*^9, 3.665172845378978*^9, 
   3.66517289533454*^9, 3.6651730088765182`*^9, {3.665173219467082*^9, 
   3.66517324247403*^9}, 3.6651733392907877`*^9, 3.665173539882122*^9, {
   3.665173756912462*^9, 3.665173773916938*^9}, 3.665174008992251*^9, 
   3.6651740840885067`*^9, 3.6651741379215117`*^9, 3.6651742497068033`*^9, 
   3.665174280964031*^9, 3.665174313074729*^9, 3.665174353905439*^9, 
   3.665174503097184*^9, 3.665174581825877*^9, {3.665174640057911*^9, 
   3.6651747101209717`*^9}, {3.665174790308454*^9, 3.6651748000077887`*^9}, 
   3.665174878505142*^9, 3.665174935335528*^9, 3.6651749990407963`*^9, 
   3.6651751034461937`*^9, 3.665175325194867*^9, 3.665175394593892*^9, 
   3.665175496425726*^9, 3.665175563329906*^9, 3.6651758182549143`*^9, {
   3.665175901844242*^9, 3.665175927252474*^9}, {3.665176051019786*^9, 
   3.665176073972555*^9}, 3.6651761186391087`*^9, 3.665176173424182*^9, 
   3.6651762849402*^9, 3.6651764322700377`*^9, 3.665176473718185*^9, 
   3.6720511337900953`*^9, 3.672051175260414*^9, 3.672051308335801*^9, 
   3.672051426341082*^9, 3.672051502592539*^9, 3.672051571873619*^9, 
   3.6720516858708487`*^9, 3.672051786171648*^9, 3.67205193644697*^9, 
   3.672052004934044*^9, 3.672052072189774*^9, 3.672052594998761*^9, 
   3.6720526677129927`*^9, 3.672052728704809*^9, 3.672052790577158*^9, 
   3.6720528504410353`*^9, 3.672052943916559*^9, 3.6720531060196733`*^9, 
   3.672053177434525*^9, 3.6720532916258698`*^9, 3.6835320213830013`*^9, 
   3.683532139717029*^9, 3.683532188606955*^9, 3.683532451652563*^9, 
   3.683532636173314*^9, 3.683532850676217*^9, 3.683532912277225*^9, 
   3.6835329777321463`*^9, 3.6835330452968493`*^9, 3.683533228396986*^9, 
   3.6835333862198153`*^9, 3.68353365530201*^9, 3.683533908162311*^9, 
   3.683533970721621*^9, 3.683534024697435*^9, 3.683534398244235*^9, 
   3.683575500466292*^9, 3.6835755882991962`*^9, 3.683575778018519*^9, 
   3.6835758431034307`*^9, 3.683575907295032*^9, 3.683575998052547*^9, 
   3.683576063732778*^9, 3.6835761469513693`*^9, 3.683576273191695*^9, 
   3.683576445068966*^9, 3.683576634310623*^9, 3.683576666756711*^9, 
   3.6835769209471207`*^9, 3.683604713307065*^9, 3.683604925483173*^9, 
   3.6836049807157707`*^9, 3.683605281905941*^9, 3.683605434390905*^9, 
   3.68360552876963*^9, 3.683605760850281*^9, 3.683605956729253*^9, 
   3.68360604274993*^9, 3.683606114166766*^9, 3.683606440310569*^9, 
   3.6836066767305517`*^9, 3.6836069757285213`*^9, 3.6836070494982967`*^9, 
   3.683607091367445*^9, 3.683607145477809*^9, 3.6836072264712133`*^9, 
   3.683607276338035*^9, 3.683607358864353*^9, 3.6836074256762533`*^9, 
   3.6836074934323397`*^9, 3.683607561348053*^9, 3.683607710951056*^9, 
   3.683607778281397*^9, 3.683607949815056*^9, 3.683608044391985*^9, 
   3.683608079311475*^9, 3.703224625384617*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"4", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "745.2029697256658`"}]}],
  SequenceForm[4, "  ", -745.2029697256658],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6537353507019987`*^9, 3.6537353678746367`*^9}, 
   3.653753595157206*^9, {3.653753791095648*^9, 3.653753816956078*^9}, 
   3.6537568255504*^9, 3.653756871362311*^9, {3.6537570356298923`*^9, 
   3.653757109646379*^9}, 3.6537571440080547`*^9, {3.653757177349011*^9, 
   3.653757217215476*^9}, {3.653757264785472*^9, 3.653757279922448*^9}, {
   3.653757314622417*^9, 3.6537573478860693`*^9}, {3.653757481663856*^9, 
   3.6537575042344112`*^9}, 3.6537577979631987`*^9, 3.653757920730242*^9, {
   3.6537582003161373`*^9, 3.653758224470086*^9}, 3.6537582768437347`*^9, 
   3.65375830823526*^9, 3.653758338985917*^9, 3.653758375170657*^9, 
   3.653758473629262*^9, 3.653758512160017*^9, 3.653758586390959*^9, 
   3.653758650608068*^9, {3.653758737233205*^9, 3.653758840941415*^9}, 
   3.653758952416843*^9, 3.653759063182476*^9, 3.6537592306191473`*^9, 
   3.653759609564907*^9, {3.653759642274246*^9, 3.6537596532806*^9}, 
   3.6537602033606052`*^9, 3.653760250624804*^9, 3.653760549965597*^9, 
   3.653760810934359*^9, 3.6537609530399027`*^9, 3.653761061405295*^9, {
   3.653761092400545*^9, 3.65376114263573*^9}, 3.653761261074397*^9, {
   3.653761339912877*^9, 3.653761409007627*^9}, {3.653761493375175*^9, 
   3.653761557983556*^9}, 3.65381574257742*^9, {3.653815813191924*^9, 
   3.65381588562243*^9}, 3.653815928052978*^9, {3.653816048245337*^9, 
   3.653816059809569*^9}, {3.653816107049507*^9, 3.653816146620564*^9}, {
   3.653816333990164*^9, 3.653816371023144*^9}, 3.653816409277748*^9, {
   3.653816447033968*^9, 3.653816498076222*^9}, {3.653816552227981*^9, 
   3.653816684425982*^9}, {3.653816720927617*^9, 3.653816883686573*^9}, {
   3.653816920814067*^9, 3.6538169506342278`*^9}, {3.653817018854169*^9, 
   3.653817032642501*^9}, {3.6538170756965933`*^9, 3.65381712463675*^9}, {
   3.653817166671172*^9, 3.653817329755625*^9}, {3.6538173634722643`*^9, 
   3.653817442961931*^9}, {3.653817481002366*^9, 3.6538175355604267`*^9}, {
   3.653817568974964*^9, 3.653817762323675*^9}, 3.653817895498541*^9, 
   3.655723803807336*^9, 3.665172627838635*^9, 3.665172845378978*^9, 
   3.66517289533454*^9, 3.6651730088765182`*^9, {3.665173219467082*^9, 
   3.66517324247403*^9}, 3.6651733392907877`*^9, 3.665173539882122*^9, {
   3.665173756912462*^9, 3.665173773916938*^9}, 3.665174008992251*^9, 
   3.6651740840885067`*^9, 3.6651741379215117`*^9, 3.6651742497068033`*^9, 
   3.665174280964031*^9, 3.665174313074729*^9, 3.665174353905439*^9, 
   3.665174503097184*^9, 3.665174581825877*^9, {3.665174640057911*^9, 
   3.6651747101209717`*^9}, {3.665174790308454*^9, 3.6651748000077887`*^9}, 
   3.665174878505142*^9, 3.665174935335528*^9, 3.6651749990407963`*^9, 
   3.6651751034461937`*^9, 3.665175325194867*^9, 3.665175394593892*^9, 
   3.665175496425726*^9, 3.665175563329906*^9, 3.6651758182549143`*^9, {
   3.665175901844242*^9, 3.665175927252474*^9}, {3.665176051019786*^9, 
   3.665176073972555*^9}, 3.6651761186391087`*^9, 3.665176173424182*^9, 
   3.6651762849402*^9, 3.6651764322700377`*^9, 3.665176473718185*^9, 
   3.6720511337900953`*^9, 3.672051175260414*^9, 3.672051308335801*^9, 
   3.672051426341082*^9, 3.672051502592539*^9, 3.672051571873619*^9, 
   3.6720516858708487`*^9, 3.672051786171648*^9, 3.67205193644697*^9, 
   3.672052004934044*^9, 3.672052072189774*^9, 3.672052594998761*^9, 
   3.6720526677129927`*^9, 3.672052728704809*^9, 3.672052790577158*^9, 
   3.6720528504410353`*^9, 3.672052943916559*^9, 3.6720531060196733`*^9, 
   3.672053177434525*^9, 3.6720532916258698`*^9, 3.6835320213830013`*^9, 
   3.683532139717029*^9, 3.683532188606955*^9, 3.683532451652563*^9, 
   3.683532636173314*^9, 3.683532850676217*^9, 3.683532912277225*^9, 
   3.6835329777321463`*^9, 3.6835330452968493`*^9, 3.683533228396986*^9, 
   3.6835333862198153`*^9, 3.68353365530201*^9, 3.683533908162311*^9, 
   3.683533970721621*^9, 3.683534024697435*^9, 3.683534398244235*^9, 
   3.683575500466292*^9, 3.6835755882991962`*^9, 3.683575778018519*^9, 
   3.6835758431034307`*^9, 3.683575907295032*^9, 3.683575998052547*^9, 
   3.683576063732778*^9, 3.6835761469513693`*^9, 3.683576273191695*^9, 
   3.683576445068966*^9, 3.683576634310623*^9, 3.683576666756711*^9, 
   3.6835769209471207`*^9, 3.683604713307065*^9, 3.683604925483173*^9, 
   3.6836049807157707`*^9, 3.683605281905941*^9, 3.683605434390905*^9, 
   3.68360552876963*^9, 3.683605760850281*^9, 3.683605956729253*^9, 
   3.68360604274993*^9, 3.683606114166766*^9, 3.683606440310569*^9, 
   3.6836066767305517`*^9, 3.6836069757285213`*^9, 3.6836070494982967`*^9, 
   3.683607091367445*^9, 3.683607145477809*^9, 3.6836072264712133`*^9, 
   3.683607276338035*^9, 3.683607358864353*^9, 3.6836074256762533`*^9, 
   3.6836074934323397`*^9, 3.683607561348053*^9, 3.683607710951056*^9, 
   3.683607778281397*^9, 3.683607949815056*^9, 3.683608044391985*^9, 
   3.683608079311475*^9, 3.7032246289429073`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"5", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "761.0104964914062`"}]}],
  SequenceForm[5, "  ", -761.0104964914062],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6537353507019987`*^9, 3.6537353678746367`*^9}, 
   3.653753595157206*^9, {3.653753791095648*^9, 3.653753816956078*^9}, 
   3.6537568255504*^9, 3.653756871362311*^9, {3.6537570356298923`*^9, 
   3.653757109646379*^9}, 3.6537571440080547`*^9, {3.653757177349011*^9, 
   3.653757217215476*^9}, {3.653757264785472*^9, 3.653757279922448*^9}, {
   3.653757314622417*^9, 3.6537573478860693`*^9}, {3.653757481663856*^9, 
   3.6537575042344112`*^9}, 3.6537577979631987`*^9, 3.653757920730242*^9, {
   3.6537582003161373`*^9, 3.653758224470086*^9}, 3.6537582768437347`*^9, 
   3.65375830823526*^9, 3.653758338985917*^9, 3.653758375170657*^9, 
   3.653758473629262*^9, 3.653758512160017*^9, 3.653758586390959*^9, 
   3.653758650608068*^9, {3.653758737233205*^9, 3.653758840941415*^9}, 
   3.653758952416843*^9, 3.653759063182476*^9, 3.6537592306191473`*^9, 
   3.653759609564907*^9, {3.653759642274246*^9, 3.6537596532806*^9}, 
   3.6537602033606052`*^9, 3.653760250624804*^9, 3.653760549965597*^9, 
   3.653760810934359*^9, 3.6537609530399027`*^9, 3.653761061405295*^9, {
   3.653761092400545*^9, 3.65376114263573*^9}, 3.653761261074397*^9, {
   3.653761339912877*^9, 3.653761409007627*^9}, {3.653761493375175*^9, 
   3.653761557983556*^9}, 3.65381574257742*^9, {3.653815813191924*^9, 
   3.65381588562243*^9}, 3.653815928052978*^9, {3.653816048245337*^9, 
   3.653816059809569*^9}, {3.653816107049507*^9, 3.653816146620564*^9}, {
   3.653816333990164*^9, 3.653816371023144*^9}, 3.653816409277748*^9, {
   3.653816447033968*^9, 3.653816498076222*^9}, {3.653816552227981*^9, 
   3.653816684425982*^9}, {3.653816720927617*^9, 3.653816883686573*^9}, {
   3.653816920814067*^9, 3.6538169506342278`*^9}, {3.653817018854169*^9, 
   3.653817032642501*^9}, {3.6538170756965933`*^9, 3.65381712463675*^9}, {
   3.653817166671172*^9, 3.653817329755625*^9}, {3.6538173634722643`*^9, 
   3.653817442961931*^9}, {3.653817481002366*^9, 3.6538175355604267`*^9}, {
   3.653817568974964*^9, 3.653817762323675*^9}, 3.653817895498541*^9, 
   3.655723803807336*^9, 3.665172627838635*^9, 3.665172845378978*^9, 
   3.66517289533454*^9, 3.6651730088765182`*^9, {3.665173219467082*^9, 
   3.66517324247403*^9}, 3.6651733392907877`*^9, 3.665173539882122*^9, {
   3.665173756912462*^9, 3.665173773916938*^9}, 3.665174008992251*^9, 
   3.6651740840885067`*^9, 3.6651741379215117`*^9, 3.6651742497068033`*^9, 
   3.665174280964031*^9, 3.665174313074729*^9, 3.665174353905439*^9, 
   3.665174503097184*^9, 3.665174581825877*^9, {3.665174640057911*^9, 
   3.6651747101209717`*^9}, {3.665174790308454*^9, 3.6651748000077887`*^9}, 
   3.665174878505142*^9, 3.665174935335528*^9, 3.6651749990407963`*^9, 
   3.6651751034461937`*^9, 3.665175325194867*^9, 3.665175394593892*^9, 
   3.665175496425726*^9, 3.665175563329906*^9, 3.6651758182549143`*^9, {
   3.665175901844242*^9, 3.665175927252474*^9}, {3.665176051019786*^9, 
   3.665176073972555*^9}, 3.6651761186391087`*^9, 3.665176173424182*^9, 
   3.6651762849402*^9, 3.6651764322700377`*^9, 3.665176473718185*^9, 
   3.6720511337900953`*^9, 3.672051175260414*^9, 3.672051308335801*^9, 
   3.672051426341082*^9, 3.672051502592539*^9, 3.672051571873619*^9, 
   3.6720516858708487`*^9, 3.672051786171648*^9, 3.67205193644697*^9, 
   3.672052004934044*^9, 3.672052072189774*^9, 3.672052594998761*^9, 
   3.6720526677129927`*^9, 3.672052728704809*^9, 3.672052790577158*^9, 
   3.6720528504410353`*^9, 3.672052943916559*^9, 3.6720531060196733`*^9, 
   3.672053177434525*^9, 3.6720532916258698`*^9, 3.6835320213830013`*^9, 
   3.683532139717029*^9, 3.683532188606955*^9, 3.683532451652563*^9, 
   3.683532636173314*^9, 3.683532850676217*^9, 3.683532912277225*^9, 
   3.6835329777321463`*^9, 3.6835330452968493`*^9, 3.683533228396986*^9, 
   3.6835333862198153`*^9, 3.68353365530201*^9, 3.683533908162311*^9, 
   3.683533970721621*^9, 3.683534024697435*^9, 3.683534398244235*^9, 
   3.683575500466292*^9, 3.6835755882991962`*^9, 3.683575778018519*^9, 
   3.6835758431034307`*^9, 3.683575907295032*^9, 3.683575998052547*^9, 
   3.683576063732778*^9, 3.6835761469513693`*^9, 3.683576273191695*^9, 
   3.683576445068966*^9, 3.683576634310623*^9, 3.683576666756711*^9, 
   3.6835769209471207`*^9, 3.683604713307065*^9, 3.683604925483173*^9, 
   3.6836049807157707`*^9, 3.683605281905941*^9, 3.683605434390905*^9, 
   3.68360552876963*^9, 3.683605760850281*^9, 3.683605956729253*^9, 
   3.68360604274993*^9, 3.683606114166766*^9, 3.683606440310569*^9, 
   3.6836066767305517`*^9, 3.6836069757285213`*^9, 3.6836070494982967`*^9, 
   3.683607091367445*^9, 3.683607145477809*^9, 3.6836072264712133`*^9, 
   3.683607276338035*^9, 3.683607358864353*^9, 3.6836074256762533`*^9, 
   3.6836074934323397`*^9, 3.683607561348053*^9, 3.683607710951056*^9, 
   3.683607778281397*^9, 3.683607949815056*^9, 3.683608044391985*^9, 
   3.683608079311475*^9, 3.703224632333477*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"6", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "760.937703557036`"}]}],
  SequenceForm[6, "  ", -760.937703557036],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6537353507019987`*^9, 3.6537353678746367`*^9}, 
   3.653753595157206*^9, {3.653753791095648*^9, 3.653753816956078*^9}, 
   3.6537568255504*^9, 3.653756871362311*^9, {3.6537570356298923`*^9, 
   3.653757109646379*^9}, 3.6537571440080547`*^9, {3.653757177349011*^9, 
   3.653757217215476*^9}, {3.653757264785472*^9, 3.653757279922448*^9}, {
   3.653757314622417*^9, 3.6537573478860693`*^9}, {3.653757481663856*^9, 
   3.6537575042344112`*^9}, 3.6537577979631987`*^9, 3.653757920730242*^9, {
   3.6537582003161373`*^9, 3.653758224470086*^9}, 3.6537582768437347`*^9, 
   3.65375830823526*^9, 3.653758338985917*^9, 3.653758375170657*^9, 
   3.653758473629262*^9, 3.653758512160017*^9, 3.653758586390959*^9, 
   3.653758650608068*^9, {3.653758737233205*^9, 3.653758840941415*^9}, 
   3.653758952416843*^9, 3.653759063182476*^9, 3.6537592306191473`*^9, 
   3.653759609564907*^9, {3.653759642274246*^9, 3.6537596532806*^9}, 
   3.6537602033606052`*^9, 3.653760250624804*^9, 3.653760549965597*^9, 
   3.653760810934359*^9, 3.6537609530399027`*^9, 3.653761061405295*^9, {
   3.653761092400545*^9, 3.65376114263573*^9}, 3.653761261074397*^9, {
   3.653761339912877*^9, 3.653761409007627*^9}, {3.653761493375175*^9, 
   3.653761557983556*^9}, 3.65381574257742*^9, {3.653815813191924*^9, 
   3.65381588562243*^9}, 3.653815928052978*^9, {3.653816048245337*^9, 
   3.653816059809569*^9}, {3.653816107049507*^9, 3.653816146620564*^9}, {
   3.653816333990164*^9, 3.653816371023144*^9}, 3.653816409277748*^9, {
   3.653816447033968*^9, 3.653816498076222*^9}, {3.653816552227981*^9, 
   3.653816684425982*^9}, {3.653816720927617*^9, 3.653816883686573*^9}, {
   3.653816920814067*^9, 3.6538169506342278`*^9}, {3.653817018854169*^9, 
   3.653817032642501*^9}, {3.6538170756965933`*^9, 3.65381712463675*^9}, {
   3.653817166671172*^9, 3.653817329755625*^9}, {3.6538173634722643`*^9, 
   3.653817442961931*^9}, {3.653817481002366*^9, 3.6538175355604267`*^9}, {
   3.653817568974964*^9, 3.653817762323675*^9}, 3.653817895498541*^9, 
   3.655723803807336*^9, 3.665172627838635*^9, 3.665172845378978*^9, 
   3.66517289533454*^9, 3.6651730088765182`*^9, {3.665173219467082*^9, 
   3.66517324247403*^9}, 3.6651733392907877`*^9, 3.665173539882122*^9, {
   3.665173756912462*^9, 3.665173773916938*^9}, 3.665174008992251*^9, 
   3.6651740840885067`*^9, 3.6651741379215117`*^9, 3.6651742497068033`*^9, 
   3.665174280964031*^9, 3.665174313074729*^9, 3.665174353905439*^9, 
   3.665174503097184*^9, 3.665174581825877*^9, {3.665174640057911*^9, 
   3.6651747101209717`*^9}, {3.665174790308454*^9, 3.6651748000077887`*^9}, 
   3.665174878505142*^9, 3.665174935335528*^9, 3.6651749990407963`*^9, 
   3.6651751034461937`*^9, 3.665175325194867*^9, 3.665175394593892*^9, 
   3.665175496425726*^9, 3.665175563329906*^9, 3.6651758182549143`*^9, {
   3.665175901844242*^9, 3.665175927252474*^9}, {3.665176051019786*^9, 
   3.665176073972555*^9}, 3.6651761186391087`*^9, 3.665176173424182*^9, 
   3.6651762849402*^9, 3.6651764322700377`*^9, 3.665176473718185*^9, 
   3.6720511337900953`*^9, 3.672051175260414*^9, 3.672051308335801*^9, 
   3.672051426341082*^9, 3.672051502592539*^9, 3.672051571873619*^9, 
   3.6720516858708487`*^9, 3.672051786171648*^9, 3.67205193644697*^9, 
   3.672052004934044*^9, 3.672052072189774*^9, 3.672052594998761*^9, 
   3.6720526677129927`*^9, 3.672052728704809*^9, 3.672052790577158*^9, 
   3.6720528504410353`*^9, 3.672052943916559*^9, 3.6720531060196733`*^9, 
   3.672053177434525*^9, 3.6720532916258698`*^9, 3.6835320213830013`*^9, 
   3.683532139717029*^9, 3.683532188606955*^9, 3.683532451652563*^9, 
   3.683532636173314*^9, 3.683532850676217*^9, 3.683532912277225*^9, 
   3.6835329777321463`*^9, 3.6835330452968493`*^9, 3.683533228396986*^9, 
   3.6835333862198153`*^9, 3.68353365530201*^9, 3.683533908162311*^9, 
   3.683533970721621*^9, 3.683534024697435*^9, 3.683534398244235*^9, 
   3.683575500466292*^9, 3.6835755882991962`*^9, 3.683575778018519*^9, 
   3.6835758431034307`*^9, 3.683575907295032*^9, 3.683575998052547*^9, 
   3.683576063732778*^9, 3.6835761469513693`*^9, 3.683576273191695*^9, 
   3.683576445068966*^9, 3.683576634310623*^9, 3.683576666756711*^9, 
   3.6835769209471207`*^9, 3.683604713307065*^9, 3.683604925483173*^9, 
   3.6836049807157707`*^9, 3.683605281905941*^9, 3.683605434390905*^9, 
   3.68360552876963*^9, 3.683605760850281*^9, 3.683605956729253*^9, 
   3.68360604274993*^9, 3.683606114166766*^9, 3.683606440310569*^9, 
   3.6836066767305517`*^9, 3.6836069757285213`*^9, 3.6836070494982967`*^9, 
   3.683607091367445*^9, 3.683607145477809*^9, 3.6836072264712133`*^9, 
   3.683607276338035*^9, 3.683607358864353*^9, 3.6836074256762533`*^9, 
   3.6836074934323397`*^9, 3.683607561348053*^9, 3.683607710951056*^9, 
   3.683607778281397*^9, 3.683607949815056*^9, 3.683608044391985*^9, 
   3.683608079311475*^9, 3.703224637595742*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"7", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "745.218475962014`"}]}],
  SequenceForm[7, "  ", -745.218475962014],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6537353507019987`*^9, 3.6537353678746367`*^9}, 
   3.653753595157206*^9, {3.653753791095648*^9, 3.653753816956078*^9}, 
   3.6537568255504*^9, 3.653756871362311*^9, {3.6537570356298923`*^9, 
   3.653757109646379*^9}, 3.6537571440080547`*^9, {3.653757177349011*^9, 
   3.653757217215476*^9}, {3.653757264785472*^9, 3.653757279922448*^9}, {
   3.653757314622417*^9, 3.6537573478860693`*^9}, {3.653757481663856*^9, 
   3.6537575042344112`*^9}, 3.6537577979631987`*^9, 3.653757920730242*^9, {
   3.6537582003161373`*^9, 3.653758224470086*^9}, 3.6537582768437347`*^9, 
   3.65375830823526*^9, 3.653758338985917*^9, 3.653758375170657*^9, 
   3.653758473629262*^9, 3.653758512160017*^9, 3.653758586390959*^9, 
   3.653758650608068*^9, {3.653758737233205*^9, 3.653758840941415*^9}, 
   3.653758952416843*^9, 3.653759063182476*^9, 3.6537592306191473`*^9, 
   3.653759609564907*^9, {3.653759642274246*^9, 3.6537596532806*^9}, 
   3.6537602033606052`*^9, 3.653760250624804*^9, 3.653760549965597*^9, 
   3.653760810934359*^9, 3.6537609530399027`*^9, 3.653761061405295*^9, {
   3.653761092400545*^9, 3.65376114263573*^9}, 3.653761261074397*^9, {
   3.653761339912877*^9, 3.653761409007627*^9}, {3.653761493375175*^9, 
   3.653761557983556*^9}, 3.65381574257742*^9, {3.653815813191924*^9, 
   3.65381588562243*^9}, 3.653815928052978*^9, {3.653816048245337*^9, 
   3.653816059809569*^9}, {3.653816107049507*^9, 3.653816146620564*^9}, {
   3.653816333990164*^9, 3.653816371023144*^9}, 3.653816409277748*^9, {
   3.653816447033968*^9, 3.653816498076222*^9}, {3.653816552227981*^9, 
   3.653816684425982*^9}, {3.653816720927617*^9, 3.653816883686573*^9}, {
   3.653816920814067*^9, 3.6538169506342278`*^9}, {3.653817018854169*^9, 
   3.653817032642501*^9}, {3.6538170756965933`*^9, 3.65381712463675*^9}, {
   3.653817166671172*^9, 3.653817329755625*^9}, {3.6538173634722643`*^9, 
   3.653817442961931*^9}, {3.653817481002366*^9, 3.6538175355604267`*^9}, {
   3.653817568974964*^9, 3.653817762323675*^9}, 3.653817895498541*^9, 
   3.655723803807336*^9, 3.665172627838635*^9, 3.665172845378978*^9, 
   3.66517289533454*^9, 3.6651730088765182`*^9, {3.665173219467082*^9, 
   3.66517324247403*^9}, 3.6651733392907877`*^9, 3.665173539882122*^9, {
   3.665173756912462*^9, 3.665173773916938*^9}, 3.665174008992251*^9, 
   3.6651740840885067`*^9, 3.6651741379215117`*^9, 3.6651742497068033`*^9, 
   3.665174280964031*^9, 3.665174313074729*^9, 3.665174353905439*^9, 
   3.665174503097184*^9, 3.665174581825877*^9, {3.665174640057911*^9, 
   3.6651747101209717`*^9}, {3.665174790308454*^9, 3.6651748000077887`*^9}, 
   3.665174878505142*^9, 3.665174935335528*^9, 3.6651749990407963`*^9, 
   3.6651751034461937`*^9, 3.665175325194867*^9, 3.665175394593892*^9, 
   3.665175496425726*^9, 3.665175563329906*^9, 3.6651758182549143`*^9, {
   3.665175901844242*^9, 3.665175927252474*^9}, {3.665176051019786*^9, 
   3.665176073972555*^9}, 3.6651761186391087`*^9, 3.665176173424182*^9, 
   3.6651762849402*^9, 3.6651764322700377`*^9, 3.665176473718185*^9, 
   3.6720511337900953`*^9, 3.672051175260414*^9, 3.672051308335801*^9, 
   3.672051426341082*^9, 3.672051502592539*^9, 3.672051571873619*^9, 
   3.6720516858708487`*^9, 3.672051786171648*^9, 3.67205193644697*^9, 
   3.672052004934044*^9, 3.672052072189774*^9, 3.672052594998761*^9, 
   3.6720526677129927`*^9, 3.672052728704809*^9, 3.672052790577158*^9, 
   3.6720528504410353`*^9, 3.672052943916559*^9, 3.6720531060196733`*^9, 
   3.672053177434525*^9, 3.6720532916258698`*^9, 3.6835320213830013`*^9, 
   3.683532139717029*^9, 3.683532188606955*^9, 3.683532451652563*^9, 
   3.683532636173314*^9, 3.683532850676217*^9, 3.683532912277225*^9, 
   3.6835329777321463`*^9, 3.6835330452968493`*^9, 3.683533228396986*^9, 
   3.6835333862198153`*^9, 3.68353365530201*^9, 3.683533908162311*^9, 
   3.683533970721621*^9, 3.683534024697435*^9, 3.683534398244235*^9, 
   3.683575500466292*^9, 3.6835755882991962`*^9, 3.683575778018519*^9, 
   3.6835758431034307`*^9, 3.683575907295032*^9, 3.683575998052547*^9, 
   3.683576063732778*^9, 3.6835761469513693`*^9, 3.683576273191695*^9, 
   3.683576445068966*^9, 3.683576634310623*^9, 3.683576666756711*^9, 
   3.6835769209471207`*^9, 3.683604713307065*^9, 3.683604925483173*^9, 
   3.6836049807157707`*^9, 3.683605281905941*^9, 3.683605434390905*^9, 
   3.68360552876963*^9, 3.683605760850281*^9, 3.683605956729253*^9, 
   3.68360604274993*^9, 3.683606114166766*^9, 3.683606440310569*^9, 
   3.6836066767305517`*^9, 3.6836069757285213`*^9, 3.6836070494982967`*^9, 
   3.683607091367445*^9, 3.683607145477809*^9, 3.6836072264712133`*^9, 
   3.683607276338035*^9, 3.683607358864353*^9, 3.6836074256762533`*^9, 
   3.6836074934323397`*^9, 3.683607561348053*^9, 3.683607710951056*^9, 
   3.683607778281397*^9, 3.683607949815056*^9, 3.683608044391985*^9, 
   3.683608079311475*^9, 3.703224641119239*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"8", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "744.1469216817786`"}]}],
  SequenceForm[8, "  ", -744.1469216817786],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6537353507019987`*^9, 3.6537353678746367`*^9}, 
   3.653753595157206*^9, {3.653753791095648*^9, 3.653753816956078*^9}, 
   3.6537568255504*^9, 3.653756871362311*^9, {3.6537570356298923`*^9, 
   3.653757109646379*^9}, 3.6537571440080547`*^9, {3.653757177349011*^9, 
   3.653757217215476*^9}, {3.653757264785472*^9, 3.653757279922448*^9}, {
   3.653757314622417*^9, 3.6537573478860693`*^9}, {3.653757481663856*^9, 
   3.6537575042344112`*^9}, 3.6537577979631987`*^9, 3.653757920730242*^9, {
   3.6537582003161373`*^9, 3.653758224470086*^9}, 3.6537582768437347`*^9, 
   3.65375830823526*^9, 3.653758338985917*^9, 3.653758375170657*^9, 
   3.653758473629262*^9, 3.653758512160017*^9, 3.653758586390959*^9, 
   3.653758650608068*^9, {3.653758737233205*^9, 3.653758840941415*^9}, 
   3.653758952416843*^9, 3.653759063182476*^9, 3.6537592306191473`*^9, 
   3.653759609564907*^9, {3.653759642274246*^9, 3.6537596532806*^9}, 
   3.6537602033606052`*^9, 3.653760250624804*^9, 3.653760549965597*^9, 
   3.653760810934359*^9, 3.6537609530399027`*^9, 3.653761061405295*^9, {
   3.653761092400545*^9, 3.65376114263573*^9}, 3.653761261074397*^9, {
   3.653761339912877*^9, 3.653761409007627*^9}, {3.653761493375175*^9, 
   3.653761557983556*^9}, 3.65381574257742*^9, {3.653815813191924*^9, 
   3.65381588562243*^9}, 3.653815928052978*^9, {3.653816048245337*^9, 
   3.653816059809569*^9}, {3.653816107049507*^9, 3.653816146620564*^9}, {
   3.653816333990164*^9, 3.653816371023144*^9}, 3.653816409277748*^9, {
   3.653816447033968*^9, 3.653816498076222*^9}, {3.653816552227981*^9, 
   3.653816684425982*^9}, {3.653816720927617*^9, 3.653816883686573*^9}, {
   3.653816920814067*^9, 3.6538169506342278`*^9}, {3.653817018854169*^9, 
   3.653817032642501*^9}, {3.6538170756965933`*^9, 3.65381712463675*^9}, {
   3.653817166671172*^9, 3.653817329755625*^9}, {3.6538173634722643`*^9, 
   3.653817442961931*^9}, {3.653817481002366*^9, 3.6538175355604267`*^9}, {
   3.653817568974964*^9, 3.653817762323675*^9}, 3.653817895498541*^9, 
   3.655723803807336*^9, 3.665172627838635*^9, 3.665172845378978*^9, 
   3.66517289533454*^9, 3.6651730088765182`*^9, {3.665173219467082*^9, 
   3.66517324247403*^9}, 3.6651733392907877`*^9, 3.665173539882122*^9, {
   3.665173756912462*^9, 3.665173773916938*^9}, 3.665174008992251*^9, 
   3.6651740840885067`*^9, 3.6651741379215117`*^9, 3.6651742497068033`*^9, 
   3.665174280964031*^9, 3.665174313074729*^9, 3.665174353905439*^9, 
   3.665174503097184*^9, 3.665174581825877*^9, {3.665174640057911*^9, 
   3.6651747101209717`*^9}, {3.665174790308454*^9, 3.6651748000077887`*^9}, 
   3.665174878505142*^9, 3.665174935335528*^9, 3.6651749990407963`*^9, 
   3.6651751034461937`*^9, 3.665175325194867*^9, 3.665175394593892*^9, 
   3.665175496425726*^9, 3.665175563329906*^9, 3.6651758182549143`*^9, {
   3.665175901844242*^9, 3.665175927252474*^9}, {3.665176051019786*^9, 
   3.665176073972555*^9}, 3.6651761186391087`*^9, 3.665176173424182*^9, 
   3.6651762849402*^9, 3.6651764322700377`*^9, 3.665176473718185*^9, 
   3.6720511337900953`*^9, 3.672051175260414*^9, 3.672051308335801*^9, 
   3.672051426341082*^9, 3.672051502592539*^9, 3.672051571873619*^9, 
   3.6720516858708487`*^9, 3.672051786171648*^9, 3.67205193644697*^9, 
   3.672052004934044*^9, 3.672052072189774*^9, 3.672052594998761*^9, 
   3.6720526677129927`*^9, 3.672052728704809*^9, 3.672052790577158*^9, 
   3.6720528504410353`*^9, 3.672052943916559*^9, 3.6720531060196733`*^9, 
   3.672053177434525*^9, 3.6720532916258698`*^9, 3.6835320213830013`*^9, 
   3.683532139717029*^9, 3.683532188606955*^9, 3.683532451652563*^9, 
   3.683532636173314*^9, 3.683532850676217*^9, 3.683532912277225*^9, 
   3.6835329777321463`*^9, 3.6835330452968493`*^9, 3.683533228396986*^9, 
   3.6835333862198153`*^9, 3.68353365530201*^9, 3.683533908162311*^9, 
   3.683533970721621*^9, 3.683534024697435*^9, 3.683534398244235*^9, 
   3.683575500466292*^9, 3.6835755882991962`*^9, 3.683575778018519*^9, 
   3.6835758431034307`*^9, 3.683575907295032*^9, 3.683575998052547*^9, 
   3.683576063732778*^9, 3.6835761469513693`*^9, 3.683576273191695*^9, 
   3.683576445068966*^9, 3.683576634310623*^9, 3.683576666756711*^9, 
   3.6835769209471207`*^9, 3.683604713307065*^9, 3.683604925483173*^9, 
   3.6836049807157707`*^9, 3.683605281905941*^9, 3.683605434390905*^9, 
   3.68360552876963*^9, 3.683605760850281*^9, 3.683605956729253*^9, 
   3.68360604274993*^9, 3.683606114166766*^9, 3.683606440310569*^9, 
   3.6836066767305517`*^9, 3.6836069757285213`*^9, 3.6836070494982967`*^9, 
   3.683607091367445*^9, 3.683607145477809*^9, 3.6836072264712133`*^9, 
   3.683607276338035*^9, 3.683607358864353*^9, 3.6836074256762533`*^9, 
   3.6836074934323397`*^9, 3.683607561348053*^9, 3.683607710951056*^9, 
   3.683607778281397*^9, 3.683607949815056*^9, 3.683608044391985*^9, 
   3.683608079311475*^9, 3.7032246466752*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"9", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "745.3825138904649`"}]}],
  SequenceForm[9, "  ", -745.3825138904649],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6537353507019987`*^9, 3.6537353678746367`*^9}, 
   3.653753595157206*^9, {3.653753791095648*^9, 3.653753816956078*^9}, 
   3.6537568255504*^9, 3.653756871362311*^9, {3.6537570356298923`*^9, 
   3.653757109646379*^9}, 3.6537571440080547`*^9, {3.653757177349011*^9, 
   3.653757217215476*^9}, {3.653757264785472*^9, 3.653757279922448*^9}, {
   3.653757314622417*^9, 3.6537573478860693`*^9}, {3.653757481663856*^9, 
   3.6537575042344112`*^9}, 3.6537577979631987`*^9, 3.653757920730242*^9, {
   3.6537582003161373`*^9, 3.653758224470086*^9}, 3.6537582768437347`*^9, 
   3.65375830823526*^9, 3.653758338985917*^9, 3.653758375170657*^9, 
   3.653758473629262*^9, 3.653758512160017*^9, 3.653758586390959*^9, 
   3.653758650608068*^9, {3.653758737233205*^9, 3.653758840941415*^9}, 
   3.653758952416843*^9, 3.653759063182476*^9, 3.6537592306191473`*^9, 
   3.653759609564907*^9, {3.653759642274246*^9, 3.6537596532806*^9}, 
   3.6537602033606052`*^9, 3.653760250624804*^9, 3.653760549965597*^9, 
   3.653760810934359*^9, 3.6537609530399027`*^9, 3.653761061405295*^9, {
   3.653761092400545*^9, 3.65376114263573*^9}, 3.653761261074397*^9, {
   3.653761339912877*^9, 3.653761409007627*^9}, {3.653761493375175*^9, 
   3.653761557983556*^9}, 3.65381574257742*^9, {3.653815813191924*^9, 
   3.65381588562243*^9}, 3.653815928052978*^9, {3.653816048245337*^9, 
   3.653816059809569*^9}, {3.653816107049507*^9, 3.653816146620564*^9}, {
   3.653816333990164*^9, 3.653816371023144*^9}, 3.653816409277748*^9, {
   3.653816447033968*^9, 3.653816498076222*^9}, {3.653816552227981*^9, 
   3.653816684425982*^9}, {3.653816720927617*^9, 3.653816883686573*^9}, {
   3.653816920814067*^9, 3.6538169506342278`*^9}, {3.653817018854169*^9, 
   3.653817032642501*^9}, {3.6538170756965933`*^9, 3.65381712463675*^9}, {
   3.653817166671172*^9, 3.653817329755625*^9}, {3.6538173634722643`*^9, 
   3.653817442961931*^9}, {3.653817481002366*^9, 3.6538175355604267`*^9}, {
   3.653817568974964*^9, 3.653817762323675*^9}, 3.653817895498541*^9, 
   3.655723803807336*^9, 3.665172627838635*^9, 3.665172845378978*^9, 
   3.66517289533454*^9, 3.6651730088765182`*^9, {3.665173219467082*^9, 
   3.66517324247403*^9}, 3.6651733392907877`*^9, 3.665173539882122*^9, {
   3.665173756912462*^9, 3.665173773916938*^9}, 3.665174008992251*^9, 
   3.6651740840885067`*^9, 3.6651741379215117`*^9, 3.6651742497068033`*^9, 
   3.665174280964031*^9, 3.665174313074729*^9, 3.665174353905439*^9, 
   3.665174503097184*^9, 3.665174581825877*^9, {3.665174640057911*^9, 
   3.6651747101209717`*^9}, {3.665174790308454*^9, 3.6651748000077887`*^9}, 
   3.665174878505142*^9, 3.665174935335528*^9, 3.6651749990407963`*^9, 
   3.6651751034461937`*^9, 3.665175325194867*^9, 3.665175394593892*^9, 
   3.665175496425726*^9, 3.665175563329906*^9, 3.6651758182549143`*^9, {
   3.665175901844242*^9, 3.665175927252474*^9}, {3.665176051019786*^9, 
   3.665176073972555*^9}, 3.6651761186391087`*^9, 3.665176173424182*^9, 
   3.6651762849402*^9, 3.6651764322700377`*^9, 3.665176473718185*^9, 
   3.6720511337900953`*^9, 3.672051175260414*^9, 3.672051308335801*^9, 
   3.672051426341082*^9, 3.672051502592539*^9, 3.672051571873619*^9, 
   3.6720516858708487`*^9, 3.672051786171648*^9, 3.67205193644697*^9, 
   3.672052004934044*^9, 3.672052072189774*^9, 3.672052594998761*^9, 
   3.6720526677129927`*^9, 3.672052728704809*^9, 3.672052790577158*^9, 
   3.6720528504410353`*^9, 3.672052943916559*^9, 3.6720531060196733`*^9, 
   3.672053177434525*^9, 3.6720532916258698`*^9, 3.6835320213830013`*^9, 
   3.683532139717029*^9, 3.683532188606955*^9, 3.683532451652563*^9, 
   3.683532636173314*^9, 3.683532850676217*^9, 3.683532912277225*^9, 
   3.6835329777321463`*^9, 3.6835330452968493`*^9, 3.683533228396986*^9, 
   3.6835333862198153`*^9, 3.68353365530201*^9, 3.683533908162311*^9, 
   3.683533970721621*^9, 3.683534024697435*^9, 3.683534398244235*^9, 
   3.683575500466292*^9, 3.6835755882991962`*^9, 3.683575778018519*^9, 
   3.6835758431034307`*^9, 3.683575907295032*^9, 3.683575998052547*^9, 
   3.683576063732778*^9, 3.6835761469513693`*^9, 3.683576273191695*^9, 
   3.683576445068966*^9, 3.683576634310623*^9, 3.683576666756711*^9, 
   3.6835769209471207`*^9, 3.683604713307065*^9, 3.683604925483173*^9, 
   3.6836049807157707`*^9, 3.683605281905941*^9, 3.683605434390905*^9, 
   3.68360552876963*^9, 3.683605760850281*^9, 3.683605956729253*^9, 
   3.68360604274993*^9, 3.683606114166766*^9, 3.683606440310569*^9, 
   3.6836066767305517`*^9, 3.6836069757285213`*^9, 3.6836070494982967`*^9, 
   3.683607091367445*^9, 3.683607145477809*^9, 3.6836072264712133`*^9, 
   3.683607276338035*^9, 3.683607358864353*^9, 3.6836074256762533`*^9, 
   3.6836074934323397`*^9, 3.683607561348053*^9, 3.683607710951056*^9, 
   3.683607778281397*^9, 3.683607949815056*^9, 3.683608044391985*^9, 
   3.683608079311475*^9, 3.703224648091223*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"10", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "741.8111383555952`"}]}],
  SequenceForm[10, "  ", -741.8111383555952],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6537353507019987`*^9, 3.6537353678746367`*^9}, 
   3.653753595157206*^9, {3.653753791095648*^9, 3.653753816956078*^9}, 
   3.6537568255504*^9, 3.653756871362311*^9, {3.6537570356298923`*^9, 
   3.653757109646379*^9}, 3.6537571440080547`*^9, {3.653757177349011*^9, 
   3.653757217215476*^9}, {3.653757264785472*^9, 3.653757279922448*^9}, {
   3.653757314622417*^9, 3.6537573478860693`*^9}, {3.653757481663856*^9, 
   3.6537575042344112`*^9}, 3.6537577979631987`*^9, 3.653757920730242*^9, {
   3.6537582003161373`*^9, 3.653758224470086*^9}, 3.6537582768437347`*^9, 
   3.65375830823526*^9, 3.653758338985917*^9, 3.653758375170657*^9, 
   3.653758473629262*^9, 3.653758512160017*^9, 3.653758586390959*^9, 
   3.653758650608068*^9, {3.653758737233205*^9, 3.653758840941415*^9}, 
   3.653758952416843*^9, 3.653759063182476*^9, 3.6537592306191473`*^9, 
   3.653759609564907*^9, {3.653759642274246*^9, 3.6537596532806*^9}, 
   3.6537602033606052`*^9, 3.653760250624804*^9, 3.653760549965597*^9, 
   3.653760810934359*^9, 3.6537609530399027`*^9, 3.653761061405295*^9, {
   3.653761092400545*^9, 3.65376114263573*^9}, 3.653761261074397*^9, {
   3.653761339912877*^9, 3.653761409007627*^9}, {3.653761493375175*^9, 
   3.653761557983556*^9}, 3.65381574257742*^9, {3.653815813191924*^9, 
   3.65381588562243*^9}, 3.653815928052978*^9, {3.653816048245337*^9, 
   3.653816059809569*^9}, {3.653816107049507*^9, 3.653816146620564*^9}, {
   3.653816333990164*^9, 3.653816371023144*^9}, 3.653816409277748*^9, {
   3.653816447033968*^9, 3.653816498076222*^9}, {3.653816552227981*^9, 
   3.653816684425982*^9}, {3.653816720927617*^9, 3.653816883686573*^9}, {
   3.653816920814067*^9, 3.6538169506342278`*^9}, {3.653817018854169*^9, 
   3.653817032642501*^9}, {3.6538170756965933`*^9, 3.65381712463675*^9}, {
   3.653817166671172*^9, 3.653817329755625*^9}, {3.6538173634722643`*^9, 
   3.653817442961931*^9}, {3.653817481002366*^9, 3.6538175355604267`*^9}, {
   3.653817568974964*^9, 3.653817762323675*^9}, 3.653817895498541*^9, 
   3.655723803807336*^9, 3.665172627838635*^9, 3.665172845378978*^9, 
   3.66517289533454*^9, 3.6651730088765182`*^9, {3.665173219467082*^9, 
   3.66517324247403*^9}, 3.6651733392907877`*^9, 3.665173539882122*^9, {
   3.665173756912462*^9, 3.665173773916938*^9}, 3.665174008992251*^9, 
   3.6651740840885067`*^9, 3.6651741379215117`*^9, 3.6651742497068033`*^9, 
   3.665174280964031*^9, 3.665174313074729*^9, 3.665174353905439*^9, 
   3.665174503097184*^9, 3.665174581825877*^9, {3.665174640057911*^9, 
   3.6651747101209717`*^9}, {3.665174790308454*^9, 3.6651748000077887`*^9}, 
   3.665174878505142*^9, 3.665174935335528*^9, 3.6651749990407963`*^9, 
   3.6651751034461937`*^9, 3.665175325194867*^9, 3.665175394593892*^9, 
   3.665175496425726*^9, 3.665175563329906*^9, 3.6651758182549143`*^9, {
   3.665175901844242*^9, 3.665175927252474*^9}, {3.665176051019786*^9, 
   3.665176073972555*^9}, 3.6651761186391087`*^9, 3.665176173424182*^9, 
   3.6651762849402*^9, 3.6651764322700377`*^9, 3.665176473718185*^9, 
   3.6720511337900953`*^9, 3.672051175260414*^9, 3.672051308335801*^9, 
   3.672051426341082*^9, 3.672051502592539*^9, 3.672051571873619*^9, 
   3.6720516858708487`*^9, 3.672051786171648*^9, 3.67205193644697*^9, 
   3.672052004934044*^9, 3.672052072189774*^9, 3.672052594998761*^9, 
   3.6720526677129927`*^9, 3.672052728704809*^9, 3.672052790577158*^9, 
   3.6720528504410353`*^9, 3.672052943916559*^9, 3.6720531060196733`*^9, 
   3.672053177434525*^9, 3.6720532916258698`*^9, 3.6835320213830013`*^9, 
   3.683532139717029*^9, 3.683532188606955*^9, 3.683532451652563*^9, 
   3.683532636173314*^9, 3.683532850676217*^9, 3.683532912277225*^9, 
   3.6835329777321463`*^9, 3.6835330452968493`*^9, 3.683533228396986*^9, 
   3.6835333862198153`*^9, 3.68353365530201*^9, 3.683533908162311*^9, 
   3.683533970721621*^9, 3.683534024697435*^9, 3.683534398244235*^9, 
   3.683575500466292*^9, 3.6835755882991962`*^9, 3.683575778018519*^9, 
   3.6835758431034307`*^9, 3.683575907295032*^9, 3.683575998052547*^9, 
   3.683576063732778*^9, 3.6835761469513693`*^9, 3.683576273191695*^9, 
   3.683576445068966*^9, 3.683576634310623*^9, 3.683576666756711*^9, 
   3.6835769209471207`*^9, 3.683604713307065*^9, 3.683604925483173*^9, 
   3.6836049807157707`*^9, 3.683605281905941*^9, 3.683605434390905*^9, 
   3.68360552876963*^9, 3.683605760850281*^9, 3.683605956729253*^9, 
   3.68360604274993*^9, 3.683606114166766*^9, 3.683606440310569*^9, 
   3.6836066767305517`*^9, 3.6836069757285213`*^9, 3.6836070494982967`*^9, 
   3.683607091367445*^9, 3.683607145477809*^9, 3.6836072264712133`*^9, 
   3.683607276338035*^9, 3.683607358864353*^9, 3.6836074256762533`*^9, 
   3.6836074934323397`*^9, 3.683607561348053*^9, 3.683607710951056*^9, 
   3.683607778281397*^9, 3.683607949815056*^9, 3.683608044391985*^9, 
   3.683608079311475*^9, 3.703224651403758*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"11", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "745.1399070543266`"}]}],
  SequenceForm[11, "  ", -745.1399070543266],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6537353507019987`*^9, 3.6537353678746367`*^9}, 
   3.653753595157206*^9, {3.653753791095648*^9, 3.653753816956078*^9}, 
   3.6537568255504*^9, 3.653756871362311*^9, {3.6537570356298923`*^9, 
   3.653757109646379*^9}, 3.6537571440080547`*^9, {3.653757177349011*^9, 
   3.653757217215476*^9}, {3.653757264785472*^9, 3.653757279922448*^9}, {
   3.653757314622417*^9, 3.6537573478860693`*^9}, {3.653757481663856*^9, 
   3.6537575042344112`*^9}, 3.6537577979631987`*^9, 3.653757920730242*^9, {
   3.6537582003161373`*^9, 3.653758224470086*^9}, 3.6537582768437347`*^9, 
   3.65375830823526*^9, 3.653758338985917*^9, 3.653758375170657*^9, 
   3.653758473629262*^9, 3.653758512160017*^9, 3.653758586390959*^9, 
   3.653758650608068*^9, {3.653758737233205*^9, 3.653758840941415*^9}, 
   3.653758952416843*^9, 3.653759063182476*^9, 3.6537592306191473`*^9, 
   3.653759609564907*^9, {3.653759642274246*^9, 3.6537596532806*^9}, 
   3.6537602033606052`*^9, 3.653760250624804*^9, 3.653760549965597*^9, 
   3.653760810934359*^9, 3.6537609530399027`*^9, 3.653761061405295*^9, {
   3.653761092400545*^9, 3.65376114263573*^9}, 3.653761261074397*^9, {
   3.653761339912877*^9, 3.653761409007627*^9}, {3.653761493375175*^9, 
   3.653761557983556*^9}, 3.65381574257742*^9, {3.653815813191924*^9, 
   3.65381588562243*^9}, 3.653815928052978*^9, {3.653816048245337*^9, 
   3.653816059809569*^9}, {3.653816107049507*^9, 3.653816146620564*^9}, {
   3.653816333990164*^9, 3.653816371023144*^9}, 3.653816409277748*^9, {
   3.653816447033968*^9, 3.653816498076222*^9}, {3.653816552227981*^9, 
   3.653816684425982*^9}, {3.653816720927617*^9, 3.653816883686573*^9}, {
   3.653816920814067*^9, 3.6538169506342278`*^9}, {3.653817018854169*^9, 
   3.653817032642501*^9}, {3.6538170756965933`*^9, 3.65381712463675*^9}, {
   3.653817166671172*^9, 3.653817329755625*^9}, {3.6538173634722643`*^9, 
   3.653817442961931*^9}, {3.653817481002366*^9, 3.6538175355604267`*^9}, {
   3.653817568974964*^9, 3.653817762323675*^9}, 3.653817895498541*^9, 
   3.655723803807336*^9, 3.665172627838635*^9, 3.665172845378978*^9, 
   3.66517289533454*^9, 3.6651730088765182`*^9, {3.665173219467082*^9, 
   3.66517324247403*^9}, 3.6651733392907877`*^9, 3.665173539882122*^9, {
   3.665173756912462*^9, 3.665173773916938*^9}, 3.665174008992251*^9, 
   3.6651740840885067`*^9, 3.6651741379215117`*^9, 3.6651742497068033`*^9, 
   3.665174280964031*^9, 3.665174313074729*^9, 3.665174353905439*^9, 
   3.665174503097184*^9, 3.665174581825877*^9, {3.665174640057911*^9, 
   3.6651747101209717`*^9}, {3.665174790308454*^9, 3.6651748000077887`*^9}, 
   3.665174878505142*^9, 3.665174935335528*^9, 3.6651749990407963`*^9, 
   3.6651751034461937`*^9, 3.665175325194867*^9, 3.665175394593892*^9, 
   3.665175496425726*^9, 3.665175563329906*^9, 3.6651758182549143`*^9, {
   3.665175901844242*^9, 3.665175927252474*^9}, {3.665176051019786*^9, 
   3.665176073972555*^9}, 3.6651761186391087`*^9, 3.665176173424182*^9, 
   3.6651762849402*^9, 3.6651764322700377`*^9, 3.665176473718185*^9, 
   3.6720511337900953`*^9, 3.672051175260414*^9, 3.672051308335801*^9, 
   3.672051426341082*^9, 3.672051502592539*^9, 3.672051571873619*^9, 
   3.6720516858708487`*^9, 3.672051786171648*^9, 3.67205193644697*^9, 
   3.672052004934044*^9, 3.672052072189774*^9, 3.672052594998761*^9, 
   3.6720526677129927`*^9, 3.672052728704809*^9, 3.672052790577158*^9, 
   3.6720528504410353`*^9, 3.672052943916559*^9, 3.6720531060196733`*^9, 
   3.672053177434525*^9, 3.6720532916258698`*^9, 3.6835320213830013`*^9, 
   3.683532139717029*^9, 3.683532188606955*^9, 3.683532451652563*^9, 
   3.683532636173314*^9, 3.683532850676217*^9, 3.683532912277225*^9, 
   3.6835329777321463`*^9, 3.6835330452968493`*^9, 3.683533228396986*^9, 
   3.6835333862198153`*^9, 3.68353365530201*^9, 3.683533908162311*^9, 
   3.683533970721621*^9, 3.683534024697435*^9, 3.683534398244235*^9, 
   3.683575500466292*^9, 3.6835755882991962`*^9, 3.683575778018519*^9, 
   3.6835758431034307`*^9, 3.683575907295032*^9, 3.683575998052547*^9, 
   3.683576063732778*^9, 3.6835761469513693`*^9, 3.683576273191695*^9, 
   3.683576445068966*^9, 3.683576634310623*^9, 3.683576666756711*^9, 
   3.6835769209471207`*^9, 3.683604713307065*^9, 3.683604925483173*^9, 
   3.6836049807157707`*^9, 3.683605281905941*^9, 3.683605434390905*^9, 
   3.68360552876963*^9, 3.683605760850281*^9, 3.683605956729253*^9, 
   3.68360604274993*^9, 3.683606114166766*^9, 3.683606440310569*^9, 
   3.6836066767305517`*^9, 3.6836069757285213`*^9, 3.6836070494982967`*^9, 
   3.683607091367445*^9, 3.683607145477809*^9, 3.6836072264712133`*^9, 
   3.683607276338035*^9, 3.683607358864353*^9, 3.6836074256762533`*^9, 
   3.6836074934323397`*^9, 3.683607561348053*^9, 3.683607710951056*^9, 
   3.683607778281397*^9, 3.683607949815056*^9, 3.683608044391985*^9, 
   3.683608079311475*^9, 3.7032246529802094`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"12", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "740.9125498414069`"}]}],
  SequenceForm[12, "  ", -740.9125498414069],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6537353507019987`*^9, 3.6537353678746367`*^9}, 
   3.653753595157206*^9, {3.653753791095648*^9, 3.653753816956078*^9}, 
   3.6537568255504*^9, 3.653756871362311*^9, {3.6537570356298923`*^9, 
   3.653757109646379*^9}, 3.6537571440080547`*^9, {3.653757177349011*^9, 
   3.653757217215476*^9}, {3.653757264785472*^9, 3.653757279922448*^9}, {
   3.653757314622417*^9, 3.6537573478860693`*^9}, {3.653757481663856*^9, 
   3.6537575042344112`*^9}, 3.6537577979631987`*^9, 3.653757920730242*^9, {
   3.6537582003161373`*^9, 3.653758224470086*^9}, 3.6537582768437347`*^9, 
   3.65375830823526*^9, 3.653758338985917*^9, 3.653758375170657*^9, 
   3.653758473629262*^9, 3.653758512160017*^9, 3.653758586390959*^9, 
   3.653758650608068*^9, {3.653758737233205*^9, 3.653758840941415*^9}, 
   3.653758952416843*^9, 3.653759063182476*^9, 3.6537592306191473`*^9, 
   3.653759609564907*^9, {3.653759642274246*^9, 3.6537596532806*^9}, 
   3.6537602033606052`*^9, 3.653760250624804*^9, 3.653760549965597*^9, 
   3.653760810934359*^9, 3.6537609530399027`*^9, 3.653761061405295*^9, {
   3.653761092400545*^9, 3.65376114263573*^9}, 3.653761261074397*^9, {
   3.653761339912877*^9, 3.653761409007627*^9}, {3.653761493375175*^9, 
   3.653761557983556*^9}, 3.65381574257742*^9, {3.653815813191924*^9, 
   3.65381588562243*^9}, 3.653815928052978*^9, {3.653816048245337*^9, 
   3.653816059809569*^9}, {3.653816107049507*^9, 3.653816146620564*^9}, {
   3.653816333990164*^9, 3.653816371023144*^9}, 3.653816409277748*^9, {
   3.653816447033968*^9, 3.653816498076222*^9}, {3.653816552227981*^9, 
   3.653816684425982*^9}, {3.653816720927617*^9, 3.653816883686573*^9}, {
   3.653816920814067*^9, 3.6538169506342278`*^9}, {3.653817018854169*^9, 
   3.653817032642501*^9}, {3.6538170756965933`*^9, 3.65381712463675*^9}, {
   3.653817166671172*^9, 3.653817329755625*^9}, {3.6538173634722643`*^9, 
   3.653817442961931*^9}, {3.653817481002366*^9, 3.6538175355604267`*^9}, {
   3.653817568974964*^9, 3.653817762323675*^9}, 3.653817895498541*^9, 
   3.655723803807336*^9, 3.665172627838635*^9, 3.665172845378978*^9, 
   3.66517289533454*^9, 3.6651730088765182`*^9, {3.665173219467082*^9, 
   3.66517324247403*^9}, 3.6651733392907877`*^9, 3.665173539882122*^9, {
   3.665173756912462*^9, 3.665173773916938*^9}, 3.665174008992251*^9, 
   3.6651740840885067`*^9, 3.6651741379215117`*^9, 3.6651742497068033`*^9, 
   3.665174280964031*^9, 3.665174313074729*^9, 3.665174353905439*^9, 
   3.665174503097184*^9, 3.665174581825877*^9, {3.665174640057911*^9, 
   3.6651747101209717`*^9}, {3.665174790308454*^9, 3.6651748000077887`*^9}, 
   3.665174878505142*^9, 3.665174935335528*^9, 3.6651749990407963`*^9, 
   3.6651751034461937`*^9, 3.665175325194867*^9, 3.665175394593892*^9, 
   3.665175496425726*^9, 3.665175563329906*^9, 3.6651758182549143`*^9, {
   3.665175901844242*^9, 3.665175927252474*^9}, {3.665176051019786*^9, 
   3.665176073972555*^9}, 3.6651761186391087`*^9, 3.665176173424182*^9, 
   3.6651762849402*^9, 3.6651764322700377`*^9, 3.665176473718185*^9, 
   3.6720511337900953`*^9, 3.672051175260414*^9, 3.672051308335801*^9, 
   3.672051426341082*^9, 3.672051502592539*^9, 3.672051571873619*^9, 
   3.6720516858708487`*^9, 3.672051786171648*^9, 3.67205193644697*^9, 
   3.672052004934044*^9, 3.672052072189774*^9, 3.672052594998761*^9, 
   3.6720526677129927`*^9, 3.672052728704809*^9, 3.672052790577158*^9, 
   3.6720528504410353`*^9, 3.672052943916559*^9, 3.6720531060196733`*^9, 
   3.672053177434525*^9, 3.6720532916258698`*^9, 3.6835320213830013`*^9, 
   3.683532139717029*^9, 3.683532188606955*^9, 3.683532451652563*^9, 
   3.683532636173314*^9, 3.683532850676217*^9, 3.683532912277225*^9, 
   3.6835329777321463`*^9, 3.6835330452968493`*^9, 3.683533228396986*^9, 
   3.6835333862198153`*^9, 3.68353365530201*^9, 3.683533908162311*^9, 
   3.683533970721621*^9, 3.683534024697435*^9, 3.683534398244235*^9, 
   3.683575500466292*^9, 3.6835755882991962`*^9, 3.683575778018519*^9, 
   3.6835758431034307`*^9, 3.683575907295032*^9, 3.683575998052547*^9, 
   3.683576063732778*^9, 3.6835761469513693`*^9, 3.683576273191695*^9, 
   3.683576445068966*^9, 3.683576634310623*^9, 3.683576666756711*^9, 
   3.6835769209471207`*^9, 3.683604713307065*^9, 3.683604925483173*^9, 
   3.6836049807157707`*^9, 3.683605281905941*^9, 3.683605434390905*^9, 
   3.68360552876963*^9, 3.683605760850281*^9, 3.683605956729253*^9, 
   3.68360604274993*^9, 3.683606114166766*^9, 3.683606440310569*^9, 
   3.6836066767305517`*^9, 3.6836069757285213`*^9, 3.6836070494982967`*^9, 
   3.683607091367445*^9, 3.683607145477809*^9, 3.6836072264712133`*^9, 
   3.683607276338035*^9, 3.683607358864353*^9, 3.6836074256762533`*^9, 
   3.6836074934323397`*^9, 3.683607561348053*^9, 3.683607710951056*^9, 
   3.683607778281397*^9, 3.683607949815056*^9, 3.683608044391985*^9, 
   3.683608079311475*^9, 3.703224656495579*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"13", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "738.0279533931316`"}]}],
  SequenceForm[13, "  ", -738.0279533931316],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6537353507019987`*^9, 3.6537353678746367`*^9}, 
   3.653753595157206*^9, {3.653753791095648*^9, 3.653753816956078*^9}, 
   3.6537568255504*^9, 3.653756871362311*^9, {3.6537570356298923`*^9, 
   3.653757109646379*^9}, 3.6537571440080547`*^9, {3.653757177349011*^9, 
   3.653757217215476*^9}, {3.653757264785472*^9, 3.653757279922448*^9}, {
   3.653757314622417*^9, 3.6537573478860693`*^9}, {3.653757481663856*^9, 
   3.6537575042344112`*^9}, 3.6537577979631987`*^9, 3.653757920730242*^9, {
   3.6537582003161373`*^9, 3.653758224470086*^9}, 3.6537582768437347`*^9, 
   3.65375830823526*^9, 3.653758338985917*^9, 3.653758375170657*^9, 
   3.653758473629262*^9, 3.653758512160017*^9, 3.653758586390959*^9, 
   3.653758650608068*^9, {3.653758737233205*^9, 3.653758840941415*^9}, 
   3.653758952416843*^9, 3.653759063182476*^9, 3.6537592306191473`*^9, 
   3.653759609564907*^9, {3.653759642274246*^9, 3.6537596532806*^9}, 
   3.6537602033606052`*^9, 3.653760250624804*^9, 3.653760549965597*^9, 
   3.653760810934359*^9, 3.6537609530399027`*^9, 3.653761061405295*^9, {
   3.653761092400545*^9, 3.65376114263573*^9}, 3.653761261074397*^9, {
   3.653761339912877*^9, 3.653761409007627*^9}, {3.653761493375175*^9, 
   3.653761557983556*^9}, 3.65381574257742*^9, {3.653815813191924*^9, 
   3.65381588562243*^9}, 3.653815928052978*^9, {3.653816048245337*^9, 
   3.653816059809569*^9}, {3.653816107049507*^9, 3.653816146620564*^9}, {
   3.653816333990164*^9, 3.653816371023144*^9}, 3.653816409277748*^9, {
   3.653816447033968*^9, 3.653816498076222*^9}, {3.653816552227981*^9, 
   3.653816684425982*^9}, {3.653816720927617*^9, 3.653816883686573*^9}, {
   3.653816920814067*^9, 3.6538169506342278`*^9}, {3.653817018854169*^9, 
   3.653817032642501*^9}, {3.6538170756965933`*^9, 3.65381712463675*^9}, {
   3.653817166671172*^9, 3.653817329755625*^9}, {3.6538173634722643`*^9, 
   3.653817442961931*^9}, {3.653817481002366*^9, 3.6538175355604267`*^9}, {
   3.653817568974964*^9, 3.653817762323675*^9}, 3.653817895498541*^9, 
   3.655723803807336*^9, 3.665172627838635*^9, 3.665172845378978*^9, 
   3.66517289533454*^9, 3.6651730088765182`*^9, {3.665173219467082*^9, 
   3.66517324247403*^9}, 3.6651733392907877`*^9, 3.665173539882122*^9, {
   3.665173756912462*^9, 3.665173773916938*^9}, 3.665174008992251*^9, 
   3.6651740840885067`*^9, 3.6651741379215117`*^9, 3.6651742497068033`*^9, 
   3.665174280964031*^9, 3.665174313074729*^9, 3.665174353905439*^9, 
   3.665174503097184*^9, 3.665174581825877*^9, {3.665174640057911*^9, 
   3.6651747101209717`*^9}, {3.665174790308454*^9, 3.6651748000077887`*^9}, 
   3.665174878505142*^9, 3.665174935335528*^9, 3.6651749990407963`*^9, 
   3.6651751034461937`*^9, 3.665175325194867*^9, 3.665175394593892*^9, 
   3.665175496425726*^9, 3.665175563329906*^9, 3.6651758182549143`*^9, {
   3.665175901844242*^9, 3.665175927252474*^9}, {3.665176051019786*^9, 
   3.665176073972555*^9}, 3.6651761186391087`*^9, 3.665176173424182*^9, 
   3.6651762849402*^9, 3.6651764322700377`*^9, 3.665176473718185*^9, 
   3.6720511337900953`*^9, 3.672051175260414*^9, 3.672051308335801*^9, 
   3.672051426341082*^9, 3.672051502592539*^9, 3.672051571873619*^9, 
   3.6720516858708487`*^9, 3.672051786171648*^9, 3.67205193644697*^9, 
   3.672052004934044*^9, 3.672052072189774*^9, 3.672052594998761*^9, 
   3.6720526677129927`*^9, 3.672052728704809*^9, 3.672052790577158*^9, 
   3.6720528504410353`*^9, 3.672052943916559*^9, 3.6720531060196733`*^9, 
   3.672053177434525*^9, 3.6720532916258698`*^9, 3.6835320213830013`*^9, 
   3.683532139717029*^9, 3.683532188606955*^9, 3.683532451652563*^9, 
   3.683532636173314*^9, 3.683532850676217*^9, 3.683532912277225*^9, 
   3.6835329777321463`*^9, 3.6835330452968493`*^9, 3.683533228396986*^9, 
   3.6835333862198153`*^9, 3.68353365530201*^9, 3.683533908162311*^9, 
   3.683533970721621*^9, 3.683534024697435*^9, 3.683534398244235*^9, 
   3.683575500466292*^9, 3.6835755882991962`*^9, 3.683575778018519*^9, 
   3.6835758431034307`*^9, 3.683575907295032*^9, 3.683575998052547*^9, 
   3.683576063732778*^9, 3.6835761469513693`*^9, 3.683576273191695*^9, 
   3.683576445068966*^9, 3.683576634310623*^9, 3.683576666756711*^9, 
   3.6835769209471207`*^9, 3.683604713307065*^9, 3.683604925483173*^9, 
   3.6836049807157707`*^9, 3.683605281905941*^9, 3.683605434390905*^9, 
   3.68360552876963*^9, 3.683605760850281*^9, 3.683605956729253*^9, 
   3.68360604274993*^9, 3.683606114166766*^9, 3.683606440310569*^9, 
   3.6836066767305517`*^9, 3.6836069757285213`*^9, 3.6836070494982967`*^9, 
   3.683607091367445*^9, 3.683607145477809*^9, 3.6836072264712133`*^9, 
   3.683607276338035*^9, 3.683607358864353*^9, 3.6836074256762533`*^9, 
   3.6836074934323397`*^9, 3.683607561348053*^9, 3.683607710951056*^9, 
   3.683607778281397*^9, 3.683607949815056*^9, 3.683608044391985*^9, 
   3.683608079311475*^9, 3.703224659913072*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"14", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "737.8984075788903`"}]}],
  SequenceForm[14, "  ", -737.8984075788903],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6537353507019987`*^9, 3.6537353678746367`*^9}, 
   3.653753595157206*^9, {3.653753791095648*^9, 3.653753816956078*^9}, 
   3.6537568255504*^9, 3.653756871362311*^9, {3.6537570356298923`*^9, 
   3.653757109646379*^9}, 3.6537571440080547`*^9, {3.653757177349011*^9, 
   3.653757217215476*^9}, {3.653757264785472*^9, 3.653757279922448*^9}, {
   3.653757314622417*^9, 3.6537573478860693`*^9}, {3.653757481663856*^9, 
   3.6537575042344112`*^9}, 3.6537577979631987`*^9, 3.653757920730242*^9, {
   3.6537582003161373`*^9, 3.653758224470086*^9}, 3.6537582768437347`*^9, 
   3.65375830823526*^9, 3.653758338985917*^9, 3.653758375170657*^9, 
   3.653758473629262*^9, 3.653758512160017*^9, 3.653758586390959*^9, 
   3.653758650608068*^9, {3.653758737233205*^9, 3.653758840941415*^9}, 
   3.653758952416843*^9, 3.653759063182476*^9, 3.6537592306191473`*^9, 
   3.653759609564907*^9, {3.653759642274246*^9, 3.6537596532806*^9}, 
   3.6537602033606052`*^9, 3.653760250624804*^9, 3.653760549965597*^9, 
   3.653760810934359*^9, 3.6537609530399027`*^9, 3.653761061405295*^9, {
   3.653761092400545*^9, 3.65376114263573*^9}, 3.653761261074397*^9, {
   3.653761339912877*^9, 3.653761409007627*^9}, {3.653761493375175*^9, 
   3.653761557983556*^9}, 3.65381574257742*^9, {3.653815813191924*^9, 
   3.65381588562243*^9}, 3.653815928052978*^9, {3.653816048245337*^9, 
   3.653816059809569*^9}, {3.653816107049507*^9, 3.653816146620564*^9}, {
   3.653816333990164*^9, 3.653816371023144*^9}, 3.653816409277748*^9, {
   3.653816447033968*^9, 3.653816498076222*^9}, {3.653816552227981*^9, 
   3.653816684425982*^9}, {3.653816720927617*^9, 3.653816883686573*^9}, {
   3.653816920814067*^9, 3.6538169506342278`*^9}, {3.653817018854169*^9, 
   3.653817032642501*^9}, {3.6538170756965933`*^9, 3.65381712463675*^9}, {
   3.653817166671172*^9, 3.653817329755625*^9}, {3.6538173634722643`*^9, 
   3.653817442961931*^9}, {3.653817481002366*^9, 3.6538175355604267`*^9}, {
   3.653817568974964*^9, 3.653817762323675*^9}, 3.653817895498541*^9, 
   3.655723803807336*^9, 3.665172627838635*^9, 3.665172845378978*^9, 
   3.66517289533454*^9, 3.6651730088765182`*^9, {3.665173219467082*^9, 
   3.66517324247403*^9}, 3.6651733392907877`*^9, 3.665173539882122*^9, {
   3.665173756912462*^9, 3.665173773916938*^9}, 3.665174008992251*^9, 
   3.6651740840885067`*^9, 3.6651741379215117`*^9, 3.6651742497068033`*^9, 
   3.665174280964031*^9, 3.665174313074729*^9, 3.665174353905439*^9, 
   3.665174503097184*^9, 3.665174581825877*^9, {3.665174640057911*^9, 
   3.6651747101209717`*^9}, {3.665174790308454*^9, 3.6651748000077887`*^9}, 
   3.665174878505142*^9, 3.665174935335528*^9, 3.6651749990407963`*^9, 
   3.6651751034461937`*^9, 3.665175325194867*^9, 3.665175394593892*^9, 
   3.665175496425726*^9, 3.665175563329906*^9, 3.6651758182549143`*^9, {
   3.665175901844242*^9, 3.665175927252474*^9}, {3.665176051019786*^9, 
   3.665176073972555*^9}, 3.6651761186391087`*^9, 3.665176173424182*^9, 
   3.6651762849402*^9, 3.6651764322700377`*^9, 3.665176473718185*^9, 
   3.6720511337900953`*^9, 3.672051175260414*^9, 3.672051308335801*^9, 
   3.672051426341082*^9, 3.672051502592539*^9, 3.672051571873619*^9, 
   3.6720516858708487`*^9, 3.672051786171648*^9, 3.67205193644697*^9, 
   3.672052004934044*^9, 3.672052072189774*^9, 3.672052594998761*^9, 
   3.6720526677129927`*^9, 3.672052728704809*^9, 3.672052790577158*^9, 
   3.6720528504410353`*^9, 3.672052943916559*^9, 3.6720531060196733`*^9, 
   3.672053177434525*^9, 3.6720532916258698`*^9, 3.6835320213830013`*^9, 
   3.683532139717029*^9, 3.683532188606955*^9, 3.683532451652563*^9, 
   3.683532636173314*^9, 3.683532850676217*^9, 3.683532912277225*^9, 
   3.6835329777321463`*^9, 3.6835330452968493`*^9, 3.683533228396986*^9, 
   3.6835333862198153`*^9, 3.68353365530201*^9, 3.683533908162311*^9, 
   3.683533970721621*^9, 3.683534024697435*^9, 3.683534398244235*^9, 
   3.683575500466292*^9, 3.6835755882991962`*^9, 3.683575778018519*^9, 
   3.6835758431034307`*^9, 3.683575907295032*^9, 3.683575998052547*^9, 
   3.683576063732778*^9, 3.6835761469513693`*^9, 3.683576273191695*^9, 
   3.683576445068966*^9, 3.683576634310623*^9, 3.683576666756711*^9, 
   3.6835769209471207`*^9, 3.683604713307065*^9, 3.683604925483173*^9, 
   3.6836049807157707`*^9, 3.683605281905941*^9, 3.683605434390905*^9, 
   3.68360552876963*^9, 3.683605760850281*^9, 3.683605956729253*^9, 
   3.68360604274993*^9, 3.683606114166766*^9, 3.683606440310569*^9, 
   3.6836066767305517`*^9, 3.6836069757285213`*^9, 3.6836070494982967`*^9, 
   3.683607091367445*^9, 3.683607145477809*^9, 3.6836072264712133`*^9, 
   3.683607276338035*^9, 3.683607358864353*^9, 3.6836074256762533`*^9, 
   3.6836074934323397`*^9, 3.683607561348053*^9, 3.683607710951056*^9, 
   3.683607778281397*^9, 3.683607949815056*^9, 3.683608044391985*^9, 
   3.683608079311475*^9, 3.703224665332139*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"15", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "737.8803212840139`"}]}],
  SequenceForm[15, "  ", -737.8803212840139],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6537353507019987`*^9, 3.6537353678746367`*^9}, 
   3.653753595157206*^9, {3.653753791095648*^9, 3.653753816956078*^9}, 
   3.6537568255504*^9, 3.653756871362311*^9, {3.6537570356298923`*^9, 
   3.653757109646379*^9}, 3.6537571440080547`*^9, {3.653757177349011*^9, 
   3.653757217215476*^9}, {3.653757264785472*^9, 3.653757279922448*^9}, {
   3.653757314622417*^9, 3.6537573478860693`*^9}, {3.653757481663856*^9, 
   3.6537575042344112`*^9}, 3.6537577979631987`*^9, 3.653757920730242*^9, {
   3.6537582003161373`*^9, 3.653758224470086*^9}, 3.6537582768437347`*^9, 
   3.65375830823526*^9, 3.653758338985917*^9, 3.653758375170657*^9, 
   3.653758473629262*^9, 3.653758512160017*^9, 3.653758586390959*^9, 
   3.653758650608068*^9, {3.653758737233205*^9, 3.653758840941415*^9}, 
   3.653758952416843*^9, 3.653759063182476*^9, 3.6537592306191473`*^9, 
   3.653759609564907*^9, {3.653759642274246*^9, 3.6537596532806*^9}, 
   3.6537602033606052`*^9, 3.653760250624804*^9, 3.653760549965597*^9, 
   3.653760810934359*^9, 3.6537609530399027`*^9, 3.653761061405295*^9, {
   3.653761092400545*^9, 3.65376114263573*^9}, 3.653761261074397*^9, {
   3.653761339912877*^9, 3.653761409007627*^9}, {3.653761493375175*^9, 
   3.653761557983556*^9}, 3.65381574257742*^9, {3.653815813191924*^9, 
   3.65381588562243*^9}, 3.653815928052978*^9, {3.653816048245337*^9, 
   3.653816059809569*^9}, {3.653816107049507*^9, 3.653816146620564*^9}, {
   3.653816333990164*^9, 3.653816371023144*^9}, 3.653816409277748*^9, {
   3.653816447033968*^9, 3.653816498076222*^9}, {3.653816552227981*^9, 
   3.653816684425982*^9}, {3.653816720927617*^9, 3.653816883686573*^9}, {
   3.653816920814067*^9, 3.6538169506342278`*^9}, {3.653817018854169*^9, 
   3.653817032642501*^9}, {3.6538170756965933`*^9, 3.65381712463675*^9}, {
   3.653817166671172*^9, 3.653817329755625*^9}, {3.6538173634722643`*^9, 
   3.653817442961931*^9}, {3.653817481002366*^9, 3.6538175355604267`*^9}, {
   3.653817568974964*^9, 3.653817762323675*^9}, 3.653817895498541*^9, 
   3.655723803807336*^9, 3.665172627838635*^9, 3.665172845378978*^9, 
   3.66517289533454*^9, 3.6651730088765182`*^9, {3.665173219467082*^9, 
   3.66517324247403*^9}, 3.6651733392907877`*^9, 3.665173539882122*^9, {
   3.665173756912462*^9, 3.665173773916938*^9}, 3.665174008992251*^9, 
   3.6651740840885067`*^9, 3.6651741379215117`*^9, 3.6651742497068033`*^9, 
   3.665174280964031*^9, 3.665174313074729*^9, 3.665174353905439*^9, 
   3.665174503097184*^9, 3.665174581825877*^9, {3.665174640057911*^9, 
   3.6651747101209717`*^9}, {3.665174790308454*^9, 3.6651748000077887`*^9}, 
   3.665174878505142*^9, 3.665174935335528*^9, 3.6651749990407963`*^9, 
   3.6651751034461937`*^9, 3.665175325194867*^9, 3.665175394593892*^9, 
   3.665175496425726*^9, 3.665175563329906*^9, 3.6651758182549143`*^9, {
   3.665175901844242*^9, 3.665175927252474*^9}, {3.665176051019786*^9, 
   3.665176073972555*^9}, 3.6651761186391087`*^9, 3.665176173424182*^9, 
   3.6651762849402*^9, 3.6651764322700377`*^9, 3.665176473718185*^9, 
   3.6720511337900953`*^9, 3.672051175260414*^9, 3.672051308335801*^9, 
   3.672051426341082*^9, 3.672051502592539*^9, 3.672051571873619*^9, 
   3.6720516858708487`*^9, 3.672051786171648*^9, 3.67205193644697*^9, 
   3.672052004934044*^9, 3.672052072189774*^9, 3.672052594998761*^9, 
   3.6720526677129927`*^9, 3.672052728704809*^9, 3.672052790577158*^9, 
   3.6720528504410353`*^9, 3.672052943916559*^9, 3.6720531060196733`*^9, 
   3.672053177434525*^9, 3.6720532916258698`*^9, 3.6835320213830013`*^9, 
   3.683532139717029*^9, 3.683532188606955*^9, 3.683532451652563*^9, 
   3.683532636173314*^9, 3.683532850676217*^9, 3.683532912277225*^9, 
   3.6835329777321463`*^9, 3.6835330452968493`*^9, 3.683533228396986*^9, 
   3.6835333862198153`*^9, 3.68353365530201*^9, 3.683533908162311*^9, 
   3.683533970721621*^9, 3.683534024697435*^9, 3.683534398244235*^9, 
   3.683575500466292*^9, 3.6835755882991962`*^9, 3.683575778018519*^9, 
   3.6835758431034307`*^9, 3.683575907295032*^9, 3.683575998052547*^9, 
   3.683576063732778*^9, 3.6835761469513693`*^9, 3.683576273191695*^9, 
   3.683576445068966*^9, 3.683576634310623*^9, 3.683576666756711*^9, 
   3.6835769209471207`*^9, 3.683604713307065*^9, 3.683604925483173*^9, 
   3.6836049807157707`*^9, 3.683605281905941*^9, 3.683605434390905*^9, 
   3.68360552876963*^9, 3.683605760850281*^9, 3.683605956729253*^9, 
   3.68360604274993*^9, 3.683606114166766*^9, 3.683606440310569*^9, 
   3.6836066767305517`*^9, 3.6836069757285213`*^9, 3.6836070494982967`*^9, 
   3.683607091367445*^9, 3.683607145477809*^9, 3.6836072264712133`*^9, 
   3.683607276338035*^9, 3.683607358864353*^9, 3.6836074256762533`*^9, 
   3.6836074934323397`*^9, 3.683607561348053*^9, 3.683607710951056*^9, 
   3.683607778281397*^9, 3.683607949815056*^9, 3.683608044391985*^9, 
   3.683608079311475*^9, 3.703224669030101*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"16", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "737.6257747974742`"}]}],
  SequenceForm[16, "  ", -737.6257747974742],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6537353507019987`*^9, 3.6537353678746367`*^9}, 
   3.653753595157206*^9, {3.653753791095648*^9, 3.653753816956078*^9}, 
   3.6537568255504*^9, 3.653756871362311*^9, {3.6537570356298923`*^9, 
   3.653757109646379*^9}, 3.6537571440080547`*^9, {3.653757177349011*^9, 
   3.653757217215476*^9}, {3.653757264785472*^9, 3.653757279922448*^9}, {
   3.653757314622417*^9, 3.6537573478860693`*^9}, {3.653757481663856*^9, 
   3.6537575042344112`*^9}, 3.6537577979631987`*^9, 3.653757920730242*^9, {
   3.6537582003161373`*^9, 3.653758224470086*^9}, 3.6537582768437347`*^9, 
   3.65375830823526*^9, 3.653758338985917*^9, 3.653758375170657*^9, 
   3.653758473629262*^9, 3.653758512160017*^9, 3.653758586390959*^9, 
   3.653758650608068*^9, {3.653758737233205*^9, 3.653758840941415*^9}, 
   3.653758952416843*^9, 3.653759063182476*^9, 3.6537592306191473`*^9, 
   3.653759609564907*^9, {3.653759642274246*^9, 3.6537596532806*^9}, 
   3.6537602033606052`*^9, 3.653760250624804*^9, 3.653760549965597*^9, 
   3.653760810934359*^9, 3.6537609530399027`*^9, 3.653761061405295*^9, {
   3.653761092400545*^9, 3.65376114263573*^9}, 3.653761261074397*^9, {
   3.653761339912877*^9, 3.653761409007627*^9}, {3.653761493375175*^9, 
   3.653761557983556*^9}, 3.65381574257742*^9, {3.653815813191924*^9, 
   3.65381588562243*^9}, 3.653815928052978*^9, {3.653816048245337*^9, 
   3.653816059809569*^9}, {3.653816107049507*^9, 3.653816146620564*^9}, {
   3.653816333990164*^9, 3.653816371023144*^9}, 3.653816409277748*^9, {
   3.653816447033968*^9, 3.653816498076222*^9}, {3.653816552227981*^9, 
   3.653816684425982*^9}, {3.653816720927617*^9, 3.653816883686573*^9}, {
   3.653816920814067*^9, 3.6538169506342278`*^9}, {3.653817018854169*^9, 
   3.653817032642501*^9}, {3.6538170756965933`*^9, 3.65381712463675*^9}, {
   3.653817166671172*^9, 3.653817329755625*^9}, {3.6538173634722643`*^9, 
   3.653817442961931*^9}, {3.653817481002366*^9, 3.6538175355604267`*^9}, {
   3.653817568974964*^9, 3.653817762323675*^9}, 3.653817895498541*^9, 
   3.655723803807336*^9, 3.665172627838635*^9, 3.665172845378978*^9, 
   3.66517289533454*^9, 3.6651730088765182`*^9, {3.665173219467082*^9, 
   3.66517324247403*^9}, 3.6651733392907877`*^9, 3.665173539882122*^9, {
   3.665173756912462*^9, 3.665173773916938*^9}, 3.665174008992251*^9, 
   3.6651740840885067`*^9, 3.6651741379215117`*^9, 3.6651742497068033`*^9, 
   3.665174280964031*^9, 3.665174313074729*^9, 3.665174353905439*^9, 
   3.665174503097184*^9, 3.665174581825877*^9, {3.665174640057911*^9, 
   3.6651747101209717`*^9}, {3.665174790308454*^9, 3.6651748000077887`*^9}, 
   3.665174878505142*^9, 3.665174935335528*^9, 3.6651749990407963`*^9, 
   3.6651751034461937`*^9, 3.665175325194867*^9, 3.665175394593892*^9, 
   3.665175496425726*^9, 3.665175563329906*^9, 3.6651758182549143`*^9, {
   3.665175901844242*^9, 3.665175927252474*^9}, {3.665176051019786*^9, 
   3.665176073972555*^9}, 3.6651761186391087`*^9, 3.665176173424182*^9, 
   3.6651762849402*^9, 3.6651764322700377`*^9, 3.665176473718185*^9, 
   3.6720511337900953`*^9, 3.672051175260414*^9, 3.672051308335801*^9, 
   3.672051426341082*^9, 3.672051502592539*^9, 3.672051571873619*^9, 
   3.6720516858708487`*^9, 3.672051786171648*^9, 3.67205193644697*^9, 
   3.672052004934044*^9, 3.672052072189774*^9, 3.672052594998761*^9, 
   3.6720526677129927`*^9, 3.672052728704809*^9, 3.672052790577158*^9, 
   3.6720528504410353`*^9, 3.672052943916559*^9, 3.6720531060196733`*^9, 
   3.672053177434525*^9, 3.6720532916258698`*^9, 3.6835320213830013`*^9, 
   3.683532139717029*^9, 3.683532188606955*^9, 3.683532451652563*^9, 
   3.683532636173314*^9, 3.683532850676217*^9, 3.683532912277225*^9, 
   3.6835329777321463`*^9, 3.6835330452968493`*^9, 3.683533228396986*^9, 
   3.6835333862198153`*^9, 3.68353365530201*^9, 3.683533908162311*^9, 
   3.683533970721621*^9, 3.683534024697435*^9, 3.683534398244235*^9, 
   3.683575500466292*^9, 3.6835755882991962`*^9, 3.683575778018519*^9, 
   3.6835758431034307`*^9, 3.683575907295032*^9, 3.683575998052547*^9, 
   3.683576063732778*^9, 3.6835761469513693`*^9, 3.683576273191695*^9, 
   3.683576445068966*^9, 3.683576634310623*^9, 3.683576666756711*^9, 
   3.6835769209471207`*^9, 3.683604713307065*^9, 3.683604925483173*^9, 
   3.6836049807157707`*^9, 3.683605281905941*^9, 3.683605434390905*^9, 
   3.68360552876963*^9, 3.683605760850281*^9, 3.683605956729253*^9, 
   3.68360604274993*^9, 3.683606114166766*^9, 3.683606440310569*^9, 
   3.6836066767305517`*^9, 3.6836069757285213`*^9, 3.6836070494982967`*^9, 
   3.683607091367445*^9, 3.683607145477809*^9, 3.6836072264712133`*^9, 
   3.683607276338035*^9, 3.683607358864353*^9, 3.6836074256762533`*^9, 
   3.6836074934323397`*^9, 3.683607561348053*^9, 3.683607710951056*^9, 
   3.683607778281397*^9, 3.683607949815056*^9, 3.683608044391985*^9, 
   3.683608079311475*^9, 3.703224674843354*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tabres", "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.703224638942259*^9, 3.703224645016397*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"B0", "B1", "S0", "S1", "eN", "eWS", "eSW", "lnL", "aic"},
     {"0.`", "0.`", "0.`", "0.`", "0.021180703148143184`", 
      "0.017957424299369258`", "0.07972517193943852`", 
      RowBox[{"-", "762.4345282841969`"}], "1524.8690565683937`"},
     {"0.`", "0.`", "0.`", "0.0878754987317178`", "0.005683558653370813`", 
      "0.00906646414786059`", "0.05539875088637751`", 
      RowBox[{"-", "761.5158157584519`"}], "1525.0316315169039`"},
     {"0.`", "0.`", "0.1282915942216768`", "0.`", "0.030884533000783167`", 
      "0.02402149310481787`", "0.09288396492297785`", 
      RowBox[{"-", "749.7293169205805`"}], "1501.458633841161`"},
     {"0.`", "0.`", "0.15225103940963308`", "0.20176586046214626`", 
      "0.0004440109039367138`", "0.006444680433900573`", 
      "0.04535202788327572`", 
      RowBox[{"-", "745.2029697256658`"}], "1494.4059394513315`"},
     {"0.`", "0.10912376582871092`", "0.`", "0.`", "0.013890051074286985`", 
      "0.014908527384472339`", "0.06565266959261985`", 
      RowBox[{"-", "761.0104964914062`"}], "1524.0209929828125`"},
     {"0.`", "0.08859756401108591`", "0.`", "0.034379726696454664`", 
      "0.005467223282053501`", "0.00984669412816987`", 
      "0.053030691595578695`", 
      RowBox[{"-", "760.937703557036`"}], "1525.875407114072`"},
     {"0.`", "0.198816197020132`", "0.1477186840530105`", "0.`", 
      "0.030256150210975486`", "0.025669129330147065`", 
      "0.08702451535350744`", 
      RowBox[{"-", "745.218475962014`"}], "1494.436951924028`"},
     {"0.`", "0.11850025271642309`", "0.15472949480852743`", 
      "0.1347766864628943`", "3.79769219453264`*^-6", "0.007546480424664037`",
       "0.041600369175914545`", 
      RowBox[{"-", "744.1469216817786`"}], "1494.2938433635572`"},
     {"0.13066409633452722`", "0.`", "0.`", "0.`", "0.012934141075594477`", 
      "0.011907601611338059`", "0.0685296198939506`", 
      RowBox[{"-", "745.3825138904649`"}], "1492.7650277809298`"},
     {"0.14340319626737122`", "0.`", "0.`", "0.17064903971699288`", 
      "0.006816227045032218`", "0.009620795297714741`", 
      "0.05539800923340309`", 
      RowBox[{"-", "741.8111383555952`"}], "1487.6222767111904`"},
     {"0.11050028541232373`", "0.`", "0.02904205107722939`", "0.`", 
      "0.017034733605280242`", "0.01463938749373498`", "0.07409376635464421`", 
      RowBox[{"-", "745.1399070543266`"}], "1494.2798141086532`"},
     {"0.10574314167607195`", "0.`", "0.05670724043993841`", 
      "0.1911162175983476`", "0.0055788148256491745`", 
      "0.009103138974847717`", "0.05317158334093922`", 
      RowBox[{"-", "740.9125498414069`"}], "1487.8250996828137`"},
     {"0.16022595221348482`", "0.26163813792566076`", "0.`", "0.`", 
      "0.00008338159926194274`", "0.008092239850497396`", 
      "0.0398774886396616`", 
      RowBox[{"-", "738.0279533931316`"}], "1480.0559067862632`"},
     {"0.1602619701503707`", "0.23629294583982932`", "0.`", 
      "0.03935183688402916`", "1.7642027809326768`*^-6", 
      "0.008002299544351573`", "0.03948697217131625`", 
      RowBox[{"-", "737.8984075788903`"}], "1481.7968151577807`"},
     {"0.14421193944901306`", "0.2599134416684076`", "0.022887067523203557`", 
      "0.`", "0.005274760240396667`", "0.011149540598701909`", 
      "0.04788966935470312`", 
      RowBox[{"-", "737.8803212840139`"}], "1481.7606425680278`"},
     {"0.13797623509639603`", "0.222016131734086`", "0.03206050573216585`", 
      "0.05917209357030063`", "1.946698205348158`*^-6", 
      "0.008006437697141683`", "0.03957464058839075`", 
      RowBox[{"-", "737.6257747974742`"}], "1483.2515495949483`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.703224682959461*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Bootstrap on a given model", "Subsubsection",
 CellChangeTimes->{{3.683621054282051*^9, 3.6836210586569147`*^9}, {
  3.7032238246206207`*^9, 3.703223828365906*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"i", "=", "16"}], ";", 
  RowBox[{"(*", 
   RowBox[{"Number", " ", "of", " ", "the", " ", "chosen", " ", "model"}], 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"X", "=", 
   RowBox[{"Round", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{
      "tabNN", ",", "tabNUP", ",", "tabNPU", ",", "tabWSN", ",", "tabWSUP", 
       ",", "tabWSPU", ",", "tabSWN", ",", "tabSWUP", ",", "tabSWPU"}], "}"}],
      "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LX", "=", 
   RowBox[{"Length", "[", "X", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SX", "=", 
   RowBox[{"Round", "[", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{"X", "[", 
       RowBox[{"[", "i", "]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "LX"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pX", "=", 
   RowBox[{"X", "/", "SX"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Y", "=", 
   RowBox[{"Round", "[", 
    RowBox[{"{", 
     RowBox[{
     "DNN", ",", "DNUP", ",", "DNPU", ",", "DWSN", ",", "DWSUP", ",", "DWSPU",
       ",", "DSWN", ",", "DSWUP", ",", "DSWPU"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SY", "=", 
   RowBox[{"Round", "[", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{"Y", "[", 
       RowBox[{"[", "i", "]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "Y", "]"}]}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pY", "=", 
   RowBox[{"Y", "/", "SY"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Nboot", "=", "200"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Alpha]", "=", "0.05"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bootB0", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"\"\<B0\>\"", ",", "Nboot"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bootB1", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"\"\<B1\>\"", ",", "Nboot"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bootS0", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"\"\<S0\>\"", ",", "Nboot"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bootS1", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"\"\<S1\>\"", ",", "Nboot"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"rep", "=", "1"}], ",", 
    RowBox[{"rep", "\[LessEqual]", "Nboot"}], ",", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"bootX", "=", 
        RowBox[{"RandomVariate", "[", 
         RowBox[{"MultinomialDistribution", "[", 
          RowBox[{"SX", ",", "pX"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"bootY", "=", 
        RowBox[{"RandomVariate", "[", 
         RowBox[{"MultinomialDistribution", "[", 
          RowBox[{"SY", ",", "pY"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"bootSFS", "=", 
        RowBox[{"Partition", "[", 
         RowBox[{"bootX", ",", 
          RowBox[{"LX", "/", "9"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"tabNN", "=", 
        RowBox[{"bootSFS", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"tabNUP", "=", 
        RowBox[{"bootSFS", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"tabNPU", "=", 
        RowBox[{"bootSFS", "[", 
         RowBox[{"[", "3", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"tabWSN", "=", 
        RowBox[{"bootSFS", "[", 
         RowBox[{"[", "4", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"tabWSUP", "=", 
        RowBox[{"bootSFS", "[", 
         RowBox[{"[", "5", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"tabWSPU", "=", 
        RowBox[{"bootSFS", "[", 
         RowBox[{"[", "6", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"tabSWN", "=", 
        RowBox[{"bootSFS", "[", 
         RowBox[{"[", "7", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"tabSWUP", "=", 
        RowBox[{"bootSFS", "[", 
         RowBox[{"[", "8", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"tabSWPU", "=", 
        RowBox[{"bootSFS", "[", 
         RowBox[{"[", "9", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"DNN", "=", 
        RowBox[{"bootY", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"DNUP", "=", 
        RowBox[{"bootY", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"DNPU", "=", 
        RowBox[{"bootY", "[", 
         RowBox[{"[", "3", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"DWSN", "=", 
        RowBox[{"bootY", "[", 
         RowBox[{"[", "4", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"DWSUP", "=", 
        RowBox[{"bootY", "[", 
         RowBox[{"[", "5", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"DWSPU", "=", 
        RowBox[{"bootY", "[", 
         RowBox[{"[", "6", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"DSWN", "=", 
        RowBox[{"bootY", "[", 
         RowBox[{"[", "7", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"DSWUP", "=", 
        RowBox[{"bootY", "[", 
         RowBox[{"[", "8", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"DSWPU", "=", 
        RowBox[{"bootY", "[", 
         RowBox[{"[", "9", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"B0num", "=", 
        RowBox[{
         RowBox[{"tabParam", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"B1num", "=", 
        RowBox[{
         RowBox[{"tabParam", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"S0num", "=", 
        RowBox[{
         RowBox[{"tabParam", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "3", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"S1num", "=", 
        RowBox[{
         RowBox[{"tabParam", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "4", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"initDBe", "=", 
        RowBox[{"Union", "[", 
         RowBox[{
          RowBox[{"Delete", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"B0", ",", "0.4"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"B1", ",", "0.3"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"S0", ",", "0.2"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"S1", ",", "0.1"}], "}"}]}], "}"}], ",", 
            RowBox[{"Position", "[", 
             RowBox[{
              RowBox[{"tabParam", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", "_Real"}], "]"}]}], "]"}],
           ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"\[Theta]NN", ",", "\[Theta]NNi"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\[Theta]NUP", ",", "\[Theta]NUPi"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\[Theta]NPU", ",", "\[Theta]NPUi"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\[Theta]WSN", ",", "\[Theta]WSNi"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\[Theta]WSUP", ",", "\[Theta]WSPUi"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\[Theta]WSPU", ",", "\[Theta]WSPUi"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\[Theta]SWN", ",", "\[Theta]SWNi"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\[Theta]SWUP", ",", "\[Theta]SWUPi"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\[Theta]SWPU", ",", "\[Theta]SWPUi"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\[Tau]NN", ",", "\[Tau]NNi"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\[Tau]WSN", ",", "\[Tau]WSNi"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\[Tau]NUP", ",", "\[Tau]NUPi"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\[Tau]WSUP", ",", "\[Tau]WSUPi"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\[Tau]SWUP", ",", "\[Tau]SWUPi"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\[Tau]WSPU", ",", "\[Tau]WSPUi"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\[Tau]SWPU", ",", "\[Tau]SWPUi"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\[Epsilon]", ",", "0.01"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\[Epsilon]WS", ",", "0.03"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\[Epsilon]SW", ",", "0.05"}], "}"}]}], "}"}], ",", 
          RowBox[{"Take", "[", 
           RowBox[{
            RowBox[{"Thread", "[", 
             RowBox[{"{", 
              RowBox[{"tabcoef", ",", "rinit"}], "}"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2", ",", 
              RowBox[{"Nchrom", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"consDBe", "=", 
        RowBox[{"Union", "[", 
         RowBox[{
          RowBox[{"Delete", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "3"}], "<", "B0", "<", "3"}], ",", 
              RowBox[{
               RowBox[{"-", "3"}], "<", "B1", "<", "3"}], ",", 
              RowBox[{
               RowBox[{"-", "3"}], "<", "S0", "<", "3"}], ",", 
              RowBox[{
               RowBox[{"-", "3"}], "<", "S1", "<", "3"}]}], "}"}], ",", 
            RowBox[{"Position", "[", 
             RowBox[{
              RowBox[{"tabParam", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", "_Real"}], "]"}]}], "]"}],
           ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[Theta]NN", ">", "0"}], ",", 
            RowBox[{"\[Theta]NUP", ">", "0"}], ",", 
            RowBox[{"\[Theta]NPU", ">", "0"}], ",", 
            RowBox[{"\[Theta]WSN", ">", "0"}], ",", 
            RowBox[{"\[Theta]WSUP", ">", "0"}], ",", 
            RowBox[{"\[Theta]WSPU", ">", "0"}], ",", 
            RowBox[{"\[Theta]SWN", ">", "0"}], ",", 
            RowBox[{"\[Theta]SWUP", ">", "0"}], ",", 
            RowBox[{"\[Theta]SWPU", ">", "0"}], ",", "\[IndentingNewLine]", 
            RowBox[{"\[Tau]NN", ">", "0"}], ",", 
            RowBox[{"\[Tau]WSN", ">", "0"}], ",", 
            RowBox[{"\[Tau]NUP", ">", "0"}], ",", 
            RowBox[{"\[Tau]WSUP", ">", "0"}], ",", 
            RowBox[{"\[Tau]SWUP", ">", "0"}], ",", 
            RowBox[{"\[Tau]WSPU", ">", "0"}], ",", 
            RowBox[{"\[Tau]SWPU", ">", "0"}], ",", 
            RowBox[{
             FractionBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"(", 
                  RowBox[{
                  "\[Theta]WSN", "+", "\[Theta]WSPU", "+", "\[Theta]WSUP"}], 
                  ")"}]}], " ", 
                RowBox[{"(", 
                 RowBox[{"\[Tau]SWPU", "+", "\[Tau]SWUP"}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                 "\[Theta]SWN", "+", "\[Theta]SWPU", "+", "\[Theta]SWUP"}], 
                 ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{"\[Tau]WSN", "+", "\[Tau]WSPU", "+", "\[Tau]WSUP"}], 
                 ")"}]}]}], 
              RowBox[{
              "\[Theta]WSN", "+", "\[Theta]WSPU", "+", "\[Theta]WSUP"}]], ">",
              "0"}], ",", 
            RowBox[{
             FractionBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"(", 
                  RowBox[{
                  "\[Theta]NUP", "+", "\[Theta]SWUP", "+", "\[Theta]WSUP"}], 
                  ")"}]}], " ", 
                RowBox[{"(", 
                 RowBox[{"\[Tau]SWPU", "+", "\[Tau]WSPU"}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                 "\[Theta]NPU", "+", "\[Theta]SWPU", "+", "\[Theta]WSPU"}], 
                 ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{"\[Tau]NUP", "+", "\[Tau]SWUP", "+", "\[Tau]WSUP"}], 
                 ")"}]}]}], 
              RowBox[{
              "\[Theta]NUP", "+", "\[Theta]SWUP", "+", "\[Theta]WSUP"}]], ">",
              "0"}], ",", 
            RowBox[{"0", "\[LessEqual]", "\[Epsilon]", "\[LessEqual]", 
             RowBox[{"1", "/", "2"}]}], ",", 
            RowBox[{"0", "\[LessEqual]", "\[Epsilon]WS", "\[LessEqual]", 
             RowBox[{"1", "/", "2"}]}], ",", 
            RowBox[{"0", "\[LessEqual]", "\[Epsilon]SW", "\[LessEqual]", 
             RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
          RowBox[{"Take", "[", 
           RowBox[{
            RowBox[{"Map", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"10", ">", "#", ">", "0"}], "&"}], ",", "tabcoef"}], 
             "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2", ",", 
              RowBox[{"Nchrom", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"MDBe", "=", 
        RowBox[{"FindMaximum", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"logLikDBS2err3", "[", 
             RowBox[{
             "Nchrom", ",", "\[Theta]NN", ",", "\[Theta]WSN", ",", 
              "\[Theta]SWN", ",", "\[Theta]NUP", ",", "\[Theta]WSUP", ",", 
              "\[Theta]SWUP", ",", "\[Theta]NPU", ",", "\[Theta]WSPU", ",", 
              "\[Theta]SWPU", ",", "\[Tau]NN", ",", "\[Tau]WSN", ",", 
              FractionBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{"(", 
                   RowBox[{
                   "\[Theta]WSN", "+", "\[Theta]WSPU", "+", "\[Theta]WSUP"}], 
                   ")"}]}], " ", 
                 RowBox[{"(", 
                  RowBox[{"\[Tau]SWPU", "+", "\[Tau]SWUP"}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                  "\[Theta]SWN", "+", "\[Theta]SWPU", "+", "\[Theta]SWUP"}], 
                  ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"\[Tau]WSN", "+", "\[Tau]WSPU", "+", "\[Tau]WSUP"}],
                   ")"}]}]}], 
               RowBox[{
               "\[Theta]WSN", "+", "\[Theta]WSPU", "+", "\[Theta]WSUP"}]], 
              ",", "\[Tau]NUP", ",", "\[Tau]WSUP", ",", "\[Tau]SWUP", ",", 
              FractionBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{"(", 
                   RowBox[{
                   "\[Theta]NUP", "+", "\[Theta]SWUP", "+", "\[Theta]WSUP"}], 
                   ")"}]}], " ", 
                 RowBox[{"(", 
                  RowBox[{"\[Tau]SWPU", "+", "\[Tau]WSPU"}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                  "\[Theta]NPU", "+", "\[Theta]SWPU", "+", "\[Theta]WSPU"}], 
                  ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"\[Tau]NUP", "+", "\[Tau]SWUP", "+", "\[Tau]WSUP"}],
                   ")"}]}]}], 
               RowBox[{
               "\[Theta]NUP", "+", "\[Theta]SWUP", "+", "\[Theta]WSUP"}]], 
              ",", "\[Tau]WSPU", ",", "\[Tau]SWPU", ",", "B0num", ",", 
              "B1num", ",", "S0num", ",", "S1num", ",", "tabcoef", ",", 
              "\[Epsilon]", ",", "\[Epsilon]WS", ",", "\[Epsilon]SW", ",", 
              "tabNN", ",", "tabWSN", ",", "tabSWN", ",", "tabNUP", ",", 
              "tabWSUP", ",", "tabSWUP", ",", "tabNPU", ",", "tabWSPU", ",", 
              "tabSWPU", ",", "DNN", ",", "DWSN", ",", "DSWN", ",", "DNUP", 
              ",", "DWSUP", ",", "DSWUP", ",", "DNPU", ",", "DWSPU", ",", 
              "DSWPU"}], "]"}], ",", "consDBe"}], "}"}], ",", "initDBe", ",", 
          RowBox[{"AccuracyGoal", "\[Rule]", "6"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"bootB0", "[", 
         RowBox[{"[", "rep", "]"}], "]"}], "=", 
        RowBox[{
         RowBox[{"B0", "/.", 
          RowBox[{"MDBe", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], "/.", 
         RowBox[{"B0", "\[Rule]", "0"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"bootB1", "[", 
         RowBox[{"[", "rep", "]"}], "]"}], "=", 
        RowBox[{
         RowBox[{"B1", "/.", 
          RowBox[{"MDBe", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], "/.", 
         RowBox[{"B1", "\[Rule]", "0"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"bootS0", "[", 
         RowBox[{"[", "rep", "]"}], "]"}], "=", 
        RowBox[{
         RowBox[{"S0", "/.", 
          RowBox[{"MDBe", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], "/.", 
         RowBox[{"S0", "\[Rule]", "0"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"bootS1", "[", 
         RowBox[{"[", "rep", "]"}], "]"}], "=", 
        RowBox[{
         RowBox[{"S1", "/.", 
          RowBox[{"MDBe", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], "/.", 
         RowBox[{"S1", "\[Rule]", "0"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"Element", "[", 
          RowBox[{
           RowBox[{"rep", "/", "10"}], ",", "Integers"}], "]"}], ",", 
         RowBox[{"Print", "[", "rep", "]"}]}], "]"}], ";"}], 
      "\[IndentingNewLine]", "}"}], ";", 
     RowBox[{"rep", "++"}]}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.683621243935403*^9, 3.68362126265443*^9}, {
   3.683621306283176*^9, 3.68362132882904*^9}, {3.683621410045061*^9, 
   3.683621449814149*^9}, {3.68362154678131*^9, 3.6836217515475082`*^9}, {
   3.683621913023075*^9, 3.6836219673328953`*^9}, {3.683622181941256*^9, 
   3.683622209704509*^9}, {3.683653270304303*^9, 3.683653277214334*^9}, {
   3.683687922748271*^9, 3.683687923258353*^9}, 3.683691329525002*^9, {
   3.683692029860979*^9, 3.6836920369071817`*^9}, {3.6836921510208797`*^9, 
   3.6836921620198708`*^9}, {3.683692311988289*^9, 3.683692340761571*^9}, {
   3.683693171313836*^9, 3.6836931722889433`*^9}, {3.68371940707172*^9, 
   3.683719407653879*^9}, {3.6837212642413797`*^9, 3.6837212645345173`*^9}, 
   3.6837250880543013`*^9, {3.683725993242016*^9, 3.683725993793109*^9}, {
   3.6837277547893543`*^9, 3.6837277553701067`*^9}, {3.683775896879681*^9, 
   3.683775897390683*^9}, {3.703223835096386*^9, 3.703223835858931*^9}, {
   3.703224801969205*^9, 3.703224803103215*^9}, {3.703225044432815*^9, 
   3.703225069462764*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"bootB0s", "=", 
   RowBox[{"Sort", "[", "bootB0", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bootB1s", "=", 
   RowBox[{"Sort", "[", "bootB1", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bootS0s", "=", 
   RowBox[{"Sort", "[", "bootS0", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bootS1s", "=", 
   RowBox[{"Sort", "[", "bootS1", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"B0min", "=", 
  RowBox[{"bootB0s", "[", 
   RowBox[{"[", 
    RowBox[{"Floor", "[", 
     RowBox[{"Nboot", " ", 
      RowBox[{"\[Alpha]", "/", "2"}]}], "]"}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"B0max", "=", 
  RowBox[{"bootB0s", "[", 
   RowBox[{"[", 
    RowBox[{"Ceiling", "[", 
     RowBox[{"Nboot", 
      RowBox[{"(", 
       RowBox[{"1", "-", " ", 
        RowBox[{"\[Alpha]", "/", "2"}]}], ")"}]}], "]"}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"B1min", "=", 
  RowBox[{"bootB1s", "[", 
   RowBox[{"[", 
    RowBox[{"Floor", "[", 
     RowBox[{"Nboot", " ", 
      RowBox[{"\[Alpha]", "/", "2"}]}], "]"}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"B1max", "=", 
  RowBox[{"bootB1s", "[", 
   RowBox[{"[", 
    RowBox[{"Ceiling", "[", 
     RowBox[{"Nboot", 
      RowBox[{"(", 
       RowBox[{"1", "-", " ", 
        RowBox[{"\[Alpha]", "/", "2"}]}], ")"}]}], "]"}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"S0min", "=", 
  RowBox[{"bootS0s", "[", 
   RowBox[{"[", 
    RowBox[{"Floor", "[", 
     RowBox[{"Nboot", " ", 
      RowBox[{"\[Alpha]", "/", "2"}]}], "]"}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"S0max", "=", 
  RowBox[{"bootS0s", "[", 
   RowBox[{"[", 
    RowBox[{"Ceiling", "[", 
     RowBox[{"Nboot", 
      RowBox[{"(", 
       RowBox[{"1", "-", " ", 
        RowBox[{"\[Alpha]", "/", "2"}]}], ")"}]}], "]"}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"S1min", "=", 
  RowBox[{"bootS1s", "[", 
   RowBox[{"[", 
    RowBox[{"Floor", "[", 
     RowBox[{"Nboot", " ", 
      RowBox[{"\[Alpha]", "/", "2"}]}], "]"}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"S1max", "=", 
  RowBox[{"bootS1s", "[", 
   RowBox[{"[", 
    RowBox[{"Ceiling", "[", 
     RowBox[{"Nboot", 
      RowBox[{"(", 
       RowBox[{"1", "-", " ", 
        RowBox[{"\[Alpha]", "/", "2"}]}], ")"}]}], "]"}], "]"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.68368781796706*^9, 3.683687829565895*^9}, 
   3.703225047511219*^9, {3.703225638023733*^9, 3.7032256421067657`*^9}}],

Cell[BoxData["0.0618010377386616`"], "Output",
 CellChangeTimes->{3.683687830207733*^9, 3.6836886589507837`*^9, 
  3.68368982930072*^9, 3.683691579102182*^9, 3.6836919518261757`*^9, 
  3.683692264813012*^9, 3.683693122738616*^9, 3.683718995471677*^9, 
  3.6837209902317457`*^9, 3.6837250735082006`*^9, 3.683725950376416*^9, 
  3.683727734835531*^9, 3.683743194325391*^9, 3.683744941047852*^9, 
  3.6837528409656343`*^9, 3.6837765489292088`*^9, 3.703226310864407*^9, 
  3.7032264863614597`*^9}],

Cell[BoxData["0.20617557952755655`"], "Output",
 CellChangeTimes->{3.683687830207733*^9, 3.6836886589507837`*^9, 
  3.68368982930072*^9, 3.683691579102182*^9, 3.6836919518261757`*^9, 
  3.683692264813012*^9, 3.683693122738616*^9, 3.683718995471677*^9, 
  3.6837209902317457`*^9, 3.6837250735082006`*^9, 3.683725950376416*^9, 
  3.683727734835531*^9, 3.683743194325391*^9, 3.683744941047852*^9, 
  3.6837528409656343`*^9, 3.6837765489292088`*^9, 3.703226310864407*^9, 
  3.7032264863655148`*^9}],

Cell[BoxData["0.06660909998924436`"], "Output",
 CellChangeTimes->{3.683687830207733*^9, 3.6836886589507837`*^9, 
  3.68368982930072*^9, 3.683691579102182*^9, 3.6836919518261757`*^9, 
  3.683692264813012*^9, 3.683693122738616*^9, 3.683718995471677*^9, 
  3.6837209902317457`*^9, 3.6837250735082006`*^9, 3.683725950376416*^9, 
  3.683727734835531*^9, 3.683743194325391*^9, 3.683744941047852*^9, 
  3.6837528409656343`*^9, 3.6837765489292088`*^9, 3.703226310864407*^9, 
  3.703226486368073*^9}],

Cell[BoxData["0.41238179556016086`"], "Output",
 CellChangeTimes->{3.683687830207733*^9, 3.6836886589507837`*^9, 
  3.68368982930072*^9, 3.683691579102182*^9, 3.6836919518261757`*^9, 
  3.683692264813012*^9, 3.683693122738616*^9, 3.683718995471677*^9, 
  3.6837209902317457`*^9, 3.6837250735082006`*^9, 3.683725950376416*^9, 
  3.683727734835531*^9, 3.683743194325391*^9, 3.683744941047852*^9, 
  3.6837528409656343`*^9, 3.6837765489292088`*^9, 3.703226310864407*^9, 
  3.703226486370615*^9}],

Cell[BoxData[
 RowBox[{"-", "0.04929858785982323`"}]], "Output",
 CellChangeTimes->{3.683687830207733*^9, 3.6836886589507837`*^9, 
  3.68368982930072*^9, 3.683691579102182*^9, 3.6836919518261757`*^9, 
  3.683692264813012*^9, 3.683693122738616*^9, 3.683718995471677*^9, 
  3.6837209902317457`*^9, 3.6837250735082006`*^9, 3.683725950376416*^9, 
  3.683727734835531*^9, 3.683743194325391*^9, 3.683744941047852*^9, 
  3.6837528409656343`*^9, 3.6837765489292088`*^9, 3.703226310864407*^9, 
  3.703226486373184*^9}],

Cell[BoxData["0.10672279182412256`"], "Output",
 CellChangeTimes->{3.683687830207733*^9, 3.6836886589507837`*^9, 
  3.68368982930072*^9, 3.683691579102182*^9, 3.6836919518261757`*^9, 
  3.683692264813012*^9, 3.683693122738616*^9, 3.683718995471677*^9, 
  3.6837209902317457`*^9, 3.6837250735082006`*^9, 3.683725950376416*^9, 
  3.683727734835531*^9, 3.683743194325391*^9, 3.683744941047852*^9, 
  3.6837528409656343`*^9, 3.6837765489292088`*^9, 3.703226310864407*^9, 
  3.703226486375792*^9}],

Cell[BoxData[
 RowBox[{"-", "0.17175690243921946`"}]], "Output",
 CellChangeTimes->{3.683687830207733*^9, 3.6836886589507837`*^9, 
  3.68368982930072*^9, 3.683691579102182*^9, 3.6836919518261757`*^9, 
  3.683692264813012*^9, 3.683693122738616*^9, 3.683718995471677*^9, 
  3.6837209902317457`*^9, 3.6837250735082006`*^9, 3.683725950376416*^9, 
  3.683727734835531*^9, 3.683743194325391*^9, 3.683744941047852*^9, 
  3.6837528409656343`*^9, 3.6837765489292088`*^9, 3.703226310864407*^9, 
  3.703226486378438*^9}],

Cell[BoxData["0.21342117784149767`"], "Output",
 CellChangeTimes->{3.683687830207733*^9, 3.6836886589507837`*^9, 
  3.68368982930072*^9, 3.683691579102182*^9, 3.6836919518261757`*^9, 
  3.683692264813012*^9, 3.683693122738616*^9, 3.683718995471677*^9, 
  3.6837209902317457`*^9, 3.6837250735082006`*^9, 3.683725950376416*^9, 
  3.683727734835531*^9, 3.683743194325391*^9, 3.683744941047852*^9, 
  3.6837528409656343`*^9, 3.6837765489292088`*^9, 3.703226310864407*^9, 
  3.7032264863809958`*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
Evaluator->"Second",
WindowSize->{1637, 1225},
WindowMargins->{{434, Automatic}, {Automatic, 38}},
FrontEndVersion->"10.4 for Mac OS X x86 (32-bit, 64-bit Kernel) (February 25, \
2016)",
StyleDefinitions->FrontEnd`FileName[{"Report"}, "StandardReport.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 372, 6, 90, "Title"],
Cell[942, 30, 191, 2, 31, "Subtitle"],
Cell[1136, 34, 85, 2, 37, "Input"],
Cell[CellGroupData[{
Cell[1246, 40, 149, 2, 65, "Chapter"],
Cell[1398, 44, 209, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[1632, 52, 222, 3, 32, "Subsection"],
Cell[1857, 57, 12078, 287, 503, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[13972, 349, 213, 3, 32, "Subsection"],
Cell[14188, 354, 1634, 38, 62, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[15859, 397, 445, 6, 32, "Subsection"],
Cell[CellGroupData[{
Cell[16329, 407, 153, 2, 31, "Subsubsection"],
Cell[16485, 411, 110, 1, 30, "Text"],
Cell[16598, 414, 2665, 69, 89, "Input"],
Cell[19266, 485, 106, 1, 30, "Text"],
Cell[19375, 488, 7874, 202, 191, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[27286, 695, 203, 3, 31, "Subsubsection"],
Cell[27492, 700, 202, 3, 30, "Text"],
Cell[27697, 705, 14486, 380, 701, "Input"],
Cell[42186, 1087, 162, 3, 30, "Text"],
Cell[42351, 1092, 23228, 555, 1483, "Input"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[65628, 1653, 289, 4, 32, "Subsection"],
Cell[CellGroupData[{
Cell[65942, 1661, 101, 1, 31, "Subsubsection"],
Cell[66046, 1664, 3884, 95, 123, "Input"],
Cell[69933, 1761, 10671, 254, 310, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[80641, 2020, 103, 1, 31, "Subsubsection"],
Cell[80747, 2023, 20466, 499, 701, "Input"],
Cell[101216, 2524, 117, 1, 30, "Text"],
Cell[101336, 2527, 29910, 686, 1483, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[131307, 3220, 147, 2, 54, "Chapter"],
Cell[CellGroupData[{
Cell[131479, 3226, 211, 3, 66, "Section"],
Cell[131693, 3231, 123, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[131841, 3236, 173, 2, 32, "Subsection"],
Cell[132017, 3240, 90, 1, 30, "Text"],
Cell[132110, 3243, 2221, 55, 174, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[134368, 3303, 207, 3, 32, "Subsection"],
Cell[CellGroupData[{
Cell[134600, 3310, 99, 1, 31, "Subsubsection"],
Cell[134702, 3313, 108, 1, 30, "Text"],
Cell[134813, 3316, 502, 9, 37, "Input"],
Cell[CellGroupData[{
Cell[135340, 3329, 187, 3, 37, "Input"],
Cell[135530, 3334, 31855, 857, 238, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[167422, 4196, 3413, 94, 305, "Input"],
Cell[170838, 4292, 201, 3, 37, "Output"],
Cell[171042, 4297, 190, 2, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[171281, 4305, 103, 1, 31, "Subsubsection"],
Cell[CellGroupData[{
Cell[171409, 4310, 3776, 112, 192, "Input"],
Cell[175188, 4424, 157, 3, 70, "Output"],
Cell[175348, 4429, 228, 5, 70, "Output"],
Cell[175579, 4436, 1446, 42, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[177086, 4485, 125, 2, 32, "Subsection"],
Cell[177214, 4489, 323, 13, 30, "Text"],
Cell[CellGroupData[{
Cell[177562, 4506, 254, 3, 31, "Subsubsection"],
Cell[177819, 4511, 2657, 61, 165, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[180513, 4577, 157, 2, 31, "Subsubsection"],
Cell[180673, 4581, 125, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[180823, 4587, 1041, 21, 37, "Input"],
Cell[181867, 4610, 3115, 44, 37, "Output"]
}, Open  ]],
Cell[184997, 4657, 112, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[185134, 4663, 4216, 88, 72, "Input"],
Cell[189353, 4753, 4961, 92, 72, "Output"]
}, Open  ]],
Cell[194329, 4848, 165, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[194519, 4854, 4883, 104, 72, "Input"],
Cell[199405, 4960, 2549, 58, 72, "Output"]
}, Open  ]],
Cell[201969, 5021, 183, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[202177, 5027, 5130, 107, 78, "Input"],
Cell[207310, 5136, 4848, 91, 72, "Output"]
}, Open  ]],
Cell[212173, 5230, 211, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[212409, 5237, 5178, 108, 78, "Input"],
Cell[217590, 5347, 4842, 90, 72, "Output"]
}, Open  ]],
Cell[222447, 5440, 204, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[222676, 5447, 5101, 108, 72, "Input"],
Cell[227780, 5557, 4833, 91, 72, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[232662, 5654, 109, 1, 31, "Subsubsection"],
Cell[232774, 5657, 111, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[232910, 5663, 5542, 116, 72, "Input"],
Cell[238455, 5781, 7263, 124, 83, "Output"]
}, Open  ]],
Cell[245733, 5908, 159, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[245917, 5914, 7617, 152, 89, "Input"],
Cell[253537, 6068, 7215, 123, 83, "Output"]
}, Open  ]],
Cell[260767, 6194, 240, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[261032, 6201, 4239, 107, 95, "Input"],
Cell[265274, 6310, 7045, 121, 83, "Output"]
}, Open  ]],
Cell[272334, 6434, 244, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[272603, 6441, 4269, 108, 95, "Input"],
Cell[276875, 6551, 718, 13, 24, "Message"],
Cell[277596, 6566, 7020, 120, 72, "Output"]
}, Open  ]],
Cell[284631, 6689, 348, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[285004, 6698, 9026, 175, 89, "Input"],
Cell[294033, 6875, 8210, 137, 72, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[302304, 7019, 168, 2, 32, "Subsection"],
Cell[302475, 7023, 2746, 75, 225, "Input"],
Cell[305224, 7100, 7583, 180, 361, "Input"],
Cell[312810, 7282, 96, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[312931, 7287, 2105, 62, 174, "Input"],
Cell[315039, 7351, 89, 1, 37, "Output"],
Cell[315131, 7354, 88, 1, 37, "Output"],
Cell[315222, 7357, 90, 1, 37, "Output"],
Cell[315315, 7360, 90, 1, 37, "Output"],
Cell[315408, 7363, 106, 2, 37, "Output"],
Cell[315517, 7367, 89, 1, 37, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[315667, 7375, 93, 1, 52, "Section"],
Cell[CellGroupData[{
Cell[315785, 7380, 143, 2, 32, "Subsection"],
Cell[315931, 7384, 89, 1, 30, "Text"],
Cell[316023, 7387, 4757, 114, 361, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[320817, 7506, 299, 4, 32, "Subsection"],
Cell[CellGroupData[{
Cell[321141, 7514, 109, 1, 31, "Subsubsection"],
Cell[321253, 7517, 4210, 118, 344, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[325500, 7640, 126, 1, 31, "Subsubsection"],
Cell[CellGroupData[{
Cell[325651, 7645, 1684, 33, 55, "Input"],
Cell[327338, 7680, 5788, 81, 37, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[333175, 7767, 217, 3, 31, "Subsubsection"],
Cell[CellGroupData[{
Cell[333417, 7774, 3695, 108, 230, "Input"],
Cell[337115, 7884, 1172, 33, 305, "Output"]
}, Open  ]],
Cell[338302, 7920, 927, 22, 37, "Input"],
Cell[339232, 7944, 414, 7, 49, "Text"],
Cell[339649, 7953, 523, 13, 95, "Input"],
Cell[CellGroupData[{
Cell[340197, 7970, 934, 26, 37, "Input"],
Cell[341134, 7998, 1955, 49, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[343126, 8052, 19988, 408, 635, "Input"],
Cell[CellGroupData[{
Cell[363139, 8464, 5101, 73, 21, "Print"],
Cell[368243, 8539, 5101, 73, 21, "Print"],
Cell[373347, 8614, 5101, 73, 21, "Print"],
Cell[378451, 8689, 5103, 73, 21, "Print"],
Cell[383557, 8764, 5101, 73, 21, "Print"],
Cell[388661, 8839, 5099, 73, 21, "Print"],
Cell[393763, 8914, 5099, 73, 21, "Print"],
Cell[398865, 8989, 5099, 73, 21, "Print"],
Cell[403967, 9064, 5101, 73, 21, "Print"],
Cell[409071, 9139, 5103, 73, 21, "Print"],
Cell[414177, 9214, 5105, 73, 21, "Print"],
Cell[419285, 9289, 5103, 73, 21, "Print"],
Cell[424391, 9364, 5103, 73, 21, "Print"],
Cell[429497, 9439, 5103, 73, 21, "Print"],
Cell[434603, 9514, 5103, 73, 21, "Print"],
Cell[439709, 9589, 5103, 73, 21, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[444861, 9668, 130, 2, 37, "Input"],
Cell[444994, 9672, 4189, 75, 327, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[449232, 9753, 170, 2, 31, "Subsubsection"],
Cell[449405, 9757, 19066, 456, 1128, "Input"],
Cell[CellGroupData[{
Cell[468496, 10217, 2532, 78, 225, "Input"],
Cell[471031, 10297, 493, 7, 37, "Output"],
Cell[471527, 10306, 494, 7, 37, "Output"],
Cell[472024, 10315, 492, 7, 37, "Output"],
Cell[472519, 10324, 492, 7, 37, "Output"],
Cell[473014, 10333, 509, 8, 37, "Output"],
Cell[473526, 10343, 492, 7, 37, "Output"],
Cell[474021, 10352, 509, 8, 37, "Output"],
Cell[474533, 10362, 494, 7, 37, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)

